# -*- coding: utf-8 -*-

"""
Jokes from Yuri Nikulin's "Анекдоты от Никулина" joke collection
http://bookscafe.net/book/nikulin_yuriy-anekdoty_ot_nikulina-217228.html

Warning:
Any offensive jokes based on racism, chauvinism, sexism, ageism, or anything else do not reflect the developer's views.
Jokes may contain typos and other errors.
"""

soviet_jokes = [
    'Напротив одесского вокзала бездействует фонтан.\n— Скажите, — спрашивает приезжий у одессита, — этот фонтан когда-нибудь бил?\n— Что за вопрос?! Он бил, есть и будет бить!',
    '— Скажите, это правда, что в Одессе отвечают на вопрос вопросом?\n— А зачем Вам это надо знать?',
    '— Скажите, Вы случайно не сын старика Ковальского?\n— Да, сын, но что "случайно", я слышу впервые.',
    'В Одессе на рынке.\nПокупательница:\n— Почем Ваши синенькие?\nПродавец:\n— Дура, это цыплята!',
    '— Извините, — спрашивает молодая мать сидящую в женской консультации даму, — чем Вы кормите ребенка?\n— Как чем? Пока бюстом!',
    '— Папа, скажи, как правильно пишется: фликончик или флякончик?\n— Деточка, не фликончик и не флякончик, а пизурок.',
    '— Рабинович! У Вас на голове сидит муха!\n— Вы что, хотите сказать, что я — говно?\n— Я ничего не хочу сказать! Но муху не обманешь.',
    '— Роза! Ты ничего не заметила? У меня давно выпадают волосы. Это ужасно! Как мне их сохранить?\n— Не волнуйся! Это же пустяк. Складывай их в картонную коробочку.',
    '— Что нужно сделать в первую брачную ночь, чтобы не испачкать простыню?\n— Нужно вымыть ноги.',
    '— Чем отличается террорист от еврейской мамы?\n— С террористом можно договориться.',
    '— Товарищ техник — смотритель! Я Вам уже три раза писал — у меня в квартире потолок протекает!\n— Это потому, что идет дождь, неужели непонятно?!',
    'Американец угощает Рабиновича черной икрой.\n— Боже мой, как вы от нас отстали! — говорит Рабинович. — Это мы ели пятьдесят лет назад!',
    'В купе поезда.\nЕдут пожилой раввин и молодой человек. Ложась спать, попутчик спрашивает:\n— Сударь, Вы не скажете, который час?\nРаввин, не говоря ни слова, поворачивается к стенке и насыпает.\nУтром поезд подъезжает к Харькову. Оба пассажира проснулись и начали готовиться к выходу. Раввин посмотрел на свои часы и сказал попутчику:\n— Молодой человек. Вы вчера меня спрашивали, который час? Так вот — сейчас половина девятого.\n— Почему же вчера Вы промолчали, когда я спросил у Вас? — удивленно заметил молодой человек.\n— Видите ли, если бы вчера я Вам ответил, который час, Вы бы меня спросили, куда я еду. Я бы ответил, что в Харьков. Вы бы мне сказали, что тоже едете в Харьков и что Вам негде ночевать. Я, как добрый человек, пригласил бы Вас к себе домой. А у меня молодая дочь. Вы бы ночью, наверняка, ее соблазнили и она бы от Вас забеременела. Вам пришлось бы на ней жениться.\n— Ну и что же из этого?! — воскликнул молодой человек.\n— Так я вчера подумал: на хрена мне нужен зять без часов?',
    'В КГБ раздается телефонный звонок:\n— Алло! Это КГБ?\n— Да.\n— Вы знаете Рабиновича, который проживает по Дерибасовской, в доме пятнадцать?\n— Да.\n— А вы знаете, что у него во дворе есть сарай?\n— Да.\n— А вы знаете, что у него в сарае есть бревна?\n— Да.\n— А вы знаете, что в бревнах он прячет золото?\n— Спасибо.\nНа следующий день Рабиновичу звонит Хаймович:\n— Ну как дела?\n— Спасибо, дорогой! Не только распилили, но и раскололи.',
    '— Скажите, Миша дома?\n— Пока дома.\n— Почему пока?\n— Вынос тела через пятнадцать минут.',
    'В Одессе.\nЖена готовит на кухне, а муж колет во дворе дрова. Вдруг раздается пушечный выстрел. Жена высовывается в\nокошко:\n— Абрам, почему стреляла пушка? Что, мясо привезли?\n— Да нет, это начальство из Москвы приехало.\nЧерез несколько минут снова выстрел.\n— Абрам, что, мясо привезли?\n— Я же сказал, начальство из Москвы приехало.\n— А что, в первый раз не попали?',
    'На границе часовой.\n— Стой, кто идет?!\n— Ша. Уже никто никуда не идет.',
    'По улице еле-еле идет старый Рабинович. Ему кричат:\n— Рабинович, как Ваше здоровье?\n— Не дождетесь!',
    '— Изя! Ты слышал, что Левина жена родила четверых детей и всех назвала Мойшами.\n— А как же она будет их различать?\n— По отчеству.',
    'Умирает жена. Рядом муж.\n— Абрам, обещай, что выполнишь мое последнее желание.\n— Хорошо! А какое?\n— Я хочу, чтобы на моих похоронах ты шел рядом с моей мамой и держал ее под руку.\n— Но тогда я же не получу от похорон никакого удовольствия.',
    '— Что такое порядочная женщина, и что такое потаскуха?\n— Потаскуха — это одинокая женщина, которая потоскует, потоскует и ложится спать одна. А порядочная любит порядок: сегодня с одним, завтра с другим…',
    'В Одессе встречаются двое:\n— Ну как?\n— Восемь.\n— Что "восемь"?\n— А что "как"?',
    '— Скажите, правда, что у одесских проституток светятся глаза?\n— Ну что Вы? Тогда в Одессе все время были бы белые ночи.',
    'Идеальный муж по — одесски: слепой, глухонемой капитан дальнего плавания.',
    '— Рабинович, говорят, что Вы большой интриган?\n— Да, а кто это ценит?',
    '— Мойша! Почем у тебя гробы?\n— По 15.\n— А у Рабиновича по 20. Но там хоть есть где развернуться.',
    '— Вы не скажете, когда мне нужно сойти, чтобы попасть на Дерибасовскую улицу?\n— Следите за мной и выходите на одну остановку раньше.',
    '— Что, Боря умер?\n— Да, еще вчера.\n— То — то я вижу он в гробу лежит.',
    '— Вы слышали, завтра обещают 44 градуса в тени?\n— А кто Вас заставляет ходить в тени?',
    '— Бабушка, а кто такой Карл Маркс?\n— Деточка, Карл Маркс был экономистом.\n— Как наш дедушка Изя?\n— Нет. Дедушка Изя старший экономист.',
    'В одесском порту у самого причала всплывает русалка с маленьким ребенком на руках и обращается к толпе любопытных:\n— А где здесь живет водолаз Жора?',
    'Идет экскурсия туристов в раю и видит: сидит старая еврейка, вяжет носки. Они с почтением говорят ей:\n— Вы такая знаменитая! Вы самая великая женщина в истории! Вы родили такого сына! Вы понимаете, для нас Иисус Христос…\n— Да, да, но если бы вы знали, как мы с мужем хотели девочку.',
    'Наводнение. Все стараются перебраться на сухое место. Лишь один старый еврей сидит в кресле.\n— Скорее, сюда! — кричат ему с последнего грузовика.\n— Бог мне поможет, — спокойно отвечает старик и молится.\nА вода все выше и выше. Она уже заливает комнату. К дому подплывает последняя лодка. С нее кричат:\n— Прыгай сюда! Осталось еще одно место!\n— Бог мне поможет, — невозмутимо отвечает старик и перелезает на крышу.\nНо вода добралась и туда. Над домом зависает вертолет, с него сбрасывают веревочную лестницу.\n— Цепляйся, это последний шанс!\nНо старик по — прежнему твердит:\n— Бог мне поможет.\nТут налетела волна и смыла старика.\nВ раю старик встречает бога и укоризненно говорит:\n— Боже, я на тебя так рассчитывал! Что же ты меня бросил в беде?\n— Идиот! Кретин! А кто, спрашивается, посылал тебе грузовик, лодку и вертолет?!',
    'В Одесский оперный театр приходит певица.\n— Скажите, где тут у вас диван, на котором голоса проверяют?',
    'Телефонный звонок.\n— Общество "Память" слушает.\n— С вами говорит Рабинович. Скажите, пожалуйста, действительно евреи продали Россию?\n— Да, да, продали, еврейская морда! Что тебе еще нужно!\n— Я хотел бы узнать, где я могу получить свою долю?',
    'В Одессе нищий просит милостыню. Подходит Исаак, долго ищет в карманах, наконец достает один рубль, кидает его в шляпу и говорит:\n— Извини, Абрамчик, вчера я женился, теперь у меня жена и теща, так что я не могу давать тебе два рубля.\nАбрам вскакивает и кричит на всю улицу.\n— Евреи, идите скорей сюда! Посмотрите на этого потца! Вчера он женился, а сегодня я уже должен его семью кормить!',
    'В Бруклине на Брайтон-бич один оборотистый одессит открыл небольшой дешевый ресторанчик для только что приехавших эмигрантов. Первые посетители были поражены расторопным официантом — китайцем, который бойко изъяснялся на иврите. Хозяина спросили:\n— Откуда у вас китаец, говорящий на чистом иврите?\n— Это мы его научили, — сказал хозяин, — но только не говорите ему — он думает, что это английский.',
    'На рынке.\n— Сколько стоит эта лошадь?\n— Но это курица, мадам.\n— Я смотрю на цену.',
    'Спрашивают жениха:\n— Ну как? Видели невесту? Что скажете?\n— Мне в ней не понравились три вещи.\n— Какие же?\n— Ее подбородок.',
    '— Здесь проживают супруги Гольдберг?\n— Нет. Но на первом этаже живет господин Гольд, а на четвертом госпожа Берг.\n— Ага. Значит, они разошлись.',
    'В овощном магазине одесситка долго и придирчиво перебирает овощи. Продавец не выдерживает:\n— Уж скорей бы уезжала в свой Израиль!\n— Я — то уеду, а тебе придется угонять самолет.',
    'Китай завоевал Советский Союз. И вот… По бывшей улице Дерибасовской, а ныне по улице Мао Цзэ-дуна иду два китайца. Один говорит:\n— Слушай, Фима, я так устал щуриться.',
    'У одессита спросили:\n— Как Вы относитесь к Советской власти?\n— Как к жене.\n— То есть?\n— Немножко боюсь, немножко люблю, немножко браню, немножко хвалю, но хочу другую.',
    'Встречаются два одессита:\n— Рабинович! Почему Вы не уехали в Израиль?\n— А чего мне туда ехать? Мне и здесь плохо!',
    'В московском метро сидит негр и читает "еврейскую" газету. Рабинович, сидящий рядом, дружески спрашивает:\n— Послушайте! Мало Вам, что Вы негр?',
    '— Я хотел бы заказать места в круизе для себя и моей жены.\n— Пожалуйста! Будут какие — либо пожелания, может быть, отдельные кровати, отдельные каюты?\n— Отдельные теплоходы.',
    'Приезжий спрашивает у одессита:\n— Так где же ваша Дерибасовская?\n— Так Вам еще ехать на троллейбусе семь остановок! — отвечает одессит.\n— Что Вы говорите? — возмущается приезжий. — Я ехал на троллейбусе и мне сказали, что нужно выходить.\n— А Вы когда ехали, сидели или стояли?',
    'В Бердичеве на одной улице четыре портняжные мастерские. На первой надпись "Лучший портной в России", на второй "Лучший портной в Европе", на третьей "Лучший портной в мире", на четвертой "Лучший портной на этой улице".',
    '— Рабинович! Какая болезнь Вам больше всего нравится?\n— Чесотка: почесался и еще хочется.\n— А какая болезнь Вам больше всего не нравится?\n— Геморрой. Ни себе посмотреть, ни людям показать.',
    'Гольдберг попал под трамвай. Друга семьи просят сообщить о случившемся поделикатней. Друг звонит в дверь:\n— Здесь живет вдова Гольдберг?\n— На тебе дулю — он ушел на работу.\n— На тебе две дули! Ребята — заноси!',
    'Ксендз говорит раввину:\n— Вот Вы простой раввин, и умрете раввином. А я надеюсь со временем стать епископом.\n— Допустим. Что дальше?\n— А епископ может стать кардиналом.\n— Допустим. А дальше?\n— Ну… кардинал может стать папой.\n— Допустим. А дальше?\n— Но… не может же папа стать Господом Богом?\n— Отчего же. Одному еврейскому мальчику это уже однажды удалось.',
    'Рабинович уехал в Штаты. Через месяц звонит родным из Нью-Йорка:\n— Все отлично. Устроился на работу и очень близко, каких-нибудь полчаса езды.\n— На метро?\n— Нет. На лифте.',
    'Приходит Рабинович к раввину:\n— Хочу жениться, ребе.\n— Ну так женись.\n— Так ведь на Риве.\n— Ну и что?\n— Она же слепая.\n— Так и хорошо. Ты придешь пьяный, она и не заметит.\n— Это верно…, но ведь она еще и глухая.\n— Ты просто не понимаешь своего счастья. Ругайся, сколько хочешь, она и не услышит.\n— Тоже верно. Но она к тому же немая.\n— Что может быть лучше молчаливой жены.\n— Ребе, но Риве еще и горбатая.\n— Но ты, Мойша, нахал! Ты хочешь, чтобы совсем без недостатков!',
    'Моисей сказал — все от Бога.\nСоломон — все от головы.\nХристос — все от сердца.\nМаркс — все от живота.\nФрейд — все от секса.\nЭйнштейн сказал, что все относительно.\nСколько евреев — столько и мнений.',
    'Богатый турист из Техаса приехал в Австралию и впервые увидел кенгуру.\n— Что правда, то правда, — признал он, — ваши кузнечики крупнее наших.',
    'Секретарь, держа в руке телефонную трубку:\n— Сэр, я думаю — это Вас…\n— Почему Вы так думаете?\n— Сэр, по телефону сказали: "Привет, это ты, старый идиот?"',
    'Жена:\n— Дай мне долларов 10. Я хочу купить бюстгальтер.\nМуж:\n— Зачем? Тебе же туда нечего положить.\nЖена:\n— Но ты же носишь трусы.',
    'Ковбой приехал в город. Нашел девушку и приехал к ней домой.\n— Милый, — спросила она, а что ты будешь делать, если раздастся стук в дверь?\n— Как что? Распахну окно, выпрыгну и попаду точно на свою лошадь, которую привязал точно под окном.\n— Да что ты! Здесь несколько этажей!\n— Не волнуйся, я никогда не промахнусь мимо седла.\nЗанимаются любовью и тут раздается стук в дверь.\nКовбой вскакивает, распахивает окно и со свистом выпрыгивает. Девушка открывает дверь. На пороге стоит мокрая лошадь.\n— Передайте моему хозяину, что на улице дождь и я жду его в подъезде.',
    'Экспресс Южный — Тихоокеанский несется вдоль границы одного из крупных в Техасе ранчо. Один из пассажиров пристально всматривается в огромное стадо, пасущееся вдоль дороги. Когда, наконец, поезд миновал территорию ранчо, он повернулся к соседу и заметил:\n— Порядочное стадо. 11 тысяч 429 голов.\nСосед изумленно уставился на него:\n— Просто непостижимо, я владелец этого ранчо, и цифра, названная Вами, совершенно точная. Но как Вы умудрились сосчитать их, когда поезд мчится со скоростью 60 миль в час?!\n— О, это довольно просто, если знать систему. Я считаю ноги, а потом делю на четыре.',
    'В ресторане посетитель спрашивает официанта:\n— Скажите, пожалуйста, у Вас есть в меню дикая утка?\n— Нет, сэр, но для Вас мы можем разозлить домашнюю.',
    'Жан в гостях у своего друга Франсуа, недавно женившегося на дочери одного миллионера. Жан шепчет другу:\n— Как же ты на ней женился? Она хромая, кривая, а еще и заикается?\n— Можешь говорить громко, она еще и глухая.',
    'Жена:\n— На что ты выбросил 1000 песет?\n— Ты же знаешь, любимая, деньги, как вода. Туда-сюда — две сотни. Хотел купить тебе цветов за 800 — вот тебе и тысяча.',
    'Под колеса машины попала курица. Водитель вылез, оглянулся и, никого не заметив, бросил курицу в багажник. Вдруг из кустов выбирается дюжий фермер:\n— Только не надо мне рассказывать, что ты хотел срочно доставить пострадавшую в больницу!',
    'Умер человек и жена стала над ним причитать:\n— Огурцы он у меня любил, огурцы! Огурцы любил, да лопнут мои бока, огурцы. Ах, огурцы он любил, что делать? Ах, огурцы, огурцы!..\nЛюдям надоело слушать про огурцы. Тогда священник подошел к вдове и попросил ее:\n— Добрая женщина! Перестань толковать про огурцы. Неудобно про огурцы.\n— А что мне еще сказать, священник? Что мне делать, о священник, о священник. О священник, о священник!\nСвященник:\n— Да простит тебя Бог. Пусть лучше будут огурцы.',
    'В ресторане джентльмен заказывает одну порцию виски, потом другую, третью. Когда он подозвал официанта и попросил заплетающимся языком принести четвертую порцию, официант возразил:\n— Простите, сэр, но, по-моему, Вам уже достаточно.\n— Нет, я все прекрасно соображаю и вижу. Что Вы видите?\n— Я вижу, как в открытую дверь входит кошка и у нее два глаза.\n— Сэр, эта кошка выходит.',
    'Человек едет на машине и вдруг его обгоняет курица. Он прибавляет газ, но догнать ее не может. При скорости 100 км в час курица резко свернула на ферму. Человек остановил машину и спрашивает у фермера:\n— Что это у Вас за куры такие?\n— А это новая порода — мясная. Только что вывели.\n— Ну и как, вкусные?\n— А хрен их знает. Догнать никто не может.',
    'Лорд спрашивает дворецкого:\n— Джеймс, что за шум на улице?\n— Демонстрация проституток, сэр.\n— А что они требуют?\n— Чтобы им больше платили, сэр.\n— А что, им действительно мало платят?\n— Да нет, сэр.\n— Почему же тогда они недовольны?\n— Бляди, сэр!',
    'Жена:\n— Нужно, наконец, уволить нашего шофера. Сегодня он третий раз чуть не убил меня.\nМуж:\n— Он отличный парень. Давай дадим ему еще один шанс.',
    'Прокладывая трассу железной дороги, инженер зашел в крестьянский дом.\n— Железнодорожное полотно будет проходить как раз через Ваш дом.\n— Не имею ничего против. Но Вы сильно ошибаетесь, если думаете, что каждый раз, когда будет проходить поезд я стану открывать и закрывать дверь.',
    'Один француз ел устрицы и подавился одной, в которой оказалась большая жемчужина.\nНо французу повезло. Жемчужина позволила оплатить врачебную помощь, а также все расходы на похороны.',
    '— Как поживает Ваша лихая бабушка? Она и поныне спускается верхом по перилам лестницы?\n— Да, но теперь это сложнее. Я велел натянуть колючую проволоку по всей длине перил…\n— И это бабушку остановило?\n— Нет, но замедлило скольжение.',
    '— Боюсь, мистер Смит, что с этого дня Вы должны бросить пить, курить, встречаться с женщинами.\n— Но, я ведь мужчина, доктор!\n— Можете продолжать бриться.',
    'Директор цирка звонит в полицию:\n— У нас сбежал слон.\n— Особые приметы? — спрашивает дежурный.',
    'Тренер утешает проигравшего боксера:\n— Но в третьем раунде ты своего противника здорово попугал.\n— Чем это?\n— Ему показалось, что он тебя убил.',
    'Хозяин предупреждает гостей:\n— Ради бога, джентльмены! Только не садитесь на этот лиман — он кишит клопами.\n— Почему Вы не выкинете его?\n— Пробовал, они его назад приносят.',
    'На повороте одну машину бьет сзади другая. Из первой выскакивает водитель — женщина и кидается к задней машине:\n— Вы что, не видели, что за рулем дама?\n— Видел.\n— Так почему же Вы так по — хамски себя ведете? Я же мигала Вам правым подфарником и повернула направо!\n— Вот это-то меня и смутило.',
    'Идут люди по шоссе и видят: из болота вылезает человек, весь в тине, в грязи, и направляется по дороге в город. Все бросаются к нему, спрашивают, что с ним? Как попал в болото?\n— О, как мне надоели все эти вопросы! Неужели вам непонятно, что я здесь живу?!',
    '— Почему Вам так везет в карты, а на скачках Вы никогда не выигрываете?\n— А Вы когда-нибудь пробовали засунуть лошадь в рукав?',
    'Пожилой состоятельный мужчина женился на молоденькой девушке. Молодость жены его очень волнует.\n— Не знаю, как мы будем жить, — жалуется он своему приятелю, — все-таки мне семьдесят, а ей восемнадцать. Что мне делать?\n— А Вы наймите молодого секретаря, — говорит ему друг.\nВстречаются через год.\n— Как Ваша жена? — интересуется приятель.\n— Спасибо, она беременна.\n— Да? Поздравляю! А как секретарь себя чувствует?\n— Спасибо, хорошо. Она тоже беременна.',
    'Две дамы беседуют о замужестве.\n— Мне кажется, — говорит одна, — что замужество напоминает мираж в пустыне с дворцами, пальмами, верблюдами. Потом исчезает дворец, за ним пальмы и, наконец, остаешься с одним верблюдом.',
    'Кадровик пришедшему наниматься на работу:\n— Вы что — то выглядите недостаточно подвижным для своего возраста.\n— А вам кто нужен — бухгалтер или обезьяна?',
    'В Швеции проходят международные соревнования лесорубов. По сигналу бросились с длинными топорами рослые лесорубы и среди них маленький человечек с небольшим топориком.\nШвед повалил за час 14 деревьев. Финн — 18. А маленький человечек свалил 25.\nПобедителя обступают репортеры:\n— Где Вы научились так ловко рубить деревья?\n— В пустыне Сахаре.\n— Там же нет ни одного дерева?!\n— Да, теперь нет.',
    'Перед смертью адвокат Кин Рой сказал жене:\n— Схорони меня поскромнее, на памятник не траться.\nПосле похорон на его могилу вдова положила табличку двери его служебного кабинета:\n"Адвокат Кип Рой — принимает ежедневно с 10 до 15 часов".',
    'В магазине женщина выбирает метлу. Перебрала все, по было, потом заставила продавца принести партию со склада, потом снова перебрала все сначала и так два часа.\nПродавец взмок.\nНаконец, она выбрала метлу:\n— Вот эту.\n— Мадам, Вам завернуть или так полетите?',
    'В Швеции проходит конкурс на самую красивую лошадь.\nПобедила лошадь англичанина. Владелец, верхом на ней, должен получить приз из рук короля. И когда он подъехал к трибуне, вдруг лошадь на всю площадь издала непристойный звук. Все замерли.\nАнгличанин покраснел до корней волос и срывающимся голосом произнес:\n— Простите, Ваше величество!\n— Вы знаете, — сказал король, — если бы Вы не извинились, я бы мог подумать, что это сделала лошадь.',
    'В публичный дом приходит клиент и видит: кругом одни русалки.\n— Я бы хотел женщину с ногами, — говорит он.\n— У нас сегодня рыбный день.',
    'Проститутка сдает деньги в парижский банк.\n— Мадам, — говорит ей служащий, — пардон, но эти деньги фальшивые.\n— Боже мой! — кричит она. — Выходит, меня изнасиловали!',
    'Капитан корабля кричит:\n— Кто там внизу?\n— Билл, сэр!\n— А что Вы там делаете?\n— Ничего, сэр.\n— А Том с Вами?\n— Да, сэр.\n— Что он делает?\n— Он помогает мне, сэр.',
    'Два рыбака провели целый день на берегу реки. Под вечер один из них говорит со вздохом:\n— Есть одна вещь, в которую я никогда не поверю.\n— Какая?\n— Как будто есть целые народы, которые живут одним рыболовством.',
    'Встречаются два индейца.\n— Чем это тебе так раскроили череп?\n— Трубкой мира.',
    'По улице Нью-Йорка мчится машина. Шофер одной рукой держится за руль, а другой обнимает девицу. Ему кричит знакомый полицейский:\n— Джим, что ты делаешь? Одной рукой?\n— А как я буду править?',
    'К балетмейстеру приходит человек и предлагает:\n— Я за двести долларов буду делать массаж всем Вашим балеринам.\n— О`кей, деньги при Вас?',
    'Вопрос французскому радио:\n— Какие сейчас груди в моде?\nПришел ответ:\n— Маленькие.\n— А что делать тем, у кого большие?\n— Донашивать.',
    '— Я хотел бы иметь твою внешность и капитал Рокфеллера.\n— Ах, я и не знал, что ты умеешь так льстить.\n— Видишь ли, если бы я имел капитал Рокфеллера, мне было бы наплевать на свою внешность.',
    'Богатый человек в Монте-Карло спустил в рулетку все свои состояние. Он вышел из казино и печальный пошел по дороге. И вдруг внутренний голос говорит ему:\n— Еще не все потеряно, не все… У тебя осталось на руке кольцо твоей покойной матери. Вернись назад и играй снова.\nЧеловек вернулся, вошел в зал и внутренний голос сказал ему:\n— Поставь на черное. Человек снял кольцо и поставил на черное. Завертелась рулетка. Выпало красное. И внутренний голос сказал:\n— Боже, как я ошибся!',
    'В одном английском колледже среди учащихся был объявлен конкурс на самый короткий рассказ. Тема любая, но есть четыре обязательных условия.\nВ сочинении должны быть упомянуты:\n1. Королева;\n2. Бог;\n3. Чтобы было немного секса;\n4. Чтобы присутствовала тайна.\nПервую премию получил студент, который, выполнив все условия, уместил весь рассказ в одной фразе:\n"О боже! — воскликнула королева. — Я беременна и неизвестно от кого!"',
    '— Скажите сударь, рассудок Вашего дяди был ясен до последнего момента?\nНаследник:\n— Не знаю, завещание будет оглашено завтра.',
    'Человек решил сделать бизнес. Поехал в пустыню Сахару торговать газированной водой на льду. Через полгода вернулся без копейки денег. Его спрашивают, почему он прогорел?\n— Никто не подходил покупать, думали — мираж.',
    'Пикассо приехал в Лондон. На вокзале у него украли часы. Инспектор полиции спросил:\n— Вы кого — нибудь подозреваете в краже?\n— Да, я помню одного человека, который помогал мне выйти из вагона.\n— Вы художник, нарисуйте его портрет.\nИ к вечеру по рисунку Пикассо оперативная лондонская полиция задержала по подозрению в краже: трех стариков, двух старух, два троллейбуса и четыре стиральные машины.',
    'Умер местный донжуан. В отместку за его грехи жена похоронила его голым. Но женщины, которых он любил, и благодарность купили ему костюм и тайком откопали гроб, чтобы его одеть. Смотрят, а в гробу пусто, лишь записка лежит: "Дорогие мои блядуньки, я через три могилы у молочницы Груни".',
    'Лорд справляет свадьбу. После свадьбы гости холостяки идут в публичный дом и застают там лорда. Они потрясены.\n— Сэр, почему Вы здесь? Ведь у Вас молодая красавиц, жена.\n— Крошка так устала, что сразу же уснула. Стоило ли будить ее из-за каких-то нескольких фунтов?',
    'Рефери считает:\n— Один, два, три…\n— Слушай, — шепчет секундант лежащему боксеру, — до восьми не вставай.\n— Хорошо, — отвечает тот. — А который час?',
    'Семейная идиллия.\nМуж читает газету. Жена вяжет. У ее ног лежит пес. В камине пылает огонь. Жена говорит мужу:\n— Умоляю тебя! Не говори "да, дорогая", всякий раз, когда пес зарычит во сне.',
    'Капитан тонущего корабля спрашивает у пассажиров:\n— Кто из вас знает все молитвы?\n— Я, — отвечает один.\n— Ну и чудесно, а то у нас не хватает одного спасательного круга.',
    '— У меня был прекрасный почтовый голубь.\n— И что же с ним случилось?\n— Погиб при исполнении служебных обязанностей.\n— Как?\n— Его пришибли на почте, когда ставили печать.',
    'Смит сидел за завтраком и просматривал газету. Вдруг остолбенел: в газете было напечатано объявление о его смерти. Он сейчас же позвонил своему другу.\n— Алло, Джон! Ты читал объявление о моей смерти?\n— Да, — ответил Джон, — кстати, откуда ты говоришь?',
    'Звонит телефон. Трубку поднимает отец трех дочерей. Не успел он открыть рот, как голос в трубке ласково спросил:\n— Это ты моя лягушечка?\n— Нет, — говорит отец, — это говорит владелец пруда.',
    'На тонущем корабле один из пассажиров спрашивает капитана:\n— Далеко ли отсюда до земли?\n— Одна миля, — мрачно отвечает капитан.\n— А в каком направлении?\n— По вертикали.',
    '— Хотел бы я иметь столько денег, чтобы мог купить слона.\n— Зачем тебе слон?\n— Слон мне не нужен. Мне нужно столько денег.',
    'Один фермер звонит соседу, такому же фермеру:\n— Джексон, скажите, Ваша лошадь курит?\n— Вы что, с ума сошли? Конечно, нет!\n— Тогда, значит, Ваша конюшня горит.',
    'В Америке провели статистику, по каким причинам мужчины ночью встают с постели:\n1. Пять процентов — чтобы сходить в туалет;\n2. Двадцать процентов — чтобы идти на работу;\n3. И семьдесят процентов — чтобы одеться и идти домой.',
    'Лорд спрашивает слугу:\n— Скажите, Джеймс, каких лошадей Вы предпочитаете?\n— Видите ли, сэр, когда я еду на вороной, мне почему-то хочется скакать на серой, а когда на серой, то думаю о вороной.\n— А каких женщин Вы предпочитаете, Джеймс? Блондинок или брюнеток?\n— Видите ли, сэр…\n— Не надо, Джеймс, я понял.',
    'Машинист парижского экспресса видит издали лежащую на рельсах парочку. Дает гудок. Никакого внимания. Снова гудит и с трудом тормозит состав. Соскочив с паровоза, подлетает к парочке со страшными ругательствами. Молодой человек поднимается и говорит:\n— Месье, один из нас должен был остановиться. Яне мог.',
    'В Голливуде один режиссер для сцены сражения при — гласил десятитысячную массовку.\n— Вы разорите меня! — стал кричать на него продюсер.\n— Не беспокойтесь. Я приказал во время съемок стрелять настоящими снарядами.',
    'Однажды знаменитый киноактер Адольф Менжу заказал у лучшего нью-йоркского портного брюки. Только через месяц, после нескольких примерок, портной выполнил заказ. Забирая брюки, Менжу с раздражением сказал:\n— Богу понадобилось семь дней, чтобы сотворить мир, а Вы мне тридцать дней шили брюки.\nНа это портной ответил:\n— Посмотрите на этот мир и посмотрите на эти брюки!',
    '— Три желания француженки:\nРюмку коньяка До и сигарету После.',
    'В Англии искали компанию, которая взялась бы за прокладку тоннеля под Ла-Маншем. В парламент пришел человек с лопатой и сказал:\n— Я пришел насчет тоннеля.\nЕго спрашивают:\n— Вы представитель какой компании?\n— Буду копать в компании с братом. Он будет копать из Франции, а я из Англии и под Ла-Маншем мы с ним встретимся.\n— Ну, а если не встретитесь?\n— Тогда будет два тоннеля.',
    'Девушка приехала в автосервис. Механик осмотрел машину.\n— Ну что, — спрашивает она, — поломка серьезная?\n— Если бы это была лошадь, — ответил механик, — я бы ее на Вашем месте просто пристрелил бы.',
    'Шотландец проиграл за вечер сто фунтов стерлингов и жалобно обращается к своим партнерам по покеру:\n— Ребята, помогите, умоляю вас! Если жена узнает, что я продул сто фунтов, она голову мне отвернет.\nНа глазах его появились слезы.\n— Заклинаю вас! Верните мне эти деньги, иначе мне не жить!\nПартнеры повздыхали, поворчали, но, сжалившись над беднягой, вернули ему деньги.\n— Ребята, — продолжал неудачник — дайте мне еще пятьдесят фунтов, чтобы она подумала, что я выиграл.',
    'Дне старые девы сидят во дворе на скамейке и, поджав скорбно губы, наблюдают за петухом, который гоняется за одной из кур и никак не может догнать. Два раза обежав округ дома, курица выбегает на улицу и попадает под колеса грузовика.\n— Она предпочла смерть, — произносит одна из дев с пафосом.',
    'Миссис Бертон говорит мужу.\n— Хочу сделать имплантацию груди.\n— Но это слишком дорого, — возражает муж. — Возьми лучше туалетную бумагу и три между сиськами.\n— И что, они станут больше?\n— Во всяком случае на твоей заднице это отразилось.',
    'Клиентка приходит в магазин и жалуется:\n— Вчера купила одеяло, которое по вашим словам изготовлено из чистой шерсти, а дома обнаружила на нем этикетку — 100 % хлопка.\n— Это верно, мадам, эта этикетка пришита специально, чтобы ввести в заблуждение моль.',
    'Один знаменитый путешественник, отправляясь в Антарктиду, включил в состав экспедиции самую уродливую женщину, какую смог найти. Он объяснил это так:\n— Когда она покажется мне хорошенькой, я пойму, что пора возвращаться на родину.',
    'Посреди океана встретились два человека, потерпевших крушение. Каждый плыл на своей лодке.\n— Добрый день, — сказал один. — Ваш корабль утонул?\n— Да, год тому назад.\n— Что Вы говорите? И Вы провели все время в море?\n— Да, а что?\n— Как Вы могли так долго выдержать?\n— Сам удивляюсь. Особенно скучно по воскресеньям.',
    'Господин Хуго встал с кровати, посмотрел через окно на улицу и сказал своей жене:\n— По всему похоже, что будет прекрасный день.\n— Ну и что из этого? — спросила супруга.\n— Ты как — то говорила, что в один прекрасный день уйдешь от меня.',
    'Дама в зоопарке, восхищаясь страусом, обращается к служителю:\n— Скажите, пожалуйста, они когда-нибудь теряют перья?\n— Обычно нет, мадам, но могут уронить, если увидят десять долларов.',
    'Гость рассматривает фотоальбом. Хозяин поясняет:\n— Это тонет корабль, это крушение поезда, это пожар в отеле, это ураган, а это моя свадьба.',
    'На диком западе ковбой заехал в бар выпить стакан виски. Оглядевшись, он заметил пианино, а над ним плакат:\n"Не стреляйте в пианиста, он играет как умеет".\nМесто возле инструмента пустовало и ковбой спросил у официанта:\n— А где пианист?\n— Пианист? — с печальным вздохом ответил официант. — К нам приезжал один ковбой, который не умел читать.',
    'В семье французов дочка выходит замуж. Перед первой брачной ночью мать говорит новобрачной:\n— Если ты дашь мужу перед сном съесть десять устриц, то у тебя будет незабываемая ночь.\nДочь сделала, как сказала мать. Утром выходит из спальни грустная. Мать спрашивает ее:\n— Ну, как?\n— Сработало только четыре устрицы.',
    'Пожилой ковбой приводит к врачу молодого.\n— Доктор, помогите моему зятю. Я вчера прострелил ему ногу.\n— Что ж это за дело — стрелять в собственного зятя?\n— Когда я в него стрелял, он еще не хотел быть моим зятем.',
    'Охотник рассказывает в гостях:\n— Самый опасный зверь — гризли. От этого медведя нет спасения. Если вы бежите, он побежит еще быстрее. Если вы броситесь в воду, он тоже поплывет.\n— А если спрятаться? — спросил кто — то из гостей.\n— Он тоже спрячется.',
    'ИЗ АНГЛИЙСКОГО ЮМОРА\nЛорд звонит ночью из клуба домой:\n— Джеймс?\n— Слушаю, сэр.\n— Как у нас дома?\n— Все в порядке, сэр.\n— А что делает моя жена?\n— Сэр, она в своей комнате лежит в постели с каким — мужчиной.\n— Джеймс, возьмите из ящика моего стола пистолет и убейте его. Я отвечаю.\n— Слушаюсь, сэр, я не кладу трубку.\nЛорд слышит шаги дворецкого, скрип двери, крики, топот ног, выстрел, а затем голос слуги:\n— Сэр, я выполнил Вашу просьбу. Он пытался бежать через зимний сад, но я догнал его и застрелил.\n— Джеймс, но ведь у нас в доме нет зимнего сада!\n— Простите, сэр, какой номер телефона Вы набирали?',
    '— Ваша милость, — обращается лакей к своему господину, — пришел портной и говорит, что не уйдет отсюда до тех пор, пока не получит денег за два костюма, которые он Вам сшил.\n— Хорошо, Джон, — спокойно отвечает лорд — приготовьте для портного комнату.',
    'Американец поехал на отдых во Флориду. Через некоторое время он внезапно заболел и умер. Тело его отправили в Нью-Йорк. На похоронах, во время прощания с покойным, один из приятелей обращается к вдове:\n— Как он хорошо выглядит!\n— Еще бы! Две недели во Флориде пошли ему на пользу.',
    'Индеец приходит в мэрию и говорит:\n— Я хотел бы сменить свое имя.\n— Пожалуйста, как Вас зовут сейчас?\n— В переводе это звучит так: "Большой Паровоз, Который Мчится По Лесу И Гудит".\n— А какое имя Вы хотели бы получить?\n— "У — у — у — у — у"!',
    'Маленький индеец спрашивает у матери:\n— Почему мою сестру зовут Восходящее Солнце?\n— Потому что она была зачата при восходе солнца.\n— А почему младшую зовут Синий Цветок?\n— Она была зачата в васильках, и хватит приставать ко мне, Рваная Резинка.',
    'Парочка занимается любовью в машине. В стекло стучит полицейский.\n— Что вы здесь делаете? Парень опускает стекло.\n— Трахаю свою подружку.\n— Хорошо. — говорит полицейский, — следующая очередь моя.\nПарень:\n— А это мне нравится, я еще никогда не трахал полицейских.',
    '— Алло! Страховая компания? У моего мужа была страховка на случай пожара. Недавно он умер. Когда я могу получить страховую сумму?\n— Причиной смерти Вашего мужа был пожар?\n— Нет. Он умер от гриппа, но я его кремировала.',
    'В полицию приходит человек.\n— Я пришел сдаться властям.\n— А что Вы сделали?\n— Я ударил мою жену.\n— И убили ее?\n— Что Вы! На ней нет даже царапины.\n— Ну это пустяки — можете идти.\n— Ни за что. Она стоит за этой дверью.',
    'Шут пошел в королевские апартаменты и увидел, что король умывается, низко склонившись над тазом. Шут разбежался и дал сильного пинка его величеству под зад. Рассвирепев, король приказал тут же казнить наглеца. Немного поостыв, он сказал, что виновник может попробовать вымолить прощение извинением еще более дерзким, чем нанесенное ему оскорбление. Шут на минуту задумался:\n— Ваше величество, — сказал он смиренно, — поймите, я не думал Вас оскорблять. Просто я подумал, что это умывается королева.',
    'Два ковбоя на конях спасаются от индейцев. Въезжая в лес, оба подпрыгивают и хватаются руками за сук дерева. Индейцы с шумом проскакивают под ними.\n— Джон! — говорит один ковбой. — Тебе не трудно висеть?\n— Да нет, легко…\n— А вот мне тяжело.\nВторой смотрит вниз и говорит:\n— Дружище, да ты забыл вынуть ноги из стремян!',
    'У входа в храм в Гетсборге пастор вывел надпись: "Если ты изнурен грешной жизнью — отвори и войди". Чуть пониже губной помадой написано: "А если не изнурен звони по телефону 16–07–66".',
    '— Ну как, Хансон? Ты доволен своей новой собакой?\n— Очень! Каждое утро она приносит мне свежую газету.\n— Подумаешь! Так делают многие собаки.\n— Возможно! Но у меня другая ситуация. Я вообще на подписываюсь на газеты.',
    '— Представьте себе — Вы идете по улице и вдруг начинают стрелять. Что Вы будете делать?\n— А что я должна делать?\n— Как! Вам не объясняли? Надо сразу лечь.\n— Господи! Неужели в наше время, чтобы заставить женщину лечь — надо обязательно стрелять?',
    '— Кельнер! Суп очень горячий.\n— Подождите немного и он остынет.\n— У меня нет времени ждать.\n— Тогда подуйте на него.\n— Если бы я собирался дуть, то заказал бы тромбон, а не суп.',
    '— Андреа, сегодня Жак будет просить руки нашей дочери.\n— А что я должен делать?\n— Молчать и кивать головой. И ни в коем случае не целовать ему руки и не говорить: "Спаситель наш!"',
    'Когда Оле спросили, может ли он вспомнить 5 лучших лет своей жизни, он ответил:\n— Конечно! Это когда я учился в 1-м классе.',
    '— Я хочу развестись с моим мужем, — говорит дама своему адвокату. — За четыре года он произнес не более четырех слов.\n— Так, так, мадам. У вас есть дети?\n— Да, четверо.',
    'Норвежцы как — то затеяли играть в футбол со шведами. Ровно в 6 капитан шведов посмотрел на часы, свистнул в свисток и сказал:\n— Рабочий день окончен.\nИ вся его команда отправилась в раздевалку.\nА Норвежцы остались в поле и только в конце дополнительного тайма смогли забить победный гол.',
    'Зав кадрами:\n— Прежде чем принять Вас на работу в нашу фирму, я хотел бы узнать — не склонны ли Вы врать, ловчить, воровать, опаздывать?\nНорвежец:\n— Нет, но если это нужно Вашей фирме, то могу научиться.',
    'В мясном магазине позади прилавка висит огромное зеркало.\n— Зачем Вы повесили зеркало? — спрашивает покупатель директора.\n— Чтобы покупательницы не смотрели на весы.',
    '— Жемчуг, который я буду носить в первом акте, должен быть настоящим, — требует капризная актриса.\n— Все будет настоящим, дорогая! — говорит директор театра. — Все будет настоящим — и жемчуг в первом действии, и яд в последнем.',
    '85-летняя вдова отправилась на свидание со своим сверстником, с которым познакомилась по брачному объявлению. Домой она явилась явно огорченная.\n— Мне пришлось три раза ударить его по щеке, — поделилась она с дочерью.\n— Мама! Он что, приставал?\n— Да нет. Я просто думала, что он умер.',
    'Служащий пришел на работу с большим опозданием и в оправдание объяснил шефу:\n— Ночью у жены были тяжелые роды.\nЧерез три недели тот же служащий снова опоздал на работу.\n— А теперь Вы почему опоздали? — строго спросил директор.\n— Понимаете, у моей жены снова ночью были тяжелые роды.\n— Что, Ваша жена крольчиха?\n— Нет. Акушерка.',
    'Изобретатель пришел в фирму:\n— Хочу предложить Вашей фирме свое последнее изобретение — автомат для бритья. Клиент опускает монетку, просовывает голову в отверстие и две бритвы автоматически начинают его брить.\n— Это хорошо… Но… Ведь у каждого клиента сугубо индивидуальное строение лица?\n— До первого бритья — да.',
    'Старый лорд подходит утром к окну гостиной, долго смотрит на окутывающий Лондон тяжелый серый туман, а затем говорит своему дворецкому:\n— Сегодня смог, Джон.\n— Поздравляю, сэр.',
    'Владелец собаки — ветеринару:\n— Мой пес повадился бегать за машинами — малолитражками и лает, как сумасшедший. Вы можете вылечить его?\n— От чего? Все псы бегают за автомашинами.\n— Да. Но мой хватает их и закапывает на огороде.',
    'Клерк входит в кабинет начальника и выливает чернила ему па лысину. Потом начинает плясать на его столе. Но тут в комнату заглядывает другой клерк и громким шепотом говорит:\n— Смит, прекрати. Ты не получил миллион наследства — мы пошутили.',
    'Идет негр по берегу моря: жарко, губы рассохлись. Спустился к морю. Вдруг увидел в воде возле самого берега золотую рыбку. Схватил ее, а рыбка и говорит:\n— Отпусти меня, я исполню три твоих желания!\nНегр подумал:\n— Ну хорошо. Во — первых. Хочу стать белым. Во — вторых. Хочу, чтобы на коленях у меня сидели женщины. В — третьих, чтобы у меня всегда было много воды.\nИ он стал унитазом в женском туалете.',
    '— Я категорически настаиваю на разводе! — заявил судье отчаявшийся истец. — Она продолжает держать в спальне ручную козу, и я просто не в силах выносить этот запах!\n— Вам можно посочувствовать, — покачивая головой ответил судья. — Но нельзя ли было открыть окно?\n— Но тогда все мои голуби разлетятся!',
    'По берегу Темзы идет мужчина с фотоаппаратом. К нему подбегает женщина:\n— Идите скорее! Моя подруга тонет!\n— Увы, мисс. У меня уже кончилась пленка.',
    '— Вам вышибалы нужны? — обращается здоровенный детина к бармену.\n— Нужны, но я не знаю Вашу квалификацию.\n— Сейчас я Вам ее продемонстрирую.\nДетина подходит к одному из столиков, берет за шиворот первого попавшегося верзилу и выбрасывает в окно.\n— Ну как?\n— Минуточку. Сейчас директор вернется и мы с Вами побеседуем.',
    '— Адам! Почему ты так поздно вернулся? С кем ты провел этот вечер?\n— Ну что ты придумала, Ева? Ведь нас в раю только двое!\nНо когда Адам засыпает, Ева на всякий случай пересчитывает его ребра.',
    'Человек идет по улице и вдруг слышит тоненький голосок, доносящийся из его кармана:\n— Стой!\nЧеловек в изумлении замирает на месте и прямо перед ним тут же падает со свистом кирпич. Человек изумляется\nеще больше:\n— Кто же меня предупредил?\n— Это я, — опять доносится тоненький голосок из кармана — Твой хранитель.\nЧеловек засовывает руку в карман и осторожно извлекает оттуда крошечного гнома. Подносит его к глазам, долго рассматривает, потом задумывается и наконец спрашивает:\n— А где же ты, гад, был, когда я женился?',
    'Нищий:\n— Мадам! Я не видел мяса целую неделю.\n— Мэри! Покажи ему котлету.',
    'Идет джентльмен по пустыне, конца края не видно. Захотелось ему в туалет, а иначе он но может — джентльмен. Навстречу ему идет караван.\n— Сэр! — спрашивает джентльмен караванщика. — Вы не подскажете, где здесь туалет?\nКараванщик задумался:\n— А какой сегодня день?\n— Понедельник, сэр.\n— А! Ну тогда до четверга — прямо, а потом налево…',
    '— Что тебе сказал отец, когда узнал, что ты разбил его автомобиль?\n— Ругательства опустить?\n— Разумеется.\n— Ни слова.',
    '— Мадам! Вы давали объявление о найме служанки?\n— А Вы согласны у нас служить?\n— Да. Согласна. Но предупреждаю: я не мою полов и не готовлю еду.\n— А играете ли Вы на арфе?\n— Нет. А почему Вы спрашиваете?\n— Мне нужно, чтобы кто-нибудь играл на арфе, пока я буду готовить и мыть полы.',
    'Парикмахер, дважды порезав клиента, чтобы как — то смягчить ситуацию, затевает с ним разговор:\n— Вы у нас раньше бывали?\n— Нет. Руку я потерял на войне…',
    'Славный парень Роланд отправляется в дальний поход. Уже сидя в седле, зовет своего верного друга, вручает ему ключ от пояса целомудрия своей жены и говорит:\n— Дорогой друг! Я буду отсутствовать несколько лет. Все это время ты должен охранять честь моей супруги и всегда держать ключ при себе.\nЗатрубили горнисты и славный рыцарь выступил в по — ход.\nНе успел он отъехать подальше от городских ворот, как его нагнал верный друг на взмыленном коне и уже издалека закричал:\n— Какое счастье, что мне удалось тебя нагнать! — Что случилось? — встревожился рыцарь. — Ты ведь дал мне не тот ключ.',
    'Муж внезапно возвращается из командировки. Жена быстренько распахивает дверь на балкон и подталкивает туда любовника.\n— Повисай…\nТот повис. Висит час, два, три, ночь… Утром дворник подметает улицу. Увидел мужика и спрашивает:\n— Что, висим? — Вишу. — Ну ладно, подними ноги, я под тобой подмету.',
    'Один гражданин работал в мастерской, где делали чучела животных. У него был стеклянный глаз, который он иногда вынимал и клал рядом с собой, так как он ему мешал. Однажды в мастерскую ему принесли телеграмму от жены. Жена сообщала о своем приезде с курорта.\nТелеграмма запоздала, до прихода поезда оставались считанные минуты. Гражданин второпях вставил не свой глаз, а глаз с чучела тигра и помчался на вокзал. Жена, выходя из вагона, увидела мужа и закричала:\n— Не смотри на меня зверем! Я сама все расскажу!',
    'Молодой коммивояжер вернулся из деловой поездки и узнал, что его жена была ему неверна.\n— Это был мой друг Джон? — сурово спросил он.\n— Нет.\n— Тогда Ричард?\n— Нет.\n— Постой, тогда это, возможно, мой друг Сэм?\n— Что ты заклинился на своих друзьях? Ты думаешь, что у меня своих мало?',
    'Муж внезапно пришел домой. Смотрит — на балконе любовник.\n— Как Вы сюда попали?\n— Да вот с парашютом прыгал, за ваш балкон зацепился.\n— Ну тогда заходите — чайку попьем!\n— А Вы даже не удивляетесь?\n— А чему удивляться! Вчера у нас в туалете геологи нефть нашли.',
    'Жена устроила подругу к своему мужу секретарем с тем, чтобы узнать, как ведет себя муж на работе. Проходит месяц, другой, жена спрашивает мужа:\n— Как новая секретарша работает?\n— Ну как, утром к 9 часам приходит, а в 6 вечера уходит.\n— А как она одевается.\n— Медленно.',
    'Жена уехала на курорт. Через несколько дней муж ей посылает телеграмму: "Где вилки?"\nОна ему в ответ телеграфирует: "Спи дома".\nИ так несколько раз. По приезде домой муж говорит ей:\n— Почему ты мне не ответила, где вилки? Она подводит его к кровати и снимает простыни — вилки под простынями.',
    'Встречаются два приятеля.\n— Послушай, тебе нравятся бабы?\n— Ну что ты, конечно нет.\n— А такие, которые выпивают и курят?\n— Ну зачем мне такие?!\n— А которые не умеют готовить ни завтрак, ни обед, ни ужин?\n— Да нет же!\n— Так какого же черта ты лезешь к моей жене?',
    'В семье родился ребенок. Не разговаривал он до пяти лет. Родители повели его к врачу.\n— Не волнуйтесь, — успокоил врач, — он будет разговаривать. Вот только те, кого первые три раза назовет — умрут.\nЧерез некоторое время ребенок сказал слово "дед". Дед умер. Вскоре он сказал: "баба". Умерла бабушка. Однажды жена сказала мужу:\n— Посиди с ребенком, а я схожу в магазин.\nГулял ребенок, гулял и сказал: "папа". Отец собрался, помылся надел новый костюм, ботинки и лег на кровать. Приходит жена домой и говорит:\n— Что это ты улегся в новом костюме на кровать? Собирайся и пойдем на похороны — сосед умер.',
    'Муж уезжает отдыхать и просит соседа присмотреть за женой:\n— Если загуляет, давай телеграмму: "Жена умерла", а я пойму.\nЧерез неделю приходит такая телеграмма, а мужчины в номере не оказалось. Сердобольные друзья дают ответную: "Сообщите, когда похороны". Получил сосед такой ответ и пишет: "Когда похороны — не знаю, но доступ к телу продолжается".',
    'Сотрудник вернулся из дома отдыха и у себя на работе делился свежими впечатлениями. Он показывает пальцем на групповую фотографию:\n— Эта со мной… А эта с этим… и т. д.\nОдин из сотрудников видит на фотографии свою жену, которая в это время тоже была в доме отдыха. Он дрожащим голосом спрашивает:\n— А эта с кем?\n— А эта у нас самая порядочная. Как с мужем приехала, так с мужем и уехала.',
    'На тот свет прибывает десять женщин. Прежде, чем распределить, кого в ад, а кого в рай, апостол Петр выстроил их в одну шеренгу и спрашивает:\n— Кто из вас хоть один раз в жизни что-нибудь украл, поднимите руку?\nДевять женщин подняли руки, а десятая — нет.\n— Кто из вас хоть один раз изменял мужу, поднимите руку?\nДевять женщин подняли руки, десятая — нет. Апостол Петр подзывает ангела:\n— Так вот. Этих девять отправьте в ад и эту, десятую, глухонемую — туда же.',
    'Жена приезжает с курорта и привозит целый чемодан денег. На вопрос мужа, откуда столько денег, она отвечает, что заработала.\n— Да за тебя же больше рубля никто не даст, — говорит муж.\n— А я больше и не брала.',
    'Жена улеглась с любовником, а муж пришел на обед. Жена быстренько спрятала любовника в холодильник. Муж заходит на кухню, открывает холодильник и…\n— Ты кто? — Вася.\n— А что ты тут делаешь?\n— Колбасу ем.\nПришел муж на работу и рассказал все друзьям.\n— Дурак ты, — рассмеялись друзья, — ведь это любовник жены!\nПрибежал муж домой и опять к холодильнику, а в нем другой мужик.\n— Как тебя зовут? — Федя. — Слушай, Федя, передай Васе, что если я его увижу — убью!',
    'Уехал муж в командировку. Вечером жена пригласила троих мужчин. Сидят за столом, выпивают. Вдруг звонок в дверь. Жена перепугалась, затолкала всех троих мужчин на балкон, посадила в пустые мешки и завязала. Входит в квартиру муж. Выпил чаю и вышел на балкон покурить. Видит, у стенки стоят три мешка. Кричит жене:\n— А что за мешки у нас появились?\n— Это мама из деревни к празднику кое-что прислала!\nМуж ткнул ногой один мешок. Из мешка:\n— Бе-е-е.\n— Отлично. Будем из барашка шашлык делать.\nПнул ногой второй. Оттуда:\n— Хрю, хрю…\n— Тоже неплохо, окорок закоптим.\nТретий мешок пнул — тишина. Еще раз — тихо. Третий раз как треснет ногой по мешку, из мешка раздалось:\n— Идиот! Неужели непонятно?! Раз молчит, значит картошка!',
    'Кто такой образцовый муж?\nТот, который, войдя в спальню к жене и увидев ее с любовником, скажет:\n— Ну вы тут продолжайте, а я пойду кофе сварю.\nА кто такой образцовый любовник?\n— Тот, кто после этого сможет продолжать!',
    'Муж обнаруживает в кровати жену с мужчиной.\n— Что вы здесь делаете? — заорал муж.\n— Вот видишь, — говорит жена мужчине, — я же тебе говорила, что он дурак.',
    'Судят мужчину, сбросившего из окна третьего этажа холодильник, который, упав, отдавил ногу проходившему внизу человеку.\nСудья:\n— Обвиняемый, расскажите, как все было.\nОбвиняемый:\n— Я прилетел утром из командировки, вхожу в дом, жена бледная, вся в смятении.\n— Где он? — кричу жене. — Она молчит, Вижу, дверь черного хода распахнута. Я кидаюсь к окну, открываю, гляжу — он, как миленький, в одних трусах бежит под окнами. Я схватил холодильник и выкинул в окно ему на голову. К сожалению, промахнулся, пришиб только ногу.\nСудья:\n— Потерпевший. Ваше слово.\nПотерпевший (входит, хромая):\n— Товарищ судья, каждое утро перед работой я занимаюсь бегом. Утром, пятого мая, как всегда, бегу своим маршрутом и вдруг сверху что-то свистит. Гляжу, летит холодильник. Я еле увернулся.\nСудья:\n— Прошу пригласить свидетеля.\nВ зал под руки вводят человека. У него на руках и ногах гипс.\nСвидетель:\n— Сижу я в холодильнике…',
    'Утром в субботу встает муж в пять часов утра, нехотя собирается на рыбалку. Оделся потеплее, взял снасти, вы — ходит на улицу. На дворе темень, льет осенний холодный дождь, ветер… Постоял он, постоял и подумал: "Да не пойду я никуда в такую погоду, пойду досыпать".\nПришел домой. Разделся и тихонько к спящей жене под одеяло.\n— Бррр… Ну и холодина на дворе!\n— И не говори, — соглашается жена, не поворачиваясь, — а мой-то дурачок на рыбалку пошел.',
    'Муж неожиданно для жены вернулся домой. Видит — стол накрыт, жена наряженная, но никого в доме нет. Муж выпил, поел и лег на кровать. Вдруг из — под кровати вы — ползает детина.\n— Я рецидивист Бабушкин, деньги на бочку!\nМуж:\n— Ничего нет.\n— Тогда выход покажи.\nПроводив гостя, муж снова лег.\nИз-под кровати другой мужик выползает:\n— Я следователь Дедушкин! Тут не пробегал Бабушкин — вор и мошенник?\nМуж: — Был, вон туда побежал.\nСледователь:\n— Опергруппа! На выход!',
    '— Представляете? Прихожу домой вечером с работы и застаю свою жену в постели с каким-то шведом.\n— Ну и что Вы ему сказали?\n— А что я мог ему сказать, я же не знаю шведского?',
    'Муж застал жену в постели с любовником, с ходу раз — вернулся и ударил любовника.\nЖена с постели:\n— Правильно! Здесь не живет, а к нам ходит.\nЛюбовник развернулся и дал ответную оплеуху мужу.\nЖена:\n— Правильно! Сам не может и другим не дает.',
    'Одна женщина приходит на работу с подбитым глазом. Ее спрашивают:\n— Кто это Вас так?\n— Муж.\n— А мы думали, что он в командировке.\n— Я тоже так думала.',
    'Карлсон, который живет на крыше, напросился в гости к женщине.\nОна спрашивает:\n— А вдруг муж вернется?\n— А я в окно.\n— Так ведь пятнадцатый этаж!\n— Я ведь Карлсон, взял и улетел.\nТолько расположились — загремел ключ в замке. Женщина схватила Карлсона и выбросила в окно.\nВходит муж:\n— Кто у нас был?\n— Никого не было.\n— А чьи на стуле штаны с пропеллером?',
    'Муж, узнав об измене жены, прибегает во внеурочное время домой. По всему похоже, что любовник в квартире, но где-то спрятался. Муж посмотрел за диваном, в шкафу, на кухне, в ванной комнате, заходит в туалет, а там сидит Шварценеггер и говорит:\n— Ну что, нашел?\n— Нет, нет, я еще под диваном не искал!',
    'Хозяин и гость сидят и пьют чай. Вдруг из спальни выходит мужчина и спокойно направляется к выходу.\n— Кто это? — спрашивает гость.\n— Но, но! — отвечает хозяин. — Только, пожалуйста, без гнусных намеков. Это спонсор моей жены.',
    'По министерству прошел слух: секретарша родила сына от министра, и он похож. Узнав об этом, министр вызывает помощника:\n— Сходи в роддом и узнай, чего там болтают, что он похож?\nВернулся помощник.\n— Ну что? — спрашивает министр.\n— Как две капли воды…\n— Как?!\n— Маленький, лысый, ничего не понимает и орет…',
    'Жена спит с любовником — вдруг стук в дверь. Возвращается муж.\n— Господи, спаси меня от греха!\nГосподь отвечает:\n— Спасу с одним условием — через год утонешь.\n"Ну за год многое изменится", — подумала она и согласилась. Господь спас ее от греха. Проходит год. Жене дают на работе горящую путевку в Новороссийск. Поехала — но в море боялась купаться. А тут предлагают круиз на теплоходе. Думает: "Не станет же Господь из-за меня теплоход топить со множеством людей". Села, поплыла. Авария, теплоход тонет.\n— Господи! Ну я одна такая, а за что же другие тонут?\nГолос сверху:\n— А я вас, блядей, целый год со всей страны собирал.',
    'Муж пришел домой раньше времени, заглядывает в спальню и видит, что двое занимаются любовью. Он, ни слова не говоря, берет сковородку, нагревает ее на газу и ставит на задницу мужчины. Страшный крик — муж убегает из квартиры. Во дворе встречает его жена.\nОн в недоумении спрашивает:\n— А кто сейчас у нас в квартире?\n— Да это моя сестра с мужем приехали погостить.',
    '— Что сказала твоя жена, когда заметила, что ты целуешься с соседкой?\n— Представь себе — ничего! А те два передних зуба и так давно пора было удалить.',
    'Муж возвращается из командировки. Стучится к соседу:\n— К моей никто не приходил?\n— Нет.\n— Совсем-совсем никто?\n— Совсем-совсем.\n— Что! Все двадцать дней никто-никто?\n— Все двадцать дней.\nПомолчал, помолчал и сказал:\n— Ну тогда и я не пойду.',
    'Муж отвечает по телефону:\n— Не знаю, звоните в бюро погоды!\n— Кто звонил? — спрашивает жена.\n— Наверное, какой — то моряк. Спрашивал, как там на горизонте?',
    'Жена с любовником лежат в постели.\nЖена спрашивает:\n— Дорогой! Ты такой сильный! Что бы ты сделал с моим мужем — если бы он появился?\nТот отвечает:\n— Я бы его в бараний рог скрутил, ноги бы вырвал, он бы кровью умылся…\nИз прихожей раздается тонкий, несмелый голос:\n— Фигушки — я еще два дня в командировке.',
    'В ресторане официант:\n— Мадам, почему Ваш муж залез под стол?\n— Это не муж, муж стоит в дверях.',
    'Жена ночью видит сон: будто спит она с любовником и тут входит муж.\nОна просыпается с криком:\n— Прыгай скорее в окно — муж идет.\nМуж вскакивает с кровати и прыгает в окно. Летит и думает: "А кто же я?"',
    'К адвокату обращается клиент с просьбой взять на себя ведение бракоразводного процесса.\n— Почему Вы хотите разойтись? — спрашивает адвокат.\n— Я не в состоянии больше этого выносить. Моя жена имеет привычку ложиться спать утром.\n— А что она делает всю ночь?\n— Ждет меня.',
    'В кабинет к директору завода врывается разъяренная жена главного инженера и говорит:\n— До каких же пор Вы будете покрывать во всем моего мужа. Всем известно, что он бабник и пьяница. Мало того, вчера он пришел домой вообще в женских трусах.\nИ швырнула трусы на стол.\nДиректор ей говорит:\n— Успокойся. Сейчас мне некогда, но я завтра разберусь и приму меры. А ты иди, сейчас ко мне придет делегация.\nА трусы со стола сунул себе в карман брюк. На следующее утро жена директора стала гладить его брюки, нашла трусы и кричит мужу:\n— Петя! Когда кончатся твои дурацкие шутки? Я два дня ищу свои трусы, а они у тебя в кармане!',
    'Встречаются два мужика на том свете:\n— Ты как умер?\n— Замерз. А ты как?\n— От смеха умер.\n— Это как?\n— Был я у любовницы, звонок в дверь, я в панику. Муж. Она ему мусорное ведро в дверь подала, пока он ходил, я оделся и ушел. Прихожу домой, звоню, а жена мне ведро протягивает. Я все понял ворвался в квартиру, все перерыл, а никого не нашел. Сел на диван, смеялся, смеялся, от смеха и умер.\n— Дурак! Заглянул бы в холодильник — оба бы живы остались.',
    'Неожиданно вернувшись из командировки, муж просыпается от подозрительного шороха и видит, как из шкафа выползает голый мужчина, закутанный в шубу жены.\n— Ты кто такой?\n— Не видишь — я моль.\n— А шубу зачем взял?\n— Дома доем.',
    '— Можно ли выпустить любовника через унитаз, если вернулся муж?\n— Можно, если любовник говно.',
    'Сидят в ресторане машинист, пилот и шофер. Спорят, у кого жена самая честная.\nМашинист:\n— У меня жена честная. Еду я с рейса, проезжаю мимо дома, даю длинный гудок. Домой прихожу — она одна, стол накрыт.\nПилот:\n— Я лечу, делаю круг над домом. Прихожу — все в порядке.\nШофер:\n— А у меня перед домом спуск. Я выключаю мотор и качу до дома. Беру монтажку. Звоню в парадную дверь, а сам к черному ходу. Ни один еще живым не ушел.',
    'Медведь сел на ежа и сказал:\n— За что я любил покойного, так это за острую критику снизу.',
    'Вовочка просит отца:\n— Папа, дай денег. Я хочу сходить в зоопарк, на удава посмотреть.\n— Возьми лупу, пойди в сад и посмотри на червяка.',
    'В зоопарке отец с сыном:\n— Вот, деточка, видишь, это ползают пищерицы.\nПодходит сторож и строго заявляет:\n— Гражданин, если Вы не знаете названий, то не морочьте голову ребенку. Это не пищерицы, а черепухи.',
    'Экскурсия в Сухумском обезьяньем питомнике.\n— Девушка! Скажите, пожалуйста, эта обезьяна — мужчина или женщина?\n— Это самец. Мужчина тот, у кого деньги есть.',
    'Едет джигит на лошади, впереди небольшая канава.\nОн кричит:\n— Я джигит — я перепрыгну!\nПерепрыгнул. Едет дальше и видит канаву в два метра.\nОн кричит:\n— Я джигит — я перепрыгну! Перепрыгнул.\nЕдет дальше. Видит канаву в десять метров шириной.\n— Я — джигит…\nЛошадь, остановившись:\n— Раз ты джигит, ты и прыгай!',
    '— Как бывает обманчива внешность, сказал ежик, слезая с сапожной щетки.',
    'На Птичьем рынке в ряды, где продают птичек, рыбок и мелкую живность врывается мужчина. Он тащит на цепи медведя, который скалит зубы и рычит. Народ пугается, шарахается по сторонам.\nОдин кричит хозяину медведя:\n— Ты что, идиот! С медведем на Птичий рынок!\n— Молчи, друг. Мне бы только эту сволочь найти, которая в прошлом году продала мне его как хомячка.',
    'Медведь, Волк и Лиса сели играть в покер. Перед началом игры Медведь сказал:\n— Предупреждаю сразу: если кто — нибудь из вас будет блефовать, повторяю, если хоть кто-нибудь будет блефовать, тот сразу же получит по морде… по этой хитрой, нахальной, рыжей морде.',
    'Останавливает Волк в лесу Красную Шапочку и говорит:\n— Давай.\n— Сейчас разденусь.\n— Да ты что, дура, пирожки давай!',
    'Волк был страшным алкоголиком, а Заяц трезвенником. Встречает Волк Зайца, а тот едет на велосипеде.\nВолк спрашивает:\n— Откуда это?\n— Ты пил, а я не пил, вот и купил.\nВ следующий раз Волк встречает Зайца на машине.\nВолк спрашивает:\n— Откуда это?\n— Ты пил, а я не пил, вот и купил.\nЧерез неделю идет Заяц, а навстречу ему летит Волк на вертолете.\nЗаяц удивился и спрашивает:\n— Откуда это?\n— Бутылки сдал.',
    'У Зайца в лесу юбилей. Все его поздравляют. Решили послать приветственный адрес и волки. Написали и думают как подписаться: "стая волков" или "группа товарищей". Думали, думали и подписали: "стая товарищей".',
    'Лев издал указ, запрещающий зверям пить в лесу. Кто нарушит указ — будет съеден. В первый же день Лев встретил в лесу пьяного Зайца.\n— Косой, указ читал?\n— Читал.\n— А почему нарушаешь?\n— Д-д-да я его обмываю.\n— Ну смотри, — пригрозил Лев.\nЧерез день идет по лесу и видит: из лужи торчат два уха. Вытаскивает за уши пьяного Зайца.\n— Заяц, ты указ читал?\n— Ч-ч-читал.\n— Пить зверям строго запрещено! Сейчас будешь съеден.\n— Да-к ведь запрещено зверям, а нас, рыб, не трожь.',
    'В лесном туалете разбито стекло. Звери ищут виновного. Все указывают на Зайца.\nСпрашивают его:\n— Ты выбил?\nЗаяц отвечает:\n— Вроде я, а вроде и не я. Сидели мы в туалете рядом с Медведем. Медведь первый закончил и спрашивает меня: "Заяц, ты линяешь?" Я говорю — нет. Он подтерся мной и выбросил в окно.\nПроходит неделя. Опять окно выбито. Опять спрашивают Зайца:\n— Ты выбил?\n— Вроде я, а вроде и не я. Сидел со мной рядом Еж, я спросил его: "Еж, ты линяешь?" Он говорит — нет. Что было дальше — не помню.',
    'Лиса вышла замуж за крокодила. Народились поросята. Вывод: все мужчины — свиньи.',
    'Идет Лиса полосу, злая — презлая. Навстречу Волк.\n— Ты чего, рыжая, не в духе?\n— Да вот, встретила Колобка в лесу и говорю ему: "Колобок, Колобок, я тебя съем". А он мне отвечает: "Пошла ты, рыжая падла, а то пасть порву".\n— Дура ты дура. Это же не Колобок, это Ежик из зоны вернулся.',
    'Разговаривают в пустыне два верблюда.\nОдин:\n— Что бы про нас люди не говорили, а пить-то хочется.',
    'По пустыне ползут две черепахи.\nОн ей: — Ты испортила триста лучших лет моей жизни.',
    'Идет по пустыне измученный жарой верблюд. Подбегает к нему тушканчик и спрашивает:\n— Верблюд! Ты что такой грустный?\n— Да вот, — говорит, — пить хочу и очень жарко.\n— А ты бегай, как я, меня ветром обдувает.\nВерблюд собрал все силы и побежал. Через несколько метров упал. Тушканчик подошел, потрогал лапой лоб и\nговорит:\n— Замерз бедняга.',
    'По реке плывет крокодил и видит, что на берегу сидит обезьяна с удочкой и ловит рыбу. "Сейчас я ее спрошу, сколько она поймала рыбы. Если скажет, что много, то скажу — везет же дуракам, а если скажет, что мало, — то, так тебе, дуре, и надо". Подплывает к обезьяне и спрашивает:\n— Обезьяна! Сколько рыбы наловила?\n— Плыви, плыви, говно зеленое.',
    'Сидит обезьяна и стучит по ядерной боеголовке зубилом.\nПрохожий говорит:\n— Дура! Она же сейчас взорвется!\n— А у меня другая есть.',
    'Царь зверей собрал всех на поляне и говорит:\n— Все красивые налево, а умные направо.\nВсе начинают выстраиваться в две шеренги, а обезьяна мечется то туда, то сюда.\nЦарь ей:\n— Ты что?\n— Но не могу же я разорваться!',
    'В ресторан приходит Мартышка и заказывает бутылку водки и стакан сметаны. Ей приносят. Она выпивает всю бутылку и начинает лить себе на голову сметану.\nЕй кричат:\n— Ты что?!\nОна отвечает:\n— Вы знаете, когда я напьюсь, то такая дура, такая дура…',
    'Один строитель пробыл три года в Африке. Работал он по контракту. Наконец, возвращается домой. В аэропорту его встречают товарищи. Он выходит похудевший, загорелый, в пробковом шлеме, на чемодане пестрые наклейки, а на плече сидит маленькая обезьянка. Его окружают друзья.\n— Ну как в Африке?\n— Устал, ребята, страшно.\n— Вась, а как там в Африке с бабами?\n— С продуктами, ребята, плохо, все покупали на рынке…\n— Вась, а как там с бабами?\n— Жара днем страшная, а ночью прохладно.\n— Ну что ты нам про жару, как с бабами-то там?\nОбезьяна дергает Васю за ухо:\n— Пап, а пап, ну расскажи им про баб.',
    'Лошадь и обезьяна идут по полю и находят ружье. Лошадь смотрит в стволы, а обезьяна возится с курками. Обезьяна спускает курок. Лошади снесло полголовы, она упала и дергается.\nОбезьяна: — Тебе, дура, смешно, а я, знаешь, как перепугалась.',
    '— Какое самое глупое животное в мире?\n— Корова. Сама пьет воду, а людям дает молоко.',
    'Пошел мужик с собакой на рыбалку. Сделал прорубь. Ловит. Вдруг из лунки выныривает корова.\n— Мужик, дай закурить.\nМужик дает.\nКорова:\n— Ну ладно, пока, — и ныряет обратно.\nИзумленный мужик, открыв рот, смотрит на собаку.\nСобака:\n— А что я? А что я? Я сама обалдела!',
    'Ввиду того, что с кормами неблагополучно, решили скрестить корову с медведем. Пусть летом доится, как корова, а зимой сосет лапу.',
    'Сидит ворона на суку и видит, что на дерево лезет корова.\n— Корова, ты что это?\n— Яблочек хочу поесть.\n— Так это же береза!\n— А они у меня с собой.',
    'Две коровы сидят на лугу и вяжут. В небе один за другим пролетают бегемоты. Одна корова говорит:\n— Что-то бегемоты нынче разлетались.\nВторая, спокойно:\n— Наверное, где-то неподалеку их улей.',
    'В совхозе идет искусственное осеменение коров. Ветеринар со специальным шприцем и банкой спермы, не спеша, обходит стадо. Окончив процесс, он садится в свой "Москвич", а тронуться не может. Коровы плотным кольцом окружили машину. Он сигналит — никакой реакции. Тогда он опускает боковое стекло и кричит:\n— Эй, вы, пошли отсюда вон!\nИ тут одна из коров с большими грустными глазами просовывает в окошко голову и печально произносит:\n— А поцеловать?',
    'На обочине шоссе стоит человек с коровой и голосует. Останавливается "Москвич". Человек просит подвезти его до деревни.\nВодитель:\n— Ты что, дядя, спятил? Куда же я корову посажу?\nЧеловек:\n— Посади меня, а она за нами побежит.\nВодитель посадил путника, медленно поехал, а корова затрусила сзади. Прибавил водитель скорость, корова побежала быстрее.\n— Да дуй на всю железку, — требует человек.\nМашина пошла уже со скоростью 60 км в час. Корова бежит сзади, не отставая. Водитель вглядывается в зеркало заднего вида и кричит хозяину:\n— Послушайте, я быстрее не могу, с коровой сейчас будет плохо, она как-то странно мигает левым глазом.\nХозяин коровы (спокойно):\n— На обгон пошла.',
    'На лугу пасется корова. По ее задней ноге вверх ползет муравей. И он начал заползать под хвост, как корова махнула хвостом; и сбросила его на землю.\nТогда муравей полез по передней ноге. Прополз ногу, шею, голову, залез в ухо и говорит:\n— Не хочешь — не надо, но зачем же в грудь бить?',
    'Бык, найдя в траве перчатку, поддел ее рогом и обратился к корове:\n— Мадам, это не вы потеряли свой бюстгальтер?',
    'Идет корова по дороге, взъерошенная, ободранная, еле ноги волочит.\nЕе спрашивают:\n— Корова, ты откуда?\n— От верблюда.',
    'Семеро козлят копытами избивают волка.\n— Что же вы делаете, волки?\n— Молчи, козел!',
    'Сидит лягушка на болоте и разглядывает себя в зеркало:\n— Бдыщик, не бдыщик, бододавка не бододавка, а… додинка!',
    'Свинья забегает с улицы в комнату. Смотрит на электророзетку в стене:\n— Какая же сволочь свинью замуровала?',
    '— Почему кобели, когда мочатся около забора, поднимают ногу?\n— Предохраняются. Потому что, когда мочился самый первый кобель, на него упал забор.',
    'По пустыне бегут два кобеля.\n— Шарик, если через десять минут мы не встретим дерева — обоссусь на ходу.',
    'Жак пришел со своей дрессированной собачкой в кафе и заключил с посетителями пари, что пес будет разговаривать. Однако пес молчал. Жак вынужден был заплатить проигранное пари и под насмешки посетителей кафе по — шел с собакой домой.\n— Из-за тебя я проспорил много, — ворчал хозяин по дороге, — ну почему ты не заговорил?\nПес презрительно посмотрел на хозяина и ответил:\n— Чудак. Ты только представь себе, сколько мы выиграем завтра!',
    'Кот и кошка играют в прятки. Кошка говорит коту:\n— Если найдешь меня — я твоя, а если не найдешь, то я в шкафу.',
    'Три мышки собрались выпить.\nОдна говорит:\n— Давайте выпьем по одной рюмочке и станцуем.\nВторая мышка сказала:\n— Давайте выпьем по две рюмочки и споем.\nА третья мышка\nсказала:\n— Давайте выпьем по три рюмки и пойдем бить морду коту.',
    'Кошка гналась за мышью, но та успела скрыться в норке. Тогда кошка подошла к норке и залаяла. Удивилась мышка: как это кошка и вдруг лает? Высунулась из норы, туг кошка ее сцапала и съела. Потом облизнулась и сказала:\n— Как полезно знать хотя бы один иностранный язык.',
    'Лягушка встречает подружку.\n— Как дела? — спрашивает она ее.\n— Да плохо. Позавчера шла по болоту. Поймали, изнасиловали. Шла вчера, опять изнасиловали.\n— Ну и что ж ты будешь делать?\n— Сегодня опять пойду.',
    'Один петух говорит другому:\n— Давай сходит в гастроном.\n— Зачем?\n— На голых курочек посмотрим.',
    'На рынке.\n— Петуха продаешь?\n— Нет.\n— Так зачем же ты его принес?\n— Куры без него не хотели на рынок ехать.',
    'Зашел Заяц в туалет и слышит по радио песенку.\n— Встаньте, дети, встаньте в круг…\nЗаяц встал и провалился.',
    'Петух на пасху забежал в избу, увидел на столе крашеные яйца, разозлился и побежал бить павлина.',
    '— Почему петух поет всю жизнь?\n— Потому что у него много жен и ни одной тещи.',
    'Звонок в полицейский участок.\n— На помощь! На помощь! На помощь! В комнату пробралась кошка!\n— Ну и что? Из — за таких пустяков вы нас беспокоите? Кто это говорит?\n— Попугай!',
    'В зоомагазине.\n— У вас есть попугай?\n— К сожалению, нет, но можем предложить дятла.\n— А что, он тоже говорит?\n— Нет, но он овладел азбукой Морзе.',
    'Мистер Джонс купил на аукционе говорящего попугая. Выносит клетку с птицей на улицу и говорит:\n— Купить-то я тебя купил, но вот говоришь ли ты?\nПопугай отвечает:\n— Дурак, а кто цену набавлял?',
    'Три вороны сидят на дереве.\nХвастается первая: купила корову.\nХвастается вторая: купила часы.\nТретья молчит, завидует.\nНа следующий день сокрушается первая: корову украли.\nСокрушается вторая: часы потеряла.\nТретья смотрит на часы:\n— Ах, уже без четверти час, пора лететь корову доить.',
    'Взлетает ворона с конопляного поля.\n— Курлы!.. Курлы! Ой! Что это я? Кар! Кар!',
    'Спрашивают ворону:\n— Ворона, правда ли, что у тебя две ноги?\n— Прравда, прравда, особенно прравая.',
    'Воробей:\n— А все- таки автомобиль менее совершенен, чем лошадь. Он не дает навоза.',
    'Голубь назначил свидание голубке в двенадцать часов дня на часах городской ратуши. Двенадцать часов — го — лубки нет. Час дня — голубки нет. Два часа — тоже. И только около пяти часов вечера она появилась у часов.\n— Почему ты так поздно пришла? — спросил голубь. Ведь от твоей площади до ратуши лететь пять минут.\n— Милый, на дворе такая чудесная погода, что я решила пройтись пешком.',
    'Маленький червячок, плача, спрашивает мать:\n— Мама, мама, а где наш папа?\n— Замолчи. Папа ушел с мужиками на рыбалку.',
    'Пришел мужик на рыбалку. Насадил червячка на крючок и забросил в воду. Через минуту поплавок заходил ходуном. Мужик подсек, из воды вылетает червяк с вытаращенными глазами:\n— Мужик, ты что обалдел? Меня там чуть не сожрали!',
    'Слон смотрел телевизор. Слониха ушла гулять. Звонок в дверь. Слон выглянул — никого. Опять звонок. Снова открыл дверь, смотрит — на кнопке звонка сидит комар.\nСлон спрашивает:\n— Ты чего?\n— А Слониха где?\n— Гулять пошла.\n— Ну передай ей, что заходил ейный хахаль.',
    'Две блохи выходят из ресторана.\n— Так что, — говорит одна, — пешком пойдем или подождем собаку?',
    'На спину слона залезли два муравья, один говорит:\n— Нам бы только его завалить, а там мы его ногами затопчем.',
    'Две мухи в ресторане. Подходит официант.\nПервая:\n— Мне, пожалуйста, тарелку говна с луком.\nВторая:\n— Мне то же самое, только без лука. Я вечером в театр иду.',
    'На вершине горы отдыхают Орел и Чебурашка.\n— Ну что, полетели дальше?\n— Подожди, дай уши отдохнут.',
    'Прибегает Чебурашка к крокодилу Гене:\n— Ой, Гена! Шапокляк родила! Такого зеленого, с длинной мордой и с большими ушами! Гена! Правда, мы с тобой тут ни при чем?!',
    'На адрес Пятачка и Винни-Пуха пришла посылка.\n— Винни, — сообщает Пятачок, — там десять апельсинов, значит, каждому по восемь.\n— Как по восемь, если всего десять?\n— Это твоя забота. Я свою долю уже съел.',
    'Чебурашка приходит в магазин и спрашивает у продавца:\n— У вас писины есть?\n— Во-первых, не писины, а апельсины, во-вторых, — нет, а, в-третьих, если еще раз скажешь "писины", приколочу твои уши гвоздями к стенке.\nЧебурашка приходит на следующий день:\n— У вас гвозди есть?\n— Нет.\n— А писины?',
    'Купил человек на последние деньги на рынке грецких орехов. Раскалывает один — пустой, второй — пустой. Дошел так до последнего. Из пустого ореха вылезает червяк в большой кепке и говорит:\n— Абыдно, да?',
    'В зоопарк пришел человек.\n— Возьмите меня на работу, а то меня отовсюду выгоняют.\n— За что?\n— У меня очень замедленная реакция.\n— Хорошо, будете сторожить у нас черепах.\nУтром приходят, он сидит, а клетка пустая.\n— Слушай, а где черепахи? — Да только клетку приоткрыл, а они как ломанули толпой!',
    'На горке стоит старый бык, под горой на лугу пасется стадо. На горку к быку прискакивает молодой бычок и предлагает:\n— Давай быстро сбежим с горки и трахнем вон ту рыжую телку!\n— Зачем спешить, зачем бежать? Давай спокойно спустимся вниз и перетрахаем все стадо.',
    'Встречаются два приятеля.\n— Ты чего такой грустный?\n— Да вот мои клопы объявили войну соседским.\n— Ну так радуйся — перебьют друг друга.\n— Ага, радуйся… Они вчера полторы тысячи пленных привели.',
    'Два комара залетели в спортзал.\nОдин говорит:\n— Холодно.\n— Ничего. За ночь надышим.',
    'Мышка вышла замуж за слона. Через один день слон умирает и мышка все плачет и плачет, а звери ее успокаивают:\n— Не плачь! Все равно ведь только один день с ним жила.\n— Да. Жила один день, а закапывать придется всю жизнь.',
    'Встречает медведь мужика в лесу.\n— Ты кто?\n— Я турист.\n— Это я турист, а ты — завтрак туриста.',
    'Гена с Чебурашкой сидят в военкомате.\n— Гена! А нас брить будут? — спрашивает Чебурашка.\n— Не знаю. Спроси у мышки.\n— Я не мышка, я ежик.',
    'Фермер после гулянки приходит доить корову. Ничего не получается. Никак не может потянуть за соски. Наконец корова не выдержала и говорит:\n— Давай так: ты покрепче держи меня за титьки, а я буду подпрыгивать.',
    'Воробей спрашивает слона:\n— Хочешь кайф получить?\n— Хочу.\nВоробей залетел в хобот, через задницу вылетел.\nСлон:\n— Хорошо! Давай еще.\nВоробей залетел, а слон хобот в задницу вставил. Вечный кайф!',
    'Ворона держит в клюве сыр. Подлетает воробей и тоже пытается поклевать.\nВорона:\n— Ты че… оборзел?\n— О да!\n— Ты че… орел?\n— Да!\n— А почему такой маленький?\n— Болел в детстве.',
    'Красная Шапочка:\n— Бабушка! А почему у тебя такой большой нос?\n— Еврей потому что, — сказал Волк и заплакал.',
    'Охотник идет по лесу и проваливается в медвежью берлогу. Теряет ружье и в страхе ожидает, что будет. Потихоньку приглядывается и видит маленького медвежонка.\n— Папа дома?\n— Нет.\n— А мама?\n— Тоже нет.\nОн пинает медвежонка ногой:\n— Тогда чего развалился, гаденыш!\nМедвежонок заплакал и закричал:\n— Бабушкааааа…!',
    'К врачу заходит бегемот с лягушкой на голове.\nВрач говорит:\n— Здравствуйте! На что жалуетесь?\nЛягушка отвечает:\n— Да вот, доктор! Что-то к заднице прилипло.',
    'Сидят Гена и Чебурашка в окопе. Гена из пулемета строчит, а Чебурашка к нему пристает:\n— Ген, а Ген! А чем кровь пахнет?\n— Отстань, Чебурашка.\n— Ген, а Ген! Ну чем кровь пахнет?\n— Отстань, Чебурашка!\n— Ген, ну Ген! Скажи. Скажи — чем кровь пахнет?\n— Да говном, отстань.\n— Ой Ген, я весь в крови.',
    'Косяк диких уток летит на юг. Молодой утенок спрашивает:\n— А почему мы летим все время за одним вожаком?\n— Потому что у него есть карта.',
    'Крокодила переехало поездом. Голова поворачивается к отрезанной части и говорит:\n— Ну что, жопа. Допрыгалась?',
    'Снесла курица яйцо весом 5 кг. Приехал корреспондент и спрашивает у курицы:\n— Как это у Вас получилось?\n— Секрет.\n— Ваши планы на будущее?\n— Снести яйцо 7 кг.\nКорреспондент идет к петуху и спрашивает:\n— Как это у вас получилось?\n— Секрет.\n— Ваши планы на будущее?\n— Надавать по роже страусу.',
    'Звери выпили. Показалось мало. Решили послать за бутылкой черепаху. Сунули ей деньги в пасть и вытолкали за кусты:\n— Чеши за угол.\nЧас ждут, другой, третий. Не выдержали, стали ругать.\nЛиса:\n— Вот кляча, сдохнешь — не дождешься.\nКрокодил:\n— Старая курва! Придет — руки, ноги поотрываю.\nТут из кустов показывается черепашья голова и произносит:\n— А если вы будете ругаться — вообще никуда не пойду',
    'Плывет корова по океану. Мимо летит чайка и спрашивает:\n— Эй, корова! Куда плывешь?\n— В Африку.\n— Так это же в другую сторону.\n— А мне какая разница. Все равно не доплыву.',
    'Волк донимает Чебурашку, а тот не знает, как от него отвязаться. Потом и говорит:\n— Волк, хочешь, чтобы у тебя член до земли был?\n— Конечно хочу.\n— Гена, откуси ему ноги.',
    'Решили колобок, жираф и бегемот утопиться. Колобок на воде держится, у жирафа голова из воды торчит, а бегемот плавает хорошо.\nРешили повеситься. Колобку не за что веревку цеплять. У жирафа сук как раз по шею. У бегемота тоже ничего не получается — сук ломается.\nРешили спрыгнуть с 16-этажки. Колобок считает:\n— Раз, два, три.\nПрыгнул. От земли отскочил и опять на крыше оказался.\nЖираф считает:\n— Раз, два, три. Прыгнул и на землю встал.\nБегемот считает:\n— Раз, два, три, песок, глина, уголь, привет шахтерам!',
    'На американской базе в бассейн, где плавают дельфины, опустили микрофон, записывать разговор умных животных. Один дельфин другому говорит:\n— Скажи-ка что-нибудь по-русски — вот забегают!',
    'Совсем маленькие мальчик и девочка рассматривают книгу Брема "Жизнь животных". Заспорили.\n— Может!\n— Не может!\n— Может!\n— Не может. Пойдем бабушку спросим.\nПрибегают на кухню.\n— Бабушка, у тебя могут быть дети?\n— Ну что вы, милые, конечно нет.\n— Я тебе говорил, что она самец.',
    'Вовочкины родители легли спать. Под дверью стоит Вовочка и подслушивает.\n— Дорогой, я бы хотела девочку.\n— Хорошо. Будет девочка.\nВ комнату влетает Вовочка.\n— А мне саблю, альбом для марок и велосипед!',
    'В бане два маленьких мальчика увидели голого мужчину с большим животом.\nСпрашивают его:\n— Дядя, а что у тебя в животе?\n— Бомба.\nОдин другому говорит тихо:\n— Давай взорвем ее.\n— Опасно, очень короткий фитиль.',
    'В дверь кто-то стучится. Миссис Джонс сняла цепочку и видит маленького мальчика с луком в руках.\n— Миссис Джонс, Вы не отдадите мне мою стрелу?\n— Конечно, маленький, где она?\n— Застряла в Вашей кошке.',
    'Вовочка спрашивает у папы:\n— Скажи, как я на свет появился?\n— Да мы с мамой купили тебя в универсаме.\nНичего Вовочка не сказал на это. А вечером, когда Вовочка заснул, отец увидел на столе раскрытую тетрадку-дневник, которую вел Вовочка. Последняя запись:\n"Сегодня говорил с отцом на сексуальную тему. Дуб дубом".',
    'Два малыша рассматривают картину, на которой изображены Адам и Ева в первые дни своего создания.\n— А какой из них муж? — спрашивает маленькая девочка своего брата.\n— А откуда я знаю, — отвечает он, — на них нет никакой одежды.',
    'Вовочка надевает на ботинки галоши.\nМама говорит ему:\n— Вовочка, на улице сухо — грязи нет.\n— А я найду.',
    'Маленький мальчик ушел в лес и пропал. Мать ждет его, бегает вокруг дачи, зовет… Наконец, он появился.\n— Где ты пропадал? Ушел на полчаса, а пришел через два.\n— Там, мама, в лесу было так интересно. На поляне голый дядя бегал за голой тетей.\n— Вот и не надо было на них смотреть, это сумасшедшие люди!\n— Ну, тетя — то, может и сумасшедшая, а вот дядя точно — нет. Это был наш папа.',
    'Первый школьный день. Учительница рассаживает первоклассников за парты.\n— Олечка! Ты сядешь вместе с Вовочкой!\n— Я не сяду.\n— Почему?\n— У него баба в первом "А".',
    'Молодые супруги первого сентября провожают сына в первый класс. Новая форма, цветы… После уроков встречают сына, он бросает портфель на диван и говорит:\n— Что же вы меня не предупредили, что эта волынка на десять лет.',
    'Ученик пришел из школы, бабушка его спрашивает:\n— Ну и чем вы, Петенька, сегодня занимались в школе?\n— Бабушка, мы на уроке химии делали опыты со взрывчатыми веществами.\n— А что же у вас завтра будет в школе?\n— В какой школе, бабушка?!',
    'Мальчики из 3-го "А" пишут девочкам в 3-й "Б":\n"Приходите сегодня вечером в парк — будем целоваться"\nДевочки отвечают:\n"Если только за этим — то пишите в 1-й "А".',
    'В школе учитель спрашивает ученика:\n— Когда умер Александр Македонский?\n— Умер? Я даже не знал, что он болел.',
    '— Что значит: королева подарила своему супругу сына? — спросила маленькая Катя учительницу.\n— Это значит, — отвечает учительница, — что она родила ему сына.\nЧерез несколько дней Катя, сияя от радости, прибежала к учительнице.\n— Мария Петровна, вчера был мой день рождения!\n— Что тебе подарили?\n— Тетя Лида родила мне маленькую таксу!',
    'Учитель спрашивает ученика:\n— Петухов, назови мне двузначное число.\n— Двадцать семь.\n— А если переставить цифры наоборот? Сколько получится?\n— Я не знаю.\n— Садись. Ивашкин, назови мне двузначное число.\n— Тридцать пять.\n— А если переставить цифры?\n— Я не знаю.\n— Рабинович, назови мне…\n— Шестьдесят шесть и тридцать три!\nА теперь начинайте ваши фигли-мигли.',
    'Учитель спрашивает ученика:\n— Скажи мне, Соколов, какое самое благоприятное время для сбора яблок?\n— Когда собака привязана.',
    'Ученик приходит в класс с распухшей губой. Товарищи спрашивают, что с ним.\n— Да в воскресенье катались по озеру с отцом на лодке, а мне на губу оса села.\n— Ты бы ее согнал.\n— Не успел. Отец ее веслом убил.',
    'Мальчик приходит из школы. Отец спрашивает его:\n— Тебя сегодня вызывали?\n— Да, завтра вызывают тебя.',
    'Мать спрашивает сына:\n— Что-то я не вижу твоего школьного дневника?\n— А у меня его Васька взял, чтобы родителей попугать.',
    '— Петя, кем бы ты хотел быть, когда вырастешь?\n— Генералом.\n— Но ведь тогда тебя на войне могут убить.\n— Кто?\n— Неприятель.\n— Тогда я лучше буду неприятелем.',
    '— Папочка, сегодня у нас в школе сокращенное родительское собрание.\n— Что значит сокращенное?\n— Ты, я и директор.',
    'Возле памятника Пушкину стоит почетный караул из двух пионеров. Подходит Вовочка и спрашивает:\n— Кому памятник?\nПионеры отвечают:\n— Пушкину.\n— Это который "Муму" написал?\n— Ты что, дурак? "Муму" Тургенев написал, а это Пушкин.\nВовочка задумался, а через некоторое время говорит:\n— Что-то я вас не пойму. "Муму" Тургенев написал, а памятник Пушкину поставили.',
    'На стройку привели на экскурсию Вовочку и других детей.\nЭкскурсовод раздал им каски.\n— Дети, наденьте их, а то был такой случай: мальчик с девочкой пошли на стройку, девочка была в каске, а мальчик нет. На голову им упало по кирпичу. Мальчик умер, а девочка засмеялась и убежала.\nВовочка воскликнул:\n— А я знаю эту девочку! Она до сих пор бегает в каске и смеется.',
    'В винно — водочный отдел заходит пионерка.\n— Тетечка, дайте мне, пожалуйста, девять бутылок портвейна.\n— А не будет ли тебе тяжело, девочка?\n— Вот я и думаю, может три здесь выжрать?',
    'На улице.\n— Дядь, дай закурить.\n— А волшебное слово?\n— А в глаз?',
    'После "новогодней елки" в детском саду отец говорит сыну:\n— Сынок, ты уже большой и должен знать, что никакого Деда Мороза нет. Это был я.\n— Да, я знаю, ведь аист — это тоже ты.',
    '— Тетя, скушай эту конфетку.\n— Спасибо, милый.\n— Вкусно?\n— Очень.\n— Странно, почему тогда и собака, и кошка все время ее выплевывали?',
    'Маленький Сережа нарисовал портрет своего отца. Тот посмотрел рисунок и сказал:\n— Недурно, очень недурно, но почему ты мне нарисовал зеленые волосы?\n— А у меня не было лысой краски.',
    '— Мама, купи мне кроссовки!\n— Какие кроссовки? Ты еще коньки не износил!',
    'Вовочка пишет сочинение на тему "Весна":\n"Солнце, снег начинает таять. Волки трахаются".\nУчительница:\n— Вовочка, это неудобно.\n— Конечно, ноги ведь разъезжаются.',
    'Абсолютно лысая девочка с огромным бантом на голове идет по улице.\n— Девочка! Как у тебя бант держится? — А как прибили, так и держится.',
    'Маленький Эраст приходит в школу с плохо приготовленными уроками.\nУчительница спрашивает:\n— В чем дело?\n— Да у меня постоянно ссорятся отец с мамой.\n— Мать я твою видела, — говорит учительница.\n— А кто твой отец?\n— Вот как раз из — за этого они и ссорятся.',
    'Учительница, которая вела в младших классах уроки богословия, спрашивает:\n— Что это за маленькое создание в коричневой шубке и с длинным пушистым хвостом прыгает с ветки на ветку и собирает орешки?\nМаленький Оскар поднял руку и ответил:\n— С обычной точки зрения это должна быть белка, но поскольку об этом спрашиваете именно Вы, то стало быть это Иисус Христос.',
    'Мама (шепотом):\n— Томми, твой дедушка очень болен. Скажи ему что-нибудь ободряющее.\nТомми:\n— Дедушка! Ты хотел бы, чтобы на твоих похоронах играл военный оркестр?',
    'Гости сели за стол. Хозяйка в последний раз окинула взглядом сервировку стола и заметила маленькую оплошность.\n— Катя, — спросила она дочку. — Почему ты Ивану Ивановичу не положила ни ножа, ни вилки?\n— А папа сказал, что он ест, как лошадь.',
    'Вовочка спрашивает доктора:\n— Дядя доктор! А шестилетняя девочка может забеременеть?\n— Нет!\n— Шантажистка!',
    '— Мама! А почему ребята меня головастиком дразнят?\n— Не обращай на них внимания. Сходи лучше за картошкой. Да ведро не бери, в твою панамку три ведра влезет.',
    'На небольшом холме, за которым разместилась деревня, стоит парнишка, с явным удовольствием наблюдая за оранжевым светом, освещающим долину. Прохожий останавливается и говорит:\n— Как приятно видеть маленького мальчика, который любуется природой. Ты часто приходишь сюда, чтобы посмотреть на заход солнца?\n— Это вовсе не заход солнца — это горит наша школа.',
    'Дети по одному входят в класс и здороваются с учительницей. Только Вовочка всех растолкал и сразу плюхнулся на свое место. Учительница строго:\n— Вовочка! Выйди из класса и зайди нормально, как твой папа домой приходит!\nВовочка покинул класс и прикрыл за собой дверь. Вдруг дверь с треском распахивается от удара Вовочкиной ноги:\n— Ну что, суки, не ждали?',
    'Вовочка приходит из школы и радостно сообщает:\n— Хотите я вам слово из трех букв напишу?\nМать дает ему пощечину, бабушка подзатыльник. Вовочка в слезах.\nПриходит отец и спрашивает:\n— В чем дело?\nВовочка объясняет, что хотел написать слово "МИР". Отец дает матери пощечину:\n— А ты что имела в виду?\nВовочка:\n— И бабушке дай. Пускай об этом не думает.',
    '— Мама! — испуганно говорит Вовочка матери, глядя в окно. — Вон идет папа. Что мы ему сначала покажем, твое новое платье или мой дневник?',
    'Джонни явился из школы в изодранном костюме.\n— Что с тобой случилось? — строго спросил папа.\n— Я подрался с Чарли.\n— Возмутительно! Теперь придется покупать тебе новый костюм.\n— Это что! — гордо сказал Джонни. — Посмотрел бы ты на Чарли. Его папе надо покупать нового ребенка.',
    'Учительница спрашивает:\n— Дети! Расскажите, как вы помогали фронту?\nНастя:\n— Я высылала на фронт кисеты с табаком.\nМаша:\n— А я была медсестрой.\nУчительница:\n— Молодцы!\nВовочка:\n— А я подносил солдатам снаряды.\nУчительница:\n— Вовочка! Ты же настоящий герой! Тебя поблагодарили?\n— О да!\nМне сказали: "Зер гут, Вольдемар!"',
    'Таксист взял пассажиров: женщину с ребенком. Вот едут, и ребенок разговаривает сам с собой:\n— Вот, если б мой папа был слон, мама слонихой, я бы был слоненком; вот если бы мой папа был волк, мама волчихой, я бы был волчонком, и т. д. и т. п.\nВодитель уже изнемогает и спрашивает:\n— Слушай! А если бы твой папа был осел, а мама козлихой, кем бы ты был?\n— Таксистом.',
    '— Мальчик! Твоя мама дома?\n— Нет.\n— А папа?\n— Нет. Тоже спрятался.',
    'Вовочка пришел домой с одноклассником и сказал:\n— Посмотри, мама, — это Миша. Он необыкновенный мальчик.\n— Чем же он такой необыкновенный?\n— Он учится еще хуже, чем я.',
    'Вовочку выгнали с урока. Мимо проходит директор.\n— Что, Вовочка, опять выгнали?\n— Да, — вздыхает Вовочка.\n— А где твой папа работает?\n— В ЦК.\n— Ты, Вовочка, иди домой, я с Марьей Ивановной поговорю.\nВовочка приходит домой веселый.\nОтец с вопросом:\n— Ты что такой веселый?\n— Опять твоя центральная котельная выручила.',
    'Один мужик вышел из тюрьмы и устроился работать воспитателем в детский сад. Приятель его по камере пришел посмотреть, как он работает. Видит: посреди двора тот сидит на стуле, а дети ходят по кругу, заложив руки за спину.\n— Иванов! Опять описался?!\n— Обижаешь, начальник, зачем мокрое дело шьешь?',
    'Вовочка после уроков приходит домой и застает мать в слезах.\n— Не плачь, мамочка, я сегодня по истории пятерку получил!\nМать продолжает плакать.\n— Мамочка, и по географии мне пятерку поставили!\nМать продолжает плакать. Вовочка утешает ее:\n— Мама, почему ты так плачешь?\n— У нас в семье большое горе… Саша вчера стрелял в царя!..',
    'Пьяницы делятся на три категории:\n1. Малопьющие — которые пьют и им все мало;\n2. Застенчивые — которые пьют, а домой идут, держась за стенку;\n3. Выносливые — которые пьют, а потом их выносят.',
    'На улице пьяный спрашивает прохожих:\n— Граждане, где здесь противоположная сторона?\nЕму показывают.\n— Совсем обалдели. А там говорят, что здесь.',
    'В ресторане.\n— Официант, три бутылки водки.\n— Слушаюсь-с, что будем кушать?\n— Ее и будем кушать.',
    'Пьяный проснулся, лежит на земле. Спрашивает прохожего:\n— А где я лллежу?\n— У Красных ворот.\n— Закрой их, а то мне в зад дует.',
    'Муж говорит жене:\n— Я сейчас лягу спать, а когда захочу выпить, ты меня разбуди.\n— А как я узнаю, когда ты захочешь?\n— Ты меня только разбуди…',
    'Мальчик приходит из школы:\n— Пап, я четверку принес!\n— Поставь в холодильник.',
    'Приходит муж домой после выпивки, а жена ему:\n— Выбирай: или я, или водка!\nМуж почесал затылок:\n— И много водки?',
    'Встречаются два алкоголика. Один говорит:\n— Пойдем ко мне, выпьем.\n— Пойдем.\nХозяин открывает квартиру, стараясь не шуметь.\n— Проходи тихонько на кухню.\nОсторожно открывает холодильник-бар, достает бутылку коньяка. Вдруг нечаянно звякнул стакан.\nХозяин: — Тише, ты!\n— А чего мы так боимся?\n— В спальне жена с любовником — это его коньяк.',
    'У алкоголика взяли кровь на анализ. Через день он получает результат, где написано:\n"Гражданин Сидоров, в Вашем вермуте крови не обнаружено".',
    'Муж пьяный возвращается домой. Жена ругается, почему опять выпил так много.\n— Да не много, взяли только бутылку на троих.\n— Почему же ты такой пьяный?\n— Двое не пришли.',
    'Муж поздно пришел домой и заметно навеселе.\nЖена:\n— Где ты был?\n— Да у Петьки просидел, в картишки перекинулись.\nЖена звонит по телефону:\n— Петя, мой у тебя был?\n— Да, до сих пор сидит.',
    'Пьяный мужик пришел ночью домой и кричит с порога в темноту:\n— Жена, начни ругаться, а то я кровать не найду!',
    'Инспектор останавливает выпившего водителя, который едет по левой стороне шоссе против движения:\n— Ты куда собрался, приятель?\n— Н-не знаю, но думаю, что опоздал. Все уже едут обратно.',
    'Муж возвращается с охоты. Входит в дом и говорит:\n— Ну жена, теперь мы месяц не будем мясо покупать.\n— Неужели кабана убил?\n— Не, получку пропил.',
    'Мальчик жалуется отцу:\n— Пап, ко мне в школе Марья Ивановна придирается, двойки ставит, грозится на второй год оставить.\nОтец:\n— Да ладно, не обращай внимания, давай, разливай.',
    'Муж приходит вечером домой. У него выбит глаз и рука в гипсе. Жена в ужасе:\n— Вася, что с тобой?\n— Да я сегодня в пивной с одним мужиком на глаз поспорил, что он мне руку не сломает.',
    'Пьяные у пивной говорят о своих женах.\nПервый:\n— У меня жена такая стройная, подтянутая, темпераментная, породистая, как борзая.\nВторой:\n— А у меня жена маленькая, кудрявенькая, ласковая, как болонка.\nТретий:\n— А у меня жена тоже сука, только не знаю, какой породы.',
    'Сын школьник спрашивает:\n— Мам, что такое трансформатор?\n— Ну, как тебе объяснить? Это как наш папа: двести двадцать получает, сто двадцать семь домой приносит, а на\nостальные — гудит.',
    'Муж собирается на субботник, а жена злится.\n— Опять придешь поздно и пьяный, знаю я тебя.\nВ три часа ночи раздается звонок. Жена открывает, муж пьяный, гневно кричит:\n— Ну что, накаркала?',
    'Жена проснулась от стука на кухне. Входит и видит — пьяный муж открывает дверь у холодильника и кричит:\n— В аэропорт повезешь?\nИ так беспрерывно. Жена снова пошла спать, приговаривая:\n— Вот пьяный дурень, холодильник за такси принял.\nУтром входит на кухню — ни мужа, ни холодильника.\n— Вот дьявол, уехал все-таки!',
    'Пьяный привел домой незнакомую женщину. Дверь открыла жена. Муж отводит жену в сторону и шепчет ей на ухо:\n— С-скажи ей, что ты моя сестра.',
    '— Мама, а что, папа вчера зарплату получил?\n— Как ты догадался?\n— А он в ванной зеркало бреет.',
    'Трое пьяных ползут по шпалам железной дороги.\nОдин:\n— Ч-черт, какие ступени высокие!\nВторой:\n— Да. И перила низкие.\nТретий:\n— Ничего, ребята, вон смотрите, лифт идет.',
    'Двое у винного отдела:\n— Ну что, две возьмем или три?\n— Наверное, три…\n— А зачем? Ведь вчера взяли три, а одна осталась.\n— Ну тогда возьмем две.\nК продавщице:\n— Девушка! Четыре бутылки водки и две ириски.',
    'Возле телефона-автомата стоит пьяный мужчина и пытается набрать номер, но у него ничего не получается. Мимо проходит женщина.\n— У, пьяница, а еще таксист.\nМужчина с недоумением на лице поворачивается к ней:\n— А почему таксист?\n— Да у тебя шапка-то таксистская.\nОн поднимает руку и ощупывает фуражку у себя на голове.\n— Да, таксистская, а была ондатровая.',
    'Двое пошли в баню. В предбаннике выпили бутылку.\nОдин говорит:\n— Ничего не почувствовал. Наверное, разбавляют. Давай еще одну бутылку выпьем в парилке.\nЗашли в парилку и внизу на скамейке распили вторую.\nВторой говорит:\n— А ты прав. Водка какая-то бракованная, не берет. Давай третью разопьем на верхней полке. Там жарко, наверное подействует.\nРаспили, обливаясь потом, третью и опять ничего не почувствовали.\nОдин вспомнил:\n— Слушай! Тут недалеко от бани друг у меня живет. У него есть спирт. Пойдем к нему, выпьем и почувствуем, наверняка.\nПриходят к другу. Звонят в дверь. Друг открывает:\n— Привет ребята! А вы что, из бани?\n— А как ты узнал?\n— Да вы же голые и с шайками.',
    '— Мой сосед на этой неделе опять гнал самогон, — говорит один житель деревни другому.\n— С чего это ты так решил?\n— Его кролики опять набили морду моей собаке.',
    'Что такое: "шампанское по-семейному"?\nОтвет:\n— Это, когда муж пьет водку, а жена шипит.',
    'Пьяный приходит в аптеку:\n— С-скажите, у вас есть геморройные\nсвечи?\n— Да.\n— А подсвечники?',
    'Из разговора двух приятелей:\n— Прихожу на днях домой, вижу, жена лежит в кровати с каким-то мужиком. Это меня сразу насторожило. Бегу к холодильнику, открываю: точно — пол-литра нет.',
    'Не соображая, и не видя ничего перед собой, идет по улице пьяный. Сходу врезается в фонарный столб. От удара отлетает, хватается за голову и, причитая, начинает кружиться на месте. Снова идет вперед и снова ударяется об этот же столб. Тогда он тихо садится на тротуар.\n— Подожду, когда кончится митинг.',
    'В ресторане один официант говорит другому, кивая на пьяного, заснувшего за столом.\n— Почему ты не выбросишь этого забулдыгу на улицу?\n— А зачем? Каждый раз, когда я его бужу, он мне оплачивает счет.',
    'Жена пришла за мужем в пивную.\nОн возмущен:\n— В конце концов! Это просто оскорбительно! Почему ты всегда идешь сразу сюда. Почему ты не ищешь меня, например, в музее?',
    'В бар входит посетитель и, указывая на мертвецки пьяного человека, говорит бармену:\n— Мне, пожалуйста, того же самого.',
    'В Петербурге на Аничковом мосту мочится пьяный.\nПодходит милиционер:\n— Это что за безобразие? Немедленно прекратите!\n— Это что же получается? Баронам можно, а рабочему человеку нельзя?\n— Почему это?\n— А вот прочти надпись… "отливал барон Клодт".',
    'Два пьяных туриста нашли в тайге пушку и решили выстрелить в сторону Хабаровска. Зарядили снаряд задом наперед и пальнули. Вся пушка вдребезги. Одному руки оторвало, другому ноги. Тот, которому ноги оторвало, схватился за голову и кричит:\n— Елки-палки! А что сейчас в Хабаровске-то делается!',
    'Муж возвращается домой под утро и объясняет жене:\n— Понимаешь, сидел вчера с друзьями. Иду домой и вдруг вижу, земля все выше и выше, и бац — мне по лбу. Так всю ночь и простоял.',
    'Выходит пьяный из ресторана. Подходит к таксисту и спрашивает:\n— У тебя в багажник ящик пива и торт поместятся?\n— Да.\nПьяный подходит к багажнику, открывает его и засовывает два пальца в рот.',
    'Доктор:\n— Спиртное употребляете?\nПациент:\n— Нет, только по торжественным случаям.\n— А что Вы считаете такими случаями?\n— Когда у меня есть, что выпить.',
    'Двое посетителей в баре заказывают пиво. Один из них добавляет:\n— Мне, пожалуйста, в чистой кружке.\nОфициант приносит два пива и спрашивает:\n— Кто из вас заказывал в чистой?',
    'Милиционер останавливает машину и спрашивает у шофера, который сидит один:\n— Почему в машине два водителя?\nШофер:\n— Стоило из-за такого пустяка машину окружать.',
    'Идет собрание общества рыболовов-любителей. Выступает председатель:\n— Приближается время зимнего лова. Сколько будем брать водки? В позапрошлом году мы брали по одной бутылке на брата — потеряли удочки, в прошлом году брали по две — потеряли автобус. Что предлагаете?\nВыходит один рыболов:\n— Предлагаю в этом году взять по три бутылки, но удочки не брать, и из автобуса не выходить.',
    'Возле общественного туалета стоит негр и писает. Подходит милиционер:\n— Как Вам не стыдно! Не можете в туалете этого сделать?\nНегр смущенно:\n— Нет, нельзя. Там белый господин вино пьет.',
    'Мужчина читает газету и видит объявление:\n"Предлагается ореховая спальня за бутылку водки".\nМужчина быстро идет в магазин, покупает бутылку водки и приходит по адресу. Дверь открывает мужик в одних\nтрусах, абсолютно пьяный.\n— Я по объявлению. Здесь продается ореховая спальня?\n— Да, здесь.\n— Проходи.\nМужчина проходит в абсолютно пустую комнату, посреди которой стоит собачья будка.\n— А где же ореховая спальня?\n— Орех, выходи, я твою спальню продал.',
    'Лежит мужик пьяный в грязи. Мимо проходит женщина.\n— Сама свинья, — говорит мужик.\n— Я же Вам ничего не говорила!\n— Зато подумала.',
    'Пьяный едет в автобусе и громко говорит:\n— Сейчас буду блевать!\nВсе его уговаривают не блевать сейчас, а подождать до остановки.\n— Хорошо, сосчитаю до 48 и наблюю.\nВсе облегченно вздохнули, благо, остановка близко.\n— Шестью восемь — сорок восемь…',
    'Два алкаша ищут третьего. Идет негр.\n— Третьим будешь?\nТот не отказался. Рядом стройка. Пошли туда к сторожу. Подходят и говорят:\n— Батя, дай стаканок, нальем.\nВыпили, негр опьянел. Ну куда деваться. Взяли его под руки и потащили. Сторож смотрел, смотрел и заорал вдогонку:\n— Ребята! Стаканок попросили — я вам дал. Но зачем же рубероид сперли?',
    'В очередной раз муж приходит домой пьяный. Жена спрашивает:\n— До каких пор это будет продолжаться? Почему водку пьешь?!\n— Пью, потому что жидкая. Была б твердая — грыз бы.',
    'Однажды пьяный муж возвращается домой поздно.\n— Опять нализался, — возмущается жена. — Ты же говорил, что сегодня придешь трезвый и будешь любить меня.\n— Обязательно буду, только дай одну рюмку.\nЖена принесла рюмку.\nМуж выпивает и задумывается:\n— Милая, чтобы любовь была горячее, мне надо выпить еще одну рюмочку.\nЖена в отчаянье выбегает на балкон и кричит:\n— Господи, есть ли в этом доме настоящие мужчины?\nС первого этажа голос:\n— А что — есть выпить?',
    'Мужчина каждый вечер берет по две рюмки коньяка по 50 грамм. На вопрос бармена: "Почему Вы не берете сразу 100 грамм?" — он отвечает:\n— А у меня с другом уговор. Я пью за него и за себя.\nОднажды вечером мужчина попросил только 50 грамм.\n— С Вашим другом что-то случилось?\n— Нет. Я бросил пить.',
    'Турист посетил озеро Лох-Несс в надежде увидеть знаменитое чудовище.\n— Когда змей обычно появляется? — спросил он у гида.\n— Обычно после пятого стакана.',
    '— Позовите к телефону Васю. — Васи нет дома, а что ему передать?\n— Передайте ему три рубля.',
    '— Будьте любезны, попросите к телефону Рабиновича.\n— Вам какого, старшего или младшего?\n— Старшего.\n— Они оба умерли.',
    'В три часа ночи раздается телефонный звонок:\n— Это баня?\n— Это квартира, — кричит раздраженный хозяин.\n— А почему голый стоишь?',
    'Ночью в три часа звонок по телефону. Заспанный голос:\n— Алло, скажите, это телефон 229-03-71?\n— Вы что, совсем с ума сошли? У меня вообще нет телефона.',
    'Наркоман звонит приятелю:\n— Гоша дома?\n— Гоша умер.\nНаркоман звонит опять:\n— Извините, я не понял, он что, за коноплей не поедет?',
    'Телефонный звонок среди ночи:\n— Если Вы сейчас же не выключите музыку, я вызову полицию!\n— Не нравится, переселяйтесь на другую улицу.\n— А я вообще с другого района звоню.',
    'Журналист берет интервью у чукчи:\n— Скажите в двух словах, как вы жили до Октябрьской революции?\n— Голод и холод.\n— А как живете теперь?\n— Голод и холод, и чувство глубокой благодарности.',
    'Заблудились двое чукчей в тайге, один говорит:\n— А ну выстрели, может, кто отзовется.\nВторой выстрелил — никто не отзывается.\n— Стреляй еще.\nОпять тишина.\n— Стреляй!\n— Не могу, стрелы кончились.',
    'По реке плывет лодка. На корме сидит чукча и курит трубку. Его жена сидит на веслах и гребет против течения.\n— Хорошо тебе, — говорит чукча, — греби себе и греби, а мне думать надо, как дальше жить.',
    'Чукча приводит сына к врачу:\n— Доктор, сын не ест ничего: ни мяса, ни масла, ни колбасы.\n— Почему же он не ест?\n— Нету.',
    'Ночью совершенно голая женщина останавливает такси, садится на заднее сиденье и бросает:\n— В Бескудниково!\nТаксист чукча, не трогаясь с места, смотрит на нее.\n— Ну, чего уставился? Голой бабы не видел?\n— Чукча видел голый баба. Чукча думает: когда приедем, откуда, однако, деньги будешь доставать?',
    'В пограничной засаде сидит чукча и чутко прислушивается к звукам. Вдруг тишину ночи нарушает всплеск. Плывет лодка. Чукча из засады кричит:\n— Стой! Говори пароля!\nНо неизвестный молча продолжает грести.\n— Стой, говори пароля, — опять кричит чукча, — а то моя твоя стреляет.\nИз темноты в ответ несется:\n— Да пошел ты к…\nЧукча облегченно вздыхает.\n— Вторая год служу на границе, а пароля все та же.',
    'Чукча-часовой увидел нарушителя.\n— Стой, стрелять буду.\n— Стою.\n— Стреляю.',
    'Женился чукча на русской. Спрашивают у него соседи:\n— Ну, как твой русский жена?\n— Хороший жена, грязный только, каждый день умывается.',
    'Едут двое чукчей в троллейбусе. Первый спрашивает водителя:\n— Я доеду на этом троллейбусе до вокзала?\n— Нет, не доедете.\nВторой чукча:\n— А я?',
    'Каждый вечер на берег моря выходит чукча и кричит в сторону Америки:\n— Нищие!\nЕму говорят:\n— Почему нищие, когда они хорошо живут?\n— Аляску купили, а на Чукотку денег не хватило.',
    'Объявление по радио на железнодорожном вокзале:\n— Поезд Москва-Чукотка отправляется со второго пути в 12 часов. Специально для чукчи повторяем: поезд Москва — домой поедет по 3-и и 4-и рельсе, когда на часах все стрелки станут кверху.',
    'Встречаются двое чукчей:\n— Салют, козел!\n— Сам салют, однако.',
    'Сидит чукча над обрывом и играет на своем народном инструменте.\nПроходит прохожий и говорит:\n— Твой олень упал с обрыва.\nЧукча продолжает играть.\n— Эй! Уже упало два твоих оленя!\nОпять ноль внимания.\n— Смотри, с обрыва упало все стадо!\nЧукча наконец отрывается от своего занятия и тихо произносит:\n— Однако, тенденция.',
    'Чукча предложил проститутке отдаться за соболью шкурку. Девушка, получив шкурку, обрадовалась и говорит:\n— Давай, чукча, еще раз.\n— Давай, — сказал чукча.\nИ после этого шкурку отнял:\n— Однако, я хотел — шкурку тебе давал. Ты хотел — шкурку мне давай.',
    'У приезжего чукчи в Москве потерялась жена. Он в милицию. Дежурный спрашивает приметы пропавшей.\n— Приметы не терял. Жена пропала.\n— Ну вот у меня жена, — объясняет милиционер, — высокая, стройная блондинка.\n— Моя маленькая, ноги кривые, волос мало, да ну ее, давай лучше твою искать.',
    'Приехал чукча в Москву — машину покупать. Ходит вокруг да около автомагазина, выбирает. Тут ему один мужик подвернулся и предлагает:\n— Купи "Жигули".\n— Не… "Жигули", однако, маленькая, мне большой нужен.\n— Ну купи "Волгу".\n— Не… "Волга" тоже, однако, маленький.\n— Ну КамАЗ тогда что ли…\n— Ну КамАЗ, однако, можно.\nКупил и уехал.\nА через некоторое время чукча снова приехал в Москву и встретил того самого мужика.\n— Ну как, машина ходит? — спрашивает мужик.\n— КамАЗа ходит, однако, только собаки быстро устают.',
    'У чукчи спрашивают:\n— Что ты делаешь, когда приходишь с охоты?\n— Люблю жена.\n— А потом? — Еще люблю жена.\n— А потом?\n— Снимаю лыжи.',
    'В больницу привозят человека. У него обожжены уши.\n— Что случилось? — спрашивает врач.\n— Да я гладил брюки, вдруг телефон зазвонил. Я вместо трубки приложил к уху утюг.\n— А почему второе обожжено?\n— А это, когда я вызывал "скорую помощь".',
    'К ветеринару приходит посетитель:\n— Здесь принимает скотский доктор?\n— Да, а что у Вас болит?',
    'Пациент спрашивает дерматолога:\n— Известно ли науке, почему некоторые люди лысеют?\n— Причина установлена точно, — ответил врач, — некоторые люди лысеют, потому что у них выпадают волосы и больше не растут.',
    '— Доктор, я опять жалуюсь на геморрой. Вы мне все свечи прописываете, а они так ни разу и не помогли.\n— Да Вы их едите, что ли?\n— Ну не в задницу же запихиваю!',
    'Пришел к доктору пациент и жалуется, что у него боль между лопатками.\nДоктор спрашивает:\n— Курите?\n— Нет.\n— Пьете?\n— Нет.\n— А с женщинами балуетесь?\n— Тоже нет.\n— Так это у Вас крылышки режутся.',
    '— Доктор, мой муж серьезно болен. Что делать?\n— Прежде всего нужно поставить диагноз. Разденьтесь и покажите, где у него болит.',
    'Пациент приходит к врачу:\n— Доктор! Дайте мне таблетку от жадности. Да побольше, побольше!',
    'Врач задумчиво смотрит на молодую женщину:\n— Никак не могу понять, что с Вами: или у Вас сильный грипп, или Вы в положении?.\nЖенщина на минуту задумалась.\n— Наверное, я в положении, доктор, но не могу представить, от кого я могла подхватить грипп?',
    '— Нервное заболевание Вашей жены не представляет опасности. С таким неврозом люди живут очень долго.\n— А я, доктор, сколько протяну я?',
    'Пациент, придя на прием к доктору:\n— Доктор, помогите, меня все игнорируют!\nДоктор:\n— Следующий!',
    'Врач говорит больному:\n— Примите сегодня две таблетки, а завтра, если проснетесь, еще две.',
    '— Доктор, это верно, что у тех, кто ест морковку, хорошее зрение?\n— Конечно. Разве Вы видели когда-нибудь кролика в очках?',
    'В поликлинике:\n— На что жалуетесь?\n— Плохо слышу.\n— Курите?\n— Курю.\n— Выпиваете?\n— Выпиваю, бывает.\n— Женщины?\n— Ну…\n— Придется Вам от всего этого отказаться.\n— Это чтобы лучше слышать? Ни за что!',
    '— Доктор, у меня ужасные боли.\n— В какой области?\n— В Черкасской.',
    'Врач говорит пациенту:\n— Операция обойдется Вам в пятьсот франков.\n— Это грабеж! Лучше я умру!\n— Не советую. Вы знаете, сколько сейчас стоят похороны?',
    'Осмотрев пациентку, врач говорит ей:\n— Вы сможете полностью излечиться, если перестанете играть на пианино.\nКогда пациентка ушла, медсестра удивленно спрашивает:\n— А что общего между ее болезнью и пианино?\n— Есть кое-что, — говорит врач, — она живет надо мной.',
    'Мужчина приходит на прием к врачу.\n— Доктор, я так волнуюсь, мне жена изменяет, а рога у меня почему-то не растут.\nВрач:\n— А они и не должны расти, это просто образное выражение.\nМужчина:\n— Спасибо, доктор. Вы меня успокоили, а то я начал волноваться, может, кальция в организме не хватает.',
    'Пациент спрашивает у врача:\n— Что означает в моем диагнозе: Ч.Е.З.?\n— Черт его знает.',
    'В гостях у судмедэксперта за столом.\n— Сколько лет Вы мне дадите? — спрашивает его одна дама.\n— По цвету губ — семнадцать, по изгибу бровей — шестнадцать, по цвету лица — двадцать, а всего пятьдесят три.',
    'Разговаривают два старых врача:\n— У меня был больной, который по всем прогнозам должен был умереть еще десять лет назад, а он все живет.\n— Да, так бывает. Это еще раз доказывает, что когда больной действительно хочет жить, то медицина бессильна.',
    'Врач спрашивает родственников:\n— Больной перед смертью потел?\n— Да.\n— Это хорошо.',
    'В медицинском институте профессор:\n— Прежде, чем назвать тему лекции, я хочу вспомнить случай из собственной жизни. Когда я сам был студентом, мне нравилась одна девушка. Нравилась она и моему другу Она отдала предпочтение моему другу и я остался с носом, а тот молодой человек — без носа. Тема сегодняшней лекции — "Сифилис и его".',
    'Больной приходит к хирургу.\n— Доктор, у меня болит живот.\nТот осмотрел пациента и говорит:\n— Давайте я Вам ухо отрежу.\nБольной возмутился и ушел. Приходит к терапевту.\n— Доктор, у меня болит живот. Пришел к хирургу, а он мне предлагает ухо отрезать.\n— Этим хирургам только бы резать. Я Вам пропишу таблетки и через месяц уши сами отвалятся.',
    'Когда больного положили на операционный стол и дали наркоз, последнее, что он видел — это маленькую бородку хирурга. Очнувшись после операции, он увидел, что у хирурга большая окладистая борода.\n— Доктор, неужели так долго шла операция, что у Вас выросла такая большая борода?\n— Ты что, с ума сошел? Я же апостол Петр!',
    'Пациент приходит к хирургу.\n— Доктор, отрежьте мне, пожалуйста, член.\n— Да Вы что?\n— Доктор, я Вас очень прошу! Мне очень надо!\n— Ну надо, так надо.\nПосле операции хирург вновь обратился к пациенту:\n— Зачем Вы это сделали? Вы такой молодой, красивый мужчина, в полном расцвете сил. У Вас вся жизнь впереди, у Вас могло быть столько женщин. Скажите мне, зачем Вам это было нужно?\n— А понимаете, доктор, я женюсь на еврейке, так у них такой обычай.\n— Так, может, Вам надо было сделать обрезание?\n— А я Вам как сказал?',
    'Операционная. Больной уже на столе, спрашивает у хирурга:\n— Доктор, а после удаления аппендицита я смогу играть на скрипке?\n— Конечно сможете, — немного подумав, ответил доктор.\n— Честное слово? — не унимался больной.\n— Честное слово.\n— Любопытная операция. Никогда на скрипке не играл, а теперь буду.',
    'Хаим пришел к доктору.\n— Помогите. Я не могу удовлетворить жену.\n— Вот Вам совет. Придите домой среди дня, быстро разденьтесь догола и бросайтесь на жену. Эта неожиданность возбудит вас обоих.\n— Ну как? — спрашивает доктор во время второго визита.\n— Вы знаете, жена испугалась, но дети так смеялись.',
    'Зубной врач, вызванный по телефону, возвращается и спрашивает ассистентку:\n— Есть еще пациенты?\n— Да, есть один, он у Вас в кабинете.\n— Так почему же Вы не готовите инструменты?\n— Он заперся изнутри.',
    'В сумасшедшем доме один больной на обходе жалуется врачу:\n— Безобразие, ко мне в палату поселили больного, который каждую ночь воображает, что он светильник.\n— Ну и пусть себе воображает.\n— Да, но я не могу спать при свете.',
    'Пациентов психбольницы перевозят в другой город, в другую больницу на самолете. Стюардесса выдала всем по бутылке минеральной воды. Через некоторое время возвращается в салон — все кресла пустые, люк открыт, сидит только один пассажир.\n— А где остальные? -\nПошли бутылки сдавать.\n— А ты?\n— А у моей бутылки горлышко отбито.',
    'В сумасшедшем доме больной тащит по полу за веревку зубную щетку. Подходит врач.\n— Что, с собачкой прогуливаетесь?\n— Это щетка.\nВрач отошел. Псих зашел за угол и говорит, обращаясь к щетке:\n— Ну что, Бобик, здорово мы его надули?',
    'Женщина жалуется врачу психиатру:\n— В последнее время муж ведет себя очень странно Выпив кофе, он съедает фарфоровую чашечку, оставляя только ручку.\n— Странно, — говорит врач, — ведь ручка — это самое вкусное.',
    'В сумасшедшем доме один из больных, приставив гвоздь шляпкой к стене, бьет по острию молотком. К нему подходит другой больной:\n— Вот и правильно тебя запрятали в сумасшедший дом. Неужели не соображаешь — это гвоздь от той стены!',
    'Молодой человек объясняет врачу психиатру, что на прием его заставили прийти родственники и только по той причине, что он предпочитает хлопчатобумажные носки и не любит синтетические.\n— Что ж тут такого? Я тоже предпочитаю хлопчатобумажные, говорит врач.\n— Правда?! — радостно восклицает пациент. — Вы как предпочитаете, с маслом или с майонезом?',
    'Медсестра идет мимо палаты дистрофиков и слышит душераздирающий крик:\n— Помогите!\nЗашла в палату. Никого нет. Только вышла — опять:\n— Помогите!\nОна заходит в палату и спрашивает:\n— Где Вы?\n— Да здесь, под плинтусом!\n— А как Вы туда попали?\n— Клопы затащили.',
    'Осмотрев пациента, врач отводит его жену в сторону и говорит:\n— Знаете, Ваш муж мне не нравится.\n— Мне тоже, доктор, но дети его очень любят.',
    'У одного человека заболело горло и он мог говорить только шепотом. Вспомнив, что недалеко живет знакомый врач, пошел к нему. Звонит. Дверь открывает жена. Он спрашивает шепотом:\n— Коля дома?\nОна тоже шепотом:\n— Нет. Заходи.',
    '— Доктор, я все время разговариваю сам с собой. Не могу ли я от этого свихнуться?\n— Никто еще от этого с ума не сходил.\n— Да, доктор, но Вы не знаете, какой я нудный.',
    '— Каждую ночь, доктор, мне снится один и тот же сон: передо мной дверь с надписью. Я ее толкаю, но никак не могу открыть.\n— А что написано на двери?\n— "На себя".',
    'Пациент врачу:\n— Скажите, доктор, я буду жить?\nВрач:\n— А смысл?',
    '— Правда ли, доктор, что женщины живут дольше мужчин?\n— Во всяком случае вдовы — да.',
    '— Доктор! Соседи считают меня сумасшедшим за то что я обожаю сосиски.\n— Какие глупости! Я тоже люблю сосиски.\n— О! Тогда пойдемте ко мне, я покажу Вам свою коллекцию.',
    'Очередь к гинекологу. Подходит мужчина и спрашивает:\n— Кто последний?\nЕму говорят, что это очередь к гинекологу.\n— Да, да, я знаю, — отвечает он.\n— Но это женский врач.\n— Но это ведь он спиральки вставляет?\n— Да, он.\n— Значит, он и снимает.',
    'Психиатр успокаивает пациентку:\n— Вы говорите, что мимо Вашего окна ездят грузовики и шоферы заглядывают в спальню? Это еще не значит, что у Вас расстройство психики.\n— Правда, доктор?\n— Конечно.\n— Но я забыла Вам сказать, что живу на шестом этаже.',
    '— Доктор, пациент из 6 палаты чувствует себя лучше сегодня первый раз заговорил.\n— А что он сказал?\n— Что чувствует себя ужасно.',
    'Доктор:\n— Поскольку Вы пришли ко мне на прием впервые, мне кажется, что было бы лучше, чтобы Вы рассказали мне все с самого начала.\n— Конечно, конечно. Итак. Сначала Бог сотворил небо и землю…',
    'Профессор спрашивает молодого акушера, как идет практика.\n— Пока неважно, — говорит тот. — Принимал роды, мать погибла, ребенка тоже не удалось спасти, да еще вы — скользнули из рук щипцы и прямо в висок отцу…\n— Выше голову, коллега! — говорит профессор. — Первый блин всегда комом, вот вам адрес — примите роды вместо меня, а вечером сообщите о результатах.\nВечером ученик докладывает:\n— На этот раз куда успешнее! Отец жив…',
    'Врач встретил на улице жену своего пациента:\n— Скажите, — обращается он к ней. — Как чувствует себя Ваш супруг? Он уже избавился от рассеянности?\n— Как Вам сказать, доктор… Видимо, еще не совсем. Входя утром в кухню, он прежде всего стукает меня ложкой по голове, а затем целует яйцо всмятку,',
    'На приеме у психиатра:\n— Доктор, вчера я окончательно понял. Я стеклянный.\n— Не волнуйтесь, сейчас мы Вас осмотрим.\nМедицинским молоточком врач стукнул пациента по коленке.\n— Дзинь, — сказал тот и разбился.',
    'Приходит женщина к врачу.\n— Доктор! Мой муж говорит, что у меня половая слабость.\n— А в чем это проявляется?\n— Никому не могу отказать.',
    'Пациент — психиатру:\n— Доктор! Благодарю Вас, что вылечили меня от мании величия.\n— Сколько миллиардов я Вам должен?',
    '— Боюсь, доктор, что у моего мужа серьезное психическое заболевание. Иногда я часами рассказываю ему что-нибудь, а затем обнаруживаю, что он не слышал ни слова.\n— Это не заболевание, мадам, — успокоил женщину доктор, — это дар божий.',
    'Дантист говорит пациенту:\n— Не нужно так широко раскрывать рот.\n— Но Вы же сами сказали, что нужно ввести туда зеркальце, щипцы, инструменты?\n— Да. Но сам-то я остаюсь снаружи.',
    'Дряхлый, но богатый банкир Айзерман женился на молоденькой.\nПриходит к врачу и просит:\n— Доктор! Сделайте так, чтобы мое супружество было не только формальным.\nВрач осматривает его и говорит:\n— Увы. Вам уже ничто не поможет.\n— А пчелиное молочко?\n— Господин Айзерман! Я могу прописать Вам пчелиное молочко. Я могу сделать так, что Вы даже будете жужжать, но жалить — это извините.',
    'Врач имел привычку, принимая больного, все время говорить "мы".\n— У нас болит живот, и нам очень плохо. Кроме того, мы чихаем. Что же мы должны будем сейчас сделать?\n— Я думаю, — заметил больной, — что нам с Вами вместе следует пойти к другому врачу.',
    'Пациент отоларингологу:\n— Доктор, у меня вилка в ухе.\n— Прием окончен, я работаю до 7.\n— Но у меня страшные боли!\nДоктор вырывает вилку из уха и втыкает ее в глаз пациенту:\n— Идите к окулисту — он до 8.',
    '— Доктор, я пришел посоветоваться. Каждое утро в 7 часов у меня обязательно бывает стул.\n— Ну и что ж здесь плохого?\n— Но просыпаюсь-то я в 8.',
    'Пациент:\n— Доктор, у моей жены там рыжие волосы.\n— Вам это мешает?\n— Мне нет, но друзья смеются.',
    'В палате дистрофиков:\n— Петя, прикати таблетку.\n— А почему сразу Петя? Пусть Иванов прикатит. Он сильный. Он майку носит.',
    '— Доктор, Вы знаете, — говорит смущенный молодой человек, — у одного моего знакомого подозрение на венерическое заболевание.\n— Ну что ж, — говорит доктор. — Снимайте штаны и показывайте своего знакомого.',
    '— Доктор, помогите, — жалуется больной. — Все болит. И тут болит, и тут, и печень болит.\n— Одеколон пьете? — спрашивает доктор.\n— Пил, не помогает.',
    'В кабинете невропатолога:\n— Вам приходилось переживать нервные потрясения?\n— Да, однажды, прямо у меня на глазах компьютер спиртом промыли.',
    'Женщина — врач с простуженным горлом тихо говорит своему пациенту:\n— Раздевайтесь.\n— А Вы? — тихо спрашивает вошедший.',
    'Пришла к гинекологу бабка:\n— Милок, помирать пора, а я все в девках. Неудобно как-то. Помоги мне, я тебе четыреста рублей дам.\n— Да ты что, бабка!\nА потом подумал и говорит:\n— Ладно, давай, бабка.\nПришел в соседний кабинет. Там студент-практикант. Он ему говорит:\n— Зайди ко мне в кабинет, там нужно с бабкой переспать — стольник будет. Студент согласился.\nВрач привел к нему бабку и ушел. Три часа, четыре… Не выходит бабка. "Что такое?" — думает врач. Вошел — видит, сидит голый студент.\nОкно раскрыто.\n— Эй, а бабка где?\n— Бабке понравилось, за седьмой сотней побежала.',
    'Приходит женщина к гинекологу:\n— Доктор, у меня там живет мышка.\nДоктор осмотрел пациентку и говорит:\n— Ого. Да у Вас там не мышка, у Вас там кирпич.\n— Ну да. Вот сразу за кирпичом и мышка.',
    'Приходит комиссия в дурдом. Видит — бежит мальчик.\nСпрашивают:\n— Мальчик, как тебя зовут?\n— Нежняю.\n— А кем ты хочешь стать?\n— Нежняю.\nВстречают девочку:\n— Девочка, как тебя зовут?\n— Нежняю.\n— А кем ты хочешь стать?\n— Нежняю.\nНаказали главврачу, чтобы через месяц все знали. Приезжают через месяц — спрашивают мальчика:\n— Тебя как зовут?\n— Коля.\n— А кем хочешь стать?\n— Космонавтом.\nСпрашивают девочку:\n— Тебя как зовут?\n— Оля.\n— А кем хочешь стать?\n— Космонавтом.\nХвалят врача:\n— Молодец! Как Вы добились таких успехов?\n— Нежняю.',
    '— Доктор, мы с женой часто ссоримся. Что делать?\n— Ходите больше пешком, не менее 5 миль в день. Это хорошо укрепляет нервы. Делайте так и позвоните мне через пару недель.\nЧерез две недели звонит телефон:\n— Доктор, Ваш совет здорово мне помог.\n— Что, не ссоритесь с женой?\n— Нет. Я ведь теперь в 60 милях от дома.',
    'Телефонный звонок директору цирка:\n— Скажите, пожалуйста, Вам не нужна говорящая лошадь?\nДиректор раздраженно бросает трубку. Снова звонок.\n— Скажите все-таки, Вам не нужна говорящая лошадь?\n— Перестаньте хулиганить!\nСнова звонок.\n— Слушай, идиот! Ты думаешь, мне легко набирать копытом номер?',
    '— Ты слыхал, в наш город приехал цирк! Надо пойти, там такие штуки показывают!\n— А что именно?\n— Представь себе: совершенно голая баба на слоне!\n— Пожалуй, пойду. Я уже лет десять, как слона не видел.',
    'Молодой артист впервые собирается выехать с цирком на гастроли. Друзья ему говорят:\n— Ты хоть чемодан купи себе в дорогу.\n— Зачем?\n— Положишь туда брюки, пиджак, белье…\n— А в чем же я тогда поеду?',
    'Один человек пришел к директору цирка с двумя большими чемоданами и продемонстрировал свой номер. Раскрыл первый чемодан — он полон кирпичей. Человек клал кирпич на голову, а его ассистент кувалдой разбивал кирпич. За десять минут он перебил все кирпичи. Директор заявляет:\n— Я беру Вас. А что у Вас во втором чемодане?\n— Анальгин.',
    'К директору цирка приходит наниматься на работу человек.\n— А что Вы умеете делать? — спрашивает директор.\n— У меня уникальный номер. Посредине арены ставят открытую бутылку с водой. Я забираюсь под купол, прыгаю вниз и ныряю прямо в бутылку.\n— Это невозможно!\n— Вам я открою свой секрет. Подлетая к бутылке, я быстро достаю из кармана маленькую воронку и вставляю в горлышко.',
    'Актер — директору цирка:\n— Вы можете смело нанять меня в качестве клоуна, месье, я рассмешу и мертвого.\n— К сожалению, у нас несколько другая клиентура.',
    'Две дрессировщицы собак хвастаются:\n— Моя Джильда читает газеты.\n— Знаю, мне про это говорил мой Шарик.',
    '— Вам требуются канатоходцы? — спросили директора цирка.\n— Очень. Но только умеющие ходить поперек каната.',
    'К директору цирка приходит фокусник.\n— Я подготовил новый номер. Я распиливаю женщин пополам.\n— Ну что же тут нового, это многие делают.\n— В длину?',
    '— Кто эта внушительного вида дама?\n— Она раньше выступала в цирке, пела в клетке со львом.\n— Почему она перестала выступать с этим львом?\n— Этого потребовало общество охраны животных.',
    'Мальчик с отцом в цирке. Ведущий объявляет:\n— Смертельный номер! Тройное сальто под куполом цирка!\nПосле исполнения все аплодируют. Мальчик спрашивает:\n— Пап, а почему называется "смертельный" номер? Ведь никто же не умер? Папа, папа!.. Па-а-а-па!!!',
    'В цирке в первом ряду сидят пожилые супруги. На манеже в клетке хищники.\nМуж говорит:\n— Как ты думаешь, Эльза, что бы мог сказать этот тигр, если бы он мог разговаривать?\n— Я леопард, Эльза, — послышалось из клетки.',
    'Фокусник позвал на манеж из зрительного зала мальчика:\n— Можешь ты, мальчик, подтвердить, что видишь меня впервые?\n— Да, папа.',
    'В передвижном цирке шапито коронным номером выступают дрессировщик со старым львом. В кабинет директора вбегает испуганный униформист:\n— У дрессировщика в револьвере патроны закончились!\n— Ну и что? Зачем ему патроны?\n— Дело в том, когда он перестает стрелять, лев засыпает.',
    'В передвижном цирке случилась беда. Обрушилась крыша шапито.\nДиректор цирка чертыхается:\n— Какой мерзавец подсунул нюхательный табак слону?',
    'Лозунг:\nСтуденты! Сдадим наши посредственные знания на "хорошо" и "отлично"!',
    'Во время экзамена преподаватель спрашивает студента:\n— Знаете ли Вы, что такое экзамен?\n— Это беседа двух умных людей о предмете.\n— А если один из них идиот?\n— Значит, другой не получит стипендию.',
    'В трамвае сидит старушка и замечает стоящего рядом худого изможденного юношу. На его руке висит плащ.\n— Милый, откуда ты такой заморенный?\n— Студент я.\n— Наверное, отличник, раз такой замученный?\n— Да нет, я средне учусь.\n— Ну давай я хоть твой плащ подержу, все легче будет стоять.\n— Это не плащ, это, бабушка, студент Сидоров — вот он отличник.',
    'Студент танцевал с девушкой и вдруг упал.\n— Воды! Воды! — закричала девушка.\nПрибежали с водой и поднесли к губам пострадавшего стакан. медленно открыл глаза и тихо прошептал:\n— И хлеба.',
    'Студент подходит к буфетной стойке:\n— Дайте, пожалуйста, две сосиски.\nОчередь (с ненавистью):\n— Шикуешь?!\n— И шестнадцать вилок, пожалуйста.',
    '— Ну что, Люсик, сдал? — спрашивает друг выходящего из аудитории абитуриента.\n— По-моему, да…\n— И что тебя спрашивали?\n— Откуда я могу знать, ведь он же спрашивал на английском языке!',
    '— Т-т- товарисч преподаватель, а м-может с-сту-дент в пьяном виде с-сдать экзамен?\n— Вообще-то может…\n— Ребята, заноси!',
    'Людоед кого — то тащит. Навстречу идет его друг.\n— Кого это ты тащишь?\n— Студента.\n— Кого? Студента? Выброси его. Я вчера одного студента варил, так он, пока вода закипала, всю картошку съел.',
    'Грузин пишет письмо домой:\n— Мама, учусь в институте. Все ездят на занятия в автобусе, а я в такси.\nМать пишет ответ сыну:\n— Сынок, зачем выделяться. Купи автобус и езди, как все.',
    'Собрались мужики выпить, да не хватает двадцать копеек. Вдруг идет парень.\n— Парень, дай двадцать копеек.\n— Мужики, нет у меня.\n— Давай, иначе побьем.\n— Да нету у меня!\n— Ты кто?\n— Студент.\n— Федя, дай ему двадцать копеек!',
    'Родители дочери-студентке:\n— Говори сейчас же! Где ты была всю ночь?\n— На лекции.\n— Что, до четырех утра шла лекция?\n— Да. Лектор оказался заикой.',
    'Экзамен в вузе. Преподаватель спрашивает студентов:\n— Вопрос на "пятерку". Как меня зовут?\nВсе молчат.\n— Вопрос на "четверку". Что сдаем?\nВсе молчат.\n— Вопрос на "тройку". Какого цвета учебник?\nС задних рядов приглушенный голос:\n— Во валит, гад!',
    'На госэкзамене в мединституте. Лежат два скелета. Председатель комиссии спрашивает выпускников:\n— Что вы можете про них сказать?\nВыпускники молчат.\n— Ну чему же вас учили все эти шесть лет?\nГолос с места: — Неужели Маркс и Энгельс?',
    'Идет студент по улице и видит, как какой-то парень пинает ногами булочку. Студент подбегает к нему:\n— Ты что? Это же булочка!\n— Тихо, ты. Затолкаю за угол — вместе съедим.',
    'Экзамены в институте. Перед студентом поставили три банки с заспиртованными мозгами. Студент отвечает:\n— Вот в этой банке мозг профессора. В этой — солдата. А в этой, с одной извилиной, прапорщика.\nЭкзаменатор:\n— Все правильно. Только в третьем случае небольшая ошибка. Это не извилина, а след от фуражки.',
    'Студент копает землю. Другой спрашивает:\n— Что делаешь?\n— Понимаешь, дали задание: найти квадратный корень. Третий день копаю, но только все круглые попадаются.\n— Это что. Иванову дали задание член на многочлен разложить. Он сидит, ножик точит, а у самого слезы текут.',
    'Идет экзамен в музыкальном училище. Одна студентка ничего не знает, и договорилась с одним другом, что он ей в окно подсказывать будет. Заходит в кабинет. Преподаватель говорит:\n— Я буду сейчас играть отрывки из музыкальных произведений, а Вы будете говорить, какой это композитор.\nНачал играть, а парень ей в окно листком кленовым машет. Она говорит:\n— Это Лист.\n— Правильно, — играет дальше.\nПарень ей пачку чая показывает:\n— Это Чайковский.\n— Тоже правильно, — играет дальше.\nОна отвечает:\n— Херников.\n— Не Херников, а Хренников! Молодой человек, уберите шпаргалку!',
    'Два карманника разговаривают в тюрьме:\n— Видал, какие замечательные часы у надзирателя?\n— Еще нет. Покажи.',
    '— Скажите, Гоша дома?\n— Он на даче.\n— Как, у Вас есть дача?\n— Нет. Он в прокуратуре на даче показаний.',
    '— Почему Вы бежали из тюрьмы?\n— Я хотел жениться.\n— Хм… Странное у Вас представление о свободе.',
    'В суде идет процесс. Судья спрашивает подсудимого:\n— Ваша профессия?\n— Акробат.\n— Сержант, закройте окно.',
    'После свидания с мужем, отбывающим тюремный срок, жена приходит к начальнику тюрьмы и просит дать ее супругу работу полегче.\n— У нас еще никто не надрывался на клейке бумажных пакетов, — сказал начальник.\n— О да! Но муж говорит, что по ночам он копает еще какой-то тоннель.',
    'Мальчик:\n— Господин полисмен! Идите скорее во двор. Там папа уже полчаса дерется с грабителем.\nПолисмен:\n— Почему же ты меня раньше не позвал?\n— Дело в том, что папа до последней минуты побеждал.',
    'Судят убийцу, который убил старушку с целью ограбления.\nСудья:\n— За что Вы убили старушку? У нее в кошельке было только 20 копеек?\nУбийца:\n— Ну и что? А пять старушек — это уже рубль.',
    'Слушается дело об убийстве. Слово подсудимому:\n— Играли мы в преферанс. Я — червой, покойничек — козырем. Я — червой, покойничек — козырем. Я — чер — вой, покойничек — козырем. Я — червой и покойничек — червой.\nСудья вскакивает:\n— Так за это же канделябром по голове!\n— Вот я так и сделал.',
    'В милицию прибегает женщина:\n— Меня изнасиловали двенадцать человек!\n— Не волнуйтесь, гражданка, всех найдем.\n— Всех не надо, только третьего, восьмого и двенадцатого.',
    'Молодого парня сажают в тюрьму. Надзиратель подводит его к камере. Там сидят рецидивисты и все в наколках.\n— Ой, дяденька! Только не сюда!\nНадзиратель подводит его к другой камере, где сидит старенький дед.\n— Вот сюда пойду, — говорит парень.\nВ камере спрашивает:\n— За что сидишь, дед?\n— За людоедство, сынок.',
    'В общую тюремную камеру приводят новичка. Его спрашивают:\n— Какой срок дали?\n— Восемь лет.\n— За что?\n— За оказание первой помощи человеку.\n— Как это так?\n— Да сидели мы за столом, ужинали, а у тещи кровь носом пошла. Чтобы кровотечение остановить, я ей на шею жгут наложил.',
    'У наружного окна следственного изолятора:\n— Значит, правду сказали, что ты здесь?\n— Как видишь.\n— Ну и как тебе тут?\n— Еще спрашиваешь. Койка, каша и параша.\n— Идиот! Ты же мог это и дома иметь.',
    '— Подсудимый! Где Вы взяли золото?\n— В тумбочке.\n— Кто его туда положил?\n— Жена.\n— А кто ей дал?\n— Я дал.\n— А Вы где взяли?\n— В тумбочке.',
    'Вор говорит сыну:\n— Бью тебя не за то, что ты втихомолку съел варенье, а за то, что на банке оставил отпечатки пальцев.',
    'В тюремной камере:\n— Ты из-за чего сюда попал?\n— Из-за насморка.\n— Как это?\n— Очень просто. Я чихнул, а сторож проснулся.',
    '— Когда я сегодня утром пришел домой, жена сказала, что ночью забрался вор.\n— И что же с ним стало?\n— Лежит в больнице. Жена подумала, что это я вернулся.',
    'Новенький спрашивает у тюремного надзирателя:\n— А решетки на окнах зачем?\n— Для надежности.\n— Глупости. Что в такой тюрьме можно украсть?',
    'Заключенный жалуется охраннику:\n— Питание у вас отвратительное. Представьте себе, в котлете нашел пистолет, а в супе патроны.',
    'Холмс и Ватсон заночевали на лоне природы. Ночью Ватсон проснулся.\n— Скажите, Холмс! Почему, когда мы ложились спать, была темнота, а теперь над нами звездное небо?\n— Это элементарно Ватсон — у нас сперли палатку.',
    'Жена свидетельствует на процессе мужа, обвиняемого в совершении тяжелой аварии.\n— Свидетель! — обращается к ней судья. — Расскажите, как это произошло?\n— Значит, так, — начинает жена. — Я управляла автомобилем, а муж сидел за рулем…',
    '— Гражданин подсудимый! Вы признаете себя виновным в групповом изнасиловании?\n— Нет.\n— Группа изнасилованных, встаньте.',
    'Действие происходит в самолете. В кабину пилота забегает мужчина с автоматом и командует:\n— Летим в Швецию!\nПилот:\n— Нет, мы полетим в деревню Кукушкино!\n— Нет, в Швецию!\n— Нет, в Кукушкино!\n— А почему в Кукушкино?\n— Это ты спроси у бабушки с минометом.',
    'Трое подсудимых сидят в камере. Их по очереди вы — водят на суд.\nПервый возвращается. — Пять лет.\nВторой приходит. — Восемь.\nТретий. — Вышка. Наверное, вас охранять буду.',
    'В перерыве судебного заседания адвокат удрученно говорит своему подзащитному:\n— Я исчерпал уже все доводы в Вашу пользу. Не знаю, что я еще могу для Вас сделать?\n— А что если Вы всю вину возьмете на себя.',
    'В камеру, в которой сидят четверо отпетых уголовников, поместили маленького, тщедушного старичка.\n— А тебя-то за что, божий одуванчик? — спрашивают сокамерники.\n— Приколист я! — отвечает старичок.\n— Это еще что?\n— Приколы устраиваю.\n— Какие приколы? Покажи?\n— Да нет, братцы, не надо. Вы еще недовольны будете, еще побьете.\n— А ну показывай! Ничего тебе за это не будет. Гадом буду.\n— Только уж потом не серчайте! — вздохнул старичок.\nВзял веник, сунул его в парашу, поболтал, потом постучал в дверь камеры, а когда в двери открылся глазок, старик сунул в него веник и быстро провернул его пару раз. Через несколько минут дверь открылась и в камеру вошли десять дюжих охранников.\n— Так, — сказал старший из них, оглядываясь. — Ну-ка, дедуля, отойди в сторону…',
    'Посадил дед репку. А Репка вышел из тюрьмы и убил дедку.',
    'В квартиру звонок. Открывает хозяйка, а на пороге два здоровенных амбала.\n— Рэкетиров заказывали?\n— Нет.\n— Тогда платите десять тысяч за ложный вызов.',
    '— Товарищ милиционер! Скажите, по этой улице ходить не опасно?\n— Было бы опасно, я бы здесь не стоял.',
    'Ночью в темном переулке встречаются двое:\n— Гражданин, Вы не видели где — нибудь здесь милиционера?\n— Нет, не видел.\n— Тогда снимайте пальто.',
    'В зале суда.\n— Знаете ли Вы, что вас ожидает за дачу ложных показаний?\n— Да, мне обещали "Жигули".',
    '— Подсудимый! Почему Вы отказываетесь от последнего слова?\n— Думаю, что это ни к чему, господин судья. Все, что нужно было сказать, сказал мой адвокат, а все, что не нужно было говорить, сказал мой прокурор.',
    'В купе одинокий пассажир. Входит грабитель, в руке пистолет:\n— Деньги — живо!\n— У меня ни гроша…\n— Так что ж ты тогда трясешься?\n— Я думал, ты контролер.',
    'В тюремной камере один уголовник рассказывает другому:\n— Эх, до чего же мы с женой приятно проводили время на берегу моря! Бегали, прыгали, закапывали друг друга в мягкий беленький песочек… Пожалуй, когда выйду на свободу, — съезжу, откопаю ее.',
    'Грабитель фомкой отжимает дверь квартиры. Приоткрывается соседняя дверь, из-за которой слышится:\n— Драгоценности они прячут в саксонской вазе, а деньги под аквариумом.',
    'Вор пришел за отпущением грехов в церковь. Но по инерции украл часы у пастора.\n— Скажи, — спросил его пастор, — какие на твоей совести грехи?\n— Украл часы у одного хорошего человека, хотите я Вам их отдам?\n— Нет, их нужно вернуть тому, кому они принадлежат.\n— Но он этого не хочет.\n— Раз так, оставь их у себя и не печалься.',
    'У адвоката:\n— Хочу развестись с женой!\n— Пожалуйста, 1000 долларов.\n— Что? Вы с ума сошли! За пятьсот долларов ее берутся пристрелить.',
    '— Обвиняемый! Объясните присяжным заседателям, почему Вы убили свою жену вместо того, чтобы убить ее любовника?\n— Я рассудил, Ваша честь, что гораздо разумнее убить одну женщину один раз, чем каждую неделю убивать по новому мужчине…',
    '— У меня есть мечта, — сказал один гангстер другому. — Ограбить банк и оставить при этом отпечатки моей тещи.',
    'Судья подсудимому:\n— Ну, ну, перестаньте волноваться и расскажите, как это произошло?\n— Я ужасно расстроен. А было так. Я сидел и чистил ножичком апельсин. Тут подошел этот тип, поскользнулся на апельсиновой корке и упал прямо на нож.\nСудья:\n— И так три раза подряд?',
    'Судья:\n— Что побудило Вас ударить жену?\nПодсудимый:\n— Судите сами, Ваша честь. Она стояла ко мне спиной, под рукой у меня была сковородка, а дверь позади меня была открыта. Ну как было не воспользоваться таким благоприятным стечением обстоятельств.',
    '— За что Вы сидите?\n— Представьте, что однажды выяснилось, что государство выпускает точно такие же банкноты, как и я.',
    'В суде.\n— Обвиняемый, Вы именно так совершили кражу, как это объяснил в своей речи прокурор?\n— Не совсем так, но его метод тоже заслуживает внимания.',
    'Начальник тюрьмы вызвал в канцелярию арестанта, который отбыл свой срок.\n— Вы выходите на свободу, — сказал начальник, — надеюсь, что Вы начнете честную жизнь.\n— Ах, господин начальник, — вздохнул арестант. — Я не в том возрасте, когда пускаются на эксперименты.',
    'На суде прокурор спрашивает убийцу:\n— Подсудимый! Объясните, почему Вы, прежде, чем взломать шкатулку, убили старушку, спавшую в другой комнате?\n— А на шкатулке было написано: "Вскрыть только после моей смерти".',
    'В грузинском суде.\nСудья — обвиняемому:\n— Ваше последнее слово?\n— Миллион и ни копейки больше.',
    'Заключенного ведут на расстрел. Он спрашивает конвойного:\n— Какой сегодня день недели?\n— Понедельник, — отвечает тот.\n— Ничего себе неделька начинается.',
    'Идет симпозиум воров всего мира.\nВстает вор из Франции и просит погасить свет на 30 секунд. Через 30 секунд с того же места, на котором он стоял, говорит:\n— Господин в белом смокинге, на противоположной от меня трибуне, возьмите свою авторучку.\nПосле чего встал американец. История повторилась. После американца встал русский и сказал:\n— Свет тушить не надо. Вася, раздай всем носки.',
    'Пропала любимая собака тещи. Черная, злая, жрет за троих, кусается, все запоминает. Кто знает местонахождение — просьба молчать.',
    'Преподаватель военного училища снимет квартиру с телефоном, радаром, ракетной установкой.',
    'В связи с ремонтом парикмахерской укладка женщин будет производиться в мужском зале.',
    'В газете:\nМедленно работающая стенографистка — машинистка ищет заикающегося директора.',
    'На столбе:\nПеревожу с НЕМЕЦКОГО и АРМЯНСКОГО на ВАГАНЬКОВСКОЕ.',
    'Меняю одну национальность на две судимости. Согласен на любые сроки.',
    'Пропал большой черный дипломат. Нашедших просим вернуть его в посольство Нигерии.',
    'В похоронном бюро:\nС 1-го числа исполнение похоронного марша будет стоить в четыре раза дороже. Для тех, кто не может уплатить по новому тарифу, похоронный марш будет исполняться в четыре раза быстрее.',
    'Объявление в "Вечерней Одессе":\nВчера вечером в порту загуляла и не вернулась домой сука пегой масти с белой грудью по кличке "Маня". Нашедшего просят передать ей, что, если сунется домой, муж ее пристрелит.',
    'Объявление:\nМолодая семья снимет комнату на два часа. Прописка необязательна.',
    'Увидев в окне конспиративной квартиры тридцать три утюга и тринадцать пар обуви, направленной носками на северо-запад, Штирлиц понял, что явка провалена.',
    'Профессор Плейшнер восьмой раз бросался с пятого этажа, но яд все не действовал.',
    'Штирлиц отправил донесение в Центр открытым текстом. Через пять минут к нему ворвались эсэсовцы.\n— С первым апреля! — пояснил Штирлиц.\nЭсэсовцы понимающе заулыбались, в это время в Центре хохотали до упаду.',
    'Проходя по коридору, Штирлиц толкнул дверь кабинета Бормана. Дверь не открылась. Штирлиц толкнул сильнее. Дверь не открылась. Тогда Штирлиц разбежался и ударил дверь плечом. Дверь не открывалась.\n— Заперто, — подумал Штирлиц.',
    'Мюллер сидел у себя в кабинете и читал газету. Ему в глаза бросилось одно объявление:\n"Поп-группе срочно требуется пианистка".\n— Обнаглел пастор, — подумал Мюллер.',
    'Штирлиц выглянул в окно и увидел, что немцы ставят танк на попа.\n— Бедный пастор Шлаг, — подумал Штирлиц.',
    'Идя по еле заметной на снегу тропинке, Штирлиц услышал раздавшееся из сугроба зловещее шипение. Он выхватил парабеллум и выпустил в сугроб всю обойму, после чего продолжил свой путь. И только через пять минут Штирлиц вспомнил, что пастор Шлаг так и не научился свистеть.',
    'Придя к себе в кабинет, Мюллер увидел Штирлица, подозрительно сидящего возле сейфа.\n— Что Вы здесь делаете, Штирлиц?\n— Трамвая жду, — ответил Штирлиц.\nМюллер вышел и, проходя по коридору, неожиданно подумал:\n— Какой к черту может быть трамвай в моем кабинете?\nОн вбежал обратно. Штирлица не было.\n— Наверное, уже уехал, — подумал Мюллер.',
    'Штирлиц стоял, склонившись над картой мира. Его неудержимо рвало на Родину.',
    'Подойдя к лесу, Штирлиц увидел: голубые ели. Когда он подошел поближе, то увидел, что голубые не только ели, но и пили.',
    'Мюллер гулял по лесу. Где-то стучал дятел.\n— Дятел, — подумал Мюллер.\n— Сам ты дятел, — подумал Штирлиц.',
    'Штирлиц пошел в лес за грибами. Искал, искал — ничего не нашел.\n— Да, видно не сезон, — подумал Штирлиц и сел в сугроб.',
    'Штирлиц вышел из дома и наткнулся на сук.\n— Шли бы вы домой, девочки, война все-таки.',
    'Штирлиц стрелял из двух пистолетов по очереди. Очередь быстро редела.',
    'Штирлиц заложил ногу за ногу. На следующее утро Ногу За Ногу взяли.',
    'Штирлиц топил печку. Через полчаса Печка утонула.',
    'Мюллер спросил Штирлица:\n— Где Вы, Штирлиц, научились так метко стрелять?\n— В ДОСААФе, — быстро ответил Штирлиц и подумал. "А не сболтнул ли я чего лишнего?"',
    'Мюллер шел по улице. Неожиданно ему на голову свалился кирпич.\n— Вот-те раз, — подумал Мюллер.\n— Вот-те два, — подумал Штирлиц, бросая второй.',
    'В секретном бункере идет совещание. Внезапно открывается дверь, заходит Штирлиц с подносом апельсинов в руке. Подойдя к сейфу, он открывает его, забирает документы, ставит поднос на стол и уходит.\n— Кто это? — закричал Гитлер.\n— Это русский разведчик Исаев! — хором закричали Мюллер и Шелленберг.\n— А почему же вы его не арестуете?\n— Бесполезно, все равно открутится, скажет, что апельсины приносил.',
    '— Барбара, у Вас не найдется чашечки кофе? — устало спросил Штирлиц.\n— Кофе нет, но есть чай. Нам вчера прислали настоящий индийский чай, — радостно захлопотала Барбара.\n— Да. Наши уже близко, — подумал Штирлиц.',
    'Штирлиц впопыхах застрелил Мюллера. На следующее утро в Попыхи приехал взвод карателей.',
    'Наступила весна. Снег давно растаял. Штирлиц явственно услыхал скрябание дерева об асфальт. Пастор Шлаг возвращался из Швейцарии на лыжах.',
    'Штирлиц ехал к Берлину. Город был окутан дымом пожаров.\n— Опять утюг забыл выключить, — с досадой подумал Штирлиц.',
    'Эсэсовцы перекрыли все выходы в доме Штирлица. Ему пришлось уходить через вход.',
    'Штирлиц заметил связную сразу. Она была в красном купальнике со звездой на груди. В руке она держала газету "Правда". Штирлиц незаметно подошел к девушке.\n— Который час? — игриво спросил он.\n— Часы забыла на Лубянке, — улыбнулась девушка. Это был пароль.',
    'Штирлиц остановил машину в лесу, откинулся на спинку виденья и закурил. А в это время глубоко под землей, в секретном бункере, Гитлер отчаянно оттягивал свой конец.',
    'Штирлиц шел в кафе "Элефант" на встречу с женой. Ее уже в четвертый раз везли через линию фронта и три границы, и каждый раз выяснялось, что это не его жена.',
    'Штирлиц стоял на своем. Это была любимая пытка Мюллера.',
    'На допросе Штирлиц порол чушь. Чушь тихо повизгивала.',
    'Мюллер:\n— Отвечайте, Штирлиц, где Вы были в 1938 году?\n— С Вами, шеф, в республиканской Испании.\n— А в 1928 году?\n— С Вами, на КВЖД.\n— Ну а в 1918 году?\n— Василий Иванович! Ты?\n— Я, Петька!!!',
    'Шелленберг дал Штирлицу наводку.\n"Немного, зато в валюте", — подумал Штирлиц, пряча в карман рейхсмарки.',
    'Штирлиц выстрелил в упор. Упор упал навзничь. Взничь подвинулась.',
    'Борман мирно спал. Вдруг в дверь его квартиры кто — то настойчиво постучал. Открыв дверь, Борман увидел человека в шинели, валенках, буденовке и ППШ за спиной.\nЧеловек сказал:\n— Слоны идут на север…\n— Слоны идут на х…! А Штирлиц живет этажом выше!',
    'Штирлиц выпил со смаком. Смак сегодня угощал.',
    'На поляне возле костра сидели люди.\n"Кастраты", — подумал Штирлиц.',
    'Раздался выстрел. По свисту ветра в голове Штирлиц понял, что ранение сквозное.',
    'Прекрасное раннее утро. Поляна цветов. Восходит солнце, поют птицы. Белая палатка. Из нее выходит в белоснежном белье поручик Ржевский. Он смотрит во — круг, вздымает вверх руки и восклицает:\n— Господи! Как же я раньше жил, не замечая этой красоты!\n— Мать… Мать… Мать… — привычно отозвалось эхо.',
    'Генерал пожелал иметь крокодиловые сапоги. Ночью спецрота десантируется на берег Нила. Проходит день, второй, месяц — новостей нет. Генерал сам вылетает к Нилу и вот что он видит: на берегу вдоль реки сидят солдаты. Весь берег завален трупами крокодилов. Из воды показался крокодил, в этот момент тяжелая дубинка опускается ему на голову. Вытащив крокодила на берег, старший группы кричит:\n— Товарищ капитан! Этот тоже без сапог!',
    'Война. Лыжный батальон в наступлении. Вечером привал. К командиру обращается солдат:\n— Товарищ майор, тут в двадцати километрах моя родная деревня. Три года не видел жену и детей.\n— А ты успеешь?\n— Я же на лыжах. Час туда, час обратно и час дома побуду.\nОтпустил командир солдата. Через три часа он вернулся довольный, счастливый. Окружили его все, спрашивают.\n— Ну как там дома?\n— Дома все хорошо. А вот кто отгадает, какие я первые два дела сделал дома, того угощаю самогоном и салом.\nПервое дело угадали сразу: понятно — жену столько не видел… А вот по поводу второго дела долго бились и никто отгадать не смог.\nТогда солдат усмехнулся и сказал:\n— Что же вы, догадаться-то не смогли? Вторым делом я лыжи снял.',
    'На бульваре встречаются два генерала пенсионера.\n— Помнишь, Коля, как нам в первую мировую войну в окопах давали такие таблетки, чтобы мы о бабах не думали?\n— Ну как же, помню, помню. Такие розовые.\n— Да. Так знаешь, они только сейчас на меня стали действовать.',
    'Три солдата соревнуются в меткости стрельбы.\nАнгличанин попал из винтовки в спичечный коробок на расстоянии двести метров.\nФранцуз попросил подбросить две монеты и двумя выстрелами попал в них.\nРусский стоял, смотрел по сторонам, потом поднял голову:\n— Слышите, комар летит?\n— Слышим.\nРусский выстрелил, но комариный писк продолжался.\n— Не попал, летает! — радостно закричали все.\n— Летать-то он будет, любить — никогда!',
    'Полковник спрашивает у жены:\n— Слушай, любовь — это работа или удовольствие?\n— Если бы это была работа, ты бы взвод солдат давно прислал.',
    'На стадионе корреспондент с магнитофоном берет интервью у болельщиков. Подходит к молодому парню.\n— Ваша любимая команда?\n— "Спартак".\nПодходит к группе девушек.\n— Девушки, какая ваша любимая команда?\n— "Динамо".\nПодходит к генералу.\n— Какая ваша любимая команда?\n— Моя любимая команда — "Смирно!".',
    'Комиссия по проверке техники приехала в танковую часть. Из бокса выходит пьяный лейтенант и, увидев генерала, подходит строевым шагом с докладом:\n— Товарищ генерал! Командир танкового корпуса — Петров!\nГенерал удивленно спрашивает:\n— Сколько служу, никогда не видел лейтенанта в должности командира танкового корпуса. Как Вам это удалось?\n— Все очень просто. Движок пропили, шасси пропили, пушку пропили, только корпус остался.',
    'Вечерняя проверка.\n— Сидоров?\n— Я.\n— Тебошвили? — Я.\n— Череззаборногузадерищенко?\n— Я.\n— Ох, и не черта себе фамилия.\n— Я.',
    'На политинформации командир взвода спрашивает:\n— Абульгетдинов, что такое Родина?\n— Не знаю.\n— Дурак! Родина, Абульгетдинов, — это твоя мать, понял?\n— Так точно.\n— Петров, что такое Родина?\n— Родина — это… мать Абульгетдинова.',
    'Командир роты, проходя по плацу, увидел лежащую голову.\n— Дневальный! Что это такое?\n— Голова, — отвечает дневальный.\n— Я вижу, что голова, но почему не стрижена?',
    'Старшина объясняет новобранцам суть земного притяжения.\n— Если, например, камень подбросить вверх, то он упадет на землю, это означает, что на него действует сила земного притяжения.\n— А если он упадет в воду? — спрашивает новичок.\n— Это нас не касается, этим занимаются на флоте.',
    'Стоит дневальный в казарме. Кругом чистота, а на полу лежит окурок. Заходит полковник, показывает на окурок и грозно спрашивает:\n— Чей?\n— Не знаю.\n— Узнать!\nДневальный убегает в казарму, через некоторое время прибегает и докладывает:\n— Товарищ полковник, "старики" сказали, что окурок ничей. Можете курить.',
    'У командира сломалась рация на бронетранспортере. Он построил личный состав и говорит:\n— У меня на бронетранспортере сломалась рация. Кто починит, поедет в отпуск.\nИз строя раздается голос:\n— Товарищ командир! У вас рация на чем, на полупроводниках или на лампах?\n— Повторяю для дебильных. На БРОНЕТРАНСПОРТЕРЕ сломалась рация.',
    'Перед строем курсантов стоит полковник и говорит:\n— Если вы такие тупые, что не можете запомнить приказ командира, то купите себе блокнот и записывайте, как это делаю я.',
    'В пустыне встречаются осел и прапорщик. Осел спрашивает:\n— Ты кто?\nПрапорщик посмотрел по сторонам — никого нет.\n— Я офицер, а ты?\nОсел посмотрел по сторонам и говорит:\n— А я лошадь.',
    'Прапорщик идет по дороге, тянет за собой веревку. Начальник штаба спрашивает:\n— Зачем Вы за собой веревку тащите?\nПрапорщик недоумевает:\n— А что, надо впереди ее толкать?',
    'Прапорщик наставляет солдата:\n— Все начинается с малого: сегодня ты не вышел на зарядку, завтра у не подшит воротничок, а в субботу ты пойдешь в увольнение, напьешься и убьешь человека.',
    '— Товарищ прапорщик, скажите что-нибудь…\n— Смирно!\n— Да нет. Что-нибудь ласковое, нежное…\n— Вольно.',
    'Генерал:\n— Товарищ прапорщик! Остановите поезд!\n— Поезд, стой! Раз, два!',
    'Генерал сидит в поезде и пишет мемуары. Под окном рокочет танк.\nГенерал высовывается из окна:\n— Товарищ прапорщик, заглушите танк!\n— А-а-а-а!..',
    'Из объяснительной:\n— Я выбежал в туалет, в чем мать родила: в трусах, майке и сапогах.',
    '— Товарищи бойцы! Времени у меня мало, поэтому буду говорить, не думая.',
    '— Короткими перебежками от меня до следующего дуба — марш!',
    '— Товарищ прапорщик! Расстегай — это рыба или мясо?\n— Дурак! Это команда!',
    '— Вы курсант или где? Вы в строю или кто?',
    '— Здесь вам не тут! Здесь вас быстро отучат водку пьянствовать и беспорядки нарушать!',
    '— Товарищи! Все, что запрещается, прошу всех соблюдать!',
    '— Водку в казарме пить?! Не позволю! Это вам не детский сад!',
    '— Когда курсанта ругают, он должен встать и покраснеть!',
    '— Сапоги нужно чистить с вечера, чтобы утром надевать на свежую голову!',
    'В воинскую часть приходит старушка:\n— Вызовите мне капрала Джима, я его бабушка.\nКапитан:\n— Это невозможно, мадам, так как капрал полчаса назад отпросился на Ваши похороны.',
    'В Уставе израильской армии появился новый пункт, 140 запрещающий отвечать вопросом на вопрос. Это связано с тем, что участились случаи, порой доходившие до курьеза.\nТак, один солдат на вопрос: "Где Вы были ночью?" — ответил:\n— А что, разве была атака?',
    'Лейтенант проверяет, как молодой солдат усвоил тему прошлого занятия.\n— Что бы Вы предприняли, в военное время, чтобы наши железные дороги не достались противнику?\n— Я бы сжег все железнодорожные билеты.',
    'Бегут по плацу три солдата. Майор их останавливает и спрашивает:\n— Ваши фамилии?\n— Рядовые Иванов, Петров, Сидоров!\n— Что, братья что-ли?\n— Никак нет.\n— А-а, однофамильцы?',
    '— "Скорая помощь"?\n— Да.\n— Скажите! Человек, который в 6 утра трубит в трубу и будит всех, нормален? Не могли бы вы прислать санитаров?\n— Адрес?\n— Кайзерштрассе, 20, казарма.',
    'Прапорщик объясняет салаге:\n— В армии встают в 6 утра независимо о времени суток!',
    '— Товарищ старшина! Смотрите, что мне выдали! Брюки только до колен, рубаха болтается, рукава короткие, сапоги хлябают, глядеть страшно.\n— Все в порядке. Воин должен внушать страх.',
    'Сержант в самолете стоит перед дверью и выпускает десантников:\n— Готов? Пошел. Готов? Пошел. Готов? Пошел. Готов?\n— Нет.\n— Пошел… Пошел, пошел, пошел… Готов!',
    '— Вась, а Вась! Давай поселим козла в казарме — вроде талисмана, на счастье.\n— А вонь?\n— Привыкнет. Мы же привыкли.',
    'Прапорщик проходит медкомиссию.\nОкулист ему:\n— Закройте левый глаз. Какая буква?\nПрапорщик молчит.\n— Закройте правый глаз. Какая буква?\nПрапорщик молчит.\n— Вы что, совсем ничего не видите?\n— Нет. Вижу я отлично, просто забыл как они называются.',
    'Офицер дает наставление по атомной защите:\n— Если взрыв будет близко, надо лечь головой к нему, натянуть каску на лоб и положить автомат под себя.\n— А зачем автомат под себя?\n— Чтобы не сплавился.',
    '— Смотри, какая страшная рожа намалевана на носу этого бомбардировщика!\n— Тихо! Это сам командир полка высунулся из кабины.',
    '— Стой! Кто идет?\n— Свой с бутылкой!\n— Свой — проходи. Бутылка стой.',
    'Старшина входит в казарму после отбоя и видит, что никто не спит.\n— По моей команде: глаза за…крыть! Отставить! Щелчка не слышу.',
    'Над двумя прапорщиками завис вертолет.\n— Слушай! — говорит один. — Чего это он остановился?\n— Должно быть, горючее кончилось.',
    '— Тебя почему комиссовали? — Болезнь.\n— Какая болезнь? — Не знаю. Но всю роту от меня тошнило.',
    'Занятие по сборке и разборке оружия.\nСтаршина:\n— Вопросы есть?\n— Есть, товарищ старшина. Почему винтовку можно собрать, разобрать а человека нельзя?\n— Вопрос понял, отвечаю. Вот представь себе, Пилипенко. Ты себя развинтил, спать лег, а тут боевая тревога. Ты второпях все свинтил, а на место головы приставил задницу. И что получается: пилотка не налазит, гимнастерка не застегивается, все кричат "ура", а ты?',
    'Молодые десантники прыгают с парашютом. Один за другим подходят к люку самолета и выпрыгивают. Вдруг один отделяется от общего строя, подходит к командиру:\n— Товарищ лейтенант! Рядовой Пилипенко…\n— Что Пилипенко?\n— Прыгнул без парашюта…\n— Как! Опять?!!',
    'Курсант летной школы отправляется в первый учебный полет. Летит с инструктором. Система управления дублирована. Курсант заводит мотор. Вцепившись в рукоятку управления, зажмуривается и выполняет все действия, которые учили на тренажере. Открывает глаза, смотрит вниз:\n— Смотрите, товарищ инструктор, какие люди внизу маленькие! Как муравьи.\n— А это и есть муравьи. Мы еще не взлетели.',
    'ПРАПОРЩИК ОБЪЯСНЯЕТ…\nПрапорщик объясняет солдатам ситуацию:\n— Вот идете вы по чистому полю. Нигде нет ни ямки, ни бугра, ни колышка, и вдруг из — за угла выезжает танк.',
    '— Или вы прекратите курить, или одно из двух.',
    '— Живете туг, как свиньи в берлоге.',
    '— В каком Вы виде, товарищ курсант, ведь перед Вами целый майор.',
    '— Товарищ курсант, закройте рот — через пищевод трусы видно.',
    '— Комбат пешком не ходит, он берет с собой ГАЗ — 69 или замполита.',
    '— Не каждый дурак может учиться в Военной академии, а я ее кончил.',
    '— От этой болезни обычно умирают или становятся дураками. Мы с братом выжили.',
    '— Лицо на фотографии должно быть квадратным.',
    'Пусть число танков равно "К", нет, "К" мало, возьмем "М".',
    'Сварливая жена была у мужика. Не успеет он порог переступить — она тут же начинает его ругать.\nОднажды приходит мужик домой, в спор не вступает, молча раздевается до пояса, поворачивается к жене и говорит: — Плюй!\n— Да ты что, сдурел?\n— Плюй, говорю!\nЖена плюнула.\n— Растирай!\nЖена растирает спину, приговаривая:\n— Да что с тобой? Что с тобой?\n— Ничего особенного, врач сказал змеиным ядом растираться.',
    '— Что такое медовый месяц?\n— Представьте себе, что брак — это бочка, полная дерьма, а наверху небольшой слой меда. Сначала Вы мед едите, а затем уже всю жизнь хлебаете остальное. Вот это и есть медовый месяц.\n— Вы знаете, кажется я открыл бочку с другой стороны.',
    'В коммунальной квартире девушка, стоя под душем, вдруг видит, что сквозь фрамугу на нее смотрит небритая физиономия.\n— Как Вам не стыдно, Вы что, не видели обнаженную натуру?\n— Плевать мне на твою натуру. Я смотрю, чьим ты мылом моешься?',
    '— Запомни, — поучает бабушка внучку. — У каждой женщины в жизни должна быть лишь одна большая любовь.\n— А кто был твоей единственной любовью?\n— Моряки.',
    'Сын спрашивает отца, какая разница между теорией и практикой.\n— Пойди на кухню и спроси у сестры и матери, смогли бы они отдаться первому встречному за миллион?\nСын возвращается.\n— Они согласны.\n— Вот видишь, сынок. Теоретически мы с тобой миллионеры, а практически у нас дома живут две шлюхи.',
    'Жена была в отъезде и позвонила мужу.\n— Как наша кошечка?\n— Сдохла.\n— Какой ужас! Неужели ты не можешь сообщить об этом поделикатнее? Например, она, мол, сидит на крыше, а уж потом бы ты мне сказал, что она упала и разбилась. Понятно?\n— Вполне.\n— А как моя мама?\n— Сидит на крыше.',
    'Познакомились японка с русским по газете. Назначили встречу. При встрече японка представляется:\n— Сукасима.\nРусский не растерялся:\n— Кобель Миша.',
    'Муж приходит домой обедать. Жена сообщает, что ветром сломало телеантенну. Он полез на крышу и сорвался с шестнадцатого этажа.\nЛетит мимо окна своей квартиры и кричит жене:\n— На меня не накрывай!',
    '— Мой муж моряк. Представляете, одиннадцать месяцев в году он в море, а один на берегу.\n— О, мадам, представляю, как Вы мучаетесь!\n— Ничего, помогает то, что половину отпуска он проводит с родителями.',
    '— Говорят, что ты женился, Люсик? Поздравляю! И как живется?\n— Нет слов! Представляешь себе! Приходишь домой уставший, голодный, а ванная приготовлена, ужин на столе, жена, поцеловав, от тебя не отходит ни на шаг, мельтешит все около тебя и все говорит, говорит, говорит… идиотка.',
    '— Отчего умерла ваша первая жена?\n— Отравилась грибами.\n— А вторая жена?\n— Отравилась грибами.\n— А третья?\n— От сотрясения мозга.\n— А почему?\n— Не захотела грибы есть.',
    'Женщина жалуется своей подруге:\n— Муж совершенно перестал обращать на меня внимание.\nПодруга советует:\n— Попробуй его удивить. Надень на себя что-нибудь экстравагантное.\nЖена долго думала и решила надеть на себя противогаз. Приходит муж с работы, она открывает ему дверь, а он как ни в чем не бывало проходит на кухню. Жена начинает подавать ему ужин, ей жарко в противогазе и, отчаявшись, она его спрашивает:\n— Дорогой, ты не находишь во мне ничего необычного?\n— Ты что, брови, что ли, выщипала?',
    '— Должен Вас предупредить, дорогая, что я не вполне здоровый человек: у меня гайморит, хронический гепатит, стенокардия, диабет и…\n— А чего у Вас нет, дорогой?\n— Зубов.',
    'В одной семье девять детей. Жена говорит мужу:\n— Говорят, скоро Указ выйдет: у кого десять детей, то дают шестикомнатную квартиру и на каждого ребенка выплачивают 120 рублей в месяц. Ты мне рассказывал, что у тебя в Сибири растет побочный сын. Забери его к нам, будет у нас десять, получим льготы.\nМуж поехал за сыном. Через три дня приезжает, заходит в квартиру, а там одна жена.\n— А где же дети?\n— А вчера все приехали, каждый забрал своего и увез.',
    'Молодожен спрашивает у своей жены:\n— Скажи, милая, сколько ты знала парней до меня?\nМолчание. Через час он спрашивает:\n— Ты все еще сердишься?\n— Нет, я все еще считаю.',
    'Приходит муж домой, жена ему говорит:\n— Хлеба купи.\n— Да не мужское это дело!\n— Ну займись тогда мужским делом, — жена распахнула халат.\n— Да ты что, уж и пошутить нельзя! Давай сумку!',
    'Лежат парень с девушкой в кровати. Тут открывается дверь и входят его родители.\nМысль парня: — Я же ей говорил, давай подождем.\nМысль девушки:\n— Наконец — то он на мне женится.\nМысль отца:\n— Сын уже стал взрослым, пора купить ему мотоцикл.\nМысль матери:\n— Дура, как она лежит, мальчику же неудобно.',
    'На печи спят дед и бабка. Деду не спится. Он будит бабку.\n— Старуха, ухи хочешь?\n— Хочу.\n— Так иди и налови рыбы.\n— Где же я ее зимой-то наловлю?\n— Ну тогда лежи и не вякай.',
    'К хозяевам, которые сидят и пьют чай, приходит гость. Гостя приглашают к столу.\nГость:\n— Можно помыть руки?\nХозяйка:\n— Вы руки моете с мылом?\nГость:\n— С мылом.\nХозяйка:\n— Тогда чай будете пить без сахара.',
    'Вернувшись с работы, муж говорит жене:\n— Наша фирма ищет кассира.\n— Но ты же говорил мне, неделю назад, что к вам приняли нового кассира.\n— Вот его — то фирма и ищет.',
    'На вокзальной площади встречаются двое.\n— Ты где был?\n— Тещу в деревню провожал.\n— А почему все лицо в саже?\n— На радостях паровоз целовал.',
    'На сельскохозяйственной выставке муж и жена в птичьем павильоне.\nЭкскурсовод:\n— Вот индийский петух, способный сто раз в день покрыть курицу.\nЖена мужу:\n— Запомни.\nЭкскурсовод продолжает:\n— Но куры должны быть все разные.\nМуж жене:\n— Запомни тоже.',
    'На кухне коммунальной квартиры разговор трех соседок.\n— А мой муж все пьет и пьет…\n— А мой все по бабам ходит.\n— А мой не пьяница и не бабник, но сифилитик.\nВ это время на кухню входит муж третьей:\n— Дура. Сколько можно тебя поправлять — не сифилитик, а филателист.',
    '— Когда наш новый сосед сменил мебель, ты заставила меня купить новый гарнитур. Когда он приволок новый телевизор с большим экраном, ты заставила меня сделать то же самое. Я уже не говорю, сколько нам стоила новая машина, которую пришлось купить из-за соседа. А что делать теперь?\n— А что он приобрел?\n— У него новая жена.',
    'Приходит мужик в магазин и говорит:\n— Взвесьте мне килограмм молока.\n— Вам как, порезать или куском?\n— А мне все равно, я на велосипеде.',
    'После регистрации брака молодая пара выходит из ЗАГСа:\n— Дорогой, ты будешь любить меня как Ромео Джульетту?\n— Не читал, не знаю.\n— А что ты читал, дорогой?\n— "Муму". Будешь выделываться, утоплю, как собаку.',
    'Он и она в постели.\n— Вань, ну скажи, ты меня любишь?\nОн отвечает:\n— Люблю, кобра.\n— Вань, ну скажи, что ты меня хочешь!\n— Хочу, стерва!\n— Ой, Вань, ты и мертвого уговоришь!',
    'Перед входом в зоопарк стоят бабушка и внучка.\n— Бабушка! — спрашивает внучка. — Что за обезьяна там, в стеклянной будке?\n— Это не обезьяна, а кассирша.',
    '— Дорогой, сходи в магазин.\n— Ну, любовь моя, сейчас такой дождь, что хороший хозяин собаку на улицу не выгонит.\n— Господи. Ну иди без собаки.',
    'Конферансье:\n— Выступает квартет имени Дружбы народов.\nСостав:\nДорошенко — Украина, Газарян — Армения, Думбадзе — Грузия, Рабинович — скрипка.',
    'Усталый муж возвращается домой и говорит жене:\n— Кто бы ни звонил, меня нет дома.\nРаздается звонок.\nЖена берет трубку:\n— Муж дома.\nМуж срывается с кресла и подбегает:\n— Я же просил…\nЖена говорит:\n— Не сердись, дорогой, звонили не тебе.',
    'Маврикиевна жалуется Авдотье Никитичне:\n— Ох, как болит голова. Я вчера поздно легла, около двух.\n— Дура, надо было возле одного ложиться, тогда бы голова не болела.',
    'Встретились женщины у подъезда. Обсуждают житейские проблемы, обмениваются новостями.\n— Знаете, соседки, ну и везет же нашей Клавке. И замуж вышла, и любовника имеет, а вчера в подъезде изнасиловали.',
    'Мужская логика:\n— Еду в автобусе. Надо передать на билет. Рядом стоит мужчина. Как к нему обратиться — на ты или на вы? Рассуждаю логически. Этот автобус — экспресс. Если мужчина не сошел на предыдущей остановке, значит, он едет в мой микрорайон. Едет с цветами, значит, к женщине. Цветы красивые, значит, едет к красивой женщине. В нашем микрорайоне две красивые женщины: моя жена и моя любовница. К моей любовнице он ехать не может, так как я сам к ней еду. Значит, он едет к моей жене. У моей жены два любовника — Петя и Вася. Петя сейчас в командировке.\n— Вася! Передай на билет!',
    'Сотрудник опоздал на работу на два часа. Сослуживцы удивляются:\n— Что случилось?\n— Жена десятку потеряла и два часа ее искала.\n— Ну, а что тебя задержало?\n— Так я ж на ней стоял.',
    'Во дворе дома мужики режутся в "козла". Случайно зашел разговор о том, как своих мужей величают жены.\n— Меня только по имени, — говорит один.\n— А меня все милый, да милый.\n— А вот моя по — итальянски величает, — говорит третий.\nИ тут на третьем этаже открывается окно и женский голос кричит:\n— Кобелино, домой!',
    'В интернациональной компании американец хвастается своей жизнью:\n— У меня две виллы и две любовницы.\nФранцуз не отстает:\n— У меня три виллы и три любовницы.\nРусский:\n— А у меня одни вилы, зато все девки в деревне — мои.',
    'Попали на необитаемый остров англичанин, француз и русский. Однажды к берегу прибило бутылку. Когда ее открыли, то из нее появился джинн и сказал:\n— Исполняю по два желания.\nАнгличанин:\n— Мне мешок денег и домой.\nФранцуз:\n— Блондинку и домой.\nКогда они исчезли, русский подумал: "Хорошая была компания и как-то по-дурацки распалась".\n— Ящик водки и всех обратно!',
    'Одной авиакомпании требовался на работу опытный пилот. Приходит немец, его спрашивают:\n— Какой у Вас налет часов?\n— Пятнадцать тысяч часов.\n— Сколько Вы хотите получать?\n— Три тысячи долларов в месяц. Тысячу — себе, тысячу — жене, тысячу в банк.\nПриходит француз. Спрашивают его:\n— Какой у Вас налет часов?\n— Одиннадцать тысяч часов. Я хочу получать шесть тысяч в месяц. Две тысячи — себе, две — жене, две — любовнице.\nПриходит русский.\n— Какой у Вас налет часов?\n— Никакого налета нет. Я не летчик, пришел к вам подработать. Хочу девять тысяч; три — себе, три — вам, а три — немцу, пускай он летает.',
    'Пошел Джон Смит сознаваться в своей шпионской деятельности майору Пронину: лучше уж Сибирь, чем на неведомую картошку.\nМайор Пронин достает лист бумаги, записывает показания. А Джон Смит рассказывает: так мол и так, шпион. Внедрился к вам, долго работал, а вчера послали на картошку — решил сознаться. Майор Пронин рвет протокол и гневно кричит:\n— Вон отсюда! Как в колхоз — так все шпионы!',
    'Спорят француз, англичанин и русский у кого жена стройнее.\nФранцуз:\n— Я покупаю галстук, а жена из него платье себе шьет.\nАнгличанин:\n— А моя жена недавно мылась в ванне и случайно открыла пробку, так ее чуть не утянуло в трубу.\nРусский: — А я вот ухожу на работу, хлопну свою жену по заду, а когда прихожу домой — зад еще колышется.\nЕго спросили:\n— А к чему Вы это рассказали?\n— К тому, что в нашей стране самый короткий рабочий день.',
    'К борту океанского лайнера подплывает мужик в корыте и орет:\n— Капитана мне! Немедленно!\nНа борт выходит капитан.\n— Чего тебе?\n— Деньги, драгоценности, спиртное, все мне сюда и быстро!\n— А не пошел бы ты к такой матери!\nМужик огорченно вздыхает.\n— Ну вот, так всегда. Опять не повезло.',
    '— Сосед, где вы были в отпуске?\n— В Ялте.\n— Ну и как?\n— Ужасно. Меня там ограбили, сына избили, а жену с дочерью изнасиловали…\n— Боже, как неприятно. А куда собираетесь в будущем году?\n— Мы с сыном хотим поехать в Пицунду, а жена с дочерью в один голос: "В Ялту".',
    'Одним грузином заинтересовались следственные органы.\n— Как это Вы, при зарплате двести рублей в месяц, умудрились купить "Волгу"?\n— Между прочим, когда я служил в армии, то три рубля семьдесят копеек получал, а имел танк.',
    'Наркоман сидит в автобусе. Входит дед без ноги. Говорит:\n— Внучек, уступи мне место, я в 43-м ногу потерял.\n— Не гони, дед, ехал я в 43 автобусе — нет там твоей ноги.',
    'Скупец молится:\n— Господи! Что для тебя миллион лет?\n— Один миг, — отвечает Бог.\n— А что для тебя миллион рублей?\n— Один грош.\n— Так подари мне этот грош.\n— Ладно, — отвечает Господь. — Обожди один миг.',
    'Женщину изнасиловали. В милиции ее спрашивают:\n— Как дело было?\n— Он ко мне сзади подошел и изнасиловал.\n— Почему же Вы не кричали?\n— Он меня все время шантажировал, все время угрожал: как только закричишь, я сразу уйду.',
    'Один приятель спрашивает другого:\n— Как жизнь?\n— На работе, как в лесу. Что ни начальник, то дуб, что ни зам, то пень, что ни бумага, то липа, что ни отдел, то болото, зато секретарши ягодки. Дома как в сказке: жена — ведьма, теща — Баба Яга, тесть — Кощей Бессмертный, зато соседка — Василиса Прекрасная, а муж ее — Иванушка — дурачок.',
    'Вошел мужик в хозмаг.\n— У вас гвозди есть?\nПродавец:\n— Где-то были, где-то были (ищет).\nМужик:\n— Давай быстрей. —\nГдетобылигдетобылигдетобыли.',
    'Петька спрашивает Чапаева:\n— Василий Иванович! Ты за "Битлз" или за "Роллинг Стоунз"?\nТот подумал:\n— А Леннон в каком?',
    'Бракоразводный процесс. Судья спрашивает:\n— Если Вам муж пообещает, что не будет Вас больше называть старой коровой, Вы намерены с ним жить дальше?\n— Да, — отвечает жена.\nСудья поворачивается к мужу:\n— Вы обещаете больше не называть ее старой коровой?\n— Да.\n— Дело закрываем, — объявляет судья.\nМуж подходит к жене:\n— Идем домой, не то врежу промеж рогов.',
    'Беседуют два охотника.\n— Каким порохом ты заряжаешь патроны, когда охотишься на дикого кабана?\n— Только дымным.\n— Он что, сильно бьет?\n— Нет, но пока дым рассеется, я успеваю влезть на дерево.',
    'Женщина в горах встречает снежного человека и говорит:\n— Давай жить вместе.\n— Зачем?\n— Я буду готовить для тебя пищу.\n— Я ем сырое мясо.\n— Тогда я буду стирать одежду.\n— Зачем мне одежда, шерсть спасает меня от холода.\n— Тогда я буду любить тебя.\n— А это еще что такое?\n— Пойдем в пещеру, там объясню.\n— Ой, ой, ой, — простонал обалдевший снежный человек, вылезая из пещеры.\n— А я, дурак, им орехи колол.',
    'Встречаются два приятеля.\n— Что тебя давно на рыбалке не видно?\n— Любовница новая, никак не отпускает от себя.\n— А ты с ней поругайся.\n— Как?\n— Да сбрось с нее одеяло и скажи: "Какая ты толстая". Она обидится, а ты сходишь на рыбалку.\nТак он и решил сделать. Лег с ней в постель, заглянул под одеяло и подумал:\n— Да на хрена мне эта рыбалка!',
    'Альпинист упал в пропасть. Товарищи ему кричат:\n— Вася, ты жив?!\n— Жив!..\n— Руки целы?!\n— Целы!..\n— Ноги целы?!\n— Целы!..\n— Так поднимайся!\n— Не могу, я еще лечу!..',
    'Одного спросили:\n— Что с Вами будет, если Вам отрежут одно ухо?\n— Я буду хуже слышать.\n— А если отрежут второе?\n— Я буду хуже видеть.\n— Почему?\n— Кепка будет на глаза сползать.',
    'Охотник снимает с плеча ружье, целится и убивает куропатку.\n— Вторая, — говорит он с гордостью товарищу.\n— А где же первая?\nОтвет:\n— Это было еще до войны.',
    '— Однажды на охоте в Африке я с расстояния пятисот метров первым выстрелом свалил слона!\n— Это что! Вот недавно на охоте в Северном море я голыми руками задушил медведя!\n— Да, к вопросу о морях. Ты когда-нибудь слыхал о Мертвом море?\n— Ну разумеется.\n— Так вот, это мы с братом его убили.',
    'Что думает женщина во время любовной встречи, глядя в потолок?\nПроститутка:\n— Заплатит или не заплатит?\nПорядочная женщина:\n— Женится или не женится?\nЖена:\n— Побелить потолок или не побелить?',
    'Армянскому радио задали вопрос:\n— Что нужно сделать, чтобы при занятиях онанизмом не подцепить СПИД?\nАрмянское радио отвечает:\n— Точно мы не знаем, но на всякий случай кипятите руки.',
    'Армянскому радио задали вопрос:\n— Как пишется "в кусты" — вместе или отдельно?\nАрмянское радио отвечает:\n— В кусты — вместе, из кустов — отдельно.',
    'Армянскому радио задают вопрос:\n— Что надо сделать полной женщине, чтобы похудеть?\n— Пусть вертит обруч, — отвечает армянское радио.\n— А если она такая полная, что не может влезть в обруч?\nТут вмешивается турецкое радио:\n— Ради бога, не надо портить красивую женщину!',
    'В Эстонии на машине едут отец (за рулем) и два взрослых сына. Вдруг кто-то выскочил из-под колес. Проходит 15\nминут.\nОтец:\n— Это молодой лось.\nПроехали еще 15 минут, Сын:\n— Нет. Это кабан.\nПроехали еще 15 минут. Второй сын:\n— Нет. Это большой заяц.\nИ еще едут 15 минут. Отец:\n— Перестаньте ссориться, горячие эстонские парни!',
    'Идут по кладбищу двое, рассматривают надгробия. Вдруг один другому говорит:\n— Смотри, что написано: "Родился в 1920 году, умер в 1990 году, жил 50 лет". Ерунда какая!\nДругой отвечает:\n— Все правильно. Это он считается жил, когда у него дача, машины, любовницы.\n— Да, в таком случае, когда я умру, напиши: "Родился мертвым".',
    'Художник предлагает молодой даме нарисовать ее портрет.\n— А сколько это будет стоить? — спрашивает она.\n— Для Вас, мадам, ничего.\n— О нет, это слишком дорого.',
    'Красные и белые на позиции. Через расположение белых едет телега. В телеге женщина. Белые ее задержали. Женщина просит пропустить ее в соседнее село, в расположение красных. Пропустили. Телега въезжает в село и подъезжает к штабу. Навстречу выходит Фурманов, женщина снимает косынку.\n— Петька! — восхищенно кричит Фурманов. — Ай да замаскировался!\n— Это еще что, — скромно говорит Петька. — Распрягите Василия Ивановича!',
    'Петька изучает Древнюю историю.\n— Василий Иванович, — спрашивает он. — Как понять? Патриции пригласили гетер и устроили оргию. Что такое оргия?\n— Да пьянка!\n— Кто такие гетеры?\n— Проститутки!\n— Ну а патриции, кто такие?\n— А здесь, Петька, опечатка. Не патриции, а партийцы.',
    '— Смотри, корова летит, — говорит Жеглов.\n— Где?\nШарапов поднимает голову к небу и тут же проваливается в канализационный люк. Жеглов наклоняется к люку и кричит:\n— Шарапов, если хочешь работать в МУРе, запомни— коровы не летают.',
    'Старая бабка обращается к патлатому парню в джинсах:\n— Молодой человек, как пройти на улицу Горького?\nОн отвечает:\n— Во — первых, не молодой человек, а чувак. Во — вторых, не пройти, а кинуть кости. В-третьих, не на улицу Горького, а на Пешков-стрит. А, в — четвертых, — вон у милиционера спроси.\nБабка подходит к милиционеру и спрашивает:\n— Чувак, как кинуть кости на Пешков-стрит?\n— Хипуешь, клюшка?',
    '— Вчера я выиграл в лотерею сто тысяч!\n— А как на это реагировала твоя жена?\n— Она от радости онемела.\n— Это же надо! Сколько счастья сразу!',
    'Мужчина приходит в детский сад и говорит:\n— Приведите моего ребенка.\nЕго спрашивают:\n— Который Ваш?\n— Какая разница, завтра все равно обратно приводить.',
    'Учительница жалуется Вовочкиному папе:\n— Ваш сын нарисовал на парте муху, как живую, и я отбила об нее руку.\n— Это еще что, — говорит папа. — Он однажды крокодила в ванной нарисовал, так я через нарисованную дверь выскочил.',
    'Купила старуха галоши, а завернуть не во что, и попросила пустую коробку. Ей дали коробку, на которой на — писано:\n"Презервативы — 1000 шт."\nЕдет в электричке домой в деревню. Ее спрашивают:\n— На сколько, бабуся, хватит этой коробки?\n— Как мой дед шаркает, хоть бы на неделю хватило.',
    'Старый моряк рассказывает внуку:\n— Однажды, в самом центре Бермудского треугольника, огромная волна подняла наш корабль на высоту пятого этажа и с размаху швырнула вниз… Ни один человек из команды не уцелел.\n— А как же ты, дедушка?\n— Я-то к этому времени был давно на пенсии.',
    'Гадалка рассказывает женщине:\n— Вскоре Вас ожидает большая утрата. Похоже, Вы потеряете мужа.\n— Но я уже два года как вдова.\n— Значит, Вы потеряете зонтик.',
    'Колхозный механизатор провел тяжелый сезон работы и получил путевку на юг. В санаторий приехал ночью. Утром проснулся, вышел на балкон и видит: морской пляж усеян женскими телами.\n— Да. Тут не отдохнешь. Работы — непочатый край.',
    'По улице один нищий на коляске везет другого, у которого нет ни рук, ни ног. Подходит дама, кидает в шапку рубль и спрашивает с состраданием:\n— Как же Вы, так целый день его и возите?\n— Зачем целый день? До обеда я, а после обеда он меня.',
    'Интеллигент попал под асфальтовый каток. Его положили перед дверью, как коврик, и все вытирали ноги. Когда он стал грязным, его перевернули на другую сторону. А когда и эта сторона стала грязной, его выстирали и повесили сушиться на дворе. А он простудился и умер.',
    'Человек гуляет по кладбищу и видит пышные похороны: оркестр, гора венков… Он спрашивает:\n— Не знаете, от чего он умер?\n— А ты ленты на венках почитай, там все написано: "От месткома", "От парткома", "От группы товарищей", "От любящих жены и сына".',
    'Два наркомана после дозы лежат под деревом и смотрят в небо:\n— Макс, смотри, собака летит. Ой, еще одна. А теперь слоны, целая стая.\n— Да-а-а… Осень.',
    'Через двадцать пять лет после окончания школы Вовочка пришел на встречу с одноклассниками. Все рассказывают о своей семье, работе.\n— Вовочка, а ты кем работаешь?\n— Я — генерал.\n— Не может быть?! Ты же в школе ничего не знал!\n— А я и сейчас ничего не знаю. Но чтобы к утру все было сделано!',
    'Умер старый учитель и попал на тот свет. Его определили в ад. Через неделю приходят к нему и говорят:\n— Извините, тут ошибка произошла. Вам положено быть в раю.\nА он отвечает:\n— Да нет, мне здесь хорошо. После школы мне ад раем кажется.',
    'Сын говорит матери:\n— Я больше в школу не пойду!\n— Это почему же?\n— Да ну… Петров опять будет из рогатки стрелять. Синицин учебником по голове, Васильев подножки ставить… Не пойду!\n— Нет, Вовочка, ты должен идти. Во — первых, тебе уже сорок лет, а во — вторых, ты директор школы.',
    'В монастыре.\n— Святой отец! Может ли душа простудиться?\n— Да ты что, сын мой, душа — это воздух.\n— А я вот вчера иду мимо кельи игумена, и слышу он говорит: "Душа моя, не ходи босиком — простудишься".',
    'Мужик собирает грибы в лесу. Навстречу ему выходит дряхлая старуха с ружьем.\n— Милый человек! Вы, наверное, хотите меня изнасиловать?\n— Нет, что Вы! Как Вы могли подумать?!\n— А придется…',
    'Летит самолет. Один пассажир обращается к стюардессе\n— Откройте мне дверь, я хочу здесь выйти.\n— Мы находимся на высоте 5 тысяч метров.\n— Откройте, я хочу выйти!\nСтюардесса бежит к экипажу:\n— Там какой-то сумасшедший хочет, чтобы ему открыли дверь, он хочет выйти.\n— Это тот, что весь в бинтах?\n— Да!\n— Откройте ему. Он всегда здесь выходит.',
    'В поезде, в одном купе едут немка на верхней полке и грузин на нижней. Немке стало скучно, она наклонилась к грузину и спрашивает:\n— Шпрехен зи дойч?\n— Очень хочу, дорогая, зачем спрашивать?!',
    'Сидят у костра людоеды. К ним подсаживается их соплеменник.\nВождь племени спрашивает его:\n— Что ты больше всего любишь в женщине?\nМолодой дикарь с придыханием отвечает:\n— Грудь.\n— А мы тебе ногу оставили.',
    'Деревенские парни на болоте собирают клюкву. Один кричит приятелю:\n— Сенька!\n— Что-о!\n— Васька в болоте увяз!\n— Глубоко ли?\n— По щиколотку.\n— Так тяни же его!\n— Не могу, он вниз головой!',
    'На совещании директоров колбасных цехов завода очень хвалят одного директора за качество продукции и просят поделиться производственными секретами.\n— Да нет у нас никаких секретов! Берем бумагу, добавляем немного фарша…\nВсе директора хором:\n— Ах, ты еще и фарш добавляешь?!',
    'Украинец попал в кораблекрушение. Прожил два года на необитаемом острове. Вдруг подъезжает лодка, в ней красивая женщина.\n— Мужичок, иди сюда! Я тебе дам то, что ты хотел два года.\nУкраинец кидается в воду, плывет к ней.\n— Вареники! Вареники!',
    'В городе живут два друга. Один заведующий моргом, а второй директор магазина мотоциклов. Вечером друг из морга звонит приятелю в магазин:\n— Вася, ты сколько сегодня продал мотоциклов?\n— Пять.\n— А… Значит, один еще где-то катается.',
    'Муж жене:\n— Люсь, ты видала мятый рубль?\nЖена рассмеялась.\n— Да, а что?\n— А десять рублей?\n— Да, но реже.\n— А десять тысяч мятыми видела?\n— Нет.\n— Ну, пойди в гараж, посмотри.',
    'Американец хвастается перед русским.\n— У нас в Штатах дороги куда лучше ваших. Ставлю я бокал виски на капот и за всю дорогу ни одна капля не прольется.\n— Подумаешь, — отвечает русский. — Вот я сажусь за руль, завожу машину, вытаскиваю подсос газа, залезаю к Машке на заднее сиденье и делаю с ней, что хочу.\n— Постой, постой, а как же машина?\n— А куда она с колеи денется?',
    'Двое мужиков решили выпить, а денег нет.\nТогда один говорит:\n— Вань, давай на дороге гаишников изображать! Насобираем штрафов и выпьем.\nНацепили красные повязки. Стоят. Останавливается машина. Они говорят:\n— Вы нарушили правила. С вас штраф — десять рублей!\nИз машины выходят здоровенные парни и начинают их бить. Потом садятся в машину и уезжают. Мужики лежат на\nдороге. Один говорит:\n— Вань, ты номер запомнил?\n— Да. Сорок три — сорок четыре.\n— А буквы?\n— Буквы на ботинках не пишут.',
    'Звонок в автомастерскую.\n— Пришлите, пожалуйста, механика, я машину завести не могу!\n— А что случилось?\n— Вода в карбюратор попала.\n— Хорошо, высылаем. Где находится машина?\n— Метрах в двадцати от берега.',
    'В автомобильный магазин заходит восточного вида человек и спрашивает сидящего за прилавком продавца:\n— Скажи, машины в продаже есть?\n— Есть.\n— И что, можно вот сейчас купить "Волгу"?\n— Можно купить.\n— А можно "Москвич"?\n— Можно "Москвич".\n— А "девятку" белого цвета?\n— Пожалуйста.\n— Слушай, что ты из меня дурака делаешь?\n— Так ты первый начал.',
    'Женщина сдавала экзамен на получение водительских прав. Когда вернулась домой, муж спросил ее:\n— Ну как, сдала?\n— Еще не знаю.\n— А что сказал инструктор?\n— Ничего. Врачи еще не могут привести его в сознание',
    'Милиционер:\n— Вы двигались со скоростью 80 км в час.\nВодитель:\n— Напишите в протоколе 120, пожалуйста!\n— Это зачем?\n— Тогда я, наконец, смогу продать свою машину.',
    'Ночью затонул пароход. На маленький островок выплыли четверо мужчин: двадцатилетний, тридцатипятилетний, пятидесятилетний и семидесятилетний. Когда они утром проснулись, то увидели, что на соседнем островке нашли пристанище четыре молодые женщины.\nДвадцатилетний с криком: "Девчонки, я к вам!" — прыгнул в воду и поплыл.\nТридцатипятилетний, попробовав воду ногой, сказал:\n— Вода холодная, давайте соорудим какой — нибудь плот.\nПятидесятилетний раздумчиво заметил:\n— Ну, зачем что-то сооружать, переплывать? Подождем, когда они сами к нам приплывут.\nА семидесятилетний сказал:\n— А зачем им сюда плыть? У меня есть бинокль.',
    'Соревнование по плаванию среди инвалидов: кто без руки, кто без ноги, а на последней дорожке — одна голова,\nДали старт. Все поплыли, а голова пошла ко дну. Вытащили ее, откачали. Голова открыла глаза и говорит:\n— Я пять лет училась ушами грести, а мне эти козлы перед самым стартом резиновую шапочку натянули.',
    'Идет мужик по пустыне и изнывает от жажды. Видит, стоит кувшин.\nПоднял, а из кувшина вылетает джинн.\n— Что прикажешь, мой господин?\n— Хочу домой.\n— Пошли.\n— Я быстро хочу.\n— Ну, тогда побежали.',
    'Идет человек по пустыне в ластах и маске. Навстречу ему туркмен на верблюде:\n— Эй, уважаемый, далеко ли до моря?\n— Километров триста будет.\n— Ну и пляж отгрохали!',
    'Матрос с катера ловит рыбу. Долго нет клева. И вдруг попадается золотая рыбка.\n— Отпусти меня, — говорит она. — Любое твое желание исполню.\nМатрос про себя думает:\n"А что мне надо? Машина у меня есть, деньги на сберкнижке есть, красавица жена есть, две любовницы есть".\n— Слушай, — говорит. — Мне от тебя ничего не надо, я тебя отпущу, а ты выполни желание того, кто первым появится на палубе.\nПроходит два часа. Скрипит дверь. Появляется заспанная физиономия боцмана. Посмотрев вокруг себя, он говорит:\n— Ну и погодка, якорь мне в задницу.',
    'Едет Шварценеггер в автобусе. Стоящая сзади женщина спрашивает:\n— Вы выходите?\n— Выхожу.\n— А люди перед Вами?\n— Выходят, только они об этом еще не знают.',
    'Палач приходит с работы домой. За плечом у него мешок, в котором что-то шевелится.\nЖена спрашивает:\n— Что это ты притащил?\n— Да так… Халтурку на дом взял.',
    'Загипсованный человек па больничной койке пишет письмо редактору:\n"Уважаемый редактор! В Вашем самоучителе по прыжкам с парашютом на 22 странице, пятая строка сверху, вероятно, допущена опечатка".',
    'Лодочная станция. Спасатель кричит в мегафон:\n— Лодка номер 99, гребите к берегу, ваше время истекло!\n— Шеф, — говорит помощник. — У нас всего 75 лодок.',
    'Один падает с крыши высотного дома. Пролетая мимо человека, стоящего на балконе, кричит:\n— Какой этаж?\n— Восемнадцатый!\n— Ну, еще можно жить.',
    'Покупатель:\n— Что же это Вы мне такое мясо взвесили?\nПродавец:\n— Я же предупреждал, что торгуем собачатиной.\nПокупатель:\n— Знаю, что собачатиной, но причем же здесь в мясе щепки, гвозди…\nПродавец:\n— Мясо второго сорта, рубим вместе с будкой.',
    'Человек выходит из аптеки. Его догоняет запыхавшаяся продавщица.\n— Гражданин, Вы сейчас взяли глюконат кальция, верните его обратно.\n— Почему?\n— Я по ошибке выдала вам цианистый калий.\n— А я его уже выпил.\n— Тогда быстрее доплатите 16 копеек.',
    'Покупатель возвращает в магазин электропилу.\n— В инструкции написано, что с ее помощью можно распилить за день пять кубометров дров, а я как ни стараюсь, больше двух не успеваю.\nПожав плечами, продавец для проверки включил пилу в электросеть.\nПокупатель вздрагивает и спрашивает:\n— А чего это она зажужжала?',
    'Забегает мужик в аптеку и спрашивает:\n— У вас апельсины есть?\n— Нет, у нас аптека, а не овощи-фрукты.\nНа другой день мужик снова пришел.\n— Апельсины есть?\nИ так несколько дней. Сотрудники, чтобы отвязаться от него, повесили на дверях табличку: "Апельсинов нет".\nНа другой день мужик снова прибегает, видит табличку и злорадно кричит:\n— А! Ведь все-таки были?! Были апельсины?!',
    'Мужчина заходит в комиссионный магазин, чтобы купить жене подарок.\n— Сколько стоят эти туфли? — спрашивает продавца.\n— Тысячу рублей.\nМужчина изумленно присвистнул.\n— А вот эти белые?\n— Два присвистывания.',
    'В магазине покупатель спрашивает продавца:\n— у Вас есть лопаты?\n— Нет.\n— А ведра?\n— Нет.\n— А гвозди?\n— Нет.\n— А почему Вы тогда здесь сидите?\n— Потому что замков нет.',
    'Идет игра "Поле чудес". Играющий крутит барабан и стрелка останавливается на секторе "Приз".\nЯкубович:\n— Будете продолжать играть или возьмете приз?\nИграющий:\n— Приз!\n— Я Вам, не глядя, за него даю сто рублей.\n— Приз.\n— Тысячу рублей!\n— Приз.\nЯкубович заглянул в черный ящик и объявил:\n— Пять тысяч рублей!\n— Приз.\n— Тогда Вы можете его взять своими руками.\nИграющий лезет в черный ящик,\n— А-а-а! Крокодил!\n— Это не крокодил, — торжественно возвещает Якубович. — Это медвежий капкан фирмы "Филипс".',
    'Такси. На заднем сиденье сидят двое.\n— Представляешь, там одни и те же рюмки под ликер и водку ставили. Кошмар!\n— А я недавно тоже был. Даже рыбных ножей не положили. Ужас!\nТаксист не выдерживает и говорит:\n— Ребята, ничего, что я к вам спиной сижу?',
    '— Если моя мама собирается у нас жить, — говорит жена мужу, — то, может, нам придется переехать в больший по размеру дом.\n— Ничего не выйдет, — отвечает он. — Рано или поздно она найдет нас и там.',
    'Два брата колхозника. В войну один был партизаном другой — полицаем. После войны первый остался рядовым колхозником, а другой, отбыв срок, пошел в гору: звеньевой, председатель, депутат, загранпоездки… Первый брат интересуется:\n— Почему тебе все так легко дается?\n— Все очень просто. Что ты пишешь обо мне в своих анкетах?\n— Что у меня брат был полицаем.\n— А я, что мой брат — партизаном.',
    'Участковый обращается к хозяину квартиры:\n— Та-ак! Будем судить вас за самогоноварение.\n— Но я ведь не гнал самогон.\n— Ну и что, аппарат же есть?\n— Тогда судите и за изнасилование.\n— А что, Вы кого-то изнасиловали?\n— Нет. Но аппарат же есть!',
    'Грузин сдает экзамен на водительские права. Ему показывают дорожный знак, на котором изображен бегущий лось.\n— Ответьте, что означает этот знак?\nГрузин долго думает, потом отвечает:\n— Звэри.\n— Правильно. А где этот знак устанавливается?\n— За двести метров перед ГАИ.',
    'В школе ЦРУ идет урок русского языка.\nПреподаватель:\n— У кого есть вопросы по теме "Винный магазин"?\n— Сэр, объясните, пожалуйста, во фразе "мужики, кто последний за водкой", в каком месте должен стоять неопределенный артикль "бля"?',
    'Мужчина пришел к одинокой женщине домой. Хозяйка накрыла на стол. Гость выпил, поел, она обняла его:\n— А теперь ты мой.\n— Нет уж, мой сама.',
    'Готовится к запуску новая американская ракета большой дальности. На дереве у стартовой площадки сидят две вороны:\n— Взлетит, — говорит одна.\n— Не взлетит, — говорит другая.\n— А я говорю, взлетит.\n— А я говорю, не взлетит.\nПроисходит запуск, ракета взрывается не взлетев.\n— Ну что, накаркала?\n— Служу Советскому Союзу.',
    'Иван перед свадьбой красит свой член в зеленый цвет.\n— Это зачем? — спрашивает его приятель.\n— Если Машка спросит: "Почему у тебя это зеленого цвета?", я ей скажу: "А где ты другой видела?"',
    'Разговор двух кадровиков.\n— Слушай! Ты теперь евреев берешь на работу?\n— Беру.\n— А где ты их берешь?',
    'Сидит мужик на кухне, читает газету. Вдруг звонок в дверь. Он открывает и видит — стоит обезьяна с ведром и шваброй и говорит:\n— Я из КБО, пришла к Вам окна мыть.\nОн говорит:\n— Проходите, пожалуйста, в комнату.\nА сам сел и стал газету читать.\nВдруг звонок опять. Открывает, а там опять обезьяна стоит. Мужик возмущенно говорит:\n— Да сколько вас еще будет?\nОбезьяна отвечает:\n— Да я все та же, просто у Вас подоконники скользкие.',
    'К дочке приезжает в гости мать. На пороге ее встречает зять:\n— Надолго ли к нам приехали?\n— Да пока не надоем.\n— Значит, чайку не попьете с нами?',
    'На Птичьем рынке мужчина продает комара в банке с надписью:\n"Заменитель мужчины — цена 50 рублей".\n— А как им пользоваться? — спрашивает покупательница.\n— Разденьтесь, лягте и выпустите его из банки. Если что не так — вот телефон.\nПридя домой, женщина открыла банку, комар сел на потолок и сидит себе. Пришлось звонить по телефону. Мужик сразу приехал, разделся и говорит комару:\n— Смотри внимательно, показываю последний раз.',
    'После венчания в церкви жених подошел к священнику:\n— Сколько я Вам должен?\n— Все зависит от красоты Вашей супруги.\nЖених сунул святому отцу 20 копеек. Тот оскорбительно подошел к невесте, заглянул под вуаль и молча вернул жениху гривенник.',
    'Официант подходит к посетителю:\n— Что будешь есть, уважаемый?\n— Шашлык.\n— Так.\n— Цыпленок табака.\n— Хорошо.\n— Зелень.\n— Прекрасно.\n— Виноград.\n— Отлично.\n— Фрукты.\n— Тоже неплохо.\n— Коньяк — 200, сухого — бутылку.\n— Извини, дорогой. Есть только морковные котлеты и чай.\n— Чего же ты раньше не сказал?\n— Хорошо говоришь.',
    'Некто пытается вскочить в трамвай, но попадает под колеса и лишается обеих рук. Ничуть не смутившись, он вскакивает в следующий трамвай и вновь неудачно: ему отрезает ноги. Беднягу вносят в вагон, чтобы отвезти в больницу, но тут он открывает глаза и требует:\n— Прошу всех предъявить билеты!',
    'В застойные годы мужик жалуется друзьям:\n— Вам всем жены по 3,5 рублей дают на обед, а мне только рубль.\nДрузья ему посоветовали любить жену покрепче, как положено. После напряженной ночи мужик засыпает и думает: "Вот теперь она мне утром рублей пять даст".\nУтром проснулся — жена на работу ушла, на столе 50 копеек и записка:\n"С жиру, гад, бесишься!"',
    'После акта девушка говорит парню:\n— А я СПИДом болею.\n— А я тоже.\n— А я пошутила.\n— Значит, больше шутить не будешь.',
    'Автобус стоит на остановке. Шофер достал бутылку:\n— Будет ли кто?\nВсе молчат.\nВыпил, покурил. Достает еще одну:\n— Будет ли кто?\nМолчат. Выпил. Надевает мотоциклетный шлем:\n— Ну что, смертнички, поехали?!',
    'На рынке женщина обращается к продавцу:\n— А где же Ваша лошадь?\n— Какая лошадь? Я продаю кроликов! Вы куда смотрите?\n— Как куда? Я смотрю на ценник.',
    '— Мама! Помнишь, ты мне как-то сказала, что путь к сердцу мужчины лежит через желудок?\n— Да, моя милая.\n— Так вот, я хотела тебе сказать, что прошлой ночью я открыла новый путь.',
    'Мужчина купил новые ботинки. Пришел домой, а никто не замечает. Сходил в душ — выходит голый в новых ботинках. Жена спрашивает:\n— Что это у тебя висит?\n— Это указатель на новые ботинки.\n— Лучше бы ты шляпу купил.',
    'Женщина рассказывает подругам:\n— Представляете, сплю я как-то одна в квартире и слышу шорох. Зажгла ночник и вижу — по комнате шастает мужик, явно вор, но симпатичный. Ну я и говорю ему, чтобы через два часа и духу его не было.',
    'Американец, англичанин и русский хвалятся, что заставят кошку есть горчицу.\nАмериканец хватает кошку и запихивает ей горчицу в пасть.\n— Это насилие, — протестует русский.\nАнгличанин кладет горчицу между двумя кусками колбасы и кошка ее съедает.\n— Это обман! — протестует русский, после чего мажет кошке под хвостом и кошка с воем вылизывает.\n— Обратите внимание, — говорит русский, — добровольно и с песней.',
    'Прохожий бросил монету в чашечку слепого. Монета выскочила из чашечки и покатилась по тротуару, но человек в темных очках быстро ее догнал.\n— А я думал, что Вы слепой, — сказал прохожий.\n— Нет, я не слепой. Я его замещаю, пока он сидит в кино.',
    'Василий Иванович провалился на экзаменах в Военную академию.\nПетька спрашивает:\n— Что тебе задали по математике?\n— Описать квадратный трехчлен.\n— Ну и что. Описал?\n— Что ты Петька! Представить страшно.',
    'В церкви молится грузин, чтобы Бог помог купить ему машину, а рядом молится русский, чтобы Бог помог ему купить пол-литра.\nГрузин:\n— На тебе 10 рублей и не отвлекай Бога мелкими просьбами.',
    'Диалог в двадцать первом веке.\n— Скажите, а противогаз не мешает Вам в интимной жизни?\n— Ну что Вы, наоборот. Во-первых, жена в нем молчит. Во-вторых, я не вижу ее лица. А, в-третьих, когда я затыкаю клапан, она хоть немножко начинает шевелиться.',
    'Ночь. Стук в дверь.\nХозяин: — Кто там?\nГолос:\n— Это я — Тыбыдымский конь.\nХозяин:\n— Иди отсюда.\nГолос:\n— Вот так всегда. Тыбыдым, тыбыдым, тыбыдым…',
    'На скамейке сидит старичок и плачет. Подходит прохожий узнать в чем дело.\n— Мне 78 лет, — всхлипывает старичок. — Дома меня ждет жена-красавица. Она меня так любит, так любит…\n— Ну так вставайте и идите к ней.\n— Я адрес забыл.',
    'В случае чего — как будем воевать с Китаем? Ведь их миллиард с лишним?\n— Справимся. Не числом, а умением, как евреи с арабами.\n— А евреев-то хватит?',
    'Профессор, последователь Мичурина, читает лекцию в институте.\nВдруг — стук в дверь, входит секретарша и говорит:\n— Ваша жена доставлена в больницу в тяжелом состоянии.\n— Что случилось? Она полезла на яблоню за укропом, а на нее арбуз упал.',
    '— Послушай, Зин! У нас такая маленькая квартира, а тут еще дядя Вася… Попросился переночевать одну ночь, а живет с нами второй год. Ты бы с ним поговорила…\n— А почему я?\n— Ну а кто же? Ведь твой же дядя?\n— Мой? А я-то все время думала, что твой…',
    'Два человека встречаются на том свете.\nПервый спрашивает:\n— Как ты сюда попал?\n— Упал с четырнадцатиэтажного дома. А ты?\n— Смотреть надо — куда падаешь!',
    'Лекция в институте на тему психологии.\nПрофессор: — Сейчас я вам покажу три степени раздражительности. Вот я беру телефонную книгу и набираю первый попавшийся номер. Подключаю к динамику, чтобы все слышали.\nНабирает номер телефона:\n— Алло! Позовите Павлика.\nГолос:\n— Нет! Вы ошиблись. Здесь таких нет.\nПрофессор:\n— Это была первая степень раздражительности, а теперь вторая.\nНабирает опять тот же номер:\n— Алло! А Павлик дома?\nИз трубки раздраженно:\n— Здесь нет никакого Павлика! Внимательно набирайте!\n— Это была вторая степень раздражительности, теперь третья.\nНабирает номер.\n— Алло! Павлика можно?\nИз трубки слышится отборный мат.\n— Это была третья степень раздражительности. У кого какие вопросы?\nОдин студент поднимает руку:\n— Профессор, я могу показать высшую степень раздражительности.\nСнимает трубку, набирает все тот же номер:\n— Алло! Здравствуйте. Я Павлик. Мне никто не звонил?',
    'Стук в дверь.\n— Кто там?\n— Милиция.\n— Никого нет дома.\n— А кто говорит?\n— Говорит Москва. 12 часов московское время.',
    'Десантник отказывается прыгать, кричит:\n— Двенадцать раз прыгал, двенадцать раз парашют не раскрывался! Не хочу! Не хочу!\nВсе-таки выпихнули его из самолета. А в совхозе в это время идет собрание. Председатель говорит:\n— Ну вот, механизаторы опять все пьяные, доярки в декрете, топлива нет…\nСтрашный грохот наверху на крыше.\n— И этот десантник… ну так надоел.',
    'В купе едут мужчина и женщина. Мужчина предлагает:\n— Давайте отгадывать профессии. Вот моя, например, начинается на "и" и заканчивается на "р"…\n— Наверное, инженер…\n— Правильно! А ваша?\n— Начинается на "б", а заканчивается "ь"…\nПовисла неловкая пауза.\n— Библиотекарь, — отвечает женщина, — а то что Вы одумали — мое хобби.',
    '— Мама, — кричит в трубку телефона дочь. — Уже два часа ночи, а мужа все нет. Он, наверное, любовницу себе завел!\n— Доченька! Зачем сразу подозревать худшее? Может, он попал под машину и лежит в реанимации или в морге.',
    'Идет Красная Шапочка по лесу. Вдруг удар по голове. Очнулась и видит записку:\n"Красная Шапочка, ты больше не девочка" и подпись: "Али-Баба и сорок разбойников".\nРасстроилась Красная Шапочка, идет дальше и снова удар по голове.\nОчнулась, опять записка:\n"Красная Шапочка, ты снова девочка" и подпись: "Тимур и его команда".',
    'Встречаются Кощей и Баба-Яга.\n— Куда путь держишь, старуха?\n— На север, Кощеюшка, на север.\n— Далеко ли?\n— В заполярный гарнизон Дурундук.\n— А зачем?\n— Да надоело в девках ходить. Дай, думаю, выйду замуж за офицера.\n— Да кто ж тебя такую возьмет.\n— Не скажи, Кощеюшка, не скажи. Это здесь я Баба-Ята, а там я Василиса Прекрасная.',
    'Человек устраивается работать на базу. Ему объясняют:\n— Здесь у на черная икра, здесь красная, здесь балык, здесь осетрина…\n— Простите. А сколько я буду получать?\n— 80 рублей.\n— Мало.\nУтром приходит другой. Ему все так же показывают. Он молчит.\n— Простите. А Вас не интересует, сколько Вы будете получать?\n— Как! У вас здесь еще и платят?',
    'Два охотника с собакой отправились на уток. Вечером идут усталые и подавленные, без добычи. Один спрашивает другого неуверенно:\n— Может, собаку надо было подбрасывать повыше?',
    'В парке молодой папа толкает коляску, в которой громко плачет ребенок.\nОтец тихо повторяет: —\nСпокойно, Вася. Успокойся, Вася.\nНавстречу идет старушка и замечает:\n— Ребенок все равно Вас не понимает. Взяли бы лучше его на руки и успокоили.\n— Видите ли, — отвечает папа. — Вася — это я.',
    'Танкисты чинят у танка гусеницу. Вдруг появляется фея и спрашивает:\n— Чем вы занимаетесь?\n— Да вот с гусеницей трахаемся.\n— А хотите по — настоящему?\n— Конечно хотим.\nФея взмахнула палочкой и… у танка отвалилась башня.',
    'Создали американцы робота, заменяющего мужчину. Пригласили русскую, американку и немку на испытания. Первой пошла американка.\nЧерез некоторое время выбегает:\n— Прекрасно!\nНемка выбежала, закричала:\n— Колоссально!\nПрошла русская. Час, два, три — нету. Потом крик:\n— Я тебе покажу — "батарейки сели"!..',
    '— Дорогой, мне так не хочется идти в гости к родственникам.\n— Мне тоже. Но ты представь, если мы не пойдем, как они обрадуются.\n— Да. Надо идти.',
    'Хазанов не был в кулинарном техникуме на занятиях три дня.\nПреподаватель спрашивает:\n— Ты почему прогулял первый день?\n— На бабу залазил.\n— А второй день?\n— С бабы слазил.\n— Интересно. А третий день?\n— Отходил. Весь день руки, ноги тряслись.\n— Да где же ты такую бабу нашел?\n— Да возле ВДНХ, с серпом стоит.',
    'На берегу реки скамейка. На ней деревенская парочка. На другом берегу тоже скамейка, но на ней парочка городских.\n— Вань, а Вань! Гляди, городские обнимаются.\nВаня молчит.\n— Вань, а Вань! Городские уже целуются.\nВаня молчит.\n— Вань, а Вань! Ну сделай хоть что-нибудь.\n— Ну хочешь, я тебе руку сломаю.',
    '— Жора! Почему ты такой желтый?\n— Да моча в голову ударила.\n— А почему синяк под глазом?\n— А ты что думал, горшок мимо пролетел?',
    '— Товарищ проводник. Разбудите меня перед станцией Раздельная.\n— Вам там выходить?\n— Нет. Моему соседу.\n— А зачем Вас будить? — Я хочу посмотреть, как он проспит свою станцию.',
    'Мужик приходит на работу. Начальник спрашивает:\n— Почему опоздал?\nМужик оправдывается:\n— Да вот вчера днем покрасил пол, сегодня забыл. Встал ногой в краску и прилип. Пока отдирал одну ногу, прилип другой. Только отодрал вторую ногу, пришла соседка. Пока отодрал соседку — время ушло.',
    'Сидит милиционер в машине и резинкой от трусов мух на лобовом стекле бьет. И вдруг одна муха говорит:\n— Не бей меня, я тебе три желания исполню.\nМилиционер не растерялся:\n— Хочу дачу под Москвой и новую машину.\nИ очутился милиционер на роскошной даче, а под окном машина.\n— А третье желание?\n— Хочу не работать и чтоб деньги были.\nВ этот же момент очутился милиционер в старом автомобиле и как прежде щелкает мух резинкой.',
    'Едут два грузина в машине. Один другого спрашивает:\n— Гоги, можно я пукну?\n— Можно, — отвечает Гоги.\n— Ну что, пахнет?\n— Нет, — говорит Гоги.\n— А можно я еще пукну? — спрашивает друг.\n— Нет, — отвечает Гоги.\n— А что, Гоги, все-таки пахнет?\n— Нет. Глаза режет.',
    'Таможенник на границе спрашивает:\n— Анаша, героин, марихуана?\nПроходящий контроль мужик:\n— Да нет, не нужно. У меня у самого этого добра чемодан.',
    'Один мужик загорал с сыном на пляже, а теща купалась. Вдруг она стала тонуть.\n— Смотри, папа! — закричал сын. — Бабушка рукой машет.\n— Что ж ты сидишь, сынок. Помаши и ей на прощанье.',
    'Сидят парень с девушкой на скамейке.\nПарень говорит:\n— Дорогая, можно я позволю себе небольшую шалость?\n— Можно, — говорит, вздохнув, девушка и зажмуривается.\n— Ну вот и все. И совсем не пахнет. Правда?',
    'Сидит мужик, ловит рыбу. Вдруг всплывает американская подводная лодка. На мостике появляется капитан.\n— Мы где находимся, дружище?\n— Пошел на х…!\nКапитан в лодку.\n— Ребята! Мы в России!',
    'Муж спрашивает жену:\n— Ну как ты сходила в гости?\n— О, это был прекрасный вечер. Петровы попросили меня спеть. И я спела им романс.\n— Молодец, Ненавижу этих Петровых.',
    'В парикмахерской сидит молодой человек с очень длинными волосами. Вокруг него ходит парикмахер с магнитом и водит им над головой клиента.\n— У вас что, новый способ стрижки?\n— Нет. Просто я ищу ножницы.',
    'Д`Артаньян вызвал Илью Муромца на дуэль и мелом поставил ему на груди крестик.\n— Зачем это? — спрашивает Илья Муромец.\n— В этом месте я тебя проткну.\n— Добрыня! Обсыпь его мелом.',
    'Приходит мужчина в магазин и спрашивает:\n— У вас трусы есть?\n— Нет, — отвечает продавщица.\n— А в продаже?',
    'На остановке трогается автобус с открытыми дверями. За автобусом бежит мужчина с арбузом. Машет рукой и что — то кричит. Автобус едет под уклон и прибавляет ход. Мужчина падает, арбуз в куски. Пассажиры помирают от смеха. Мужчина вскакивает, продолжает что — то кричать и бежать.\nОдна дама высовывается из окна и кричит ему:\n— Мужчина! Перестаньте бежать. Мы тут от смеха уписались!\n— Сейчас усретесь, я водитель автобуса!',
    'Пассажиры садятся в самолет. Среди них молодой человек с синяком под глазом и в одних трусах. Один из пассажиров подходит к нему и говорит:\n— Послушай! А ты поприличней не мог одеться?\n— Ты понимаешь, я — невезучий. Вот сейчас только вышел из дома, на меня напали, обокрали и раздели. Один билет только остался.\nОни садятся в самолет. Их места оказались рядом.\nНевезучий продолжает разговор:\n— Вот посмотришь, до места не долетим, я ж невезучий.\nВыходит стюардесса и говорит:\n— Просьба не паниковать, наш самолет падает в океан. Сейчас вам выдадут спасательные жилеты и свистки для отпугивания акул.\n— Ну вот, что я говорил! А теперь или жилет попадется дырявый, или акула глухая.',
    'В магазине:\n— Синька есть?\n— Есть.\n— Какого цвета?',
    '— Ваши права?\n— Права? Неужели Вы их потеряли? Ведь я их отдал Вам на прошлой неделе.',
    'Гномик в аптеке.\n— Дайте мне, пожалуйста, пирамидон.\n— Вам завернуть?\n— Нет, я так покачу.',
    'В аптеке.\n— Нет, нет. Чтобы купить мышьяк, нужен рецепт с печатью. Одной фотографии Вашей тещи недостаточно.',
    'На могильной плите надпись:\n"Спи спокойно, дорогой Гиви, факты не подтвердились".',
    '— Ты никогда не бывал в Самаре?\n— Нет, никогда.\n— Тогда ты должен знать мою сестру, она тоже никогда там не бывала.',
    '— Мама, скажи, как тебе удалось отучить папу грызть свои ногти?\n— Очень просто! Я спрятала его вставную челюсть.',
    'Пожилого официанта спросили, какова самая заветная мечта в его жизни?\nОн отвечает:\n— Чтобы все гости ели и пили дома, а чаевые присылали по почте.',
    'Новичок на рыбалке.\n— Что это значит, сосед? Видите, поплавок почему-то все время тонет.\n— Сидите спокойно! Это бракованный поплавок!',
    'Выходя из ресторана, жена тихо говорит мужу:\n— Нет, ты сошел с ума! Дал гардеробщику десять рублей!\n— Дура! Посмотри, какую он мне дал шапку!',
    '— Посмотри, Сема! В твоем пиве плавает муха!\n— Всего одна. Ну, сколько она может выпить?!',
    'Жена приходит к мужу и обнимает его.\n— Ты меня любишь?\n— Короче. Что тебе купить?',
    'В купе поезда сидят два пассажира. Один долго рассматривает другого, а потом говорит:\n— Вы знаете, если бы не усы, Вы были бы страшно похожи на мою жену.\n— Да, но у меня нет усов.\n— Зато у жены есть.',
    'С высотной стройки летят вниз два кирпича. Один — другому:\n— Говорят, сегодня погода нелетная…\n— Да черт с ней, с погодой, лишь бы человек хороший попался.',
    '— Вы на рояле играете?\n— Нет, карты скользят.',
    'На кладбище в Елопове. На плите надгробная эпитафия:\n"Ну что, фраеры из профсоюза, поверили, что я болел? "',
    'По Тверской идет пожилая дама. К ней подходит молодой человек, видимо приезжий.\n— Простите, Вы не знаете, где здесь магазин имени Елисеева?\n— Вон там, только не имени, а памяти.',
    'В музее перед статуей Венеры стоят отец с маленьким сыном.\nОтец:\n— Если ты будешь грызть ногти, с тобой будет то же самое.',
    'Возмущенная покупательница говорит продавцу в отделе сыров:\n— Я не понимаю, что Вы мне сказали об этом сыре? Он прислан из Швейцарии или выслан оттуда?',
    '— Где Ваш супруг?\n— Дома, со своим четвероногим другом.\n— Я и не знал, что Вы обзавелись собакой.\n— Это вовсе не собака, а диван.',
    '— Что такое смешанное чувство?\n— Это тогда, когда собственная теща на собственной "Волге" зятя катится в пропасть.',
    '— Сколько цехов на заводе "Серп и молот"?\n— Три: цех серпов, цех молотов и сборочный.',
    '— Знаешь, почему я заплакала? — спрашивает жена мужа, выходя из универмага.\n— Знаю, но у меня таких денег нет.',
    'Портной снимает мерки: первая — 120 см, вторая — 120 см, третья — 120… - Мадам, где будем делать талию?',
    '— Давно ли охотитесь на слонов?\n— Да нет, недавно. Я приехал сюда ловить бабочек и потерял очки.',
    'Парикмахер спрашивает клиента:\n— Вас как подстричь?\n— Молча.',
    'Женщина о современных мужчинах:\n— Положишь на себя — спит, положишь под себя — задыхается, положишь на бок — смотрит телевизор, по — ставишь на ноги — и след простыл.',
    '— Знаешь, дорогая, почему рыбы немые?\n— Не знаю.\n— А ты сунь голову в воду и попробуй что-нибудь сказать.',
    'Один человек всегда любил преувеличивать, даже в анкете, в графе "место рождения", писал Восьмипалатинск.',
    'Сторож на пляже:\n— Гражданин, вылезайте из воды. После 8 часов купаться запрещается!\nГолос из воды:\n— Я не купаюсь, я тону!',
    'В троллейбус вбегает мужчина и с ходу хватает женщину за грудь.\n— Хам, как Вам не стыдно! Что Вы делаете?\n— Простите, я думал, что началась давка.',
    'Один мужик стоит на трамвайной остановке и хохочет.\n— Чего Вы смеетесь? — спрашивают его.\n— Да я кондуктора обманул, взял билет и не поехал.',
    'Из разговора в поезде:\n— Вы знаете, у меня жена — ангел!\n— Счастливец, а моя еще жива.',
    '— Как строят заборы?\n— Пишут слово из трех букв и прибивают к нему доски.',
    '— Пап, а почему бабушка по огороду зигзагами бегает?\n— Для кого бабушка, а для кого теща. Отойди, не мешай целиться!',
    'Секретарша директору:\n— Вы что, меня уволили?\n— Нет, с чего Вы взяли?\n— А диван почему убрали?',
    '— Извините, что деньги мокрые, — сказала дама продавцу меховом магазине. — Муж так рыдал, когда отдавал их мне.',
    'Он и она занимаются любовью.\nОна:\n— Вась, ты меня любишь?\n— А я что делаю?',
    '— Вась, может, поженимся?\n— Ладно, созвонимся.',
    'Одну женщину спросили:\n— Что Вы делаете вечером?\n— Все!',
    'В квартире свадьба. В самый разгар веселья — звонок. Открывают дверь. На площадке стоят два здоровенных лба.\n— Мы из бюро добрых услуг. Вы драку заказывали?',
    '— У Вашего мужа перелом руки.\n— Доктор, Вы что — то от меня скрываете? Я готова услышать самое худшее. Скажите правду: он сможет мыть посуду?',
    'Разговор двух приятелей:\n— Слушай, Ваня, я уже два месяца не имел женщину.\n— Так у тебя же есть жена.\n— Ты бы еще маму вспомнил.',
    'Начальник спрашивает своего подчиненного:\n— Почему Вы ежедневно опаздываете на работу?\n— Да я у стенки сплю, как утром начинаю перелезать…',
    'Начальник говорит секретарше:\n— Я еду в Госснаб, а от нее домой.',
    '— От любви с первого взгляда есть прекрасное лекарство.\n— Какое?\n— Взглянуть второй раз.',
    '— В зарубежной печати можно встретить утверждения, как будто закон всемирного тяготения открыл англичанин Ньютон, — говорит лектор.\n— Однако, еще задолго до Ньютона, закон этот действовал на Руси.',
    '— Никак не подберу себе жену. Девушки не нравятся матери.\n— А ты выбери такую, чтобы она была похожа на нее.\n— Нет, что ты! Тогда у моего отца инфаркт будет.',
    '— Это ужасно, — ругается жена. — Ты стал часто приходить за полночь, будишь меня и я не могу уснуть.\n— Давай мне больше денег и я буду приходить утром.',
    'В дверь квартиры стучатся грабители.\n— Кто там?\n— Не бойтесь, не гости.',
    '— Если ты мне откажешь, — сказал он, — я умру.\nОна отказала.\nЧерез шестьдесят лет он умер.',
    'Жена подает на развод.\n— А какой повод у Вас для развода? — спрашивает ее судья.\n— Он заставляет меня есть все, что я приготовила.',
    'Старушка с интересом заглядывает в коляску:\n— Какие изумительные близнецы! Оба мальчика?\n— Нет, только слева, — отвечает хозяин коляски, — справа дыня.',
    'В магазин заходит мальчик и спрашивает продавщицу:\n— Тетенька, у вас есть булочки с маком?\n— А батон с анашой не хочешь?',
    'Мастер помощнику:\n— Пойди, окна покрась.\nЧерез некоторое время тот возвращается и спрашивает:\n— А рамы тоже красить?',
    'За утренним чаем жена говорит мужу:\n— Завтра исполняется двадцать два года, как мы женаты, не зарезать ли по этому поводу курицу?\n— Еще чего! Курица ни в чем не виновата!',
    '— Официант, почему это блюдо так странно называется: "Разбойничье рагу"?\n— Вы это поймете, когда я принесу счет.',
    '— Когда Ваша сестра думает выйти замуж?\n— Всегда!',
    'Наркоман идет по рельсам и видит перерезанную крысу:\n— Ой какие мы нежные. Ну прямо Анна Каренина.',
    'Жена:\n— Мне сегодня в метро трое мужчин уступили место.\nМуж: — И тебе хватило?',
    'Жена говорит мужу:\n— Я сбегаю к соседке на минутку, а ты помешивай кашу каждые полчаса.',
    '— Холме, объясните мне такое явление: когда я захожу в туалет, свет сам зажигается, а когда выхожу — гаснет.\n— Это элементарно, Ватсон. Не путайте туалет с холодильником.',
    'Идет мужик по лесу.\n— Кукушка, кукушка! Сколько мне осталось жить?\n— Ку…\n— А почему так ма…? — Упал и умер.',
    'Смотрит муж на свою жену и говорит:\n— Была бы ты чужой — цены бы тебе не было.',
    'Зять похоронил тещу. Возвращается домой. Сверху с крыши ему падает сосулька. Он поднял глаза к небу:\n— Господи! Эта сволочь уже на небе!',
    'Жена спрашивает мужа в канун Нового года:\n— В прошлом году мы подарили маме стул. А что по — дарим в этом году?\n— Проведем в стул электричество.',
    'Один пилот говорит другому:\n— Скажи парашютистам, чтобы перестали прыгать. Мы еще не взлетели.',
    '— Как только я увижу тебя, так сразу вспоминаю Ковалева.\n— Но ведь я же не похож на него.\n— Это верно, но он тоже должен мне 50 рублей.',
    '— Я придумал новое ругательство; "небоскреб"!\n— Что ж тут ругательного?\n— Во-первых, — звучно, во-вторых, — многоэтажно, а, в-третьих, какова концовочка!',
    'Обломов кричит на всю усадьбу:\n— Иван! Иван!\nПрибегает Иван.\n— Что угодно, барин?\n— Хочу трахаться!\nИван, стягивая свои портки, со вздохом говорит:\n— Жениться Вам, барин, пора.',
    'Мужчина летит с двенадцатого этажа. На балконе пятого стоит обнаженная девушка.\n— А-а-а! Ух, ты!.. А-а-а!',
    '— Что Вы такой грустный?\n— Меня вчера в подъезде хотели побить.\n— С чего Вы взяли, что хотели?\n— Если бы не хотели, не побили…',
    'Грузин подходит к родильному дому и кричит жене, которую видит в окне:\n— Кто родился, мальчик?\nЖена отрицательно кивает головой.\n— А кто?',
    'Грузин спрашивает у русского:\n— Сколько ты зарабатываешь?\n— Когда двести, когда триста, а когда триста пятьдесят.\n— Понятно, день на день не приходится.',
    'Придя домой после ночи картежной игры, муж радостно сообщает жене:\n— Знаешь, как мне сегодня повезло в карты? Мой синий костюм, что ты мне сшила за двести рублей, я проиграл как за шестьсот.',
    '— Маэстро! — обращается дама к художнику. — Вы можете нарисовать мой портрет в обнаженном виде?\n— Нет ничего проще, — отвечает художник и начинает раздеваться.',
    'Жена говорит мужу:\n— Посмотри, как наш сын стал хорошо учиться с тех пор, как мы ему платим за хорошие оценки.\n— Да, я знаю, но мне кажется, что он вошел в долю с учителем.',
    '— Пять лет назад мы с мужем отдельно отдыхали друг от друга.\n— И Вашему мужу понравилось?\n— Не знаю, он еще не вернулся.',
    'Через несколько месяцев после знакомства.\n— Дорогой, не пора ли тебе познакомить меня со своими родными?\n— Даже не знаю как. Дети сейчас у тещи, а жена в отпуске.',
    'Человек идет по улице в одном сапоге. Его спрашивают:\n— Что, мужик, сапог потерял?\n— Нет, нашел.',
    '— Что нового?\n— Жена мне изменяет.\n— Ты не понял. Я спрашиваю: что нового?',
    '— Господин учитель, папа говорит, что мы произошли от обезьян.\n— Происхождение вашей семьи меня не интересует.',
    '— В какой институт принимают без вступительных экзаменов?\n— В институт Склифосовского.',
    '— Итак, Вас обвиняют в шарлатанстве. Вы продавали своим клиентам эликсир вечной молодости. Осуждались ли Вы ранее?\n— Да. В 1600, в 1750 и в 1895 годах.',
    '— у Вас вши есть?\n— Есть.\n— А чем Вы их лечите?\n— А они у меня не болеют.',
    '— Вы будете платить пошлину?\n— Нет. Я все везу контрабандой.',
    'Девушка останавливает машину и просит довезти ее до города.\nВодитель говорит:\n— Сегодня уже восьмую женщину везу до города.\n— А я не женщина!\n— Ну так еще и не город.',
    'В бане Петька трет спину Чапаеву:\n— Василий Иванович! Майка показалась.',
    'Жена врачу:\n— Доктор! Есть хоть какая-нибудь надежда?\n— В зависимости от того, на что Вы надеетесь, мадам.',
    '— Как правильно говорить: "сратостат" или "статосрат"?\nОтвет:\n— Если вы не умеете говорить правильно, говорите "дирижопль".',
    '— Что делать, если на Вашу тещу напал тигр?\n— Сам напал, сам пусть и защищается.',
    '— Что самое ценное в женском молоке?\n— Тара.',
    '— Где у женщины аппендицит?\n— Как войдешь — налево.',
    'Два яйца в кастрюльке. Одно другому говорит:\n— Смотри-ка. Всего 10 минут варимся, а уже такие крутые.',
    'Летят две утки, корова и лошадь. Одна и говорит:\n— Это надо же! Вроде на север и юг летим, а все четверг!',
    '— Твоя жена дома? — Нет. Она на аукционе.\n— Черт возьми! И сколько ты думаешь за нее получить?',
    '— Сколько тебе понадобилось, чтобы научиться летать?\n— Точно не помню. Но примерно, семь, восемь.\n— Месяцев?\n— Самолетов.',
    '— Наш детский сад только для детей военнослужащих. Мы вас не запишем.\n— Как это не запишете, если он у меня от неизвестного солдата?!',
    'Звонок в дверь:\n— Кто там?\n— Джек-потрошитель!\n— Дорогая, это к тебе.',
    '— Девушка, можно Вас на минуточку?\n— А Вы успеете?',
    'Колобка приговорили к расстрелу. Поставили к стенке и говорят:\n— Твое последнее желание?\n— Только не в голову.',
    '— Официант! Что это ползет по салату?\n— Витамины, сэр.',
    'Едут в купе трое, знакомятся.\n— Иван — москвич.\n— Грицко — запорожец.\n— Мамед — ГАЗ — 24.',
    '— Послушайте, Вы у меня пятый раз покупаете билет, — говорит кассирша мужчине.\n— Да. Но там, на входе, какой — то идиот их все время рвет.',
    '— Как Вы собираетесь отметить серебряную свадьбу?\n— Минутой молчания.',
    '— Мама! Ты знаешь, где умер Наполеон?\n— Где?\n— На Святой Елене.\n— И таким гадостям вас учат в школе?',
    '— Что ты такой грустный?\n— От меня ушла жена…\n— Я тебе сочувствую.\n— Я не договорил… а сегодня вернулась.',
    'Разговор двух подружек:\n— Знаешь, это так интересно — быть замужем за художником. Он рисует, а я готовлю, а потом вместе разгадываем, что у кого получилось.',
    '— За что Вас списали с подлодки?\n— Я спал с открытым окном.',
    '— Мадам! Вы обладаете даром очаровывать мужчин!\n— Даром? Во… — и показывает фигу.',
    '— Шеф! Вы опять поссорились с женой? — спрашивает секретарша своего начальника, когда он утром входит в офис.\n— Как Вы догадались?\n— Очень просто. У Вас из спины торчит кухонный нож.',
    '— Доктор, скажите, неужели целоваться взасос вредно?\n— Да.\n— А почему?\n— Пломбы вылетают.',
    'Администратор гостиницы спрашивает молодоженов:\n— В котором часу вас разбудить?\n— В час, три и в пять.',
    'В конторе у секретарши начались родовые схватки. Директор посылает своего зама срочно отвезти ее в роддом. Через некоторое время зам звонит шефу по телефону:\n— Маша родила двойню. Мой умер, Ваш весит 3,5 кг',
    '— Ребенок: никак не хочет уснуть, — мать говорит мужу. — Может, мне спеть ему что-нибудь?\n— Ну зачем сразу так? — отвечает муж. — Попробуй с ним сначала по-хорошему.\n—\nБабка приходит на прием к врачу.\n— Бабушка! Вы беременны.\n— Вот чертовы внуки! Сначала расскажи, потом покажи, а потом дай попробовать!\n—\n— Официант! Нельзя ли немного устриц — свежих, вкусных, хорошо очищенных, не очень крупных и охлажденных?\n— Можно конечно! Вы только не уточнили — Вам с жемчужиной или без?',
    '— Скажите, пожалуйста! Какое сегодня число?\n— Зачем Вы спрашиваете, у Вас же в руках газета?\n— Так это же вчерашняя.',
    'Жена говорит мужу:\n— Я уже не знаю, как штопать твои носки — дырка на дырке.\n— А ты их к туфлям пришей.',
    '— Дорогая Нора! — воскликнул молодой человек. — Ты все, что у меня есть на свете!\n— Боже мой! Что случилось? Неужели ты разбил свою машину?',
    'Встречаются в небе два облака. Одно другому:\n— Отольем?',
    '— "Скорая"?! Тут человек под асфальтный каток попал!\n— Адрес, где он лежит.\n— Проспект Ленина, 21,23,25.',
    'Из протокола собрания:\nГоворили за жизнь. В конце состоялось голосование: "За" — 39 человек, "Против" — 16.',
    '— Я укладчик парашютов! На мою работу никто еще не приходил\nжаловаться!',
    'Парень приглашает девушку танцевать:\n— Можно Вас?\n— Можно, но сначала давайте потанцуем.',
    'Состоялся Всемирный конгресс женщин. На повестке дня стояли три вопроса:\n1. Все мужчины сволочи.\n2. Носить нечего.\n3. Разное.',
    '— Почему ты ходишь только на поминки и никогда не бываешь на свадьбах?\n— Потому что на поминках никто не спрашивает: "А ты когда?"',
    'Жена перелистывает записную книжку мужа:\n— А что это у тебя за новый телефон появился? — спрашивает она ревниво.\n— Дура! Это стоимость авиабилета от Москвы до Хабаровска!',
    'Сидит мужчина в парикмахерской, а на него собака уставилась. Он спрашивает парикмахера:\n— Почему она на меня так смотрит?\n— Иногда вместе с волосами уши падают, а она их обожает.',
    'Два приятеля беседуют о жизни:\n— Мой дом настоящий рай!\n— В каком смысле?\n— Я — Адам, жена — Ева, теща — Змея.',
    '— Мучают ли Вас эротические сны? — спрашивает психиатр.\n— Почему мучают? — спрашивает клиент.',
    'Летит по лесу ворона в каске. Не смешно? Зато про войну.',
    'Доктор:\n— На что жалуетесь?\n— У меня ноги чернеют.\n— А Вы их мыть пробовали?\n— А что, помогает?',
    '— Сынок! Не ходи каждый вечер на дискотеку. Оглохнешь.\n— Спасибо, мама! Я уже пообедал.',
    '— Дорогая! — обращается облысевший сердцеед к юной красавице. — Что я должен дать Вам, чтобы добиться Вашей любви?\n— Наркоз.',
    'В отделе кадров:\n— Как долго Вы работали на последнем месте?\n— Восемь лет.\n— А почему ушли оттуда?\n— Объявили амнистию.',
    'Встретились два друга:\n— Слушай! Сколько ты даешь за мою жену?\n— Да нисколько.\n— Договорились.',
    'Встречаются два грузина.\n— Эх, Вано, если бы ты знал, как это тяжело — потерять жену! -\n— Знаю, Гоги, знаю. Практически невозможно.',
    'Корреспондент берет интервью:\n— Вот Вы, инженер, кандидат наук, мать двоих детей! Как же Вы стали валютной проституткой?\n— Даже не знаю. Просто повезло, наверное.',
    'Приходит мужик в телеателье, приносит телевизор:\n— Вот! Сижу вечером, смотрю телевизор, в ушах гвоздиком ковыряю, и вдруг… бац — звук пропал!',
    'Армянское радио спрашивают:\n— Что такое "тютелька в тютельку"?\nАрмянское радио отвечает:\n— Точно мы не знаем, но что — то из интимной жизни лилипутов…',
    'Женщина подбегает к длинной очереди, спрашивает:\n— Что дают?\n— Кристи!\n— А это лучше драпа?\n— Не знаю, еще не пил.',
    '— Знаете, как привести в действие польский парашют?\n— Он открывается автоматически при ударе о землю',
    'Вопрос:\n— Что мужчины делают стоя, женщины — сидя, а собака — поднимая одну лапу?\nОтвет:\n— Здороваются. Но мы догадались, о чем подумали вы.',
    '— Ты мне своей мини — юбкой весь вечер испортила\n— А ты мне своим мини — членом — всю жизнь.',
    'Едут двое в трамвае. Сидят напротив. Молчат. Один тяжело вздохнул.\nВторой:\n— А Вы думаете у меня тещи нет?',
    'Одна дама подходит к другой и говорит:\n— Скажите, Вам никогда не говорили, что Вы похожи на Брижит Бардо?\n— Нет, никогда.\n— И правильно.',
    'Жена мужу:\n— Тебе не удастся меня отговорить. Я все равно брошусь с балкона! Не хочу жить с таким бабником. И перестань меня подталкивать.',
    '— Ты знаешь, как легче всего убить осу?\n— Нет.\n— Загони ее под шкаф и отпили ножки.',
    '— Что было раньше: яйцо или курица?\n— Раньше было все.',
    '— Коля! Почему ты не пришел на нашу свадьбу?\n— Из-за двух слов.\n— Каких?\n— Не пригласили.',
    'Спрашивают русского туриста в Турции:\n— Правда, что в России дураков много?\n— Правда, но мы их больше турками зовем.',
    '— Вот женишься, сынок, тогда поймешь, что такое счастье.\n— Да?\n— Да. Но будет поздно.',
    'Иван с Марусей занимаются любовью. С ее стороны — ноль эмоций.\nИван спрашивает:\n— Марусь, у тебя хоть матка-то есть?\n— Нет, я круглая сирота.',
    'Двое в кровати:\n— Вань, во мне есть хоть что-нибудь хорошее?\n— Да, но скоро выну.',
    'Шесть основных противоречий социализма:\n1. Нет безработных, но никто не работает.\n2. Никто не работает, но план выполняется.\n3. План выполняется, а в магазинах ничего нет.\n4. В магазинах ничего нет, а у всех все есть.\n5. У всех все есть, но все недовольны.\n6. Все недовольны, но все "за".',
    '— Является ли коммунизм наукой?\n— Нет, если бы коммунизм был наукой, его сначала попробовали бы на собаках.',
    'Ленин говорил:\n— В партии есть только три настоящих коммуниста: Ульянов, Ленин и я.',
    'У Ленина спрашивают:\n— Лучше иметь жену или любовницу?\n— И жену и любовницу. Жене говоришь, что пошел к любовнице, а любовнице говоришь, что будешь у жены. Самому же можно забраться на чердак и учиться, учиться и еще раз учиться.',
    '— Никогда не думал, что ЦК подложит мне такую свинью, — сказал Ленин в марте 1953 года.',
    'Воскрес Ленин и сразу направился в пивную пообщаться с пролетариатом. Рабочие стоят, выпивают и не обращают на вождя внимание.\n— Что, товарищи, не узнали меня?\n— Вань, гляди, червонец!',
    '1930 год. Рабинович приходит к ребе.\n— Ребе! Меня заставляют вступить в колхоз, а я не знаю: вступать или не вступать?\nВ этот момент вбегает невеста, отталкивает Рабиновича, обращается к ребе:\n— Скорее! Я прямо со свадьбы! Сегодня первая брачная ночь! Ребе, скажите, мне в рубашке ложиться или без рубашки?\n— В рубашке или без рубашки, все равно тебя трахнут… И к Вам, Рабинович, это тоже относится.',
    'Идет партсобрание. Парторг:\n— Абрамович! Почему Вы не выступаете? У Вас, что, нет своих мыслей?\n— Почему же, есть.\n— Так почему же Вы молчите?\n— Я с ними не согласен.',
    'В аду переизбирают секретаря парторганизации. Предложили одного длинноволосого, бородатого. Рекомендуют, потому что в теории подкован.\nОн дает себе самоотвод.\n— Не гожусь для текущего момента.\n— Почему?\n— Во — первых, почти всю жизнь я прожил за границей. Во — вторых, у меня жена дворянского происхождения, в — третьих, я еврей.\nИз задних рядов:\n— Имя! Назовите имя!\nБородатый:\n— Карл. Карл Маркс.',
    'Вытащил дедка колхозную репку. Посадили дедку за репку, бабку за дедку, внучку за бабку, Жучку за внучку, кошку за Жучку, а мышку — посмертно реабилитировали.',
    'В колхозе была объявлена лекция о любви со слайдами. Вечером клуб заполнен до отказа.\n— Есть четыре типа любви, — начал лектор. — Первый — это любовь между мужчиной и женщиной. Второй — это любовь между двумя женщинами. Третий — это любовь между двумя мужчинами. А вот четвертый тип — это любовь к нашей Партии. Вот о нем и будем сегодня говорить. Товарищ Иванов! Давайте слайды!',
    'Сталину доложили, что обнаружился его двойник.\n— Расстрелять! — приказал Сталин.\n— А может, сбрить усы, товарищ Сталин?\n— Ха-а-а-рошая мысль! Сбрить усы и расстрелять!',
    'Заявление:\n"Генеральному секретарю ЦК КПСС тов. Сталину И.В. от гражданина Рабиновича И.М., заявление: прошу расстрелять меня по собственному желанию, 15.05.1937 года".',
    'В концлагере сидят: американец, француз, англичанин и русский.\nПриходит эсэсовец.\n— Сейчас мы вас расстреляем. Но так как мы гуманная нация, то можем выполнить последнее желание каждого.\nОдин попросил на последнее желание — возлюбленную, другой — стакан виски, третий еще что-то, а русский говорит:\n— Дайте мне пинка под зад, да посильнее.\nУдивились, но дали пинка. Он ударился об стенку, отлетел, выхватил у охранника автомат и всех немцев перестрелял.\n— Выходите, братцы, на свободу!\nЕго спрашивают:\n— Почему же ты раньше так не сделал, если мог?\n— Нам, русским, пока по жопе не надают, мы ничего сделать не можем.',
    'На следующий день после смерти Сталина в ворота рая начали ломиться черти.\n— Куда лезете, нечистые? — спрашивает святой Петр.\n— Вчера к нам прибыл товарищ Сталин, мы — первые беженцы.',
    'Армянское радио спрашивают:\n— Сколько человек управляют Советской страной?\n— Полтора. Вечно живой Ленин и полуживой Брежнев.',
    'Телефонный звонок. Брежнев поднимает трубку:\n— Дорогой Леонид Ильич слушает.',
    'Брежнев выступает по телевидению:\n— По Москве распространяются слухи, будто вместо меня в машине возят чучело. Заявляю ответственно — это клевета. На самом деле вместо чучела возят меня.',
    'Из сообщения по радио: "Сегодня в Кремле товарищ Брежнев принял израильского посла за французского и имел с ним дружественную беседу".',
    'В первый день пасхи приезжает Брежнев в ЦК. Идет по коридору, а навстречу ему кто-то из сотрудников:\n— Леонид Ильич, Христос воскрес!\n— Спасибо, — отвечает Брежнев.\nИдет дальше. Второй сотрудник встречает его:\n— Леонид Ильич, Христосе воскресе!\n— Спасибо, мне уже доложили.',
    'На пресс — конференции.\n— Господин Брежнев! Вы говорите, что страна на пути к коммунизму, а между тем народу нечего есть.\n— А никто в дороге кормить не обещал.',
    'Самый страшный сон Брежнева: на Красной площади чехи китайскими палочками едят мацу.',
    'Леонид Ильич обращается к внуку:\n— Кем ты хочешь стать, когда вырастешь?\n— Генеральным секретарем.\n— Постой, а зачем же нам два Генеральных секретаря?',
    'Рассказывают, что когда американцы высадились на Луне, Брежнев вызвал в Кремль наших космонавтов и сказал:\n— Американцы на Луне. Нужно их переплюнуть, мы решили послать вас на Солнце.\nКосмонавты заволновались.\n— Мы же там сгорим!\n— Вы что же думаете, в правительстве сидят дураки? Вы полетите ночью.',
    'На подоконник открытого окна кабинета Брежнева опустился Карлсон.\n— Ты кто такой? — спросил Леонид Ильич.\n— Ты что, не узнал меня? Я — Карлсон.\n— Откуда Карлсон? Какой такой Карлсон?\n— Ну, как же? Я — Карлсон, который живет на крыше. Вы что, про меня не читали?\nБрежнев задумался:\n— Постой, постой… Карлсон. Ах, Карлсон! Как это я сразу не узнал? Кстати, а где твой друг Энгельсон?',
    'Выступает Брежнев:\n— Товарищи! Гм, гм, гм. По Советскому Союзу, гм, гм, гм, ходят слухи, что я, гм, гм, люблю получать, гм, всевозможные ордена, гм, и медали, гм. Это неправда, гм, товарищи! Недавно я, гм, отказался, гм, от высшей награды, гм, республики Магабулы, гм, "Золотое кольцо в нос", гм.',
    'Брежнев выступает перед рабочими.\n— Товарищи! Скоро будем жить еще лучше.\nГолос из зала:\n— А мы?',
    '— Что будет, если Брежнева проглотит крокодил?\n— Он две недели будет срать орденами.',
    'Два старика встретились в трамвае.\n— Слушай! А я тебя помню.\n— Чего ты помнишь?\n— Да мы вместе Зимний брали. Ты еще на ступеньках упал, за пальто зацепился, и винтовка в сторону полетела. Было такое?\n— Да, вроде было. А как ты меня узнал-то?\n— Да как же! По пальто и узнал.',
    '— Чем отличается курс доллара от курса рубля? — Штурманом.',
    'К Ленину заходит секретарь:\n— Владимир Ильич! Вам посылка пришла из Красного Креста!\n— Детям, все детям.\n— Владимир Ильич! Там презервативы.\n— Пгезегвативы? Пгоколоть и отдать меньшевикам.',
    'Брежнева водят по художественной выставке и дают краткие пояснения к картинам.\n— Хорошая картина! — роняет генсек время от времени.\n— А это, Леонид Ильич, Врубель.\n— Хорошая картина. И не дорогая.',
    'Покупатель спрашивает продавца:\n— Товарищ, у вас лезвия есть?\n— Нет.\nПокупатель ушел, а другой продавец спрашивает:\n— Почему ты так сказал? Ведь у нас лезвий полно?\n— Если он назвал меня "товарищ" — пусть бреется серпом.',
    '— Слышали? В нашей стране будет теперь новый герб — амур!\n— Почему?\n— Раздетый, разутый и вооруженный до зубов.',
    'В школе:\n— Файнштейн, Буберман и Иванов по матери! Завтра не приходите — будет арабская делегация.',
    '— Мама! А что такое красная икра?\n— Это такие красные шарики.\n— С серпом и молотком?\n— Не помню…',
    'У грешника на небесах спрашивают:\n— Ты в какой ад хочешь, капиталистический или социалистический?\nНачал грешник выбирать. Пошел в капиталистический ад и спрашивает у других грешников:\n— Сколько у вас здесь варят?\n— Как и положено — 8 часов.\nПошел в социалистический.\n— Сколько у вас здесь варят? — Круглосуточно.\n— И как вы выдерживаете?\n— Да нас еще ни разу не варили. То дров нет, то котлы испорчены, то черти пьяные.',
    'Сообщение ТАСС:\n"Сегодня в 9.00 после тяжелой и продолжительной болезни Генеральный секретарь ЦК КПСС, Председатель президиума Верховного Совета СССР Константин Устинович Черненко, не приходя в сознание, приступил к исполнению своих обязанностей".',
    'После похорон Черненко в Кремле раздается звонок:\n— Алло! Вам генсеки не нужны?\n— Вы что, товарищ, без ума, что ли?\n— Да! И без ума, и старый, и больной!',
    'Сообщение ТАСС:\n"Вчера, в восемнадцать ноль ноль, китайские войска силами четырех дивизий при поддержке танков и авиации перешли советско-китайскую границу и напали на мирно пашущий советский трактор. Трактор шквальным огнем отразил вероломное нападение, сбив при этом восемь самолетов, уничтожив тридцать танков и до тысячи единиц живой силы противника. После этого он выпустил крылья и улетел".',
    '— Можно ли построить коммунизм в Израиле?\n— Зачем такой маленькой стране такое большое счастье?',
    'В КГБ приходит человек.\n— У меня улетел попугай. Если он прилетит к вам, имейте в виду, что я его политические взгляды не разделяю.',
    'Сообщение ТАСС:\n"Вчера в Черном море столкнулась с айсбергом и затонула американская подводная лодка. Команда айсберга награждена орденами и медалями".',
    'Приметы времени.\nМатч по легкой атлетике СССР — США. Бегут двое: американец и наш. Победил американец.\nСоветские газеты сообщили: "В беге на сто метров советский спортсмен пришел одним из первых. Американский бегун был предпоследним".',
    '— Вань, а Вань, что такое встречный план?\n— Ну, как тебе, Мань, объяснить?.. Вот, скажем, ты мне говоришь: давай, Ваня, два раза сегодня, а я тебе встречным планом — нет, Мань, давай три! Хотя мы оба знаем, что даже одного толком не выйдет.',
    'Общее собрание у колхозников.\nНа повестке дня два вопроса: первый — ремонт сарая, второй — построение коммунизма. Председатель колхоза говорит:\n— В связи с тем, что нет досок, переходим сразу ко второму вопросу.',
    'Вовочка приходит из школы домой:\n— Папа, дай рубль. У нас собирают деньги в помощь голодающим в Гваделупе.\n— В Гваделупе нет голодающих, — отрезал папа и не дал рубль.\nНа другой день Вовочка говорит папе:\n— Нам сказали принести по рублю в помощь пострадавшим от засухи в Гваделупе.\n— В Гваделупе не может быть засухи.\nНа следующий день Вовочка заявляет папе:\n— Дай рубль в помощь Компартии Гваделупы.\nПапа вздохнул и протянул сыну трешку.\n— Если в Гваделупе есть Компартия, значит там есть голодающие и засуха возможна.',
    'В армянское радио пришел вопрос из Америки:\n— Сколько получает советский инженер?\nПосле долгого молчания армянское радио отвечает:\n— А у вас негров линчуют!',
    'Один американский журналист спрашивает нашего:\n— Почему у вас дефицит со спичками?\nНаш журналист отвечает:\n— У нас спичек не хватает, потому что мы едим много мяса, а зубочисток не выпускают.',
    '— Что такое — не стучит, не рычит и не царапает пол?\n— Это советская машина для стука, рычания и царапания пола.',
    'Спросили нашего и японского рабочего, сколько часов в день они работают?\nЯпонец ответил:\n— Шесть. Два часа на Японию, два часа на хозяина и два на себя.\nНаш рабочий сказал:\n— А я работаю только два часа на себя, потому что хозяев у нас нет, и на хрена мне еще работать на Японию?',
    'Американец приезжает из СССР домой. Друзья спрашивают:\n— Джон, ну, как там?\n— О! Это долго рассказывать. Объясню в двух словах. Есть там праздник Великого Октября, но справляют его в ноябре. И вот так у них все.',
    '— Что это за очередь? — спрашивает иностранец.\n— Масло дают.\n— О! Дают? У нас только продают… А что это за очередь?\n— Ботинки выбросили.\n— Какие? Вот эти? Да… И у нас такие выбрасывают.',
    'Культурный обмен: мы им — Ростроповича, Солженицына, Нуриева, а они нам — прах Шаляпина.',
    'Надзиратель в тюрьме заключенному:\n— Прежде всего Вам нужно принять душ.\n— С какой стати? В приговоре об этом не сказано.',
    '— Слушай, что-то тебя в последнее время не видно совсем. Где ты работаешь?\n— В КГБ, но это — между нами.\n— А что ж вы там делаете?\n— Занимаюсь недовольными Советской властью.\n— Ха, ха! А что, есть довольные?\n— Есть. Но ими занимается ОБХСС.',
    'Встречаются два врага перестройки.\n— Ты работаешь?\n— Работаю.\n— А что делаешь?\n— Ничего.\n— А сколько платят?\n— Двести.\n— Ну, брат, за такие деньги можно еще немного и вредить.',
    'Ослепший американский миллионер написал письмо племяннику в СССР и попросил его приехать для помощи в ведении дел. Племянника вызвали в "органы" и предлагают:\n— Напишите дяде, чтобы ликвидировал свою фирму, перевел деньги сюда и ехал к нам, мы его здесь обеспечим.\n— Простите, вы не поняли его письма, он же не сошел с ума, он только ослеп.',
    'Перед репатриацией из Израиля в СССР армянин договаривается с оставшимися братьями на Западе, что если в СССР хорошо, то он напишет письмо обычными чернилами, а если плохо — зелеными. Через некоторое время приходит от него письмо, написанное обычными чернилами: "Все отлично, получил квартиру, работаю, все в изобилии.\nЕсли и есть недостатки, то мелкие. Так, например, трудно достать зеленые чернила".',
    'Американец закуривает на Красной площади. К нему подходит милиционер и объясняет жестами, что курить нельзя. Американец гасит сигару:\n— О! Я понимайт — аэродром, аэродром…',
    'Вопрос:\n— Должен ли коммунист платить членские взносы со всех взяток?\nОтвет:\n— Должен, если он честный коммунист.',
    'Летит над Русской землей трехглавый Змей Горыныч. Первая голова кричит:\n— Гласность!\nВторая голова надрывается:\n— Перестройка! А третья голова не отстает:\n— Демократия!\nА жена его, старая Горынычиха, смотрит на небо и вздыхает:\n— Опять ночью депутатов наелся.',
    'Новое объявление в метро:\n"Демократов просят отойти от края платформы".',
    '— Правда ли, что при коммунизме продукты можно будет заказывать по телефону?\n— Правда, но выдавать их будут по телевизору.',
    'Письмо рязанского рабочего в редакцию газеты "Правда". "Уважаемая редакция! Я слышал, что в Африке люди недоедают. Так нельзя ли, все, что они не доедают, нам присылать?"',
    '— Какой урожай будет в этом году?\n— Средний: хуже, чем в прошлом году, но лучше, чем в будущем.',
    'Вопрос, на который армянское радио не смогло ответить:\n— Если все страны станут социалистическими, то где мы будем покупать зерно?',
    'В Агропром пришло письмо:\n"Для выполнения продовольственной программы в на шей стране прошу обменять меня на мешок канадской пшеницы".',
    'На лекции:\n— К концу пятилетки у нас будет по 10 кг мяса на человека.\n— Простите, здесь плохо слышно! Вы сказали "ка" или "ке"?\n— Не понял вопроса.\n— На человеКА или человеКЕ?',
    '— Где больше всего хлеба в Советском Союзе?\n— В котлетах.',
    '— Что такое — плюрализм?\n— Это когда тебя посылают на… А ты идешь, куда хочешь.',
    'Поймал эстонец зайца, принес его домой и говорит жене:\n— Зажарь мне зайца.\nЖена:\n— Масла нет.\n— Ну, тогда свари его.\n— На чем варить-то, газа нет.\n— Ну, тогда засоли его, потом съедим.\n— Соли нет.\nРассердился эстонец, как швырнет зайца в окошко. Заяц вскочил, встрепенулся, да как заорет:\n— Да здравствует свободная Эстония!',
    'Ночь 1991 года. Украинская деревня. Дверь одной избы с треском открывается, в комнату вваливается немец и кричит:\n— Бабка! Млеко, яйки, курка, шнапс!\nИспуганная бабка:\n— Да ты что, оглоед! Мы этого сами давно не видели!\n— Глупая женщина! Это все я тебе привез.',
    '— Как будет выглядеть человек коммунистического будущего?\n— У него будут маленькие руки, так как он ничего не будет делать руками (за него будут работать машины); у него будут маленькие ноги, так как он не будет ходить, а только ездить, плавать или летать; у него будет маленький живот, так как он будет питаться высококалорийными пилюлями; у него будет очень большая голова, так как он будет очень много думать…, думать, как достать эти пилюли.',
    'Ленин и Луначарский на выставке художников-футуристов в 1920 году.\nЛенин:\n— Ничего не понимаю.\nЛуначарский:\n— Ничего не понимаю.\nЭто были последние советские вожди, которые ничего не понимали в искусстве.',
    'Когда Господь Бог собирался создать землю, то заранее запрограммировал, что в 20-м веке в России будет править КПСС и решил дать Бог людям России такие три качества, как ум, честность и партийность, но тут вмешались ангелы — архангелы:\n— Ты что же это делаешь, о Боже? Такие три качества и простым смертным людям? Хватит им и двух. С тех пор и повелось.\nЕсли человек умный и честный — то он беспартийный. Если умный и партийный — то нечестный. Если честный и партийный — то дурак.',
    'Соратники Ленина были большими шутниками. Они любили писать и расклеивать по столице объявления типа: "Продается дойная корова", "Плету лапти недорого" или "Продается самогон" и везде указывали кремлевский адрес Ильича. Вот и тянулся к Ленину народ нескончаемым потоком.',
    'В Матросской тишине разговаривают два таракана:\n— Лукьянов-то своему целыми днями лирику читает.\n— Повезло рыжему, — вздыхает другой. — А меня Крючков каждый день в разведку посылает.',
    'Там же. Таракан подходит к Крючкову и спрашивает:\n— Товарищ Крючков! Разрешите жениться?\n— А ты ее хорошо проверил?\n— Все чисто, наша муха, советская. В туалете редакции "Правда" работает.']
