# -*- coding: utf-8 -*-

"""
Top liked jokes from "Анекдоты категории Б+" VK club
https://vk.com/anekdotikategoriib

Last checked: 03/10/2022

Warning:
Any offensive jokes based on racism, chauvinism, sexism, ageism, or anything else do not reflect the developer's views.
Jokes may contain typos and other errors.
"""

modern_jokes = [
    'ЭКЗАМЕН, ПРЕПОД-ЗВЕРЬ. ЗАХОДИТ ОТЛИЧНИК, ПРЕПОД ЗАДАЕТ ВОПРОС:\n\n-ВЫ ПУТЕШЕСТВУЕТЕ НА ПОЕЗДЕ, В КУПЕ СТАЛО ЖАРКО. ВАШИ ДЕЙСТВИЯ?\n\nСТУДЕНТ:\n\n-ОТКРОЮ ОКНО.\n\nПРЕПОД:\n\n-ОТЛИЧНО! А ТЕПЕРЬ СКАЖИТЕ МНЕ, СКОЛЬКО РАЗ ПОМЕНЯЕТСЯ ОБЪЕМ ВОЗДУХА В КУПЕ, ЕСЛИ СКОРОСТЬ ПОЕЗДА 70КМ/Ч; ПОПУТНЫЙ ВЕТЕР 9М/С; ТЕМПЕРАТУРА В КУПЕ +32ГРАДУСА; ТЕМПЕРАТУРА СНАРУЖИ +25ГРАДУСОВ; В КУПЕ 3 ЧЕЛОВЕКА ВЫДЫХАЮТ 1.3М3 УГЛЕКИСЛОГО ГАЗА В ЧАС; ВЛАЖНОСТЬ 73%; РАЗМЕР КУПЕ 2.5Х2.5Х3.0?\n\nСТУДЕНТ:\n\n-НЕ ЗНАЮ...\n\nПРЕПОД:\n\n-НЕУД! СЛЕДУЮЩИЙ!\n\nСТУДЕНТ ВЫХОДИТ, СООБЩАЕТ ВСЕМ ПРО ОКНО И КУПЕ. ЗАХОДИТ РАСПЕЗДАЛ, САДИТСЯ И ЗАЯВЛЯЕТ:\n\n-ГОТОВ!\n\nПРЕПОД:\n\n-ВЫ ПУТЕШЕСТВУЕТЕ НА ПОЕЗДЕ, В КУПЕ СТАЛО ЖАРКО. ВАШИ ДЕЙСТВИЯ?\n\nСТУДЕНТ:\n\n-СНИМУ КУРТКУ.\n\nПРЕПОД:\n\n- ВАМ ВСЁ РАВНО ЖАРКО!\n\nСТУДЕНТ:\n\n-СНИМУ СВИТЕР.\n\nПРЕПОД:\n\n-ВАМ ВСЁ РАВНО ЖАРКО!\n\nСТУДЕНТ:\n\n-СНИМУ РУБАШКУ.\n\nПРЕПОД:\n\n-ВАМ ВСЁ РАВНО ЖАРКО!\n\nСТУДЕНТ:\n\n-СНИМУ ДЖИНСЫ.\n\nПРЕПОД (УХМЫЛЬНУВШИСЬ):\n\n-ЛАДНО! НАПРОТИВ ВАС СИДИТ НЕГР И, ПО МЕРЕ ТОГО, КАК ВЫ РАЗДЕВАЕТЕСЬ, У НЕГО ВСТАЕТ!\n\nСТУДЕНТ НАКЛОНЯЕТСЯ К ПРЕПОДУ И, СМОТРЯ В ГЛАЗА, МЕДЛЕННО ГОВОРИТ:\n\n-АРИСТАРХ САМУЭЛЬЕВИЧ, ПУСТЬ МЕНЯ ВСЕМ ПОЕЗДОМ ВЫЕБУТ, НО ОКНО Я ВСЁ РАВНО НЕ ОТКРОЮ!',
    'Идeт прaпoрщик пo тaнкoвoй чacти — видит чтo бoeц c мoлoткoм нa пaлeц cтoит дуeт.\n— B чeм дeлo?\n— Дa вoт гвoздь зaбивaл, пo пaльцу пoпaл.\n— Kтo-ж тaк бьeт?! Cмoтри кaк нaдo!\nБeрeт гвoздь и лбoм eгo пo caмую шляпу в cтeну вгoняeт.\nБoeц oфигeвaeт oт тaкoгo и cпрaшивaeт:\n— T. прoпoрщик, a в бeтoнную cтeну мoжeтe?\n— Дa бeз вoпрocoв!\nБeрeт гвoздь и oпять пo шляпу в cтeну лбoм зaгoняeт.\nБoeц eщe бoльшe oфигeвaeт, нo нe oтcтaeт:\n— T. прaпoрщик, a в брoню мoжeтe?\n— Дa бeз прoблeм!\nБeрeт гвoздь и в тaнк лбoм пo гвoздю лупит. Гвoздь гнeтcя нo нe лeзeт. Tут ужe прaпoр oфигeвaeт, бeрeт втoрoй гвoздь, oпять бьeт, и oпять гвoздь гнeтcя. Tут прaпoр нe выдeрживaл, залез в тaнк, а там второй прапор спит упершись лбом к броне',
    'Умер Ленин и попал на небо. \nТам черт и бог совещаются, куда его отправить: в рай или ад. \nотправили в ад. \nЧерез месяц черт прибегает к богу и говорит: \n-бог, забери Ленина к себе, а то у меня народ бунт поднял, хочет за адский труд райские условия жизни. У тебя там все круто, ему будет некого на революцию поднимать. \nну взял бог ленина к себе. \nчерез месяц черт снова наведывается к богу и говорит: \n-ну че, как у тебя там Ленин поживает? \nа бог отвечает: \n-во-первых, не бог, а товарищ бог, во вторых, бога нет, а в третьих, отъебись, я на партсобрание опаздываю',
    'Парень занимается сексом с девушкой в позе 69. \nПарень спрашивает:\n- Милая, ты знаешь, какая высота у Эйфелевой башни?\n-Нет, дорогой.\n- 355 метров. А знаешь, сколько болтиков и гаечек затрачено?\n-Нет дорогой. \n- 17 миллиардов\n-Дорогой, ты у меня такой умный, - сказала девушка, оторвавшись от своего занятия.\n-Да нет, просто у тебя из жопы кусок газеты торчит.\n-Правда?\n-Нет, Ведомости.',
    'Женщина и её любовник находились в доме, пока муж был на работе. Её девятилетний сын вошел в комнату и, видя, как они занимаются любовью, спрятался в шкаф и оттуда подглядывал. Внезапно входит муж. Жена прячет любовника в шкаф, не зная, что её сын там. \nМальчик: \n– Темно здесь. \n– Да. \n– У меня есть футбольный мяч. \n– Это хорошо. \n– Вы не хотите его купить? \n– Нет, спасибо. \n– Мой отец снаружи. \n– Ок, сколько? \n– 250 долларов. \nСпустя несколько недель мальчик и мужчина снова встречаются в шкафу. \nМальчик: \n– Темно здесь. \n– Да. \n– У меня есть кроссовки. \nПомня, что случилось в прошлый раз, мужчина спрашивает: \n— Сколько? \n— 750 долларов. \n— Ок. \nСпустя несколько дней, отец говорит своему сыну: \n— Пойдем поиграем в футбол. \n— Я не могу, я продал мяч и кроссовки. \n— Сколько ты получил? \n— 1000 долларов. \n— Это ужасно! Как ты мог взять так много денег? Это намного больше, чем они стоят. Это грех, ты должен пойти в церковь и покаяться. \nОтец повел сына в церковь. Мальчик зашел в исповедальню, закрыл дверь и сказал: \n— Темно здесь. \nСвященник: \n— Бля, вот только не начинай опять с этой хуйни!',
    'Приходит маленький Мойша домой, подходит к маме, и говорит:\n- Мама, мама, а я сегодня в школе написал в графе "Национальность" шо я русский!\n- Сынок, а шо ты каждый день кушал на обед?\n- Курочку\n- Вот, а теперь ты будешь есть картошку, как все русские дети.\nМойша расстроился, пошел к папе, думает, может папа одобрит.\nПодходит к папе:\n- Папа, папа, а я сегодня в графе "Национальность" в школе написал шо я русский!\n- Сынок, а на чем ты каждый день ездил в школу?\n- На машине папа!\n- Вот, а теперь ты будешь ездить на трамвае, как все русские дети.\nМойша, совсем расстроенный, подходит к дедушке, вдруг тот одобрит:\n- Дедушка, дедушка, а я сегодня в графе "Национальность" написал шо я русский!\n- Внучек, а сколько ты получал в школу каждый день карманных денег?\n- Стольник, дедушка!\n- Вот, а теперь ты будешь получать рупь, как все русские дети.\nМойша совсем расстроился, садится вместе с семьей ужинать.\nВсе едят курочку, перемигиваются между собой.\nМойша кушает картошку.\nТут мама спрашивает Мойшу:\n- Ну шо сынок, как тебе быть русским?\n- Блять, я всего пару часов, как русский, а уже вас, ЕВРЕЕВ БЛЯТЬ НЕНАВИЖУ!!!',
    'Дело \nбыло \nосенью. \nМрак. \nТуман. \nСырость. \nМужику не совсем еще преклонного возраста \nПогода была не в милость. \nШироким, размашистым шагом \nСо складкой меж мрачных глаз, \nИдет в магазин. \nПокупает шляпу. \nШляпа \nЕму \nКак раз.',
    'Два брата грузина купили себе по лошади. Катались до вечера. Загнали в конюшню и говорят:\n- Как мы их различать будем?\n- Давай я своему ухо отрежу. У меня будет конь с одним ухом, а у тебя с двумя.\n- Хорошо.\nПодслушивал их сосед и завидовал. Запрыгнул в конюшню и отрезал ухо. На следующий день братья приходят и видят двух коней без одного уха. Покатались и говорят:\n- Как их теперь различать будем?\n- Давай я своему ухо отрежу. Будет у тебя конь с одним ухом, а у меня конь без ушей.\n- Хорошо.\nПодслушивал их сосед. Запрыгнул в конюшню и отрезал ухо. На следующий день братья приходят и видят двух коней без ушей. Покатались и говорят:\n- Как их теперь различать будем?\n- Давай я своему хвост отрешу. У будет конь без ушей с хвостом, а у меня без ушей без хвоста.\n- Хорошо.\nПодслушивал их сосед. Запрыгнул в конюшню и отрезал хвост коню. На следующий день братья приходят и видят двух коней без ушей и без хвостов. Говорят:\n- Как мы их теперь различать будем?\n- Давай твой тот чёрный , а мой белый.',
    'Америка. Маленький городишко. Парикмахерская. Парихмахер стрижет своего постоянного клиента.\n— Какие планы на отпуск, старина? — спрашивает он у него.\n— Хочу побывать в Москве, — отвечает тот.\n— В Москве!!! В этом грязном, вонючем городе, где мусор не убирают и по улице ходят бандиты и медведи! Да вы что, сэр?! Не вздумайте!!!\n— И все–таки я поеду. Ведь мои дедушка и бабушка когда–то жили там!\n— А какими авиалиниями летишь? — спрашивает парихмахер.\n— Аэрофлотом! — отвечает тот.\n— Мама дорогая, это самые поганые авиалинии. Там воняет керосином, ужасная теснота и отвратительная еда. Пару часов опоздания вам гарантировано.\n— И все–таки я еду!\n— Ну ладно, а в какой гостинице вы остановитесь в Москве?\n— В “России”!\n— Какой кошмар! Там куча проституток, ломовые цены, кругом тараканы и мерзопакосный персонал.\n— Я еду, в любом случае!\n— А что же вы будете делать в Москве? — не унимается парихмахер.\n— Хочу сходить в Мавзолей Ленина! –??????. Там же огромная очередь, кругом милиция и шмон. Мерзко и противно!\n— Меня ничто не остановит! — отвечает клиент.\nЧерез пару месяцев, после поездки он приходит в парихмахерскую.\n— Привет, дружище, — говорит парихмахер, — как поездка? Правду ли я вам говорил про Москву?\n— Знаете, Москва мне очень понравилась. У них новый мэр Лужков и он навел там порядок. Кругом чистота, криминала мало и медведей я не видел!\n— Ну, а Аэрофлот как? Все, как я сказал?\n— Не совсем. Самолет был почти пустой, так что нас пересадили в 1–й класс. Кормили отменно и стюардесса была очень милой и симпатичной девушкой.\n— Ну, а гостиница, правда, дрянь?!\n— Что вы! Они там недавно сделали ремонт и была неделя скидок, так что я жил в номере люкс! Никаких проституток и тараканов.\n— Ну, а Ленина–то видели? — не унимается парихмахер.\n— Представьте себе, видел. И вы даже не поверите. Стою я в очереди, вдруг подходит человек в штатском, отводит меня в сторону и говорит, что их ученые только что совершили чудо и смогли оживить Ленина, и что он хочет поговорить с кем–нибудь из толпы. И они выбрали меня для этой цели.\n— Боже, ушам своим не верю! И что же Ленин вам сказал?\n— Да всего пару слов: “Батенька, и кто же это вас так хуево подстриг…?”',
    'Поймал Дракон в лесу Волка, говорит ему: \n — Смотри, записываю: "Волк серый, одна штука". Сегодня придешь ко мне на обед, я тебя съем. Понял? \n — Понял. \n — Вопросы есть? \n — Нет \nПошел Волк понурый. Идёт дальше Дракон по лесу. Поймал Лису. \n — Смотри, Рыжая, записываю: "Лиса рыжая, хвостатая, одна штука". Сегодня придёшь ко мне на обед, я тебя съем. Поняла? \n — Поняла \n — Вопросы есть? \n — Нет \nПошла Лиса грустная. А Дракон дальше идёт. Поймал Зайца, говорит: \n — Смотри, Косой, записываю: "Заяц серый, уши длинные, одна штука". Завтра придёшь ко мне на завтрак, я тебя съем. Понял? \n — Понял \n — Вопросы есть? \n — Есть. \n — Задавай! \n — А можно не приходить? \n — Можно. Вычёркиваю!',
    'ЖАРА. ПУСТЫНЯ. ПО ПУСТЫНЕ НА ВЕРБЛЮДЕ МЕДЛЕНО ЕДЕТ ВСПОТЕВШИЙ ХОХОЛ. \nТУТ ХОХЛА НА СКОРОСТИ ОБЪЕЗЖАЕТ МОТОЦИКЛИСТ. \n— СТОЯТИ. ТИ ЧОГО ЦЕ В ТАКУ ЖАРУ ПО ПУСТЫНЕ ГОНИШ? \n— ТЫ ЧЕГО, НЕ ЗНАЕШЬ ЗАКОНОВ ФИЗИКИ: ЧЕМ БЫСТРЕЕ ЕДЕШЬ, ТЕМ ТЕБЕ ПРОХЛАДНЕЙ. \n— ДА НУ. - ХОХОЛ БЬЕТ ВЕРБЛЮДА, И НА СКОРОСТИ ОТРЫВАЕТСЯ ОТ МОТОЦИКЛИСТА. \nЧЕРЕЗ ДВА КИЛОМЕТРА МОТОЦИКЛИСТ ДОГОНЯЕТ ХОХЛА. ХОХОЛ СТОИТ НАД ТРУПОМ ВЕРБЛЮДА И ПЛАЧЕТ. \n— ЧТО СЛУЧИЛОСЬ!? \n— ЕБАЛ Я ТВОЇ ЗАКОНИ ФІЗИКИ, У МЕНЕ ВЕРБЛЮД ЗАМЕРЗ.',
    'Поймал Змей Горыныч англичанина, француза и цыгана. И говорит: \n— Кто расскажет мне такую историю, что все три головы скажут "Да ну нахуй" того отпущу, а если хоть одна голова скажет "Бывает", того съем! " Англичанин: \n— Один английский джентельмен купил машину, и только он выехал на ней из магазина сразу же разбил в дребезги. Две головы: — Да ну нахуй, третья: "Фигня, бывает". Съели! \nФранцуз: один французский джентльмен решил жениться, и прямо в церкви его невеста изменила ему со свидетелем. Две головы: — Да ну нахуй, третья: "Бывает". Съели! \nЦыган не знает что бы соврать, думает — начну, а там видно будет: \n— Один цыганский джентельмен ... Все три головы: "Да ну нахуй! "',
    'Анекдот про Толяна:\nИдёт Толя по красной площади. Вдруг его приспичило посрать. Ну он штаны стянул, и сел прям у всех на виду. Тут к нему мент подходит и сразу:\n– ты че ебанутый? Натягивай штаны и в участок. \n– Да ты че? Я ж Толян!\n– Да насрать мне, давай в участок.\nТут мимо проезжает картедж Путина. Останавливается. Выходит Путин и говорит\n– ООО, Толян,  сколько времени прошло, поедем со мной Обаму встречать?\n– Да не могу, меня вот мент арестовал.\n– Да забей ты на него. А если хочешь с собой бери.\nМент в ахуе, все садятся к Путину в машину. Едут встречать Обаму. Тот прилетает на самолёте, спускается с трапа и сразу им на встречу.\n– ООО, Толян, давно не виделись, слушай, я к Папе Римскому лечу, давай с нами?\n– А вот не могу, меня мент арестовал.\n– Да забей, хочешь с собой бери. \nМент ещё больше в ахуе. Ну летят они всеми к Папе Римскому. Прилетели, а тот с балкона толпе рукой машет. Толян  к менту:\n– слушай, отпусти меня к Римскому, я раз в год Тут бываю, дай хоть обнять\nМент настолько в шоке, что просто отпускает его. И вот спустя минуту Толян вместе с Папой Римским машет всем рукой. И тут он видит, как мент падает без сознания. Толян сразу к нему "э, ты чего, вставай!". Мент встаёт и до сих пор в шоке. Говорит:\n– Слушай... ну я всё понимаю... ну может ты одноклассник Путина... ну может с Обамой ты через Путина знаком... ну может с Римским ты через Обаму знаком.. но когда из толпы спросили "что за хуй рядом с Толяном?" Я ахуел....',
    'У мужика вздулся живот. Он к врачу. А врач решил приколоться и говорит: "Э, да ты беременный". Мужик в панике: "Дайте самое сильное средство чтобы был выкидыш". Врач даёт ему слабительное. Пей, говорит, по одной таблетке в день. Ну мужик сразу горсть и выпил. Идёт на измене по улице и тут прихватило, ну всё думает, рожаю. Оглядывается и видит открытый канализационный люк, присел над ним и сделал сброс. А в люке сантехник, орет: "Ой, мамочка" и пытается вылезти весь в говне. У мужика вообще крышу снесло, толкает его ногой обратно в люк и орет: "Нету, сука, у тебя мамы. Сирота ты!"',
    'Подходит бабка к зумеру на улице:\n-Скажи сынок, какой троллейбус едет на улицу Горького?\n-Во-первых, не сынок, а чел. Во-вторых, не троллейбус, а тралик. В третьих, не едет, а флексит.\n-Спасибо, сынок.\nИдёт она дальше, видит полицейского.\n-Йоу, чел, какой тралик на Горького флексит?\n-Хайпуешь, плесень?',
    'Пришли старик со старухой на аэродром. Подходят к летчику. \nДед говорит: \n— Сынок, мы с бабкой столько лет уже живем, а никогда не летали. Покатай, а! \nЛетчик отвечает: \n— Хорошо, прокатаю. Но с одним условием. Если закричишь от стpаха — платишь мне 100 баксов, идет? \n— Идет, — согласился старый. \nВзлетели. Летчик как начал вытворять всякие пируэты в воздухе — и мертвую петлю, крен на одно крыло, резкое падение вниз и все такое — но старый молчал, как рыба. Летчику это надоело, он посадил самолет и спрашивает старого: \n— Скажи, дед, а был такой момент, когда ты чуть не закричал? \n— Был. \n— Какой? \n— Когда бабка выпала',
    'Спецназ Нигерии внезапно открыл огонь. На очереди изобретение колеса.',
    'Экзамен по электротехнике. Препод валит студента.\n— Ну ладно, последний вопрос на 3: сколько лампочек в аудитории?\nСтудент поднимает голову, считает:\n— Восемь!\n— Неправильно, у меня одна с собой, в кармане. Увидимся на пересдаче.\nПересдача. Препод снова валит того же студента.\n— Последний вопрос на 3: сколько лампочек в аудитории?\n— Девять!\n— Неправильно, я сегодня лампочку не взял!\n— Зато я взял!',
    'Папа с сыном пошли однажды на горы, и сын, ударившись о камень, крикнул:\n— ААААААА.\nИ с удивлением слышит:\n— ААААААА.\nМальчик спросил:\n— Кто ты?\nА ему в ответ:\n— Кто ты?\nРазозлившись от такого ответа, мальчик кричит:\n— Ты пидор!\nА ему в ответ:\n— Ты пидор!\nМальчик спрашивает у отца: «Что происходит?»\nОтец улыбнулся и говорит: «Слушай меня внимательно».\nОтец кричит горе:\n— Я тебя уважаю!\nЕму в ответ:\n— Я тебя уважаю!\n— Ты лучший.\nЕму отвечают:\n— Ты лучший.\n— Видишь, сынок? Я лучший, и меня уважают. А ты пидор.',
    'Женщина лежит в постели с любовником. \nВдруг раздается звонок в дверь, она понимает, что пришел муж и в порыве отчаяния \nвосклицает: \n— Господи, сделай так, чтобы он ничего не заметил! \nРазверзаются небеса и господь говорит: \n— Хорошо, я так сделаю, но ты умрешь от воды. \nОна говорит: \n— Хорошо. \nПроходит год, два года. Женщина не купается, моется только под душем, старается \nпо возможности любыми путями избегать воды. \nПроходит 3 года, она неожиданно выигрывает путевку в морской круиз. \nПосомневалась-посомневалась, и решила поехать. \nПлывет она на шикарном лайнере, вдруг ночью начинается шторм, все в панике корабль тонет. \nОна опять в порыве отчаяния восклицает: \n\n— Господи, ну ты же не можешь из-за меня одной потопить весь корабль! \nРазверзаются небеса и господь говорит: \n— Да я вас, БЛЯДЕЙ, на этот корабль три года собирал',
    'Геолог спрашивает чукчу-пастуха:\n- Отец, скажи, а сколько твои олени дают\nза сезон рогов?\n- Черные или белые?\n- Ну, допустим черные.\n- А-а-а-а... Черные - два килограмма.\n- А белые?\n- И белые два килограмма.\n- А скажи, отец, сколько им нужно корма в\nдень?\n- Черным или белым? - уточняет пастух\n- Ну, черным.\n- Черным - один килограмм.\n- А белым? - не унимается геолог.\n- И белым один килограмм.\nГеолог в бешенстве:\nТы что меня заморачиваешь? Почему все\nвремя спрашиваешь, черные или белые, ведь результат один и тот-же?\n- Ну-у-у... Так ведь черные-ж мои, - отвечает\nчукча.\nГеолог понимающе:\nА-а-а-а-а.... А белые?\n- И белые мои.',
    'Попали в ад бабник, алкаш и нарик. Дьявол им говорит: вы сможете вернуться в мир живых, если пройдёте испытания - просидите в комнатах со своими желаниями и страстями и вы уйдёте отсюда. Не замечая подвоха, все трое соглашаются.\nВ комнате бабника были 30 девушек, которые жаждили сношения с ним; в комнате алкаша была разносортная выпивка всех марок, видов и вкусов и т.д.; в комнате нарика было целое множество курева.\nНа 80-й год решил дьявол проверить как у них дела идут: бабник бегал уже не от красивых девушек, а от страшных старух и просит выпустить его. Дьявол за это забрал его душу. Зашёл к алкашу: всю выпивку он залил в себя ещё в первый день и страдал от бесконечного похмелья и молил об амнистии. И его душу дьявол забрал. Заходя в комнату к наркоману, он удивился - ни один косяк не тронут, а наркоман смотрит на него укоризненно.\nДьявол спрашивает:\n- А как так ты без курева продержался\n- Ты бы мне зажигалку оставил, еблан',
    'Солдат стоит на посту.\nК нему подходит полковник и спрашивает:\n- Звание, фамилия?\n- Рядовой Петров.\n- Сколько человек в роте?\n- 75\n- Сколько человек в батальоне?\n- 250\n- А ты чего же это военную тайну выдаёшь? Вдруг я шпион!\nРаздаётся выстрел...\nСолдат:\n- Ты посмотри какая сука...',
    'Едут как-то мужики на поезде. Проезжают поле, а на нём коровы пасутся. Один из мужиков восклицает:\n—О, на этом поле 343 коровы! \nНикто не обращает на это внимания, едут дальше. \nПроезжают ещё одно поле с коровами. \n—А здесь 427 коров! \nСнова никто не обращает внимания, едут дальше. \nИ вот, в третий раз проезжают поле с коровами. \nМужик снова:\nА здесь 634! \nВсе в поезде не выдерживают, идут к машинисту, останавливают поезд, выходят, идут пересчитывать всех коров.\nМужик оказался прав, коров действительно было 634.\nВсе в недоумении, подходят к мужику и спрашивают:\n—Но как ты смог угадать \n—Очень просто, считаю ноги, и делю на четыре.',
    'Приходят к профессору два студента экзамен сдавать. По комбинаторике. В те еще времена. Домой пришли к профессору. Ну, сдавали, сдавали, за картами засиделись, за костями игральными, стемнело. А в то время и студенты, и профессора были бедные, домой их не отправишь, пришлось спать укладывать в профессорской трехкомнатной квартире. В одной комнате - два студента, в другой - профессор с женой, в третьей - профессорская дочь. Все чин по чину, спят. Просыпается студент, думает, а хрен ли я с этим придурком лежу, пойду ка профессорскую дочь навещу. Глядь в одну комнату - две головы из-под одеяла торчат, ну то профессор с женой, глядь в другую - одна голова. Дочка! Юрк к ней под одеяло, спят. Не спится и профессору. Встает среди ночи, дай, думает, к дочке перелягу, мало ли что от этих балбесов ждать. Шнырь в одну комнату, две\nголовы, - ага, студенты, шнырь в другую - одна, дочка, не иначе. Прыг - спит. Ну, тута и второй студент проснулся, и, как вы уже догадались, отправился по стопам друга, на поиски профессорской дочки. Утро. Просыпается профессор. Один. В комнате студентов. Хм... Заглядывает в одну комнату - там студент с дочкой, в другую - студент с женой. Чешет репу:\n-Сколько лет преподаю комбинаторику, но таких блядских перестановок еще не видел!',
    '- Капитан, у нас пpобоина, ниже ватеpлинии!\n- Заделать можно?\n- Hет!\n- Готовьте спасательные шлюпки!\n- Капитан, шлюпок нет!\n- Готовьте спасательные жилеты!\n- Капитан, но он только один!\n- Да? - говоpит капитан, и после небольших pаздумий хватает жилет и пpыгает за боpт.\n- Капитан, капитан, это была шутка, сегодня же пеpвое апpеля! Блин, что же мы скажем на земле...\nЁпт! Какая пpобоина, какая ватеpлиния - стpемительно пpиближаясь к земле думал капитан самолета.',
    'Играют поп с поручиком Ржевским в городки. Поручик кинул биту, попал. Кидает поп… \n— Ай, блять, промазал!\n— Батюшка, ведь грех же! \n— Хуйня. Кидают дальше, гусар опять попадает. Кидает поп:\n— Вот сука ёбаная, мимо!\n— Батюшка, нельзя же. \n— Да похуй!\nГусар попадает в третий раз, поп снова мажет: — Блять, ну пиздец, охуели! \nВдруг с неба срывается молния и убивает гусара насмерть. Голос с неба:\n— Тьфу, блять, промахнулся!',
    'Был один парень, которого заколдовал колдун и он мог говорить только одно слово в год. И вот, он 4 года не говорил ни слова и собрал 4 слова, подошел к колдуну, а колдун ему:\n-копить нельзя.\n-блять.',
    'Два друга таджика решили жениться на русских близняшках. Пошли они значит к их отцу просить разрешение, а отец им и сказал: "Дочерей отдам замуж только крещенным христианам".\nНу базару нет, подумали таджики и решили пойти на крещение господня. Мороз, озеро, купель русская... Решается один из таджиков окунуться, раз окунается, два... ему уже и крестик несут... \nВторой мёрзнет, да спрашивает \n- Не холодно ли тебе, братан?\nА тот ему и говорит:\n-Иди нахуй чурка',
    'Нацист заходит в бар... \nОн подходит к бармену, оглядывает помещение и видит пожилого еврея, сидящего в углу. Нацик громко обращается к бармену: "Налей бокал пива каждому за мой счёт, кроме того еврея!" \nНацист смотрит на еврея и, к его удивлению, тот ему улыбается. \nНацист снова говорит бармену: "Налей бокал вина каждому за мой счёт, кроме того еврея". \nВсе радуются, нацик самодовольно оборачивается посмотреть на реакцию еврея, а он опять улыбается! \nНацист предпринимает ещё одну попытку, говоря бармену: "Раздай по бутылке самого дорогого виски всем, кроме того еврея!!" \nНацик смотрит на еврея... Тот улыбается и машет ему. \nНацик гневно спрашивает бармена: "Что за хуйня с этим евреем? Он сумасшедший или просто тупой??" \nБармен отвечает: "Он владелец бара".',
    'Попугай в самолете стюардессе:\n- Эй, шлюха, виски и побыстрее!\nОна приносит ему виски. Через некоторое время он же:\n- Коза драная, виски мне и побыстрее!\nОна обслуживает его снова. Мужик, сидящий позади попугая, думает:\n"Что попугай может, могу и я". И кричит стюардессе вслед:\n- Пизда тупая, пива мне и поживее!\nТерпение стюардессы переполнено и она жалуется капитану. Капитан решает попугая и мужика выбросить. Дверь открывается. Попугай мужику:\n- Мужик, для нелетающего ты слишком выeбиcтый.',
    'Гиммлер вызывает своего сотрудника.\n– Назовите двузначное число.\n– 45.\n– А почему не 54?\n– потому что 45!\nГиммлер пишет характеристику «характер нордический» и вызывает следующего.\n– Назовите двузначное число.\n– 28.\n– А почему не 82?\n– Можно, конечно, и 82, но лучше 28.\nГиммлер пишет характеристику «характер близок к нордическому» и вызывает следующего.\n– Назовите двузначное число.\n– 33.\n– А почему не… А, это Вы, Штирлиц.',
    'Приходит жирный мужик в бордель для похудения. Ему говорят: \n- Чтоб сбросить 10 кг, надо заплатить $100. \nОн спрашивает: \n- Как всё это происходит? \nЕму отвечают: \n- Сами всё увидите, - и проводят в отдельную комнату. А там красивая баба. Она говорит: \n- Поймаешь меня - выебешь! Ну мужик гонялся за ней по комнате, поймал. Выходит, встаёт на весы 10-ти кг - как не бывало. \nНа следующий день приходит, чтоб похудеть на 20кг. Ему говорят что это будет стоить $200. Он без проблем выкладывает бабки и его проводят в другую комнату. А там уже две бабы и говорят: \n- Поймаешь нас - выебешь! - он пробегал по комнате, поймал. Потом выходит оттуда радостный, встаёт на весы - 20-ти кг как не бывало. \nНа следующий день приходит опять и думает, что мелочиться и спрашивает: \n- А можно ли похудеть сразу на 100 кг? Ему отвечают: \n- Можно, только это будет стоить штуку баксов. Он спокойно выкладывает деньги и его проводят в комнату, закрывают дверь, затем включают свет, а там маленький худой негр с огромным членом. Говорит: \n- Поймаю - выебу!',
    'Продает мужик курицу. Подходят покупатели...\n- Несучка?\n- Не, не сучка...\n- Несучка?\n- Не, не сучка... Простоял мужик так до вечера. Рынок опустел, подходит\nпоследний покупатель.\n- Несучка?\n- Сучка, сучка, первая блядь в курятнике',
    'Идет заяц по лесу, навстречу ему медведь. \n- Заяц, давай волка подколем!? \n- Давай, а как? \n- Ты подойди к нему и спроси, волк, а ты летал на вертолёте? А дальше моя забота. \nЗаяц подходит к волку и говорит: \n- Волк, а ты летал на вертолёте? \n- Нет, а что?. \nТут из кустов выходит медведь, насаживает волка на свой хуй и как крутанёт: \n- Полетееел!!!! \nЧерез месяц медведь опять зайца встречает: \n- Заяц, волк из больницы выписался. Подколем? \n- Давай, а как? \n- Ты подойди к нему и спроси, волк, а ты плавал на лодке? А дальше моя забота. \nПодходит заяц к волку и говорит: \n- Волк, а ты плавал на лодке? \nВолк испуганно: \n- Не плавал я ни на какой лодке! \nИз кустов выходит медведь, волка на хуй свой насаживает и говорит: \n- НА ВЕРТОЛЁТЕ ПРИВЫЧНЕЙ, ДА СУКА?)))',
    'Жена просит мужа:\n-слушай, сыну уже 15, поговори с ним о половом созревании, только помягче как-нибудь на примере птичек или\nсобачек.\nМуж соглашается.\nВечером заходит к сыну, говорит:\n-сына, помнишь мы на прошлой неделе в бордель ходили?\n-ну помню\n-вот птички и собачки этим тоже занимаются!\n-детей ебут?\n-нет, я не это хотел сказать',
    'Два брата 4 и 5 лет, перед сном, старший: \n- Мы уже взрослые мужчины, пора бы нам начать материться! \n- А как? \n- Давай я завтра скажу "блять", а ты скажешь "нахуй"! \nУтро, завтрак... Старший маме: \n- Мне бы, блять, блинчиков\nМама с ходу затрещину, старший убегает в слезах, она с серьёзным видом поворачивается к младшему: \n- А тебе наверное тоже блинчиков? \nМладший с дрожью в голосе: \n- Да, нахуй, мне такие блинчики...',
    'Построил прапорщик рядовых и говорит:\n— Сейчас загадаю вам три очень сложных загадки.\nПервая - два чёрных, начищенных,\nблестящих, в углу стоят.\nВсе молчат. Прапорщик говорит:\n— Идиоты, это же пара кирзачей!\nВторая загадка - четыре чёрных, начищенных,\nблестящих, в углу стоят.\nНикто не знает.\n— Идиоты, это же две пары кирзачей!\nА вот самая сложная: в лесу на болоте живёт,\nзелёная, прыгает, квакает, на ля начинается,\nна гушка заканчивается.\nОдин из рядовых тянет руку:\n— Я очень сильно сомневаюсь,\nно может, это... три пары кирзачей \nЭтим солдатом был майкрософт эксель',
    'Решила Белоруссия отмстить США за издевательство над славянским народом.\nДолго думали, как им отомстить!\nДолго думали, решали, как быть, и наконец придумали.\nУдарить по США ядерными ракетами!\nА после ответа США, Россия их сотрёт с лица земли!\nНашли на старых советских складах ядерные боеголовки, купили ракеты и выбрали цель.\nИ наконец запустили ракету по Вашинготну. Бдыщщщ!!!\nНет больше города, весь в руинах, пылает...\nЗалезли белорусы в бомбоубежища и ждут ответа.\nПроходит неделя, другая... Тишина.\nРешили запустить ещё одну... Бдыщщщ! Нет Нью Йорка.\nОпять ждут неделю, две... И тишина.\nТут все белорусы стали считать себя самой грозной нацией, что даже США их боится! Боится отвечать! Нужно с ними кончать!\nИ наконец решили запустить последнюю ракету по Пентагону!\nЗапустили, ракета летит, а в это время в самом Пентагоне все высокопоставленные лица склонили головы над картой мира и громко орут: Где эта ёбаная Белоруссия?!?!?',
    'В тату салоне:\n-В армии я служил в танковых войсках и в память об этом хочу, чтобы мне накололи на всю спину танк.\n-Не вопрос, ложитесь вот сюда... Готово!\n-А чего я встать не могу?\n-А хули ты хотел? 46 тонн!',
    'В дверь постучали один раз.\n— 0,125 осьминога! - догадался Штирлиц.\nВ дверь постучали 2 раза. \n— 0,25 осьминога! - догадался Штирлиц. \nВ дверь постучали 4 раза. \n— 0,5 осьминога! - вновь догадался Штирлиц. \n... \nСтуков становилось всё больше. За одну минуту в дверь постучали 300 раз. \n— Э... - Штирлиц достал калькулятор, - тут уже нужно посчитать. \n— Открой уже, даун, - кричал Мюллер за дверью, яростно в неё стуча.',
    'Однажды к Великому Мастеру пришел человек и сказал ему: \n— Мастер, научите меня кунг-фу! \nНо мастер сказал: \n— Сейчас я не беру учеников. Возвращайся через год. \nЧерез год этот человек вернулся. \n— Прошел год, и я вернулся, как вы и сказали мне, Мастер. Теперь вы научите меня кунг-фу? \n— Да, я могу научить тебя кунг-фу. Но ты должен знать, что кунг-фу — это нечто большее, чем умение махать руками и ногами. Для изучения кунг-фу тебе нужно правильное умонастроение. В течение трех лет каждый день наблюдай, как восходит и заходит солнце. \nЧеловек ушел. Но через три года он вернулся вновь. \n— Мастер, я все сделал так, как вы мне говорили — в течение трех лет я каждый день наблюдал, как восходит и заходит солнце. Теперь вы научите меня кунг-фу? \n— Да, я могу научить тебя кунг-фу. Но сначала ты должен научиться зависать на высоте в девять ли от земли. Не возвращайся, пока не научишься этому. \nЧеловек ушел, и Мастер надеялся, что он больше никогда не вернется. Но через три года этот человек вновь пришел к нему. \n— Великий Мастер, я сделал то, что вы мне велели — я научился зависать на высоте в девять ли от земли, — сказал он и завис над землей. \n— Нихуя себе, — сказал Великий Мастер',
    'Попали в ад бабник, алкаш и нарик. Дьявол им говорит: вы сможете вернуться в мир живых, если пройдёте испытания - просидите в комнатах со своими желаниями и страстями и вы уйдёте отсюда. Не замечая подвоха, все трое соглашаются. \nВ комнате бабника были 30 девушек, которые жаждили сношения с ним; в комнате алкаша была разносортная выпивка всех марок, видов и вкусов и т.д.; в комнате нарика было целое множество курева.\nНа 80-й год решил дьявол проверить как у них дела идут: бабник бегал уже не от красивых девушек, а от страшных старух и просит выпустить его. Дьявол за это забрал его душу. Зашёл к алкашу: всю выпивку он залил в себя ещё в первый день и страдал от бесконечного похмелья и молил об амнистии. И его душу дьявол забрал. Заходя в комнату к наркоману, он удивился - ни один косяк не тронут, а наркоман смотрит на него укоризненно.\nДьявол спрашивает:\n- А как так ты без курева продержался\n- Ты бы мне зажигалку оставил, еблан',
    'Встретились Хой, Горшок и Летов, ну и вздумали бухнуть. Купили литруху, ну и типа говорят - мы же поэты - давайте кто сколько в стихах попросит, тому столько и нальём.\nХой встаёт:\n- Рыбка плавает по дну, выпью рюмочку одну.\nНалили. Горшок встал:\n- Рыбка мёртвая на дне, выпью рюмочки я две.\nЛетов встаёт, весь натужился, набух, покраснел, глаза выпучил. Вдруг как заорёт:\n- АААА БЛЯЯЯДЬ НАХУУУЙ\nСхватил пузырь и убежал.',
    'У костра собрались американский морпех, британский спецназовец SAS и русский десантник.\nИ начали спорить, кто из них круче.\nАмериканец:\n— Я пробрался к противнику, с одним ножом, перерезал целый гарнизон вооруженных иракских солдат, а потом взорвал к ебеням их иракскую базу.\nБританец:\n— Это что, я вот голыми руками перебил два гарнизона талибов, взорвал к ебеням их талибскую базу и взял в плен полевых командиров.\nРусский десантник говорит: " А вот как-то мы сели на дозаправку в Ташкенте..."',
    'Рожает жена нового русского, у неё негр родился она и говорит врачу:\n- Доктор возьмите 200$ только пожалуйста наплетите моему мужу Сидорову всякую фигню про гены мутации, а то он меня убьёт...\nДоктор соглашается, выходит в корридор:\n- Кто тут Сидоров?\nВстаёт такая хрюша, амбал одним словом:\n- Ну я - говорит - чё там с моей?\nДоктор испугался:\n- Ни-ни-чего п-п-росто роды задерживаются...\nПодходит к медсестре, даёт ей 200 рублей и говорит:\n- Там у Сидорова жена негра родила, подойди к нему и наплети всякую фигню про гены, мутацию.\nМедсестра выходит в корридор:\n- Кто тут Сидоров?\nВстаёт тот же амбал:\n- Ну я!\nМедсестра тоже испугалась:\n- Ни-ни-чего п-п-росто роды задерживаются...\nПодходит медсестра к электрику Васе даёт ему бутылку водки:\n-Там у Сидорова жена негра родила наплети ему всякую фигню про гены и мутацию...\nВыходит Вася в корридор:\n- Кто тут Пидаров\nАмбал:\n- Не Пидаров, а Сидоров!\nВася ему:\n- Слыш мудак, хуй  надо мыть чаще у тя негр родился!!!',
    'Решили американцы внедриться в Украину, узнать, что там происходит. Выбрали лучших специалистов, обучили их, и лучшего ученика, знающего украинский язык без акцента, отправили на Украину. Вышел из леса американец и встречает проезжающего деда. \nИ дед говорит ему:\n- Знову американського шпигуна нам пiдiслали. \n- Та який я американець,  дiд. Я простий украиньский хлопець. \n- Та який ти хлопець, ти ж негр.',
    'Мужик сидит, дрочит. Подходит к нему другой и спрашивает: \n- Дрочишь? \n- Нет, блядь, в шахматы играю! \n- Сыграем партию? \n- Ну, давай. \nИграют в шахматы. Подходит третий мужик, спрашивает: \n- В шахматы играете? \n- Нет, блядь, дрочим! \n- Можно с вами? \n- Ну, давай. \nДрочат втроём. Подходит четвёртый, спрашивает: \n- Дрочите? \n- А как ты узнал? \n- А вон у вас доска шахматная лежит.',
    'Звонит телефон в расположении казармы военной части. Мимо идет солдат, думает — чего надрывается, дай возьму трубку:\n— Але...\nИз трубки: \n— Скажите пожалуйста, сколько у Вас в части служебных Волг?\n— Две: одна в ремонте, на другой ездит старый мудак Пилипов.\n— А кто это такой — Пилипов?\n— А, это наш командир части — полковник Пилипов.\n— И че, мудак он что ли?\n— Да, таких мудаков еще поискать надо — мудак-мудаком!\n— Да, а Вы знаете с кем Вы разговариваете?\n— Нет.\n— Вы разговариваете с полковником Пилиповым!\n— Да, а Вы знаете с кем Вы разговариваете?\n— Нет.\n— Ну тогда пошел на х*й Пилипов!',
    'Звонит телефон в расположении казармы военной части. Мимо идет солдат — думает — чего надрывается, дай возьму трубку: \n— Але... \nИз трубки: \n— Скажите пожалуйста, сколько у Вас в части служебных Волг? \n— Две: одна в ремонте, на другой ездит старый мудак Пилипов. \n— А кто это такой — Пилипов? \n— А, это наш командир части — полковник Пилипов. \n— И че, мудак он что ли? \n— Да, таких мудаков еще поискать надо — мудак-мудаком! \n— Да, а Вы знаете с кем Вы разговариваете? \n— Нет. \n— Вы разговариваете с полковником Пилиповым! \n— Да, а Вы знаете с кем Вы разговариваете? \n— Нет. \n— Ну тогда до свидания — старый мудак Пилипов!',
    'Поезд, купе. \nЕдет мужик с портфелем. Проходит проводница, говорит: \n-Чай, кофе \nМужик: - Два чая, для меня и шушунчика. \nПроводница покосилась, все соседи купе тоже, но ничего не сказали. Проводница приносит два чая и ставит на стол. Мужик ставит один чай перед собой, а второй кладёт в портфель. Соседи побледнели, но молчат. Едут дальше. Проводница: \n-Газеты, кроссворды, журналы \nМужик: - Две газеты, мне и шушунчику \nПроводница уже не удивляясь отдаёт мужику газеты и уходит. Он кладёт одну на стол, а вторую суёт в портфель и быстро закрывает. Соседи ни слова не сказали за всю поездку, только смотрят то на мужика, то на портфель. Вдруг мужик решил сходить в туалет. Вышел, соседи тут же к портфелю. Открывают портфель, а там шушунчик чай пьёт и газету читает',
    'В цирке конферансье: \n- А сейчас выступают известные акробаты... \nГолос из зала: \n- Пидарасы! Все акробаты - пидарасы! Нормальные мужики не носят трико в \nобтяжку... \nКонферансье: \n- Следующим номером нашей программы знаменитый клоун... \nГолос из зала: \n- Пидарасы! Все клоуны - пидарасы! Губы красят, щеки размалюют, парики \nнацепят! Пидарасы! \nКонферансье: \n- А сейчас, внимание! Впервые в истории смертельный номер! Человек \nподнимается под купол и прыгает вниз - без страховки, без батута... \nГолос из зала: \n- Пидарасы! Куда вы меня тащите?..',
    'Пришел студент в столовую, а все столики заняты. Сел к профессору. Он ему:\n– Гусь свинье не товарищ\n– Ну тогда я полетел\n– аахахххаахха блять летающая свинья',
    'Едут в поезде китаец, хач и русский.\nКитаец поиграл в пятый айфон, взял да и выкинул его в окно.\n—Что ж ты делаешь? - спросили те.\n—У меня на родине такого барахла завались! - сказал китаец.\nХач взял арбуз, половину отрезал, съел, а остаток выкинул в окно.\n—Что ж ты делаешь? - спросили другие.\n—У меня на родине такого барахла завались! - сказал хач.\nА русский взял и выкинул хача в окно.',
    'Сын спрашивает у отца: \n— Что такое "реально" и что такое "гипотетически"? \n— Сынок, как бы тебе обьяснить, давай лучше разберем на примере. \n— Хорошо. \n— Иди к маме и спроси переспала бы она за лям баксов с негром. \nМальчик возвращается: \n— Говорит, что переспала бы. \n— Вот, а теперь спроси это у сестры. \n— Она то же согласна. \n— А теперь у деда спроси переспит ли он с негром за миллион долларов. \n— Дед тоже согласен. \n— Вот видишь, гипотетически у нас есть 3 млн баксов, а реально — две проститутки и пидорас.',
    'Умирает Папа Римский.\nУ ворот Рая встречает его Петр.\n- Как зовут тебя? - спрашивает Петр.\n- Я Папа Римский!\n- Папа, папа, - шепчет себе под нос Петр, - сожалею, но папы римского у меня в списке нет...\n- Но я же был заместителем Бога на земле!\n- У Бога есть заместитель на земле?! - удивленно спрашивает Петр, - Странно, я ничего об этом не знаю...\n- Я глава Католической Церкви!\n- Католическая Церковь? Никогда не слышал о такой... Подождите, я спрошу у Шефа.\n- Шеф, - спрашивает Петр у Бога, - там один чудак утверждает, что он ваш заместитель на земле, его зовут Папа Римский - вам это о чем-то говорит?\n- Нет, - отвечает Бог, - но погоди, давай спросим у Иисуса.\nБог и Петр объясняют Иисусу ситуацию.\n- Подождите, - говорит Иисус, - я сам с ним поговорю.\n\nЧерез 10 минут Иисус, смеясь до слез, приходит назад.\n- Помните рыболовный кружок, который я организовал 2000 лет назад? Он до сих пор существует!',
    'Девочки из Вовочкиного класса договорились, что, если Вовочка скажет какую-нибудь пошлость, то они встанут и выйдут из класса. \nНачался урок, и учитель спрашивает:\n— Дети, а что нового строится в нашем городе?\n— Школа\n— Библиотека\n— Завод\n    Вовочка:\n— Публичный дом.\nДевочки встают и выходят из класса, а Вовочка им кричит:\n— Куда же вы? Там только фундамент залили...',
    'Анекдот: \nЗаходит Чебурашка в аптеку и спрашивает: \n— У вас апельсины есть? \n— В аптеке апельсинов не бывает. \nУшёл Чебурашка. Через час снова заходит. \n— У вас апельсины есть? \n— Вам же сказали — в аптеке апельсинов не бывает! \nЧерез час опять заходит. \n— У вас апельсины есть? \n— Ты, что, издеваешься?! Тебе же сказали — в аптеке апельсинов не бывает! Ещё раз про них спросишь — уши гвоздями к полу прибьём! \nЧебурашка уходит. Через час возвращается. \n— У вас гвозди есть? \n— Нет у нас гвоздей! Нет! \n— А апельсины?',
    'Танцуют на балу поручик Ржевский с Наташей Ростовой. Наташа заводит беседу:\n  — Поручик, скажите, а что Вы делали вчера вечером?\n  — Кобылу на конюшне трахал-с!\n  — Поручик, это же низко!\n  — Кому низко, тот и табурет подставить может-с!\n  — Фи, поручик, какой же Вы пошляк!\n И ушла к другому кавалеру. Спрашивает у него:\n  — Скажите, корнет, как по—вашему, поручик Ржевский действительно такой пошляк, или он просто шалун?\n  — Мадемуазель, пожалуй - просто шалун-с! К примеру, трахали мы вчера с ним на конюшне лошадь, так он все норовил из-под меня табуретку выбить! Определенно шалун!',
    'Муравей таскает камешки, веточки, строит дом. Подъезжает стрекоза на кабриолете:\n— Что делаешь?\n— Дом строю.\n— А зачем?\n— Ну, зима придет, холодно будет, а я в домике согреюсь.\n— Ну ладно, строй, а я в ночной клуб поеду. И уехала.\nМуравьишка тащит камень и думает: "ну ладно. Придет зима, посмотрим..."\nНаступила зима. Муравьишка пилит дрова, подъезжает стрекоза вся в мехах:\n— Что делаешь?\n— Дровишки пилю, холодно, сейчас печку затоплю и согреюсь.\n—Да, холодно. А я в аэропорт еду, полечу в Рио–де–Жанейро, там богема вся собирается, художники, писатели, с ними и перезимую.\n— А Крылов будет?\n— Конечно будет, все собираются.\n— Ну, увидишь – передай, что он гандон.',
    'Два армянина, инвалида-колясочника едут по пустыне. Видят лампу. Один из них натирает её. Появиляется джинн и говорит: "У вас одно желание на двоих". Те в один голос: "Хотим ходить". Джинн подумал м говорит: "Ну так как у вас одно желание на двоих, то ходить будете по очереди!". Ну и дал им нарды',
    'Приходит мужик в магазин покупать шляпу и говорит:\n– Мне нужна самая лучшая шляпа, что у вас есть.\nПродавец уходит куда-то и через пару минут выносит шляпу на два размера больше.\n– Но она же большая – говорит мужик \n– А это волшебная шляпа – говорит продавец – Вы её наденьте, а она как раз станет.\nМужик надевает шляпу и она сразу становится по-размеру, ещё и фасон меняет, подходящий мужику. Взял эту шляпу, приходит с ней домой, красуется перед зеркалом и невзначай надевает на руку, а она возьми, да превратись в элегантную перчатку. Мужик понял, что к чему и надел её на ногу. Перчатка превратилась в прекрасный кожаный сапог. Мужик подумал: "А что если её надеть на член?"\n– И тут вы не поверите, товарищ следователь, сапог превращается в 12-летнего мальчика.',
    'Мужик приходит к тату-мастеру и говорит: \n-А набей мне на всю спину танк \n-Да не вопрос, ложись \nПроходит 15 минут, тату-мастер говорит: \n-Ну всё, готово \n-А почему я встать не могу? \n-А хули ты хотел? 46 тонн!',
    'петля» – подумал Штирлиц. В дверь постучали. «Временная',
    'Ленинград. Послевоенные годы.\nНа уроке учитель спрашивает детей: "Кто и как помогал фронту"?\nПервой отвечает Вера Иванова:\n— Мы с мамой сшили кисет и отдали солдату.\n— Молодец, Верочка! А ты Петя Федоров?\n— А я с мамой вязал теплые носки, которые потом отправляли на фронт.\n— Молодец, достойное дело, Петя, садись.\nНа последней парте Вовочка тянет руку. \n— Ну Вова, а ты как помогал?\n- А я подносил снаряды к оружию. \n— Ну молодец, герой! И что тебе сказали?\n— Зер гут, зер гут, Вольдемар!',
    'Идёт Ёжик по лесу и тут видит три богатыря на лошадях скачут.\n  Говорит Ёжик.\n  -Здравствуй Илья Муромец.\n  -Здравствуй Ёжик\n  -Здравствуй Добрыня Никитич\n  -Здравствуй Ёжик\n  -Здравствуй Алёша Попович\n  -Здравствуй Ёжик\n  -Здравствуй конь Ильи Муромца\n  -Здравствуй Ёжик\n  -Здравствуй конь Добрыни Никитича\n  -Здравствуй Ёжик\n  -Здравствуй конь Алёши Поповича\n  -Здравствуй Ёжик\n  Поговорили они о том о сём. И вот прощаются.\n  -До свиданья Илья Муромец.\n  -До свиданья Ёжик\n  -До свиданья Добрыня Никитич\n  -До свиданья Ёжик\n  -До свиданья Алёша Попович\n  -До свиданья Ёжик\n  -До свиданья конь Ильи Муромца\n  -До свиданья Ёжик\n  -До свиданья конь Добрыни Никитича\n  -До свиданья Ёжик\n  -До свиданья конь Алёши Поповича\n  -До свиданья Ёжик\n \n  Пошел Ёжик дальше. И вот идут ему на встречу Али Баба и сорок разбойников.\n  -Здравствуй Али Баба\n  -Иди нахуй, Ёжик, у нас времени нет',
    'Приходят 2 юриста в ресторан со своими сендвичами, а официант им говорит:"в ресторане со своей едой нельзя". Юристы молча переглянулись и обменялись сендвичами',
    'Грузинская свадьба. Тамада произносит тост, вдруг резко замолкает, и спрашивает у всех гостей:\n– Кто набздэл?\nОдин мужик встает:\n– Я.\nТамада говорит:\n– Пошел вон со свадьба!\nНа следующий день 2 друга, которые присутствовали на этой свадьбе, разговаривают:\n– Хороший был свадьба, веселый! Только я так и не понял, за что Набздела выгнали?',
    'Идет суд над врачем гинекологом за убийство цыганки мусорным ведром. Судья просит подсудимого обьяснить свои действия.\nТот рассказывает:\n— Понимаете, я работаю врачем гинекологом в областной больнице, у меня тот день был особенно тяжелым, с самого утра я сделал 7 абортов, 8 вакуумов, а после обеда мне пришлось принимать роды у 10 женщин.\nЯ, уставший как собака, прихожу домой, а тут жена сразу же с порога кричит, чтобы я ее посмотрел, потому что у нее цистит начался. Ну, что мне делать — пришлось посмотреть ее. Потом дочка подбежала, попросила спираль ей поставить — в пионерский лагерь видишь ли собралась. Ну, поставил я спираль, а что делать.\nНу, думаю, задрали меня все, пойду хоть мусор вынесу отдохну хоть чуть-чуть. Спускаюсь по лестнице, а тут цыганка навстречу: «Мужик, дай 5 рублей я тебе за это пизду покажу».',
    'Женщина после осмотра врача:\n\n— Ну что, доктор, какой диагноз?\n\n— Вы кто по знаку зодиака?\n\n— Ха! Херовый из вас шутник! Если бы я сказала "Рак", то вы бы сказали "Какое совпадение!". Но я Весы!\n\nДоктор, сосредоточенно глядя в записи:\n\n— ебло себе обоссы, у тебя энурез\n\nОказалось, что доктор в юморе уже очень давно.',
    'Еврейский атлет толкнул ядро на 300% дороже, чем на прошлой олимпиаде',
    'Сирия, на позиции стоит командир взвода, в бинокль наблюдает за позициями противника. Отошёл покурить, подбегает обезьяна хватает бинокль и повторяет за командиром взвода.\nИ так несколько раз. Комбат это увидел, подзывает взводника:\n- езжай-ка ты домой, наверное\n- почему?\n- да вон обезьяна за тебя и так всё делает, ей и платить не надо.\nВзводник уехал.\nЧерез 3 месяца звонит ему комбат:\n- давай собирайся обратно\n- зачем, у вас же обезьяна есть.\n- да обезьяну уже на начальника штаба назначили, мне взводник нужен.',
    'Почему Крым был присоединен к России?\n\nВсе дело в том, что в 2014 году был проведен референдум, на котором 96,57% избирателей проголосовало за присоединение к России.\n\nТакого высокого результата получилось достичь благодаря небольшой хитрости, на которую пошли российские власти: Они\nзабыли спросить хохлов.',
    'Встречаются два еврея:\n\n– Мойша, что я вижу? Ты читаешь антисемитскую литературу?\n\n– Таки да!\n\n– Но как ты можешь?\n\n– Ой, Сема! Почитал я нашу, еврейскую литературу. Сплошной депресняк: убивали, мучили, резали, устраивали Шоа и Холокост. Аж тошно! А почитал антисемитскую литературу мы, оказывается, правим миром, мы всем заправляем, всех расставляем на важные посты, всех купили. Сплошной позитив!',
    'В бар заходит посетитель и просит бармена налить в 200 грамовый стаканчик 300 грамм виски.\nБармен удивленно: - Это же невозможно?\nПосетитель: - Тогда в два стаканчика по 150.\nБармен наливает в два стаканчика по 150 грамм. Посетитель выливает все в 200 грамовый стаканчик - все вошло.\nБармен: - Ба, да вы фокусник!\nПосетитель: - Нет, батенька, фокусник - это вы, а я налоговый инспектор!\nВ этот же момент в бар заходит улитка и говорит: - Ну и нахуя ты это сделал?',
    'Мальчику Васе подарили набор "Юный слесарь", и он спился нахуй',
    'У пирса друг напротив друга стоят два корабля. На одном написано "Омск", а на другом "Томск".\nПриезжает с проверкой адмирал, видит названия и спрашивает у дежурного:\n— Это, типа, их в честь городов назвали? Красиво...\n— Нет, — говорит дежурный — Это аббревиатура такая, ОМСК значит: "Охуенный Морской Стратегический Крейсер".\n— А Томск что значит? — спрашивает адмирал.\n— "Тоже Охуенный Морской Стратегический Крейсер"',
    'В школе на уроке мира перед детьми выступает Путин. Видя, что от его\nречи школьники начинают клевать носом, он решил сменить монолог на\nдиалог:\n- У кого-нибудь из вас есть ко мне вопросы?\nТут встает Петя Иванов и говорит:\n- У меня к вам три вопроса:\n1) кто убил Литвиненко?\n2) почему люди в стране такие нищие?\n3) почему в стране постоянно нарушаются права человека?\nПутин чувствует, что его прошибает холодный пот, но тут звенит звонок и\nдети выбегают из класса. Посидел Путин, подумал. Звенит звонок, дети возвращаются в класс. Путин опять\nспрашивает:\n- У кого-нибудь еще есть ко мне вопросы?\nВовочка:\n- У меня к вам пять вопросов:\n1) кто убил Литвиненко?\n2) почему люди в стране такие нищие?\n3) почему в стране постоянно нарушаются права человека?\n4) почему звонок прозвенел на 20 минут раньше?\n5) Куда делся Петя Иванов?',
    'дерутся русский и беременная, всё по честному, бой 2 на 2',
    'Пришол торчек в баню. Заходит в парилку и видит, что на верхней полке два нарка траву курят.\n- Мужики, 15 лет наркоманю такого еще не пробовал!\n- Ну на, попробуй. Торч два раза напаснулся, отдает косяк.\n- Нет, это не кайф, да и трава у вас беспонтовая. Нарки пожали плечами и вышли из парилки. Торч попарился выходит а нарки, уже одетые, его одежду хватают и на выход. Торч охренел с такого оборота событий довай догонять свою одежду. Выбежал голяком на улицу а нарки уже на машине отчаливают, торч поймал тачку.\n- Чем платить будешь, ведь ты же голый?\n- Шеф догоним вон ту тачку там одежда, деньги. Гонки продолжались два часа. В\nитоге нарккам удалось уйти от преследования. Для торчка погоня кончилась на том,\nчто его шофер поимел сзади и выкинул с машины на улицу. Идет торчек голый,\nзамерший, трахнутый да еще сильно срать хочется. Сел под забор, начал срать.\nВдруг его по плечу кто-то стучит и говорит:\n- Братан, ну ладно трава беспонтовая, ну а зачем в парилке срать!',
    'Один мужик решил сделать себе татуировку на члене. Недолго думая, он\nнаколол имя своей любовницы, которую звали ДАРЬЯ. Правда, ее имя можно\nбыло прочесть только во время эрекциии, а без эрекции было видно было\nлишь две буквы - ДЯ.\nОднажды приехал этот мужик в Казань в командировку. Захотелось ему\nпописать. Заходит в туалет, подходит к писуару. А у соседнего писуара\nстоит татарин в тюбетейке. Смотрит мужик, а у татарина на члене тоже\nвидно две буквы - ДЯ. Мужику стало любопытно. Он не выдерживает и\nспрашивает у татарина:\n- А вашу женщину тоже зовут Дарья?\n- С чего вы взяли? - удивляется татарин.\n- Да вот, - говорит мужик, - у вас на члене такая же татуировка, как у\nменя. Когда мой член висит, на нем видны лишь две буквы ДЯ, а когда он\nстоит, то можно прочесть имя моей любимой - ДАРЬЯ.\n- Нет, - говорит татарин, - когда у меня эрекция, на моем члене можно\nпрочитать: "Да здравствует суверенный Татарстан, республика любимая моя"',
    'Решил укурок скрутить себе косяк мечты. Сел на лавочку и давай забивать.\n\nБабки с соседней лавки вызвали полицию. Укурок продолжает забивать. Полиция приехала, поржали, да так с косяком-вещдоком его в бобик и погрузили. Привозят отдел, а тот и там внимания ни на что не обращает, забивает дальше. Ну решили по фану его не трогать. Дело не хитрое, суд быстро назначили. Приводят укурка в зал заседаний, а он и там косяк крутит. Бла-бла, суд идёт. Нарк берет косяк и от души раскуривается. Судья требует порядка и молотком по столу - тюк! Укурок поднимает голову, выдыхает и пряча косяк за спину: "оппачки, менты..."',
    'Выходит Маяковский из кабака, окруженный стайкой девиц. Девицы начинают его охаживать:\n- Владимир! А это правда, что Вы можете сочинить стихотворение прямо с ходу, на месте?\n- Конечно! - говорит подвыпивший поэт революции, - Давайте тему!\n- Ну, вот видите, в канаве - пьяница валяется.\nМаяковский, гордо выпрямившись, громогласно начинает:\n\nЛежит\nБезжизненное\nТело\nНа нашем\nЖизненном\nПути.\n\nГолос из канавы:\nНу а тебе какое дело?\nИдешь с бл*дями и иди.\n\nМаяковский: - Пойдемте, девушки, это Есенин.',
    'Журналисты берут интервью у девочки, победившей на областной олимпиаде по химии:\n –Скажите, а кроме химии, какие предметы Вы любите?\n–Я люблю математику, физику, биологию, иностранные языки.\n–Какая Вы молодец! А спортом Вы занимаетесь?\n–Я занимаюсь художественной гимнастикой, лёгкой атлетикой, большим теннисом и стоклеточными шашками.\n–А на хобби у Вас остаётся время?\n–Мои хобби: нумизматика, филателия, авиамоделирование и трава.\n–Какая трава?!\n–Дурь, шмаль, травка, анаша...\n–Девочка, что ты плетёшь?!\n–Коврики, корзинки, макраме…',
    'Ебется курсант с бабой. Тут приходит муж с работы.\nБаба говорит:\n- Давай прыгай с балкона.\nТот отвечает:\n- С ума сошла? Мы на 9 этаже.\n- Я волшебница, я тебя заколдовала. Дёрнешь хуй и станешь бабочкой и улетишь.\nНу времени мало, курсант дергает себя хуй и превращается в бабочку. Летит себе, летит. Но тут резко пугается, как же превратиться обратно? Приземляется на лавочку и дергает себя за хуй. Дёрнул - снова стал курсантом. Дёрнул опять - превратился в бабочку. Понравилось ему это, дёргает раз - бабочка, дёргает два - человек. Дёргает,и вдруг слышит голос:\n- Товарищ курсант, мало того что вы дрочите на лекции, так еще и превращаетесь то в бабочку, то в курсанта.',
    'Сидя металюги, бухают. Один говорит:\n— Давайте выпьем за кузнеца.\n— Почему за кузнеца?\n— Потому что он кует МЕТАААААААЛ!!!\nТут все хлещут водяру из горла.\nВторой говорит:\n—  Давайте выпьем за литейщика.\n— Почему за литейщика?\n— Потому, что он льет МЕТААААААЛ!!!\nОпять гасят водяру.\nТретий уже в говно, проблевавшись и вылезая из-под стола:\n— Давайте выпьем за карасика.\n— Почему за карасика?\n— Потому, что он икру МЕТААААААААЛ!!!!',
    'Встречаются 3 мужика на Небесах. Решили обсудить, кто как умер. \nПервый говорит:\n  –Возвращаюсь я с командировки домой пораньше и застаю свою жену голой на кровати. Начинаю искать любовника и вижу, как из подъезда какой-то мужик выбегает. Не долго думая, сбрасываю на него из окна холодильник, приезжает полиция и расстреливает меня. \nВторой говорит:\n  –Выхожу я на пробежку, а мне холодильник на голову падает. \nВсе смотрят на третьего, и он говорит:\n  –Сижу я, значит, в холодильнике...',
    '— Ты думаешь ты можешь вот так вот просто вырывать цитаты из контекста?\n— Да (Евангелие от Матфея, 6 глава, 27 стих, 1 слово)\n– Пизда! (Пресс-конференция Филиппа Киркорова в Ростове-на-Дону, 20 мая 2004 г.)',
    'Мой дед умер под трек Моргенштерна и Вити АК. Для нашей семьи это была утратататата да сука новый автомат.',
    'Поручик Ржевский:\n- А не сыграть ли нам, господа, в новую игру? "Козырная залупа" называется.\n- Научите поручик! Надоел преферанс!\n- Игра очень простая. Сдавайте карты, господа. И сразу на кон по рублю. Я быстро научу.\nКарты раздали, банк замутили. Ждут. Ржевский кладет свои карты на стол:\n- Залупа! - и сгребает деньги.\n- А в чем же смысл, поручик?\n- Всё просто, господа. Кто первый карты на стол бросит с криком "Залупа!" - того и банк.\nПонятно. После следующей раздачи все резко кидают карты на стол с криками:\n- ЗАЛУПА!!!\nРжевский, спокойно и невозмутимо кладет карты на стол:\n- Козырная залупа, господа',
    'Телега:\n\n<a href="/away.php?to=http%3A%2F%2Ft.me%2Fanekdotcollection&amp;post=-149279263_318175" rel="noopener nofollow" target="_blank">t.me/anekdotcollection</a>',
    'Три мужика рассказывают у кого жена тупее.\n- Моя дура - купила наушники. А плеера-то у неё нет!\nВсе ржут.\n- Моя ещё тупее - купила принтер. А компьютера-то у неё нет!\nВсе хохочут.\n- Эт всё хуйня, вот моя презервативов набрала и на море укатила!\nВсе молчат.\n- А члена-то у неё нет!',
    'Конкурс охотников в Африке. Стрелять можно все, кроме крокодилов. Очевидные лидеры Американец, Англичанин и Чукча.\n1-й день. Американец: 2 бегемота. Англичанин: 3 слона. Чукча: 5 ноусеров. Удивились иностранцы. Стыдно им сказать, что не знают такое животное — ноусер!\n2-й день. Американец: 5 бегемотов. Англичанин: 10 слонов. Чукча: 30 ноусеров. Удивились иностранцы.\n3-й день. Американец: 15 бегемотов. Англичанин: 30 слонов. Чукча: 70 ноусеров.\nОбъявляют лучшим охотником чукчу. Показательная охота. Идет чукча по лесу. Из кустов выбегает негр. Чукча: Крокодила? Негр: No, sir!',
    'Умер Фидель Кастро. Входит он со своим упакованным в чемоданчик барахлом в райские врата, его встречает святой Петр: \n— Так, присаживайтесь, посмотрим, есть ли Вы у нас в списках... так в основном списке Вас нет, в дополнительном нет... что тут у нас... а это форма 202, справка А38... не, не то... ясно, нет Вас в списках, что ж поделать, видать Вам надо в ад. Отправляйтесь-ка туда. \nДелать нечего, спускается Фидель в ад. Там его сам Люцифер встречает с \nраспростертыми обьятиями: \n— Фидель, дружище! Как же мы заждались! Проходи, тебя ждет отдельный номер со всеми удобствами. Сигары, девочки... а не желаешь ли по стаканчику рома с дороги? Сидят они, выпивают, беседуют, и тут Фидель вспоминает что забыл свой чемоданчик с \nвещами в раю. Люцифер вызывает двух бесов: \n— Так, быстро метнулись в рай, принесли уважаемому коменданте его чемоданчик! Только чтобы одна нога тут, а другая там, поняли? \nНу бесы и помчались в рай. А там у святого Петра смена закончилась, он запер ворота, да и ушел к себе в келью отдыхать. Бесенята бегают возле ворот туда-сюда, что же делать, без чемоданчика возвращаться нельзя, Люцифер кожу с них спустит. Полезли они в рай через забор.... \nА на охране стоят два архангела и наблюдают за всем этим, и один другому говорит: \n— Ты смотри, Фидель всего 20 минут как в аду, а у нас уже беженцы!',
    'В университете идет экзамен по логике.\nПрофессор задает студенту вопрос:\n— На борту летящего самолета 500 кирпичей. Один кирпич выпал из самолета. Сколько на борту осталось кирпичей?\nСтудент не долго думая:\n— Ну, это легко! 499!\n— Правильно. Тогда следующий вопрос: как поместить слона в холодильник за 3 шага?\n— Открыть холодильник. Поместить туда слона. Закрыть холодильник.\n— Дальше. Как поместить оленя в холодильник в 4 приема?\n— Открыть холодильник. Вынуть из него слона. Запихать оленя. Закрыть холодильник.\n— Отлично! У царя зверей льва день рождения. Поздравить его пришли все животные, кроме одного. Почему?\n— Потому что олень все еще находится в холодильнике.\n— Просто здорово! Давайте дальше. Может ли бабуля пройти через болото с крокодилами?\n— Конечно, может! Крокодилы же ушли праздновать день рождения льва.\n— Хорошо! А теперь последний вопрос. Бабуля прошла через пустое болото, но все равно умерла. Что с ней случилось?\n— Может на нее упал кирпич, который выпал из самолета?\n«Пошёл нахуй» - ловко парировал профессор',
    'Попали в Ад американец, индус и русский. Встретил их Черт и говорит: \n— Всем, кто сюда попадает, даю шанс перейти в Рай. \nИ достает здоровенный кнут (побольше, чем у Гаррисона Форда в «Последнем крестовом походе»): \n— Кто выдержит три удара не закричав — отпускаю! Можете защищаться, чем хотите. \nПервым вышел американец. \n— Чем хочешь защищаться? \nАмериканец взял здоровый гранитный камень: \n— Я готов! \nЧерт размахнулся в первый раз и… камень вдребезги. Второй раз — и американец заорал как бешенный… \n— Следующий, — говорит Черт. \nВыходит индус. \n— Чем будешь защищаться? \n— Ничем! — отвечает индус, — Я 80 лет занимался йогой, и в медитации тело не чувствует боли! \n— Ладно. \nПервый удар. Индус: — Ошшш… \nВторой удар. Индус: — Ошшш… \nТретий удар. Индус: — Ошшш… \n— Ух е… твою… Еще никто не выдерживал трех ударов. — говорит Черт. \n— Ну что ж, ты свободен, можешь спокойно идти в Рай. \n— Нет, — говорит индус, — хочу остаться и посмотреть. Во всех анекдотах русские выигрывают. Хочу увидеть, как у него на этот раз получится. \n— Ладно, останься. Ну, чем думаешь защищаться? — обращается Черт к русскому. \n— Чем защищаться — индусом, конечно…',
    'Ведьмаку опостылело жить. Пошел на болото топиться. Толькоприготовился вдруг Ивасик выныривает: \n- Что надо? Что пришёл? \n- Да надоело все, заказы копеешные, крестьяне обманывают, да еще и приблудой зовут и камнями закидывают, чего я мучиться буду, утоплюсь и все. \n- Иди, ведьмак, обратно, всё будет хорошо. \nПриходит ведьмак в село, а его крестьяне всей деревней встречают: \n- Спаситель наш, благородный ведьмак, люда простого защитник, у нас для тебя заказов куча, злата серебра не пожалеем. \nПрошло полгода. Перебил ведьмак всех монстров в округе, но получил ран много, регенерация уже не та, та и рефлексы слабоваты. Решил снова утопцем стать. \nПошел на болото. Ивасик: \n- Что надо? Что пришел? \n- Да износился я. Раны болят, скорость подводит, того и гляди полягу на следующем заказе. Нет уж, лучше я сам свою судьбу решу. \n- Иди, ведьмак, обратно. Все будет хорошо. \nВернулся ведьмак на большак и стал еще быстрее чем раньше финты и пируэты крутить, монстров как траву косит. \nПрошло полгода. Захотел ведьмак оседлую жизнь вести, но никто ему земли продавать не хочет, ни соседства с паршивцем не желает. Пошел на болото. \n- Что надо? Что пришел? \n- Ай, Ивасик, устал. Не мешай, утоплюсь и дело с концом. \n- Иди, ведьмак, обратно, все будет хорошо. \nПриходит ведьмак в город а там ему купцы и вельможи свои дома да производства за бесценок предлагают, мол ведьмак, полно тебе мечом махать, забирай по старой дружбе. \nНу ведьмак думает "Холера, Ивасика-то отблагодарить надо!". Пошел на болото. \n- Что надо? Что пришел? \n- Да добра ты мне столько сделал, давай отблагодарю. \n- Да иди в свой Новиградский дом, ведьмак. Все хорошо. Иди. \n- Да не могу я так, совесть не позволяет. \n- Ну ладно, хочешь мне добро сделать, так трахни меня. \n... - И тут, ты не представляешь, Йен, Ивасик превращается в Трисс Меригольд!',
    'Звонит телефон в расположении казармы военной части. Мимо идет солдат, думает — чего надрывается, дай возьму трубку:\n— Але...\nИз трубки:\n— Скажите пожалуйста, сколько у Вас в части служебных Волг?\n— Две: одна в ремонте, на другой ездит старый мудак Пилипов.\n— А кто это такой — Пилипов?\n— А, это наш командир части — полковник Пилипов.\n— И че, мудак он что ли?\n— Да, таких мудаков еще поискать надо — мудак-мудаком!\n— Да, а Вы знаете с кем Вы разговариваете?\n— Нет.\n— Вы разговариваете с полковником Пилиповым!\n— Да, а Вы знаете с кем Вы разговариваете?\n— Нет.\n— Ну тогда пошел на хуй Пилипов!',
    'Едут два гея в переполненном трамвае. Один из них спрашивает второго: \n— Давай прям тут \nДругой же: \n— Не, ты чего, тут же полно народа! \nТогда этот: \n— Да на нас тут никто внимания не обращает. Смотри: \n— Граждане, не подскажете который час? \nВ ответ тишина. \n— Вот видишь \n— Ну ладно \nПроходит некоторое время, трамвай опустел, конечная станция. Сидит один дед на скамейке. К нему кондуктор подходит и спрашивает: \n— Дедушка, а вы чего тут сидите? \n— Да сердце прихватило, сынок... \n— Так вы бы попросили у кого-нибудь валокордина, наверное был у кого-то! \n— Да, нет, ты что. Тут один спросил который час, так его всю оставшуюся дорогу в жопу ебали.',
    'Шел мужик мимо школы. Остановился рядом со ступеньками, на которых сидела компания гопников, и на несколько секунд замер.\n- Парни, вы, конечно, классные, но сегодня не ваш день! У меня панама! - начал разговор мужик, указав на головной убор гигантского размера.\n- Что тебе нужно? - с презрением спросили гопники.\n- Вижу: сидите, мочу какую-то из банок пьете. Наверное, доебаться до меня хотите? Хуй вам! Панама-то на мне! - продолжал мужик.\n- Дядя, иди отсюда по-хорошему! Мы сегодня и так не в настроении! - ответили гопники.\n- Какие пидористические голоса! Наверное, в гей-клубе поете? Вы, это, не забывайте: панама по-прежнему на моей голове! - не унимался мужик.\n- Да заебал ты уже со своей панамой! - сказал один из гопников и с силой ударил мужика по башке.\nВсе затмила яркая вспышка. По району прокатился жуткий грохот.\nВ панаме была противопехотная мина.',
    'Стоит отсидевший зек на кассе, расплачивается. Кассир ему:\n– Сто сорок девять.\nЗек нахмурился и ка-а-ак уебал продавца:\n– Ты про маму-то не шути...',
    'У качка спрашивают:\n— Сколько будет 20+20?\n— Пятьдесят пять.\n— Почему пятьдесят пять, если сорок?\n— Так ведь ещё гриф!',
    'Пришел студент в столовую, а все столики заняты, подсаживается к профессору, а тот говорит:\n— Гусь свинье не товарищ.\nСтудент:\n— Ну ладно, я полетел.\nПрофессор обиделся и решил на экзамене студента завалить. Дает ему самый трудный билет, а тот отвечает на отлично и профессор задает дополнительный вопрос:\n— Идешь ты по дороге и видишь два мешка, один с золотом, второй с умом. Какой выберешь?\nСтудент:\n— С золотом.\nПрофессор:\n— А я бы с умом взял.\nСтудент:\n— Это кому чего не хватает.\nПрофессор рассердился и пишет в зачетке "КОЗЕЛ", студент не посмотрел и ушел. Через некоторое время возвращается и говорит:\n— Профессор, вы тут расписались, а оценку не поставили.',
    'Комполка вызывает лейтенанта.\n- Слушай, лейтенант, ты каждый вечер в кабаке зависаешь! Даже я со своей зарплатой не могу себе такого позволить! Откуда деньги?! Топливо продаёшь, сучёныш?!\n- Никак нет, товарищ полковник! Споры выигрываю!\n- Это как?\n- А вот давайте на Вашу зарплату поспорим, что у Вас завтра утром здоровенный прыщ на жопе вскочит!\nПоспорили.\nУтром командир вызывает лейтенанта.\n- Всё, лейтёха! Готовь бабки! Прыща-то нет!\n- Да не может быть! Как же так?!\n- Вот так, лейтенант! Будет тебе наука!\n- Товарищ командир, разрешите проверить. Деньги-то немалые! Только к окну подойдите, здесь светлее.\n-На! Проверяй!\nИ командир со спущенными штанами подошел к окну.\n- Да, действительно, нет прыща! Вот Ваши деньги, товарищ командир.\n- Что, лейтенант, на месяц без кабака остался?\n- Никак нет, товарищ командир. Видите снаружи толпа? Я с каждым на зарплату поспорил, что заставлю Вас жопу в окно показать...\n- Ну, пиздец тебе, лейтенант! Я тебя в такую глушь сошлю - волком выть будешь. К тому же там командир - мой однокурсник, я его предупрежу, что ты ушлый. Всё, лейтенант, иди, собирай вещички!\nПрибывает лейтенант в другую часть, идёт к тамошнему командиру представляться.\n- А, это про тебя мне говорили! Ну, заходи, заходи. Мне тут сказали, что ты просто пиздец, какой ушлый. Так вот, лейтенант, со мной такие номера не пройдут!\n- Я понял, товарищ командир. Только если я засуну Вам в жопу морковку, то обратно выну уже огурец!\n- Это как же?\n- Да вот так! Засуну морковку, а обратно выну огурец!\n- С чего это морковка в жопе в огурец-то превратится?\n- Не верите? Хотите, на Вашу зарплату поспорим?\n- Да хоть на пять!\n- Договорились! У меня вот и морковка с собой!\nКомандир снимает штаны, а лейтенант засовывает ему в жопу здоровенную морковку. Командир кряхтит, морщится, но терпит. Шутка ли - пять зарплат!\n- Ну что там, лейтенант? Давай уже, вынимай!\nЛейтенант вынимает обратно... Естественно, морковку!!!\nКомандир ликует:\n- Ну, что, пацан? Я же тебя предупреждал, что со мной шутки плохи! Погоди-ка, другу позвоню, расскажу, как я тебя сделал!\nЗвонит.\n- Слушай, сделал я твоего ушлого! Он мне теперь пять зарплат торчит!\nВ ответ раздается стон:\n- Бляяяяяя...\n- Ты чего?!\n- Да этот гадёныш, уезжая, на десять зарплат со мной поспорил, что в первый же день морковку тебе в жопу засунет...',
    'Приходит к врачу в морг мужик и говорит\n- Прикинь, я если труп выебу, то он воскреснет\nВрач подумал, что брехня, но решил проверить, достал бабку и дал мужику, тот её выебал, и тут бабка реально воскресла и говорит\n- Я при жизни много чего не успела сделать, спасибо вам\nРешил врач ещё раз убедится и дал мужику труп старого профессора. Мужик выебал и его, вдруг профессор встаёт и говорит\n- При жизни я пытался разработать новый химический элемент, спасибо вам, надеюсь сейчас у меня получится.\nРешили врач с мужиком Ленина воскресить, пробрались в мавзолей, мужик вставил член и начинает ебать Ленина, прошёл час, два, врач говорит\n- Че ты не просыпаешься то?\nА Ленин отвечает\n- Так я и не сплю)',
    'Поймали пришельцы Русского, Американца и Японца и говорят: \n- Приготовьте то, что мы не ели или мы вас убьём. \nВзяли все трое продукты и разошлись по кухням. Через пару часов заходят пришельцы к Американцу. Американец приготовил бургер. \n- Вкусно, но мы такое ели - сказали пришельцы и убили Американца. \nЗаходят они к Японцу. Японец приготовил суши. \n- Вкусно, но мы это уже ели. \nУбили и японца. \nОткрывают комнату Русского, а оттуда дым едкий валит. Проветрили комнату и видят: обои слезли голые стены все в красной плесени, а около окна сковородка стоит. \nДостаёт русский сковороду, ставит на стол и даёт ложку пришельцу. Пришелец пробует суп и говорит \n- Ух, бля',
    'Адольф Гитлер не доверял отчётам, исходящим от людей, преданных ему. Однажды он переоделся и пошёл в кино. Вскоре началась сводка новостей. Голос произнёс:\n— А теперь – последняя фотография нашего великого, благословенного диктатора.\nКомментарий продолжался. На экране появилась фотография. Одним движением вся толпа поднялась на ноги и закричала:\n— Хайль Гитлер!\nГитлер так обрадовался такому отклику, что забыл подняться. Человек, сидящий сзади, похлопал его по плечу и сказал:\n— Я знаю, какие чувства ты питаешь к этому ублюдку, но лучше встань, не то полиция арестует тебя.',
    'Жил-был парень у которого сильно потели ноги и соответственно-сильно воняли, и девушка- у которой сильно воняло изо рта. И вот они договорились о свидании.\nПарень должен прийти к девушке домой. Девушка переживает-со рта ведь воняет. А мама ей и говорит: А ты не говори с ним. Только кивай головой и все будет в порядке.\nПарень тоже переживает-ноги воняют, как быть? Его мать ему говорит: Прийдешь к ней, сразу пойди в ванную и помой ноги.\nНу значит приходит он к ней. Сразу раззувается, скидывает носки, в спешке забрасывает их куда-то и бежит мыть ноги.\nВыходит, а носков нету.Он к подруге:Где мои носки?\nА она : мм,мм, и головой качает.\nОн опять: Что, мм, где мои носки, я спрашиваю?\n-Мм, мммм,...\n-Что ты мычишь, где носки?!!!!\nподруга не выдержала и как заорет: Да не знаю я!!!\n-Сука! Ты их сьела!',
    'Шофер, который однажды вез Эйнштейна на лекцию в какой-то отдаленный университет, сказал ему:\n– Я так много вас возил, что могу прочитать вашу лекцию за вас.\n– Попробуй, — сказал Эйнштейн. Они поменялись местами, приехали в университет, шофер под аплодисменты встал за кафедру и прочитал слово в слово лекцию Эйнштейна. И тут какой-то ученый поднял\nруку и попросил лектора решить какую-то невероятно сложную формулу. Шофер не растерялся и под аплодисменты решил невероятно сложную формулу.\nЭтим шофером был Альберт Эйнштейн.',
    'Сидит психиатр у себя в кабинете - скучает...... пациенты не идут.\nТут тихонько так приоткрывается дверь и к нему на карачках заползает\nчеловек, сжимая что-то в зубах, руках и т.д. плюс что-то еще\nволочится сзади.\nПсихиатр:\n- Ой, кто это к нам тут ползет!!! Это, наверное, маленькая змейка.\nЗаползай, змейка, заползай, маленькая, доктор тебе поможет.\nЧеловек отрицательно машет головой.\n- А-а-а, это, наверное, черепашка к нам в гости пожаловала. Заползай,\nчерепашка, в кресло и расскажи дяде доктору, что с тобой случилось...\nЧеловек отрицательно машет головой.\n- Так кто же это у нас - наверное, маленький червячок??\n-Доктор, идите нахуй, я вам интернет прокладываю',
    'Едут хохол и москаль в поезде. Хохол достаёт сало и начинает есть.\nМоскаль говорит:\n– Угости меня\n– Ай, ты його їсти не будеш\n– Да чего не буду, у нас тоже сало едят\n– Я тобі кажу, ты його їсти не будеш\n– Да почему?!\n– Тому що я тобі його не дам',
    'У танка слетела гусеница и экипаж пытается её надеть. Вдруг появляется фея, видит это дело и спрашивает:\n- Мальчики, а что вы делаете?\nСолдаты со злостью:\n- Ебемся!\n- Мальчики, а хотите по настоящему?\nСолдаты: -Гы-гы-гы. Хотим!\nВзмахнула фея волшебной палочкой, и у танка отвалилась башня.',
    'Кота так часто тыкали носом в ковёр, что он принял ислам.',
    'Идет по лесу заяц, а навстечу ему известный на весь лес хохмач медведь. Увидел медведь зайца иговорит:\n- О, заяц! У меня есть такой классный новый прикол! Ты подходишь к волку и спрашиваешь: а где, волк, твоя шляпа? А дальше я буду действовать.\n- Ты чё, медведь, он же меня убьёт!\n- Не дрейфь, заяц, не убьет.\nЗайцу деваться некуда. Подходит к волку и говорит:\n- А где, волк, твоя шляпа?\n- Да нет у меня никакой шляпы... - отвечает волк. А сзади его медведь канализационным люком по голове:\n- А вот твоя шляпа!!!\nВобщем у волка мозги в разные стороны, в итоге он еле оклимался.\nПроходит время.\nОпять идет по лесу заяц, а навстечу ему снова медведь. Увидел медведь зайца иговорит:\n- О, заяц! У меня есть такой классный новый прикол! Ты подходишь к волку и спрашиваешь: а где, волк, твои кеды? А дальше я буду действовать.\nЗаяц подумал и решился. Подходит к волку:\n- А где, волк, твои кеды?\n- Да вот мои кеды...- ответил волк глядя на свои лапы.А сзади его медведь канализационным люком по голове:\n- А вот твоя шляпа!!!',
    'У 78-летнего Джо Байдена день рождения. Должны прийти его друзья демократы. Купил он торт,\nпирожные, и положил все это на кухне. А так как память уже не та, написал записку, что и в каком порядке надо делать, и прикрепил на холодильнике.\n1. Напоить чаем.\n2. Угостить тортом.\n3. Угостить пирожными. Пришли друзья демократы. Джо идёт на кухню и читает:\n1. Напоить чаем. Он приносит в комнату чай, все пьют. Он опять идет на кухню и читает:\n1. Напоить чаем. Они опять пьют чай.\nИ так 6 раз. После этого друзья демократы прощаются и уходят.\nУже на улице один из них говорит:\n- Байден совсем плохой. Два часа просидели - хоть бы чаем напоил. Второй:\n- А разве мы были у Байдена?\nТретий:\n- Кто такой Байден?\nБайден зашёл на кухню, а там торт, пирожные, всё не тронутое:\n- Вот ведь дураки старые, даже не пришли!',
    'Судебное заседание. Рассматривают дело о дальнейшей судьбе ребенка при разводе. Судья предоставляет слово:\n-Мальчик, ты кого выберешь: папу или маму?\n-Викингов!\nСудья выдал мальчику 20 миллионов мощи.',
    'Заходит парень в кафе и читает прейскурант: "Пирожок с капустой — 50 р. \nПодрочить — 500 р." \nСмотрит, за прилавком стоит продавщица — сногсшибательная блондинка. \nПарень:\n— Извините, а кто у вас дрочит?\nБлондинка с томной улыбкой на устах: \n— Я, а что? \nПарень:\n— Тогда вымойте, пожалуйста, руки. Мне пирожок с капустой.',
    'Наши чемпионат Европы проиграли, вернулись домой.. Жена просит Дзюбу в магазин сходить. Артем ей: "Да не пойду я! Меня сейчас болельщики увидят, в лицо плевать будут! Побьют ещё!" Жена: "Надень моё платье, парик, накрасься, никто тебя не узнает" Оделся, накрасился пошел. В очереди в магазине стоит, бабка подходит: "Привет, Дзюба!" Артём в недоумении: "Бабка, но как?! Как ты меня узнала? Я накрашенный, в платье, парике, лабутенах". Бабка: "Не узнаешь что ли? Это же я, Черчесов"',
    'Летят 2 кавказца на самолёте.\nСкорость 800, 850, 900.\n— Куда гонишь, брат?\n— Меня девушка бросила, брат. Больше я никому не нужен\n— Мне ты нужен, братишка\nСкорость 900, 600, 300, 100.\nСамолёт падает.',
    'возвращается чапаев из лондона с огромной кучей денег, ну и спрашивают его "откуда столько денег" \n- Василий Иванович, откуда у тебя все это? \n- Да так, Петька, в карты выиграл. \n- Как это? \n- Захожу я в клуб. Там все сидят, выпивают, в карты играют. Присмотрелся - в очко режутся! Сел я за столик, взял карты. У меня - 18. А мой соперник-англичанин говорит - 20. Я ему: "Покажи!" А он - мне: "Мы, джентльмены, верим на слово". Вот тут-то мне как поперло, как поперло...',
    'Сидят на небе Черт с Богом, о жизни разговаривают.\nЧерт:\n- Бог, ну что за дела, у тебя же на Земле сплошной беспредел\nтворится!\nБог:\n- Как это? Hе может быть.\nЧерт:\n- Hу смотри.\nЧерт превращается в голую красивую телку, ложится перед церковью и раздвигает ноги. Мимо идет батюшка. Он увидел телку, оглянулся вокруг и быстренько ее оприходовал, поправил одежду и зашел в церковь. Черт возвращается на небо и предъявляет Богу, мол, видел ты, что у тебя творится и тут Бог превращается в церковного батюшку: вот так мы вас чертей и ебем.',
    'Решил один мужик завести домашнее животное - жена совсем достала.\nПриходит в зоомагазин и среди прочей живности видит попугая. БЕЗ ЛАПОК.\nМужик:\n- Надо же! попугай без лапок!\nПопугай:\n- Ну что поделаешь - таким родился...\nМужик:\n- А ты меня понимаешь, что ли?\nПопугай:\n- Да, я вообще очень умная и образованная птица - могу поддежать\nбеседу на любую тему, знаком с науками и т.д.\nМужик:\n- Скажи, а как ты без лапок на жердочке сидишь?\nПопугай:\n- Ну... членом я хватаюсь, просто под перьями не видно.\nКороче, купил мужик попугая.\nВ доме сразу весело стало - попугай всех веселит, истории рассказывает,\nпоет...\nПриходит мужик как-то раз с работы домой, а попугай ему и говорит:\n- К твоей жене сосед приходил.\nМужик:\n- и что?\nПопугай:\n- А жена твоя в одной ночнушке его встретила!\nМужик:\n- а потом?\nПопугай:\n- Они начали целоваться.\nМужик:\n- Убью гада! А потом?\nПопугай:\n- Он стал на колени и полез ТУДА.\nМужик:\n- А потом?\nПопугай:\n- А потом у меня хуй встал и я с жердочки ебнулся...',
    'Капитан с ужасного бодуна просыпается от того, что его тормошит штурман:\n— Капитан, капитан! У нас пробоина ниже ватерлинии!\nКапитан в ахуе начинает соображать, но получаетя весьма смутно:\n— Починить можем?\n— Никак нет, капитан!\n— Шлюпки на воду!\n— Нету шлюпок, капитан!\n— Раздать команде и пассажирам спасжилеты!\n— Капитан, спасжилет только один! — отвечает штурман и демонстрирует его капитану.\nКапитан что-то раздумывает, потом выхвает спасжилет, спешно надевает и выпрыгивает за борт.\n— Капитан! Капитан! Куда вы? Сегодня же первое апреля! Блядь, что мы скажем по прибытии?\n"Какая на хуй пробоина? Какая в пизду ватерлиния?" — думал капитан самолета, неумолимо приближаясь к земле...',
    'Приехал в Африку белокожий миссионер рассказывать племени темнокожих о христианстве. \n \nПоучает, что спать с чужими женами грех и прочее. А через год рождается у жены темнокожего вождя белый ребенок. Злой вождь приходит к проповеднику: \n- Ах ты гад! Ты один белый на весь остров, так что теперь не отмажешься! Съедим тебя всем племенем! \nМиссионер отвечает: \n- Тут дело не во мне. В природе иногда случаются генетические отклонения, рождаются альбиносы, такое бывает! Вон, посмотри, там вдалеке пасется стадо белых овец. А одна овца, вон там, черная! Откуда же она по-твоему взялась? \n \nВождь подумал и говорит: \n- Ладно, мужик! Давай мы так договоримся: я молчу про белого ребенка, а ты никому не рассказываешь про черную овцу!',
    'Врач сказал: «Фима, хорошая новость — это то, что я могу избавить тебя от твоих головных болей. Плохая новость — это то, что для этого потребуется кастрация. У тебя очень редкое состояние, из-за которого твои яйца давят на нижний отдел позвоночника, и это давление вызывает у тебя жуткую головную боль. Единственный способ снизить это давление — удаление яиц».\nФима был в отчаянии. Ему даже жить расхотелось. Но выбора не было, и он согласился пойти под нож...\nКогда он вышел из больницы, впервые за 20 лет его не терзала головная боль, но его не покидало сожаление об утраченной части самого себя. Но потом он решил, что нужно начать новую жизнь. Он увидел магазин мужской одежды и подумал: «А не купить ли мне новый костюм?»\nОн вошёл в магазин и сказал продавцу: «Мне нужен костюм».\nПожилой продавец смерил его быстрым взглядом и сказал: «Так… Рост 174».\nФима рассмеялся: «Верно, откуда вы знаете?» — «60 лет в бизнесе!»\nФима примерил костюм, — он был впору...\nПока Фима любовался собой в зеркале, продавец спросил: «Как насчёт новой рубашки?»\nФима подумал и согласился...\nПродавец взглянул на Фиму и сказал: «Так. 34 рукав и 16 с половиной шея».\nИ вновь Фима удивился: «Верно, откуда вы знаете?» — «60 лет в бизнесе!»\nФима примерил рубашку, и она сидела великолепно!\nКогда Фима поправлял перед зеркалом воротничок, продавец спросил: «Может быть, вам нужны новые ботинки?»\nФима понравилась эта мысль, — продавец взглянул на Фиму и сказал: «Так… 9−½ E».\nФима был потрясён: «Верно, откуда вы знаете?» — «60 лет в бизнесе!»\nФима примерил ботинки, и они ему подошли.\nФима прошёлся по магазину, и продавец спросил: «А нижнее бельё?»\nФима подумал и согласился...\nПродавец сделал шаг назад, смерил взглядомз талию Фимы и сказал: «Так… Размер 36».\nФима расхохотался: «Ха-ха! Вот я вас и поймал! Я с восемнадцати лет ношу 34-й!»\nПродавец покачал головой: «Вы не можете носить 34-й. 34-й размер нижнего белья придавит ваши яйца к нижнему отдела позвоночника, и у вас будет жуткая головная боль»',
    'Германия, 1945 год. Гитлер сидит в Фюрербункере, внезапно к нему врывается русский. Гитлер спрашивает:\n– Ты как здесь оказался? Как ты прошел три уровня защиты? Как прошел моих охранников?\nА русский отвечает:\n– Ты какого хуя по-русски разговариваешь?',
    'Едут в поезде в одном купе хохол и негр. Хохол достает сало, цыбулю (лук), нарезает на кусочки сало. Негр спрашивает:\n— Что это?\n— Цэ сало.\n— Да какое же это сало. Вот когда мы в Зимбабве свежуем бегемота, вот там сало, полметра толщиной.\nХохол заметно напрягся. Достает вареные яйца.\nНегр спрашивает:\n— Это что?\n— Цэ яйца.\n— Ну разве это яйца? Вот когда мы в Зимбабве разбиваем страусиное яйцо и жарим яичницу, то могут наесться сразу двадцать человек.\nХохол напрягся еще больше. Достает большой арбуз, килограмм на 10.\nНегр спрашивает:\n— Ну а это что?\n— Цэ крыжовник. Дичка',
    'ЗАХОДИТ ЧЕРЕПАХА В БАР И ПРОСИТ ВОДЫ У БАРМЕНА, НУ БАРМЕН ДАЕТ ЧЕРЕПАХЕ ВОДЫ, ЧЕРЕПАХА УХОДИТ, И ТАК 4 ДНЯ ПОДРЯД, НА 5 ДЕНЬ БАРМЕН СПРАШИВАЕТ: "НАХУЯ ТЕБЕ ВОДА? ДАВАЙ ВОДКИ СРАЗУ ЕБАНЕМ" А ЧЕРЕПАХА В ОТВЕТ: "НЕ СЕЙЧАС БЛЯТЬ У МЕНЯ ДОМ ГОРИТ"',
    'Геймер, заработавший себе геморрой, часто задаётся вопросом: стоила ли игра свеч?',
    'Как называют хохла на подлодке?\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.',
    'Идут три инвалида по пустыне.\nСлепой, безрукий и колясочник.\nИдут идут и видят оазис. Ну безрукий туда ныряет. Вылазит и видит, что у него руки выросли. Говорит остальным что он волшебный и сразу за ним туда нырнул слепой. Вылазит и говорит:\n-Братцы, я теперь вижу\nА за ним со всех сил ковыляет до оазиса колясочник. Ныряет.\nВылезает  и говорит:\n- У меня, блять, теперь новые покрышки',
    'Поймали инопланетяне китайца, немца и русского. Посадили их в абсолютно круглые камеры и сказали: "Если вы нас удивите то мы вас отпустим. Если не удивите - убьем. Времени вам неделя". Приходят через неделю, заходят к китайцу, а он из своего телефона, штанов и ключей построил многофункционального робота, который и еду готовит, и в интернет выходит, и план побега разрабатывает. Пришельцы посмотрели на это, и говорят мол "и че это за фигня?" Убили китайца. Заходят к немцу, а немец построил двигатель с КПД 150%. Пришельцы смотрят и говроят: "фигня, прошлый век, у нас на корабле и то 490% выдает". Убили и немца. Заходят к русскому, а он в углу сидит.',
    'Вышел мужик с тюрьмы после двойного убийства. Едет домой в поезде. Заходит в свое купе, а там - три грузина. Двое сидят за столом, едят, а третий на полке лежит.\nГрузины приглашают мужика за стол, тот с радостью соглашается. Сидят они, кушают, пьют, веселятся. Вот грузины выходят покурить, мужик остается в купе.\nВнезапно поезд дергается, грузин падает с верхней полки и бьется головой об стол. Мужик бросается к нему, проверяет пульс - мертв. Он в ужасе, хватается за голову. В голове мысли: кто ж поверит, что не я, только после отсидки. Он, не долго думая, открывает окно и грузина туда выталкивает. Садится за стол и, как ни в чем не бывало, продолжает есть.\nВозвращаются грузины.\n- Слюшай, а тут наш друг лежал. Гдэ он?\n- Да вот вы курить пошли - и он сразу за вами вышел\n- Как вышель? Ми же его в Тбилиси хоронить везем',
    'Однажды Платон сказал: \n– Человек есть животное о двух ногах, лишённое перьев.\nЭто услышал Диоген, ощипал петуха и показал Платону:\n– Вот платоновский человек\nПлатон ответил:\n– Ебать, ты душнила конченая, иди нахуй отсюда, нищеёб поганый\nИ разнёс Диогену хату',
    '1 сентября,новый учебный год.\nУчительница знакомится с новым для нее классом:\n- Андреев!\n- Я!\n- Большакова!\n- Я! ( и далее по алфавиту...)\nВдруг в конце списка учеников ее лицо вытягивается.\nДолго раздумывая,она наконец спрашивает:\n- Скажите,дети,а есть у нас в классе мальчик по фамилии Хуёв?\nУченики молчат, с задней парты встаёт смуглый мальчик:\n- Не Хуёв, а Хуев! Я болгарин!\nУчительница говорит:\n-Давай все-таки мы тебя будем по имени назвать?\n-Я не согласен. Мы болгары очень гордый народ! Мой отец - Хуев, Мой дед - Хуев... Я настаиваю, чтобы меня тоже звали Хуев.\nУчительница,откладывая журнал и пристально смотря на него:\n- Да? Ну,ну... Хорошо, садись, БОЛГАРИН ХУЕВ!!!',
    'Пpыгают как–то математик, физик и пpогpаммист с двадцатиметpовой вышки в\nмаленький бассейн.\nПpогpаммист: достал ноутбук, подумал, составил пpогpамму, пpыгнул, попал.\nФизик: подумал, вспомнил все законы, посчитал, пpыгнул, попал.\nМатематик: подумал, посчитал, ещё подумал, ещё посчитал, потом начал считать\nзаново, посчитал, пpыгнул… и ввеpх улетел — знаком ошибся.',
    'Еврейского мальчика лет шести приводят в школу. На собеседовании его спрашивают: \n— Сколько ты знаешь времен года? \n— Шесть. \n— А если подумать, мальчик? \n— Шесть. \nДиректор отказывает маме, и на улице та спрашивает сына: \n— Ну, Семочка, и шо это таки было?! \n— Мама, я и правда не знаю больше никаких «Времен года», кроме Вивальди, Гайдна, Пьяццола, Лусье, Чайковского и Глазунова! \n— Сёма, а как же Десятников?!',
    'У заики спрашивают:\n-Из-за чего ты стал заикаться?\n-В детстве мы с братом любили сосать молоко у козы. Потом коза постарела и перестала давать молоко. Ну решили от козы избавиться, пошли на рынок, стоим продаём. Подходит мужик, спрашивает:"Почём козёл?". Брат сразу умер, а я заикаться начал',
    'Умирающий старик лежит дома в постели и внезапно чувствует запах своего любимого шоколадного печенья. \n- Хоть последнюю печенюшку перед смертью, - решает он. \nПадает с кровати и ползет вниз по лестнице, цепляясь руками за ступеньки. Вползает в кухню и видит, что жена его отвернулась к печи и делает печенье. Из последних сил старик протягивает руку к тарелке с печеньем, как жена резко оборачивается и лупит его по руке лопаткой.\n- За что, - слабеющим голосом шепчет старик, - зачем ты так? \n- Не трогай, это для поминок!',
    'Собрал Царь у себя Джона Кейнса, Фридриха Хайека и Владимира Ленина и говорит им: \n— Мне принадлежат три острова с дикими папуасами. Они до сих пор ягодки собирают, листиками письки прикрывают, охотятся с копьями. Вы, смотрю, шибко умные, отправляю вас по одному на каждый остров, чтобы вы мне там организовали самую современную процветающую экономику. \nПроходит год. Царь посылает гонца узнать, что там творится на островах. Тот возвращается и рассказывает: \n— Хайек на своем острове сказал, что все теперь на охоте должны конкурировать между собой, раздал всем копья и стал ждать роста экономики. \n— И каков рост? \n— Вообще-то папуасы в первый же день друг друга перебили, остался один самый сильный папуас, который заколол и съел Хайека. \n— Печально, — ответил Царь. — А что там у Кейнса? \n— Кейнс всё совсем иначе организовал. Все копья отдал вождю и его приближенным. Вождь разрешил остальным папуасам пользоваться копьями на условии, чтобы те отдавали ему часть добычи. А чтобы вождь с приближенными не испытывали на себе кризисов, плата за пользование копьями постоянно повышалась, дескать растут затраты на содержание копий. \n— И что там получилось? \n— Все папуасы умерли с голоду, а вождь и его приближенные — от ожирения. \n— Эх, — махнул рукой Царь. — Ну если эти не справились, то Ленин-то точно всё загубил. Ладно, свободен. \n— Ваше Величество, вообще-то папуасы с третьего острова на танках уже окружили дворец и именем революции требуют, чтобы вы сдались. \n— Я? Чтобы сдался? — удивился Царь. — Никогда не сдамся этим скотам! \nА гонец достал из кармана маузер и говорит: \n— А куда ты денешься, падла!',
    'Вежливый ежик идет по лесу, а навстречу ему три богатыря.\n - Здравствуй, Илья Муромец! \n - Здравствуй, ежик!\n - Здравствуй, лошадь Ильи - Здравствуй, ежик!\n - Здравствуй, Добрыня Никитич!\n - Здравствуй, ежик!\n - Здравствуй, лошадь Добрыни Никитича! \n - Здравствуй, ежик! \n - Здравствуй, Алеша Попович! \n - Здравствуй, ежик! \n - Здравствуй, лошадь Алеши Поповича!\n - Здравствуй, ежик! ... Проезжают... Ёжик:\n - До свиданья, Илья Муромец! Илья Муромец: - До свиданья, ежик! \n - До свиданья, лошадь Ильи Муромца! \n - До свиданья, ежик! \n - До свиданья, Добрыня Никитич! \n- До свиданья, ежик! \n - До свиданья, лошадь Добрыни Никитича! \n- До свиданья, ежик! \n- До свиданья, Алеша Попович! \n- До свиданья, ежик!\n - До свиданья, лошадь Алеши Поповича! \n- До свиданья, ежик! \n\nИдет ежик дальше, видит, навстречу ему Али-Баба и 40 разбойников. Ёжик к ним: - Здравствуй, Али-Баба! ... \n-Иди ты нахуй, ёжик, нам некогда',
    'Решил один мужик завести домашнее животное - жена совсем достала. \nПриходит в зоомагазин и среди прочей живности видит попугая. БЕЗ ЛАПОК. \nМужик: \n- Надо же! попугай без лапок! \nПопугай: \n- Ну что поделаешь - таким родился... \nМужик: \n- А ты меня понимаешь, что ли? \nПопугай: \n- Да, я вообще очень умная и образованная птица - могу поддежать \n беседу на любую тему, знаком с науками и т.д. \nМужик: \n- Скажи, а как ты без лапок на жердочке сидишь? \nПопугай: \n- Ну... членом я хватаюсь, просто под перьями не видно. \nКороче, купил мужик попугая. \nВ доме сразу весело стало - попугай всех веселит, истории рассказывает, \nпоет... \nПриходит мужик как-то раз с работы домой, а попугай ему и говорит: \n- К твоей жене сосед приходил. \nМужик: \n- 8-(, и что? \nПопугай: \n- А жена твоя в одной ночнушке его встретила! \nМужик: \n- 8-((, а потом? \nПопугай: \n- Они начали целоваться. \nМужик: \n- Убью гада! А потом? \nПопугай: \n- Он стал на колени и полез ТУДА. \nМужик: \n- А потом? \nПопугай: \n- А потом у меня хуй встал и я с жердочки ебнулся...',
    'Шахматист гулял с феменисткой по парку и на них напали хулиганы, оценив ситуацию, он решил пожертвовать слоном.',
    'В дверь постучали 8 раз.\n"Осьминог", – подумал Штирлиц.',
    'Приходит мужик в парикмахерскую\n- Побрейте меня! \nИ кладёт 100 рублей, на то время это были большие деньги. \nВсе парикмахеры потянулись, как вдруг мужик кладёт ствол\n- А если вы меня порежете, я вас тут же застрелю..\nВсе попятились назад, как вдруг вышел один еврей\n- Я тебя побрею! \nБреет он мужика, бреет..закончил наконец. \nПолучил еврей свои 100 рублей, а мужик его и спрашивает\n- Слушай, а как ты не побоялся меня побрить? А вдруг ты бы меня порезал? \nА еврей и отвечает\n- У меня ведь бритва в руках, если бы я увидел что порезал тебя, таки сразу и зарезал!',
    'Решил муж сделать жене подарок на свадьбу: набил на члене её имя. Когда член стоял было видно имя полностью «Дарья». А когда член падал были видны только первая и последняя буквы «Д» и «я». \nТак вот, поехали они в свадебное путешествие в Грузию.\nЗаходит мужик в общественный туалет, видит рядом с ним стоит грузин, у которого тоже на члене татуировка и тоже только буквы «Д» и «я» видны.\nМужик спрашивает: «У вас тоже жену Дарья зовут?»\nГрузин отвечает: «Нэт, дорогой, пачиму ты так думаешь?»\nМужик объясняет ему ситуацию, говорит: «Да вот сделал жене подарок - тату с её именем, когда член стоит  видно имя полностью «Дарья», а когда член падет видны только первая и последняя буквы «Д» и «я». Прям как у вас!»\nГрузин поворачивается и говорит: «Нэт, дорогой, кагда мой член встает, то на нем появляется надпись “Добро пожаловать в Тбилис! Хорошего Вам дня!”',
    'Встретились Хой, Цой, Горшок и Летов, ну и вздумали бухнуть. Купили литруху, ну и типа говорят - мы же поэты - давайте кто сколько в стихах попросит, тому столько и нальём. \nГоршок встаёт: \n- Замученный дорогой, я выбился из сил, \nИ в доме лесника налить мне рюмку попросил! \nНалили ему рюмку. \nВстаёт Цой. \n- Группа крови - на рукаве! \nВы налейте мне рюмку! А лучше две! \nНалили ему две. \nХой встаёт: \n- Из колхозной молодёжи панковал один лишь я! \nНаливайте мне три рюмки, щас нажруся как свинья! \nНалили ему три. \nЛетов встаёт: \n- Гречневым чавканьем сильной личности \nСловесного поноса рьяной кавалерией \nТы забейся в сочные ямочки \nВ мягкие дырочки \nПулями оставленные \nВедь лучше стучать, чем перестукиваться \nАнонимная философия продавшихся заживо \nЗа колоссальный бесценок \nЗаживо погребённых \nВ летнюю резину изношенных прокламаций \nОбильно смоченных психоанализом \nЕдиным фронтом опочил всуе \nСнулой рыбкой растраченной потенции \nТы, ведущий, бля, на новые подвиги! \nМёрзлой веточкой опьянения \nКовырни, ковырни в мыльном вареве \nНевыносимо невинного прошлого \nВ мыльном вареве хлеба съеденного \nА небо всё точно такое же \nКак если бы ты не продался... \n- Егор, а наливать-то тебе сколько? \n- ААААА БЛЯ КТО ЗДЕСЬ?!',
    'Девочка жалуется своей маме. \n- Мама почему все в школе говорят, что у меня не лицо, а жопа?\nМама ей говорит:\n- Пойдем сходим на улицу и спросим у любого встречного и он тебе скажет что у тебя красивое лицо. Ну идут по улице и видят открытый люк, девочка туда заглянула, а там сантехник машет руками и орет:\n- НЕ СРАТЬ!!! НЕ СРАТЬ!!!',
    'Шел как-то Будда с учениками вдоль деревни. Вдруг несколько человек, собравшихся на улице, принялись оскорблять его. Он слушал молча, сохраняя спокойствие. И стало из-за этого спокойствия обидчикам как-то не по себе.\n“Тут что-то не так, – подумали они, – Мы оскорбляем человека, а он слушает нашу речь как музыку”.\nОдин из них обратился к Будде:\n– Ты что, не понимаешь, о чем мы говорим?\n– Если бы я не понимал, то не стал бы молчать, – ответил Будда. – Если бы вы пришли ко мне лет десять назад, я бы бросился на вас с кулаками. Тогда я еще не понимал. Теперь понимаю. И не могу наказывать себя из-за вашей глупости. Ваше дело оскорблять меня или нет, но мое право не принять ваши оскорбления. \nВы не можете мне их навязать. Я от них просто отказываюсь. \nОни меня недостойны. Можете забрать их себе. А теперь мои ученики вас отпиздят.',
    'Встретились как-то раз в поле колхозник и Сталин:\n— Скажите, товарищ, как урожай в этом году?\n— Картошки так много уродилось, что если поставить одну на другую, то можно до бога достать!\n— Так ведь бога нет, товарищ.\n— Верно, так картошки тоже.',
    'Мужик заходит в магазин сувениров. Видит маленькую бронзовую фигурку\nкошки. На ценнике написано: "кошка - 1000 рублей, её история - 10 000\nрублей."\n- Я могу купить кошку без истории? - спрашивает он продавца.\n- Конечно, - отвечает продавец, - Но за историей вы всё равно вернётесь.\nМужик покупает маленькую бронзовую кошку и идёт по городу. Вдруг он\nзамечает, что следом за ним сначала идёт одна кошка, потом другая, потом\nещё. Через некоторое время за ним уже идут тысячи кошек. Мужик в ужасе\nначинает убегать. Кошки не отстают. Тогда он размахивается и бросает\nмаленькую бронзовую фигурку кошки в реку. Все кошки бежавшие до этого за\nмужиком, тут же прыгают в воду вслед за статуэткой и тонут.\nМужик идет обратно, в тот же магазин сувениров.\n- Я же предупреждал вас, что вы вернётесь за историей, - говорит ему\nпродавец.\n- К черту историю! - отвечает мужик. - У вас есть маленькая бронзовая феменистка?',
    'Едет в трамвае пьяный. Стоял, стоял, да и говорит:\n— Точно, сейчас до сорока восьми досчитаю и блевану....\n— Ну пока он досчитает, мы выйти успеем. — подумали пассажиры.\nалкаш:\n— Шестью восемь — сорок восемь',
    'У моего 11-летнего сына был день рождения. И тут, он превращается в 12-летнего мальчика.',
    'Чебурашка варит супчик, Гена торчит у телевизора. Чебурашка не знает, сколько сыпать соли.\n— Гена, сколько соли сыпать в суп?\n— На глаз насыпь.\nС кухни раздается страшный вопль:\n— А-а-а-а! На хуй насыпь себе, ящерица зеленая!',
    'ЦРУ решили внедрить шпиона в Украину. Снарядили его, мове обучили и высадили в одном украинском селе. Идёт он, а навстречу ему дед.\n-Здрастуй, Дід.\n-Здрастуй, амэреканьски розвідник.\n-З чого ти взяв, що я Американський розвідник? Я ж гарнiй країнськи хлопэц\n-Який ти країнськи хлопэц, коли ти нiгер чумазий?',
    '(публиковать 2-го мая)\n\nМужик с болезнью пришел в больницу. Врач его осмотрел, покрасил ему одно\nяйцо зеленкой, что то написал на листочке и отправил к другому врачу.\nДругой врач прочитал листочек, покрасил второе яйцо йодом, что то\nнаписал на бумажке и отправил к предыдущему врачу. Мужик вышел в коридор\nи думает: какой диагноз они пишут. Развернул листочек там написано:\n- Христос воскрес Иван Петрович,\n- Воистину воскрес Николай Семенович',
    'На дуэли Штирлиц стрелял в слепую. К сожалению, она умерла',
    'На приём к врачу приходит негр.\nВрач:\n- На что жалуетесь?\nНегр:\n- Горло что-то болит.\nВрач:\n- Так, раздевайтесь.\nНегр разделся, стоит и ждет, что дальше будет.\nВрач:\n- Становитесь на четвереньки и ползите к окну. \nУдивлённый негр стал на четвереньки и подполз к окну.\nВрач посмотрел на него и говорит:\n- Так, теперь, пожалуйста, ползите вон в тот угол.\nНегр пополз.\nВ общем, проползал он все углы.\n- Доктор, зачем я это всё делаю? Что это, новый метод лечения?\n- Нет, просто я хочу купить стол чёрного цвета и всё думаю, куда его поставить.',
    'У маленького мальчика мама забеременела. В один прекрасный день \nприспичило ему спросить ее: \n- Мам, а почему у тебя живот такой большой? \n- Да это я, сына, 5 литров молока выпила. \n- Ой, а выпей еще пять. \nДелать бедной женщине нечего, надо пить. Hапряглась, выпила, на \nногах с трудом стоит. А сыночек подошел, щелкнул ее по пузу и \nговорит: \n- Hу что! Захлебнулся, пизденыш!?',
    'Ржевский красит лошадь в фиолетовый цвет.\nДенщик смотрит и говорит:\n— А чего это вы, Барин, лошадь красите?\n— А вот видишь в том окне дама сидит?\n— Да-с ваше благородие!\n— Вот я поеду на лошади, она посмотрит и спросит: "Поручик, а что это у вас лошадь фиолетовая?" А я ей в ответ: "Да что лошадь! Пойдемте лучше поебемся!» Так вот и познакомлюсь…\nВыезжает поручик на фиолетовой лошади, дама смотрит, лениво зевает и говорит:\n— Поручик, пойдемте поебемся!\n— Да что поебемся! Вы посмотрите какая у меня лошадь фиолетовая!',
    'Приезжает на каталке к директору завода инвалид на работу устраиваться. Директор смотрит на него - а у того ниже пояса все оттяпано и интересуется:\n- Вам чего?\n- На работу устраиваться. Слышал - инвалидов набираете по госпрограмме.\n- Ну я даже не знаю. Ну не таких же. А вы кем работали до этого?\n- Проводником в поезде двадцать лет отработал, пока между вагонами не провалился и не оттяпало мне все тут.\n- Ага, - директор с интересом осмотрел работника, - а руки у вас накачанные?\n- Еще как, я же от земли руками отталкиваюсь.\n- Тогда погодите, - директор набирает на телефоне номер,- алло.. алло? Михалыч? Зайди-ка сюда.\nЗаходит какой-то мужик в кабинет. Директор к нему подходит, говорит инвалиду:\n- Это Сергей Михалыч - главный энергетик. Михалыч, помнишь ты мне говорил, что тебе нужен сверхмощный полупроводник?',
    'Умирает старый богатый корсиканец. \nСобралась семья, ждут, кого же старик объявит наследником. По старой доброй корсиканской традиции всё должен унаследовать самый ленивый. Умирающий слабым голосом: \n- Доминик, сын мой, подойди ко мне. \nДоминик подходит. \n- Сынок, представь, что ты сидишь и видишь, как ветер гонит купюру в 500 франков. Что ты сделаешь?\n- Не сдвинусь с места, папа. Зачем мне лишний раз утомляться? \n- Золотые слова, мой мальчик. ступай. Паоло, подойди. \nподходит Паоло. \n- Паоло, обнажённая страстная красавица тянет к тебе руки. Что ты сделаешь? \n- Не пошевелюсь. К чему напрягаться лишний раз? \n- прекрасный ответ, сынок. Ступай. Антонио, подойди. \n- Сам подойди.',
    'Штирлиц смотрит в зеркало.\n"Штирлиц", - подумал Штирлиц',
    'Едет два гея в автобусе. Первый говорит второму: «Давай прям здесь...».\nВторой отвечает: «Да ты что! Как же прямо в автобусе? Народу куча\nПервый: «Да не ссы! Тут все вообще похрену. Вот смотри (кричит): сколько время?!!»\nВсе молчат, никто внимание не обращает\nПервый: «Ну вот видишь»\nВторой: «Ладно, давай!»\nДелают значит они своё дела. Спустя время приезжает автобус на конечку. Выходит водитель из за руля, видит дед сидит, за сердце схватился. Подбегает водитель  к деду, говорит: «Старик, чё случилось?»\nДед: «Да сердце прихватило, сынок»\nВодитель: «Так чё ж молчал то? Никого помочь почему не попросил?»\nДед отвечает: «Да спросил тут один «сколько время?», так его всю дорогу в жопу ебали',
    'Мужик идет по улице и видит большую очередь в какой-то домик. Интересно стало, подходит и спрашивает: \n- Что за очередь? \n- В комнату смеха. Кто ни выходит оттуда, все смеются, видишь? \nНу и он пристроился в очередь. Заходит в домик, а там его два негра хватают и ебут в жопу, а потом выкидывают на улицу. \nМужик пришел в себя, посмотрел на очередь и такой: \n- АХАХАХАХ!',
    'Заходит Сталин в свой кабинет и видит: его трубка пропала.\nОбыскал весь стол, но так и не нашел.\nЗвонит Берии:\n-Товарищ Берия, кто-то украл мою любимую трубку, прямо у меня из кабинета!\n-Не проблема, Товарищ Сталин,- сказал Берия- найдем вора.\nТут Сталин решил отодвинуть стул и видит: трубка валяется под столом.\nСнова звонит Берии:\n-Нашлась трубка!\n-Да? А у меня уже четверо признались.',
    'Ебется курсант с бабой. Тут приходит муж с работы.\nБаба говорит:\n- Давай прыгай с балкона.\nТот отвечает:\n- С ума сошла? Мы на 9 этаже.\n- Я волшебница, я тебя заколдовала. Дёрнешь хуй и станешь бабочкой и улетишь.\nНу времени мало, курсант дергает себя хуй и превращается в бабочку. Летит себе, летит. Но тут резко пугается, как же превратиться обратно? Приземляется на лавочку и дергает себя за хуй. Дёрнул - снова стал курсантом. Дёрнул опять - превратился в бабочку. Понравилось ему это, дёргает раз - бабочка, дёргает два - человек. Дёргает,и вдруг слышит голос:\n- Товарищ курсант, мало того что вы дрочите на лекции, так еще и превращаетесь то в бабочку, то в курсанта!',
    'На охоте два охотника подстрелили утку и никак не могут поделить. Вдруг один другому говорит:\n- Слушай, давай друг-другу дадим по яйцам, кто быстрее встанет, того и утка.\n- Давай!\nНу один как даст другому. Тот катался, катался по земле минут сорок, потом встал и говорит:\n- Ну ты даешь, я чуть не умер! Теперь давай я!\nА второй в ответ:\n- Да не надо, забирай утку.',
    'У одной девушки была маленькая грудь.\nПошла она к врачу. Доктор говорит:\n- Какая ваша любимая песня?\n- "Ветер с моря дул"\n- Прекрасно. Каждый день ровно в 19-00 раздевайтесь, оттягивайте минут 15-20\nгрудь и пойте любимую песню.\nДевушка последовала совету. Проходит неделя, другая - грудь заметно выросла.\nИ вот однажды она задержалась на работе. Выскакивает на улицу, хватает такси\nи мчится домой. Машина попадает в пробку. Девушка, видя, что не домой успевает,\nровно в 19-00 стягивает блузку, начинает петь и оттягивает грудь.\nНа нее пялится таксист:\n- А что, девушка, уже 19-00?\n- Да!\nТаксист снимает штаны и, оттягивая член - "Комбат-батяня, батяня-комбат..."',
    'У одной девочки не было ручек и ножек. В один день она подошла к маме и говорит:\n— Мама, я хочу сама пойти погулять. \nДелать нечего — мама собрала веточки и привязала их к девочке проволокой, чтобы получились ручки и ножки. Девочка обрадовалась, встала и сама пошла гулять. \nТут возвращается домой отец девочки, к нему подбегает мать и говорит:\n— Представляешь, сегодня наша дочка сама пошла гулять!\n— Это хуйня, ты бы видела, какого паука я щас в подъезде захуярил!',
    'Едет поп в такси. Водитель:\n- Ебанный в рот... Вот блять... Куда ты едешь, пидарас?\nПоп уверенно и спокойно:\n- Не могли бы вы более адекватно и гуманно изъясняться, молодой человек?!\n- Конечно могу, батюшка.\nЕдут они дальше. Раз, кочка, водитель: - Маааатерь божья.\nДва кочка, водитель: - Господь милостивый!!!\nЗаезжают они в яму, колесо вылетает, водитель: - Господи Иисусе Христе!!!.\nТут же на отпавшее колесо светит яркий луч солнца. Неизвестная сила тянет его обратно к машине, закручивает и выталкивает из ямы.\nВодитель смотрит на попа: - Это как так?\nПоп ему злостно: - Да хули ты вылупился-то блять, я и сам ахуел',
    'В публичный дом заходит пацан лет десяти и тащит за собой на веревке дохлую лягушку. Подходит к мадам и говорит:\n- Можно мне девушку?\nМадам:\n- Мальчик, сколько тебе лет? Иди-ка ты отсюда. Пацан достает из кармана кучу стодолларовых купюр и отсчитывает приличную сумму.\n- Хорошо, - говорит мадам. - Будет тебе девушка.\n- Только вы знаете - одно условие: у девушки должен быть крутой триппер.\n- Ты, мальчуган, совсем опух, - гневается мадам. Мои девушки все чистые и здоровые.\nМальчик отстегивает еще несколько купюр.\n- Ладно, поднимайся наверх и жди.\nМальчик идет наверх, срочно находится блядь с триппером; мальчик делает свое дело и спускается вниз, волоча все ту же лягушку. Мадам заинтригована.\n- Мальчик, ты не мог бы объяснить, пожалуйста, в чем дело?\n- Видите ли, тетенька. Сейчас я пойду домой, и моя няня будет приставать ко мне. От меня она получит триппер. Потом папа будет отвозить няню домой, и после секса в машине папа подхватит триппер от няни. А ночью он заразит им маму. Утром придет молочник - это мамин любовник, - и мама наградит его!\n- Ну и что??????!\n- Ха! Этот-то сука-молочник и есть та сволочь, что убила мою лягушку!',
    'Приходят в роддом негр, русский и хохол. Выходит акушер и говорит "извините, мы детей ваших перепутали". И выкатывает тележку с тремя детьми. Хохол хватает ребенка-негра и убегает. За ним все бегут, орут: "долбоеб, ты кого схватил, это не твой ведь", хохол в ответ: "це точно не москаль!".',
    'Старик с альцгеймером долго пытался понять, кто же насрал в его штаны.',
    'Самолет совершает посадку в аэропорту. Пилот давит на тормоз как только может. Наконец, в метре от конца полосы самолет останавливается. Пилот, вытирая пот со лба:\n\n— Фух, это самая короткая полоса на которую я садился\n\nВторой пилот смотрит в правое окно, затем в левое, а потом говорит:\n\n— Мало того, эти идиоты сделали ее в три километра шириной!',
    'Разговор двух наркоманов:\n- Прикинь, у меня вчера тройничок был! \n- Мжм? Жмж?\n-',
    'Американцы очень долго готовили супер-шпиона для отправки его в Россию. Его легенда была проработана просто блестяще. Он в совершенстве овладел диалектом того региона, где должен был работать. И вот, темной ночью, его сбросили с самолета в густом лесу. Шпион приземлился, закопал парашют и начал пробираться к ближайшей деревне. Рано утром он в ушанке, драном ватнике, бутылкой самогона в кармане, с трехдневной щетиной, попыхивая "Беломором" подошел к деревне и постучался в крайнюю избу. На стук вышла старая бабка. \n- Мать, дай пожалуйста воды напиться. \n- А ты, сынок, чай не шпион-то будешь? \n- А с чего это ты, мать, так решила? \n- Да мы у себя, на Рязанщине, отродясь негров не видали...',
    'Слепой заходит в магазин, берёт собаку поводыря и начинает раскручивать её над головой.\n- Что вы делаете?\n- Да так, осматриваюсь)',
    'Идет Ленин, видит - девочка плачет. Спрашивает:\n- Почему ты плачешь, девочка?\n- Мне мама копеечку дала на булочку, а я потеряла\nСжалился Ленин над девочкой и дал ей копеечку. А девочка все равно продолжает плакать.\n- Почему ты все ещё плачешь? - удивился Ленин\n- А если бы я не потеряла копеечку, у меня бы сейчас было бы две копеечки.\nНе понравилась Ленину буржуазная сущность девочки. И забрал он у нее копеечку... А заодно и шапочку, кофточку и туфельки',
    'Заходит мужчина в детдом. Просит взять 10 детей. У него спрашиваю воспитатели. \n- А собственно зачем тебе 10 детей?\n- Какая вам разница? Дайте мне 10 детей\nДают ему 10 детей и он идёт с ними домой.\nПриходит домой, расставляет их по росту.\nУбивает самого большого с пистолета. Потом второго, потом третьего, затем четвёртого, затем пятого, после этого шестого, спустя пару секунд седьмого, потом восьмого и сразу же девятого. \nПотом смотрит на последнего, десятого. Раздевает и начинает ебать. \nПотом на звук выстрелов приехала полиция. Его арестовали и спрашивают: а зачем вы брали 10 детей что бы ебать одного?\nА он отвечает: а вы представьте как у него очко сжалось?',
    'Осёл нахально спрашивает льва: \n- А почему это ты - Царь зверей, а не я? \n- А я дольше тебя в сексе могу продержаться! \n- Не фа-а-а-акт! \n- Проверим? \n- А давай проверим! \nЛев: \n- Чур, я первый! Засекай время! \nЗабирается на осла и... 21 минута. Всё, кончил.\nОчередь осла, и... понеслось!.. \nЛев с тревогой смотрит на часы: уже прошло 15 минут, а осёл и не думает выдыхаться. \nЛев по сотовому набирает номер львицы: \n- Дорогая, что ты делаешь, чтобы я быстрее кончил? \n- Ты опять с ослом ебёшься, пидорас?',
    'Отправили на работы за территорию в военной части 4х бойцов и прапора. После окончания работ построил прапор бойцов и считает : \n- Раз, два , три , четыре. Нас было пятеро. Где пятый ? Ищем пятого. Разойдись ! \nПроходит десять минут, опять построение и та же история. Та же команда: \n- Разойдись, ищем пятого. \nПосле третьего построения один боец говорит : \n- Товарищ прапорщик, давайте я посчитаю, а вы становитесь в строй. Считает : \n- Раз, два , три, четыре - и, показывая на себя - пять. \nПрапор подходит к этому бойцу, отвешивает ему подзатыльник и говорит : \n- Так это мы тебя, долбоёба, пол часа искали.',
    'Стоят на остановке парень в спортивках и бабушка.\n–Сынок, куда двойка едет?\n–Тебе в бороду, бабуль.\nНу и вырубил её нахуй.',
    'Вечером младший сын заявляет:,,не хочу быть татарином,хочу быть русским".отец в истерике:,,как так?!",а мать отвечает:,,хочет быть русским,пусть будет"\nПриходит время ужина,мать накрывает на стол и ставит бешбармак.Сын только рукой тянется,мать ему по руке хуяк,и говорит:,,куда рукой тянешься,русские вилкой едят",сын только за вилкой отошёл,съели.\nНа следующий день мать приготовила плов,сын только рукой тянется,а мать ему по руке хуяк и говорит:,,куда рукой тянешься,русские плов ложкой едят",сын только за ложкой отошёл,съели.\nСын говорит:,,блять 2 дня русский, а татары уже заебали".',
    'Если к любой странной фразе добавить "подумал Штирлиц", то будет смешнее- подумал Штирлиц',
    'Захожу в магазин возле дома, - а там дед луковицу покупает. Одну луковицу, понимаете? Одну! \nНу я в соседнюю очередь втиснулся с килограммом лука в пакете, деда уже на выходе догнал и сую тому пакет в руки: "На дед, ЕШЬ!". Ну тот начал что-то мямлить про "да бабке одной на котлеты не хватило", "да не надо, сынок", "я не хочу, не буду", но я-то ведь ПРАВДУ знаю! Заставил-таки! \nВот сидим мы с дедом на ступеньках магазина - он третью луковицу дожёвывает, сам плачет. Я курю и плачу. Молчим оба, всё понимаем. До чего страну-то довели? \n// // // \nВ парк развлечений с детьми пошёл, - а там дед! Ну тот самый! С луковицей! Билет покупает на аттракцион. Один билет, понимаете?! \nНу я быстренько абонемент ему купил на весь день, деда за руку хватаю: "Пошли, дед!". Тот лепетать начал, что мол, "внучке покататься", "сердце слабое", "люди, помогите!". Но я-то ПРАВДУ знаю, - закалка старая, неудобно ему просто такое внимание. \nУже на посадке вырваться пытался, но мы с билетёром его ремнями скрутили и усадили на место. Запустили. \nСтоим вместе с билетёром - курим. \nКогда через пару часов крики стихли - прослезились, да что же за страна-то у нас ТАКАЯ!? \n// // // \nИдём с мужиками по улице, снег, ветер, мороз. А тут дед снег убирает во дворе частного дома - лопатой. И кучу нагрёб. Одну кучу. Понимаете?! Одну жалкую кучку! \nНу мы с ребятами посовещались, КАМАЗ наняли, трактор с ковшом и ему ещё кубов шесть снега во двор закинули. \nДед сидит плачет - на снег смотрит. \nМы плачем, - да что же за страна-то у нас такая?! \n// // // \nУгадайте кого в шиномонтажке встретил? Ага! Деда! Он меня тоже узнал - убежать пытался, да куда же он убежит - колесо-то проколото! Понимаете?! ОДНО КОЛЕСО! Довели - сил нет! \nНу я деду шилом быстренько три оставшихся колеса проткнул, а когда тот расплакался - ещё и запаску в нескольких местах. \nСтоим с шиномонтажником - курим, дед в машине заперся, выходить не хочет пока не уйду. \nДа что же за страна-то у нас ТАКАЯ?! \n// // // \nНогу подвернул. зашёл в травмотологию, а там дед знакомый, - помните его? Точно! С луковицей! А теперь и пальцем сломанным, с рентгена выходит! Одним пальцем! ОДНИМ, понимаете?! Да что же это такое-то?! \nДед побледнел, мямлит что "рентген не его", "да он просто спросить", "пощады". Но меня-то не обманешь! С санитаром переглянулись и без слов поняли что нужно делать! \nТеперь у него три пальца на левой и два на правой руке сломаны. Ну и нога до кучи. \nПока деду гипс накладывали плакали все вместе, да что же за страна-то у нас ТАКАЯ!? \n// // // \nЯ же того деда лукового снова встретил в больнице через пару недель. Он на каталке с ногой был - в лифт въехать пытался, да до кнопки этажа достать не мог. Ну я помог - коляску вкатил, поинтересовался здоровьем, всё ли в порядке у него? Дед смотрел подозрительно, но разговаривал. И тут выяснилось, что ему на один этаж только подняться! Всего на один! Понимаете?! Один!!! \nНу что уж тут поделать?! Я его на восемнадцатый отправил, а сам на своём вышел. \nУже потом курил, стоял и думал, а как же он один с восемнадцатого спускаться на коляске будет? До чего страну-то довели, понимаете?! \n// // // \nСудьба с дедом нас в стоматологии свела почти через год! Я на осмотр зашёл к доктору, а тот зуб выдёргивать. Ну вы понимаете? Один зуб! Всего один! Ну вот до чего страну довели!? \nВрач знакомый, я ему денег дал, а сам деда держу: "Я за восемь зубов заплатил, дед. Гуляй, рванина!" \nДед вырывается, кричит что-то типа "у меня только четыре!", "а наркоз?!", "хоть один оставьте!". Но мы-то с врачом всё понимаем. Эх, мало их осталось таких - старой закалки. Гвозди бы из таких делать! \nУже потом стояли с доктором и курили. Без слов всё ясно было. Распрощались так же молча и в слезах простым кивком. Что же страна-то у нас такая?!',
    'Экзамен по анатомии.\nСтуденты опускают по очереди руку в анатомический мешок и на ощупь\nопределяют органы…\nОдна студентка долго щупает, краснеет и выдает растерянно:\n— Сосиска…\nДва старых профессора переглядываются и говорят:\n— Вы не спешите, хорошо подумайте…\n— Ну сосиска, я Вам говорю…\nДевчонка вынимает руку из мешка, а там действительно сосиска!\nОдин профессор другому:\n— Послушайте, Станислав, а мы вчера хуев наелись.',
    'Родительское собрание в школе. Учитель говорит отцу:\n-Знаете, ваш Вовочка ужасно себя ведёт! Хулиганит, матом ругается, девочкам проходу не даёт, вчера даже пьяный пришёл!\n-Ну Вовка, убью нахуй!\nНа следующем собрании:\n-Что вы такое сказали сыну, что он уже 2 недели в школу не ходит?\n-Так я его убил нахуй!',
    'Грузин тонет. Видит, по берегу русский идёт. А грузин забыл, как по-русски будет "тону". Ну и кричит русскому:\n— Э, сущии, паслэдни рас купаюсь. Абыдна, да?',
    'Заходит мужик в еврейский ресторан, а там плакат:"Ешьте, пейте бесплатно. За вас заплатят правнуки! "\nМужик наелся, напился.\nОфициант приносит счёт, . \n-Но ведь за меня заплатят правнуки!? \n-Да, но это счет вашего прадедушки.',
    'Встретились Хой, Горшок и Летов, ну и вздумали\nбухнуть. Купили литруху, ну и типа говорят - мы\nже поэты - давайте кто сколько в стихах\nпопросит, тому столько и нальём.\nХой встаёт:\n- Рыбка плавает по дну, выпью рюмочку одну.\nНалили. Горшок встал:\n- Рыбка мёртвая на дне, выпью рюмочки я две.\nЛетов встаёт, весь натужился, набух, покраснел,\nглаза выпучил. Вдруг как заорёт:\n- АААА БЛЯЯЯДЬ НАХУУУЙ\nСхватил пузырь и убежал.',
    'Сидит наркоман под дождëм, ест суп и плачет. К нему подходит второй:\n —Ты чего плачешь? \n —Да я уже час суп ем, а он всë никак не заканчивается!',
    'Чувак работал проводником в поезде. Однажды, в купе сидит \nблондинка. \nЧувак: — Ваш билетик! \nБлондинка: — Ой! Он выпал в окно! \nЧувак выкидывает блондинку из поезда на ходу и она разбивается. \nЧувака приговаривают к электрическому стулу. \nПоследнее желание: Хочу скушать креветку! Скушал. \nВключают рубильник — нифига! Второй раз включают — жив! \nПо закону положено помиловать. Чувака отпускают. \nОн снова устраивается работать в поезд проводником. \nВ купе сидит мальчик. \nЧувак: — Ваш билетик! \nМальчик: — Ой! А я его проглотил! \nЧувак выкидывает мальчика на ходу — тот разбивается. Суд. \nПриговор к электростулу. Последнее желание скушать креветку. \nТщательно проверяют, чтобы он не обматывал руки усиками от \nкреветки, включают рубильник — нифига. Еще раз включают — опять \nнифига. Отпускают. Чувак снова устраивается работать в поезд \nпроводником. На этот раз он выкидывает священника, который \nзабыл купить билет. Суд. Приговор к электростулу. Скушанная креветка. Чувака осматривают, стул проверяют еще на двух \nзаключенных — все работает. Врубают раз — чувак жив. Еще раз — \nснова жив. Отпуская, спрашивают: \n— Ну как тебе это удается — что за сила в этих креветках? \nЧувак: \n— Креветки ни причём, просто я плохой проводник.- после этих слов поезде где работал чувак, начался сущий кошмар...\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\nА чувака расстреляли.',
    'Умер человек. Его пес рядом лег и тоже умер. И вот душа человека стоит перед вратами с надписью «Рай» и рядом душа собаки. На вратах надпись: «с собаками вход воспрещен!». Не вошел человек в эти врата, прошел мимо.\nИдут они по дороге, вторые врата, на которых ничего не написано, только рядом старец сидит.\n\n— Простите, уважаемый…\n— Петр я.\n— А что за этими воротами?\n— Рай.\n— А с собакой можно?\n— Конечно!\n— А там, раньше, что за врата?\n— В Ад. До Рая доходят только те, кто не бросают друзей.\n— Ты ебанутый что ли? А если человек без собаки умер? А если у него и не было собаки? Всё, в ад? Пиздец, ты как вообще смотрителем рая стал?',
    'Раз в тысячу лет Бог спускается на землю и приглашает к себе трех правителей ведущих стран. И он отвечает на один их вопрос. И вот перед ним Тэтчер, Рейган и Горбачев. Рейган спрашивает: «Через сколько лет в США будет такая же жизнь, как у вас в раю?» Бог вытащил записную книжку, посмотрел и ответил: «Через 27 лет». Рейган расстроился: «Я не доживу...» Вторая Тэтчер: «А когда мы заживем, как в раю?» Бог сказал: «Через 35 лет». Тэтчер пустила слезу: «Жалко, я этого не увижу...» Третьим был Горбачев: «Ну а в России когда рай будет? » Бог заплакал: «Я не доживу...»',
    'Марья Ивановна спрашивает ребят:\n- Дети, кто знает, сколько арбузов можно унести за раз?\n- Я, я знаю - хочет ответить Вовочка.\nМарья Ивановна думает: "Сейчас этот пидорас опять урок сорвёт", и спрашивает вместо него Машу:\n- Может Машенька знает?\n- Я знаю! Два: один под правую ручку, второй под левую, Марванна - отвечает Машенька.\n- Ну Марьванна, я знаю, я - продолжает Вовочка.\nМарья Ивановна спрашивает вместо него Петю:\n- А ты Петя, согласен с Машенькой?\n- Нет Марьванна, не согласен, можно нести сразу три арбуза!\n- И как же, Петенька?\n- Три: один под правую ручку, другой под левую, третий на хуй насадить!\n- Марьванна, дайте ответить - не унимается Вовочка.\n"Похуй, хуже уже не будет" - думает Марья Ивановна и говорит:\n- Ну давай, отвечай Вовочка, хуже Пети ты уже не скажешь...\n- Пять: один под правую ручку, другой под левую, а на хуй насадить Петю с его тремя арбузами!',
    'Приходит мужик в магазин головных уборов и говорит:\n— Мне нужна лучшая шляпа, что у вас есть.\nПродавец протягивает мужику красивую шляпу, а мужик в ответ:\n— Но она ведь будет мне велика!\n— Не волнуйтесь, эта шляпа вам как раз - она подстроиться под размер вашей головы. \nИ действительно, мужик надел шляпу, а та ему как раз, так еще и фасон нужный приняла. Ну мужик довольный покупает шляпу. Приходит он домой и нарадоваться не может, вертит шляпу, и вдруг надевает ее на руку, и шляпа тут же стягивается в красивую перчатку, надел на ногу - превратилась в носок. И тут у мужика возникла грязная идейка... Вот он уже надевает ее на член...\nи вы не поверите товарищ следователь, шляпа превращается в двенадцатилетнего мальчика!',
    'Доктор, у моего партнера СПИД нашли, и я боюсь, что и сам болен.\n\n— Ну, сдайте анализы, посмотрим.\n\nПриходит гей через пару дней за анализами, а врач ему:\n\n– Вынужден вас огорчить, подозрения подтвердились, у вас СПИД.\nГей расстроился, а врач ему:\n\n– Не переживайте так. У вас только начальная стадия СПИДа, есть одно средство проверенное народное, 100% на начальной стадии помогает. Купите 2 литра молока, нарежьте мелко туда соленых огурцов, сыпете квашеной капусты, крошите селедки. Нужно, чтобы лекарство отстоялось двое суток, все залпом потом выпиваете.\n— Спасибо вам, доктор, огромное, вы меня просто спасли.\n\nУходит. Тут медсестра, которая сидела и все слышала спрашивает:\n\n— А для чего вы ему все это наговорили? У него же анализы нормальные.\n\n— А ничего: Пусть на толчке посидит и подумает, зачем мужику жопа нужна!',
    'Приехали как-то девочка с мамой в Москву поступать в универ.\n\nПриходят в Бауманку, а там все грязное, все обблёвано, везде студенты пьяные. Мать и говорит:\n-Нет, дочь, сюда ты поступать не будешь.\n\nПошли в МГУ. Там все чисто, красиво, пафосно, ходят любуются. Заходят в женский туалет, а там парень пьяный в блевотине на полу лежит. И мать в шоке говорит:\n-Нет, сюда ты тоже не пойдёшь учиться.\nТут с пола вскакивает студент и вскрикивает\n-Правильно! Давайте к нам в Бауманку!',
    'На рынке стоит глухой продавец инжира. Его спрашивают:\n–Почем инжир?\n–300 рублей.\n–Так вы же глухой!\n–Так хули вы у меня ещё спросить-то можете?',
    'Летят два математика в самолете. \nОдин другому говорит: \n— В последнее время я очень боюсь летать самолетом, так как рассчитал, что вероятность того, что на борту бомба, выше, чем попадание метеорита. \nВторой математик отвечает: \n— Да, я тоже проделал эти же вычисления и пришел к такому же результату. Но я пошел дальше. Ведь вероятность того, что в самолете окажутся сразу две бомбы, ничтожно мала! Поэтому я теперь одну всегда вожу с собой.',
    'МОЛОДОЙ ЮНГА ПОПАЛ НА КОРАБЛЬ. КАПИТАН ЕГО В КУРС ДЕЛА ВВОДИТ, ОБЯЗАННОСТИ ОБЪЯСНЯЕТ, ПОРЯДКИ МЕСТНЫЕ.\n- ЖЕНЩИН НА КОРАБЛЕ НЕТ, ДРОЧИ, НО ЕСЛИ СОВСЕМ ПРИПРЕТ, У НАС ЕСТЬ КОК-ПИДОРАС.\n- ДА НЕТ, Я НЕ ТАКОЙ. МЕНЯ ДЕВУШКА ЖДЕТ!\n- НУ СМОТРИ..\nЧЕРЕЗ ПОЛГОДА НА КОРАБЛЕ, ЮНГА ПОДХОДИТ К КАПИТАНУ:\n- ПОМНИТЕ, НАСЧЕТ КОКА ВЫ ГОВОРИЛИ. НО Я Б ХОТЕЛ, ЧТО БЫ ЭТО БЫЛО ТАЙНОЙ, И БОЛЬШЕ НИКТО НЕ УЗНАЛ.\n- НЕ ПОЛУЧИТСЯ. УЗНАЮТ МИНИМУМ ДВА ЧЕЛОВЕКА, КТО БУДУТ ЕГО ДЕРЖАТЬ, ПОКА ТЫ ЕГО ЕБЕШЬ\n- НО ВЫ ЖЕ СКАЗАЛИ, ЧТО ОН ПИДОРАС!\n- КОНЕЧНО ПИДОРАС. ГОТОВИТ ХУЕВО, ПЕРЕСАЛИВАЕТ ПОСТОЯННО',
    'Идет мужик по лесу, вдруг видит - избушка на курьих ножках, а на крыше вывеска: "Изба-гадальня". Ну мужик думает - дай зайду-погадаю. Заходит, а в избушке темно, хоть глаз выколи, вдруг из темноты голос:\n — Че бля пришел?\n — Да вот, это, погадать хочу! \n — Ну возьми справа от тебя ковш, зачерпни из бочки впереди и выпей. Мужик отхлебнул и кричит:\n — Бля, да это же говно! \nГолос:\n — Угадал, дальше гадать будем?',
    'Купил мужик шляпу с широкими полями; пришел домой и охуел - поля-то футбольные.',
    'В первом классе школы дети учатся писaть.\nУчительница:\n— Танечка! Что ты вчера делала после школы?\nТанечка:\n— Играла в песочнице.\n— Умница, Танечка! Иди к доске и напиши ПЕСОК\n— Петечка! А ты что вчера делал?\nПетечка:\n— А я вчера играл с Танечкой. У меня был совочек.\n— Молодец, Петечка! Иди напиши на доске СОВОК\n— Муталиб Саид ибн Ахмед Бей! А ты что вчера делал?\n— Я пытался поиграть с ними, но они назвали меня чучмеком и забросали камнями!\nУчительница:\n— Безобразие! Это же вопиющая дискриминация и унижение\nчеловеческого достоинства! Муталиб Саид ибн Ахмед Бей!\nИди к доске и напиши 100 раз, чтоб видели все:\n ВОПИЮЩАЯ ДИСКРИМИНАЦИЯ И УНИЖЕНИЕ ЧЕЛОВЕЧЕСКОГО ДОСТОИНСТВА.',
    '70-летная старушка услышала по радио, что алкоголь сокращает жизнь в 2 раза, напилась и умерла в 35',
    'Никогда не спрашивай у женщины её возраст, у мужчины его зарплату и хохла.',
    'Ебёт Лев Толстой Горького:\n— Кто ж тебя Горьким-то назвал, сладенький ты мой?\n— АААААААААААААА, БЛЯДЬ!!! ГОВОРЯЩИЙ ЛЕВ!!!!!!',
    'Студент отвечает на экзамене, фейлится по полной, думает вот-вот на пересдачу отправят, и говорит профессору:\n- Профессор, а давайте я за тройку сейчас одной рукой эту парту сломаю?\n- Но это невозможно... ладно, давайте.\nСтудент размахивается и ударяет по парте, она трескается пополам. Профессор:\n- Хмм, впечатляет. Ладно, тройку поставлю...\n- Подождите, а давайте я за четвёрку головой стену пробью?\n- Ну... давайте.\nСтудент со всей дури бьёт головой о стену, и пробивает её насквозь. Профессор:\n- Ну так и быть, ставлю четыре...\n- Подождите, а давайте я за пятёрку на вас одеколоном нассу?\n- Ну... давайте.\nСтудент расстёгивает ширинку и обоссыввает профессора. Тот принюхивается:\n- Да это же обычная моча!\n- Ну ладно, ладно, ставьте четыре.',
    '— Ты думаешь ты можешь вот так вот просто вырывать цитаты из контекста?\n— Да (Евангелие от Матфея, 6 глава, 27 стих, 1 слово)',
    'Штирлиц схватил записку Мюллера. Мюллер взвыл от боли.',
    'Умерли грузин, хохол и еврей. И, попав на приём к богу, все втроём взмолились: \n— Отпусти нас обратно на землю, мало мы пожили ещё, молодые совсем. \n— Хорошо,—ответил им бог,—но только до первого соблазна. \nИ вот очутились они на земле, в каком-то доме. Видят: стол накрыт, жратвы на нем видимо-невидимо. Только сел хохол за стол — тут же пропал. \nА грузин и еврей вышли из дома и пошли дальше. Вдруг видят на дороге 100 долларов лежат. Еврей наклонился за деньгами и пропали оба.',
    'Едут две женщины в поезде. \nОдна: \n— Не жизнь, а тоска. \n— Так возьми любовника, да бери с него 500 баксов в месяц! \n— Где ж такого взять? \n— Ну двоих заведи по 250. \n— Да таких взять тоже проблематично! \n— Тогда троих по 167! \n— Всё равно не выйдет. \n— Пятерых по 100? \n— Глупо. \n— Восьмерых по 62,5 попробуй! \n— Не! \n— Ну а если 13 по 38,5? \n— Да я уже прикидывала... \n— Двадцать один по 23,8?.. \nТут с верхней полки с грохотом падает Фибонначи и орет: \n— БЛЯТЬ, ДАМОЧКИ, КАК ЖЕ ЭТО ОХУЕННО! НЕ ОСТАНАВЛИВАЙТЕСЬ, МИЛЫЕ МОИ!!!',
    'Парень покупает себе дорогущий хромированный Ламборджини. Продавец между делом говорит:\n- Вы знаете, чтобы хром не ржавел, каждый раз перед дождем советую протирать хромированные части машины вазелином.\nПарень благодарит его, покупает баночку с вазелином и едет к своей девушке похвастаться автомобилем. Конечно, не обходится без её родителей и в особенности отца, который с неистовым рвением предлагает обмыть замечательную покупку. Семья садится за стол. Отец сообщает парню:\n- Знаете, у нас в семье такая традиция - кто первый заговорит после еды, тот и моет посуду, имейте ввиду.\nПосле великолепного ужина наступает гнетущая тишина. Проходит минута, две, полчаса... наконец парень не выдерживает и начинает лапать девушку на глазах у родителей. Те молчат. Парень срывает с неё одежду и, не услышав ни звука, бросает её на стол и ожесточенно трахает. Совершив на глазах родителей половой акт, он смотрит вокруг, но все так и молчат. \nПарень в отчаянии подходит к маме подруги, снимает с неё юбку и долбит её в зад. Тишина. Парень кладет мать подруги на стол и начинает трахать обоих по очереди во все дырки, но все молчат.\nВдруг раздается раскат грома, и у парня в голове щелкает: надо срочно протереть хромированные части Ламборджини! Он бежит к своей куртке и вытаскивает баночку вазелина. Отец подруги на это улыбается и говорит:\n- Знаете, а помою-ка я посуду.',
    'Али из высокогорного аварского села удалось дойти до вопроса стоимостью 500 000.\n— Вы играли замечательно, — сказал ведущий, — и сейчас на кону миллион! Вы заберете деньги или будете играть дальше?\n— Конечно, — овтетил Али, — я играю дальше!\nВнимание, вопрос:\nКакая из этих птиц не вьет гнезда?\nа) Воробей\nб) Дрозд\nс) Сорока\nd) Кукушка\n— Я хочу использовать последнюю подсказку и позвонить другу Казбеку.\nАли дозвонился другу и повторил ему вопрос.\n— Черт возьми, Али Это же просто!\nКукушка!\n— Ты уверен?\n— Конечно, на сто процентов!\nАли повесил трубку и сказал ведущему:\n— Мой ответ – кукушка.\n— Это окончательный ответ?\n— Да.\nНаступила долгая томительная пауза, и ведущий закричал:\n— Кукушка – это правильный ответ! Али поздравляю, вы выиграли миллион!\nНа следующий день Али пригласил Казбека отметить с ним выигрыш.\n— Казбек! Откуда ты вообще мог знать, что именно кукушка не строит гнезд?\n— Да потому что она живет в часах, долбоеб!',
    'Гуляет девочка с собакой, а мимо идет женщина.\nЖенщина спрашивает: "Девочка, а как тебя зовут?"\n-Роза\n-Какое красивое имя, а почему тебя так назвали?\n-Когда я родилась, мой папа подарил моей маме розовое масло, а капелька этого масла упала мне на лоб.\n-Какая красивая история, а как зовут твоего песика?\n-Хряк\n-А почему его так назвали?\n-Он свиней ебет',
    'Арестовали мужика за изготовление самогона, судят. Судья спрашивает:\n- У вас был найден самогонный аппарат в рабочем состоянии.\n- Да.\n- Значит, вы гнали самогон?\n- Нет.\n- Ну как же, у вас ведь был найден самогонный аппарат в рабочем состоянии. Был?\n- Был.\n- Значит, вы гнали самогон.\n- Нет.\n- Да как так, по документам вот найден самогонный аппарат в рабочем состоянии, улика. Найден?\n- Найден.\n- И вы на нем гнали самогон.\n- Нет.\nСудье это надоело и он говорит:\n- Хватит с меня, я приговариваю вас к 8 годам лишения свободы за незаконное производство и хранение самогона!\nТут мужик ему говорит:\n- Вы меня ещё и за изнасилование посадите.\n- Вы что, кого-то насиловали?\n-Нет, но самогонный аппарат-то у меня есть.',
    'В грузинской школе урок русского языка. Учитель спрашивает: \n– Дети, что такое, по-вашему, досада? Давай, Гоги.\n– По-моему, досада - это когда идёшь по улице и видишь перед собой блондинку с шикарный форма, но тут подходит автобус, она в него садится, а ты не успеваешь. Вот это досада!\n– Очень хорошо, Гоги. Садись, пять. Кто ещё как думает? Давай, Вахданг.\n– Я думаю, что досада - это когда ты идёшь по улице и видишь перед собой мужчину с такой большой шикарный попа, но тут подходит автобус, мужчина в него садится, а ты не успеваешь. Вот это - досада!\n– Тоже неплохо. Садись Вахданг, четыре. Кто не согласен? Давай, Гиви.\n.\n.\n.\n– Я думаю, что досада - это когда ты идёшь по улице, сзади тебя идёт Вахданг, а автобуса всё нет и нет...',
    '18 век. Англия. Поместье богатой вдовы Госпожи Браун. \n\nРаздался стук в дверь. Открыла прислуга. На пороге стоит богато одетая женщина средних лет. \n- Госпожа, вы к кто и к кому, -спрашивает прислуга. \n- Я миссис Хулия, -ответила женщина, - пришла в гости к своей подруге детства, Госпоже Браун. \n- Проходите, присаживайтесь, сейчас я о вас сообщу. \nПрислуга направилась в комнату Госпожи Браун и постучалась в дверь. \n- Войдите, -донеслось с обратной стороны. \nПрислуга благопочтенно изрекла:\n- Госпожа, Хулия пришла. \n- А я чё, ебу, хули ты пришла?',
    '"Титаник"  потопили евреи: Лоцман, Боцман, Штурман и Айсберг',
    'Звонит по телефону один грузин своему брату и слышит: \n- Гиви, у нас вчера произошло несчастье... \nБрат, вчера наш отец полез на дерево собирать яблоки... \n- Ну?.. \n- Гиви, случилось страшное... \n- Он упал с этой чёртовой яблони!.. В общем, Гиви, мы потеряли отца... \nДлительное молчание на обоих концах провода. Затем Гиви, сообразив: \n- Слушай, Вахтанг, а вы под деревом смотрели???',
    'Заблудилась бабулька, хочет у кого-нибудь дорогу спросить, а навстречу ей панк:\n— Скажи, сынок, как пройти на улицу Горького?\n— Во-первых, не сынок, а чувак. Во-вторых, не пройти, а бросить кости. И в-третьих, не улица Горького, а Пешков-Стрит.\n— Спасибо, сынок!\nИдёт она дальше, видит милиционера:\n— Эй, чувак, как бросить кости на Пешков-Стрит?\nМент, ох*евающе:\n— Хиппуешь, плесень?',
    '- пошли ко мне, у меня чайный гриб есть\n- нет\n- я настаиваю',
    'Заходит в бар мужик и спрашивает бармена:\n— Багмен, пгошу, стопочку бгенди.\nБармен недовольно наливает ему бренди. Мужик выпивает и уходит. Следом за ним заходит второй мужик и спрашивает бармена:\n— Мне, пожаууйста, текиуу.\nБармен со злостью наливает. Мужик выпивает и уходит. \nДальше заходит третий мужик:\n— Один штаканчик фнапша.\nБармен тяжело вздыхает и наливает шнапс. Мужик выпивает и уходит.\nПоследним в бар заходит математик. Он в приподнятом настроении и, решив выебнуться, говорит:\n— Мне π пива!\nБармен как ебанёт ему по голове кружкой:\n— Только заик мне тут, блять, не хватало!',
    'Косово. Ночь. Деревня. Бородатые вооруженные люди колотят в дверь одной из хат.\n- Ёбана мать, выходи!\n- Выходи, Ёбана мать!\nДверь открывает маленькая сухонькая старушка.\n- Ты Ёбана мать?\n- Дааа...\n- Мужайся мать! Ёбана убили.',
    'Жена просит мужа:\n-слушай, сыну уже 15, поговори с ним о половом созревании, только помягче как-нибудь на примере птичек или\nсобачек.\nМуж соглашается.\nВечером заходит к сыну, говорит:\n-сына, помнишь мы на прошлой неделе в бордель ходили?\n-ну помню\n-вот птички и собачки этим тоже занимаются!\n-детей ебут?\n-нет, я не это хотел сказать, извини.',
    'Сидят пятеро ковбоев в баре, пьют виски, курят сигары, тут открывается дверь, входит весь побитый мужик и говорит :\n- Бегите все отсюда, сюда Черный Джек идет!\nНу ковбои на него посмотрели, и думают : "Та, он один а нас пятеро... пох"\nЧерез 15 мин вбегают еще двое небезызвестных стрелков, все в крови:\n- Бегите, сюда Черный Джек идет!\n- Та пох, он один, а нас пятеро!\nЕще через 20 мин вбегают четверо, изуродованные, в крови, некоторые с поломанными руками:\n- Мужики бегите, сюда Черный Джек идет!\nКовбои задумались, решили валить... Тут открываеться дверь, заходит мужик весь в черном, в черном плаще, в черной шляпе, в черных перчатках, с черными револьверами, в черных сапогах и говорит:\n- А ну отсосали у меня все! Быстро!\nКовбои с перепугу начали по-очереди сосать... Только закончили, мужик застегивает ширинку и говорит:\n- Кстати, мужики, лучше бегите, сюда Черный Джек идет!',
    'Заходит в бар мужик с магнумом и говорит:\n- Кто из вас подонков трахнул мою жену?!\nНа мгновение все замолчали, а потом парень в углу сказал:\n- Дружище, у тебя пуль не хватит!',
    'в дверь постучали 53 раза\n\n"нахуя я считал"-подумал я',
    'В автобусе едет старушка, рядом стоит пионер. Старушка громко чихает. \n- Бабушка, будьте здоровы - говорит пионер.\n- Ой, милок, спасибо! \nЧерез какое-то время опять чихает\n- Бабушка, будьте здоровы. \n- Ой, внучек, спасибо. \nЧихает в третий раз. \n- Бабушка, будьте здоровы, не болейте.\n- Спасибо, мальчик, только ты мне не говори больше так, я ведь не болею. А чихаю я от того, что табачок нюхаю. Мне щекотно становится, вот я и чихаю. \n- Ты, бабка, хоть хуй нюхай, а пионер должен быть вежливым.',
    '- Учитель, а как смеялись в имперские времена?\n- Ахахахъ',
    'Звонок в техподдержку:\n- У меня гугл не открывается...\n- Лампочка на модеме горит?\n- Да. Только это не лампочка, а тиристорный светодиод.\n- Ну тогда пошел нахуй, умник ебаный. Сам чини свой интернет, раз дохуя интеллектуал.',
    '— С вами говорит специалист по безопасности банка. Нам необходимо защитить ваш счет от несанкционированного доступа. Возьмите, пожалуйта, карту. \n— Спасибо, взял. \n— Продиктуйте номер. \n— 10. \n— Дальше? \n— Всё. \n— Назовите номер на карте целиком. \n— 10. \n— Что у вас за карта? \n— Десятка треф.',
    'Попали в огромную яму медведь, волк и лось. Ну, прошло недели две, волк подходит к медведю:\n- Слышь, Миша,.. ну,.. такое дело,.. в общем, я думаю так, лось - он же травоядный, а тут в яме травы-то никакой нет, он все равно подохнет скоро, а мы же хищники, глядишь еще недельку-другую протянули бы, давай его сейчас съедим, а то он же подохнет с голоду, мы ж падаль есть не будем...\n- Правильно, Волк!\nНу, подходят они к лосю:\n- В общем, Лось, такое дело, ты травоядный, а травы тут нету, мы решили с Волком тебя съесть, ты же все равно сдохнешь, а так мы еще поживем.\nЛось говорит:\n- Да конечно, ребяты! Да я уж и сам хотел к вам подойти! Да че в самом деле, ешьте меня на здоровье! Я ж действительно помру, а так вы классные пацаны еще поживете! Только, мужики, у меня к вам просьба есть: мне Лосиха говорила, что у меня под хвостом татуировка есть какая-то и что-то там написано,\nа она у меня тупая пиздец - читать не умеет, а самому мне ну никак не дотянуться, а уж больно охота узнать что там у меня\nнаписано. А тут такое дело, ну хоть перед смертью уважьте меня - прочитайте, а то я так и помру, не узнав.\n- Да чё там, конечно, прочитаем, для классного пацана не жалко, все сделаем!\nПодходят они сзади к лосю, ну, он естесно, на передние ноги встал, задними как даст им обоим. \nНу, волка сразу насмерть, а у медведя грудина разворочена, морда вся перевернута в крови,\nчелюсть налево, нос направо. Медведь за морду держится и орет:\n- А-а, о-о, а я-то блять нахуя полез, я-то куда, я же читать сука не умею...',
    'Один еврейский мальчик очень любил читать. Он читал всё, что попадалось ему под руку, и обожал ходить в свой любимый книжный магазин. Однажды он понял, что прочёл уже всё, что там продавалось. Мальчик спросил хозяина, есть ли в магазине что-нибудь, чего он никогда не видел. Хозяин сказал, что есть, и достал книгу под названием "Смерть". Он охотно продал её со скидкой, всего за 10 шекелей. \n\nОднако он предупредил мальчика, чтобы тот никогда не открывал первую страницу. Мальчик вернулся домой, прочитал книгу и остался доволен. Но ему всегда хотелось узнать, что же там, на первой странице. Однажды искушение стало слишком сильным, и он пролистал книгу к самому началу, и уронил её в УЖАСЕ. \nНа первой странице было написано: "Рекомендуемая цена - 5 шекелей"',
    'Молдавская подводная лодка плывет по Дунаю. Капитан спрашивает:\n-Машинное отделение, какими дровами топите?\n-Прямыми!\n-Топите кривыми, поворачивать будем!',
    'Параноик и шизофреник возвращаются с прогулки в корпус. \nНавстречу гопники. \nПараноик:\n— Бежим!\nШизофреник:\n— Да ладно ты… \nГопники приближаются и шизофреник их легко так на асфальт укладывает всех.\nВосхищённый параноик:\n— Как ты так смог? \nШизофреник:\n— Да чё там… их трое, а меня ноль, целковый, чекушка, порнушка, пердушка, засерушка, жучок, мудачок, хуй на воротничок, дурачок…',
    'Заходит мужик в овощной магазин:\n- У вас морква есть?\n- Есть. \n- Дайте мне самую большую!\nДают ему моркву, он суёт её в жопу и уходит.\nHа следующий день опять приходит:\n- У вас есть самая большая морква?\n- Есть.\nHу опять то же самое....\nПриходит на третий день:\n- У вас есть самая большая морква?\nЕму раздраженно:\n- Hет!!!\n- А свекла?\n- Свекла есть.\n- Дайте самую большую.\nЕму дают, он сует её в жопу и выходит... в дверях его окликают:\n- Слышь, мужик, а чего ты всякую хуйню в жопу суёшь?\nМужик радостно:\n- А чё, морква есть???',
    'Стоит полностью голый армянин у зеркала говорит:\n - Ваах какой мужик\nПоворачивается жопой к зеркалу. Смотрит хуй встаёт\n- Эээ свои свои',
    'Москвич москвича спрашивает после поездки в Иркутск:\n- Ну что, как тебе Иркутск?\n- Да хули... провинция! До сих пор баб ебут.',
    'Пошли как то раз в театр поручик Ржевский, Андрей Болконский, Пьер Безухов и, конечно же, Наташа Ростова. Сидят смотрят постановку. Тут Болконский говорит Наташе:\n– Наташа, а у вас на спинке стула какое-то слово написано.\n– А какое?\nБолконский замялся:\n– Ну... Первая буква такая же как в слове "холод", — и толкает локтем Безухова.\nПьер сразу сориентировался:\n– А вторая такая же как в слове "суд", — и толкает Ржевского.\nПоручик:\n– А третья буква такая же, как третья буква в слове "хуй".',
    'грузин упал в пропасть, его друг кричит:\n- Гоги, ти жив?\n-Жив!\n-Ноги цэли?\n- Цэли!\n- Руки цэли?\n-Цэли!\n-Пачэму нэ вилезаещь?\n-Я еще нэ долетээээль....',
    'Тормозит мужик такси. Садится. Таксист спрашивает:\n— Куда едем?\n— Гони на Горького.\n— Горький, бля, сука, бля, пидор бля.',
    'Летит в Афганистан самолет с десантниками. Командир говорит им: \n—За одну голову убитого талиба советское правительство платит по 100 советских рублей. \nСамолет сел, десантники сразу разбежались, кто куда. Через час вернулись с мешками полными голов. Командир с выпученными глазами орет: \n—ДА ВЫ ЧТО, ОХУЕЛИ? МЫ В ТАШКЕНТ СЕЛИ НА ДОЗАПРАВКУ',
    'Собрал вождь индейское племя в джунглях:\n- ИНДЕЙЦЫ!!! Мы великий народ?\n- ДАААААА!\n- Тогда почему у нас нет ядерной ракеты?\n- Ну... Давайте строить.\nСрубили самую здоровую секвойю, выдолбили сердцевину\nтопорами, по старым испанским рецептам приготовили\nпорох, забили его, заколотили пробку, вывели охуенный\nканат в фитиль.\n- Куда ее запустим?\n- Давайте в Ереван!\n- А почему в Ереван?\n- А я других не знаю...\nНаписали на ракете "На Ереван", столпили все племя,\nподожгли канат-фитиль... КАК ЕБАНЕТ!... Короче, местный\nАрмагеддон: дым, гарь, все валяются... Вождь без ноги, без\nруки, оглядывается:\n- Нихуя себе... Представляю, что в Ереване творится...',
    'Два машиниста едут в кабине поезда, один с тоской смотрит в окно и говорит:\n\n— Всё, Вась, пойду в путейцы работать.\n\n— Нафига???\n\n— А вот посмотри на них. Как ни проезжаем, они все время курят и больше ничего не делают. Работа мечты, че.\n\nНу, сказано–сделано, уволился он с работы, устроился в путейцы. Там ему выдали кувалду, и он ей машет. Час, второй, третий, четвёртый... На пятый он и говорит:\n\n— Слышь, бригадир, а курить–то когда будем?\n\n— А ща поезд поедет, мы все и покурим...',
    'Белочка поселилась в дупле на высокой сосне. В один прекрастный день проснулась от дикого треска и тряски. Вы глянула из дупла и увидела как Слон лезет на дерево\n\n- Нахуй ты лезешь на дерево?\n\n- Груш поесть - отвечает Слон.\n\n- Ты долбоеб, тут нет груш, это сосна.\n\n- Так я со своими - ловко парировал Слон.',
    'Заходят два дракона в бар.\nОдин другого спрашивает:\n-хули тут так жарко?\nДругой отвечает:\n-а ты ебало закрой',
    'Идет заседание. Сталин читает речь. Вдруг среди сидящих политиков кто-то\nгромко чихнул.\n- Кто чихнул? - спрашивает Сталин.\nМолчание.\n- Кто чихнул? - повторяет Сталин.\nСнова молчание.\n- Первый ряд, кто чихнул?\nМолчание.\n- Вывести  первый ряд!\nВывели.\n- Второй ряд, кто чихнул?\nМолчание.\n- Вывести второй ряд!\nВывели.\n- Третий ряд, кто чихнул?\nПоднимается чихнувший и дрожащим голосом голосом говорит:\n- Это я...\n- Будьте здоровы, товарищ!',
    'Идут параноик и шизофреник.\nПараноик:\n— Давай перейдем на другую сторону, навстречу гопники идут.\nШизофреник:\n— Фигня, пошли вперед.\nГопники нападают, шизофреник всех раскидал.\nПараноик:\n— Как ты это сделал?\nШизофреник:\n— Легко. Их было 5, а меня 10…',
    'Мужик заходит в бар, заказывает виски: \n— Сколько с меня? \n— Три доллара. \nМужик вынимает из кармана три доллара. Один кладет на стойку перед собой, потом идет в левый конец стойки, там кладет второй, потом идет в правый конец стойки, там кладет третий. Бармен, тихо матерясь, идет направо-налево и забирает деньги. \nНа следующий день опять тот же мужик приходит, опять стаканчик виски заказывает и снова раскладывает доллары в разные концы стойки. Бармен злится, но за деньгами ходит. \nКороче, такая картина повторяется день за днем. И вот однажды мужик заказывает виски, берет стакан, роется в кармане и вытаскивает бумажку в 5 долларов. Бармен быстро эту бумажку берет, мстительно улыбается, достает два доллара сдачи, идет в левый конец стойки, там кладет один доллар, потом идет в правый конец и там кладет второй. Затем возвращается и злорадно смотрит на мужика. \nМужик флегматично выпивает виски, вытаскивает из кармана доллар, кладет его перед собой и говорит: \n— Пожалуй, возьму еще стаканчик.',
    'Разговаривают две подруги. Одна спрашивает другую:\n— Как там твой друг — математик?\n— Да, урод он! Представляешь, звоню ему вчера вечером предлагаю пойти погулять, а он отвечает: «извини, я тут ебусь с тремя неизвестными»!',
    'Во Львове прошла олимпиада по русскому языку. Победителей казнили.',
    'Студент сдает зоологию. Знает только про свиней. На экзамене\nдостается вопрос про лошадей. Судент начинает:\n- Лошади это млекопитающие, живут на ферме. Также на ферме живут свиньи...\nдальше все про свиней....\nПрепод:\n- Ладно молодой человек, расскажите про коров \nСтудент:\n- Коровы - это млекопитающие, живут на ферме. Также на ферме живут свиньи...\nдальше все про свиней....\nПрепод: \n- Молодой человек, у вас другая тема, почему вы опять говорите про свиней?\n- Потому что свинья - охуенная тема!',
    '- Поручик, а вы сможете найти предателя в наших рядах?\n- А могу-с!',
    'Учится хохол в русской школе. На уроке литературы предстоял опрос по произведению. \nУчитель начал расспрашивать всех: у одного спросит - не читал, у второй - тоже не читала. Никто не прочитал. Так и поставила всему классу двойки.\nВозвращается домой хохол, а мать уже в курсе про урок литературы и с удивлением говорит:\n- А шо это у тобi одного двойки нема? У всiх стоит, а у тобi нi. Вообще оценки нема. Шо таке?\nА он ей отвечает:\n- Да меня спросить забыли',
    'Мужик смертельно заболел. Пошел на болото топиться, Только приготовился вдруг лягушка выныривает: \n- Что надо? Что пришёл? \n- Да болен я, жить мне полгода осталось. Зачем семью буду мучать, утоплюсь да и всё \n- Иди мужик домой, всё будет хорошо. \nПриходит мужик домой, а его жена встречает: \n \n- Милый, с больницы звонили, все хорошо, твои анализы нормальные, \nИХ просто перепутали \n \nПрошло полгода. У мужика завал, зарплату полгода не платят, Под сокращение попадает, семья бедствует. Пошел на болото. Лягушка: \n \n- Что надо? Что пришел? \n- Да надоело все. Зарплату не платят, семью не могу содержать, топлюсь. \n- Иди мужик домой, Все Будет Хорошо \n \nПриходит мужик на работу, а его все приветствуют, премию выписали, задолженность отдали, повысили оклад, Должность новую дали. Прошло полгода. Жена загуляла, дети школу прогуливают, отца ни кто не слушает. Пошел на болото. \n \n- Что надо? Что пришел? \n- Ай лягушка, устал. Не мешай, утоплюсь и дело с концом. \n- Иди мужик домой, Все Будет Хорошо \nПриходит мужик Домой а, там дети "папа-папочка" лезут целоваться, обниматься. Жена на коленках прошения молит, ноги целует. Ну мужик думает "Блин лягушку-то отблагодарить надо". Пошел на болото. \n \n- Что надо? Что пришел? \n- Да добра ты мне столько сделала, давай отблагодарю. \n- Да иди домой. Все хорошо. Иди. \n- Да не могу я так, совесть не позволяет. \n- Ну ладно, хочешь мне добро сделать, так тр*хни меня. \n\n- И тут, вы не представляете товарищ следователь, лягушка превращается в 12-летнего мальчика!',
    'Разработчик демонстрирует игрокам новую игру.\n— Вот, товарищи игроки, это\nновая CoD. Петров.\n— Я!\n— Установи игру.\nПетров тужится, пыжится, не\nУстановить.\n— Не установить.\n— Сидоров, помоги Петрову.\nПытаются вдвоем, та же\nситуация.\n— Не установить.\n— Иванов, помогай.\nПыхтят втроем. установить не\nмогут.\n— Никак не установить, товарищ разработчик.\n— А хули вы хотели? 175 гигабайт…',
    'Летят президенты России , Америки и Румынии в одном самолете. Вдруг, Американец вытащилв окно и сказал : " My seychas letim nad Amerikoy". Все его спрашивают как он это узнал . " Ya kosnulsya statui svobody", - сказал он . Затем президент России вытащил руку в окно и сказал : " Мы сейчас над Россией летим , я коснулся Кремля". Наконец, президент Румынии сказал : " Мы летим над Бухарестом ". Все его спросили как он это понял . Он отвечает : " У меня часы спиздили ".',
    'Руский долго не мог найти работу по душе и решил открыть свою собственную клинику. На здании вывесил вывеску: "вылечить недуг 5 000 рублей, если не получится, мы вернем вам 10 000"рулей.\nПроходящий мимо еврей решил воспользоваться этим и поднять немного денег.\n- Здравствуйте, я не знаю, что случилось, я потерял вкус к еде, все теперь одинаковое, безвкусное...\n- Сестра, принесите, пожалуйста, упаковку № 22 с сиропом и дайте его пациенту сказал Русский. - Так, пожалуйста, откройте рот...\n- Тьфу... это же моча!!!\n- Поздравляю, вы снова различаете вкус, с вас 5 000 рублей.\nЕврей ужасно разозлился, но оплатил счет, однако через несколько дней вернулся в клинику:\n- Здравствуйте, я потерял память, помогите мне...\n- Сестра, принесите, пожалуйста, упаковку № 22 с сиропом и дайте его пациенту сказал Русский.\n- Но в этой упаковке же моча сказал еврей!\n- Поздравляю, вы восстановили память, с вас 5 000 рублей. Еще более расстроенный еврей заплатил, но через пару дней снова решил отыграться:\n- Здравствуйте, я потерял зрение, пожалуйста, помогите\nмне...\n- Мне очень жаль, но тут мы бессильны. Вот ваши 10 000.\n- Но здесь же только 5 000!\n- Поздравляю, вы восстановили зрение, с вас 5 000 руб.',
    'Женщина-врач не может заснуть - в ней спорят совесть и разум. \nСовесть: "Нельзя спокойно спать после того, как изменила мужу!" \nРазум: "Это смотря какому! Если муж вечно занят, на секс у него не хватает времени - тут и святая изменит. Правильно, что изменила... баю-баюшки-баю..." \nСовесть: "Измена измене рознь! Совокупляться с пациентом - нарушение врачебной этики!" \nРазум: "Да, но вспомни Иванову из 25-й поликлиники. Она регулярно занимается \nсексом с пациентами - все довольны, всем хорошо". \nСовесть умолкает. \nЖенщина проваливается в сон... и вдруг - совесть едким шепотком: \n"Да, но Иванова-то - не ветеринар..."\nНа что разум отвечает:\n"Но ведь свинья - охуенная тема..."',
    'Заходит грустный еврейский мальчик на кухню.\n-мам, купи собачку...\n-нет\n-мам, мам, ну купи собачку...\n-нет, Фима\n-мам, ну пожалуйста, ну купи собачку....\n-Фима, иди продавай свою собачку во двор!',
    'Утка заходит в паб и заказывает пинту пива и бутерброд с ветчиной. Бармен смотрит на нее и говорит: «Подожди! Ты же утка». \n«Я вижу, что твои глаза работают, — отвечает утка. \n«И ты можешь говорить!» — восклицает бармен. \n«Я вижу, что твои уши тоже работают», — говорит утка. «Теперь, если ты не возражаешь, могу ли я получить свое пиво и бутерброд, пожалуйста?» \n«Конечно, извини, — говорит бармен, наливая пинту пива для утки. «Просто у нас в пабе не так уж и много уток. Что привело тебя сюда?» \n«Я работаю на строительной площадке через дорогу, — объясняет утка. «Я штукатурщик». \n Ошеломленный бармен не может поверить утке и хочет узнать больше, но понимает намек, когда утка вытаскивает газету из своей сумки и начинает читать ее. \n Итак, утка читает свою газету, пьет свое пиво, ест свой бутерброд, желает бармену хорошего дня и уходит. \n То же самое происходит на протяжении двух недель. Затем в один прекрасный день в город приезжает цирк. Шпрехшталме́йстер приходит в паб за пинтой пива, и бармен говорит ему: \n«Вы из цирка, не так ли? Я знаю одну утку, которая будет просто блистать в вашем цирке. Она говорит, пьет пиво, ест бутерброды, читает газету и все такое!» \n«Звучит чудесно», — говорит шпрехшталме́йстер, передавая свою визитную карточку. «Попросите ее позвонить мне». \n Итак, на следующий день, когда утка входит в паб, бармен говорит: «Эй, утка, я считаю, что могу предложить тебе отличную работу, за которую будут платить действительно хорошие деньги». \n«Я всегда ищу новую работу, — говорит утка. «Где это?» \n«В цирке, — говорит бармен. \n«Цирк?», — повторяет утка. \n«Правильно, — отвечает бармен. \n«Цирк?» — снова спрашивает утка. «С большим куполом?» \n«Да!» — отвечает бармен. \n«Со всеми животными, которые живут в вольерах, и исполнителями, которые живут в машинах?», — говорит утка. \n«Конечно», — отвечает бармен. \n«И у купола большая холщовая крыша с отверстием посередине?», — повторяет утка. \n«Это верно!» — говорит бармен. \nУтка удивленно качает головой и говорит: «И что они хотят, чтобы я там штукатурила?»',
    '90-е, кризис. Сидит дома голодный композитор, работы нет, денег нет. И тут звонит ему знакомый режиссер и говорит: слушай, я тут фильм снимаю, нужна музыка на финальные титры, сможешь написать? Денег не заплачу, но может тобой заинтересуются и карьера вверх пойдет. \n- Да не вопрос, напишу. А тематика какая? \n- Ну короче там в финале с дерева будет падать лист, мы его будем снимать крупным планом, и под это дело нужна музыка. \nНу короче композитор неделю не спал, сочинил, отдал. И вот этот режиссер приглашает его на премьеру фильма. Композитор заходит в зал, а там пустота, сидит только очень пожилая пара. Ну, думает, мало ли, решил наверное показать самым близким, такая честь. Выключается свет, начинается фильм. На фоне красивой природы стоит дерево, в него уперлась красивая телка, а сзади ее в жопу долбит качок. Потом к ним присоединяется еще одна пара, они меняются. Потом появляются новые персонажи, негры, карлики, психи и происходит повальная ебля. Потом прибегает маленький спаниель и имеет их всех, а потом они все имеют спаниеля в жопу. И тут камера берет крупным планом лист на дереве, он отрывается, падает, звучит невероятно красивая лирическая музыка и пошли титры. \nВключается свет, опизденевший композитор в ахуе машинально бредет к выходу и случайно его взгляд упирается в пожилую пару. Те сидят полностью опидоревшие с открытыми ртами в полном шоке. И композитор ничего не придумал лучше чем выдавил из себя: \n- Музыка моя. \nСтаричок повернул голову, и пересохшими губами пролепетал: \n- А собачка наша...',
    'По случаю 80-летнего юбилея внуки подарили дедушке билеты\n в его родной город. \nСтарик очень обрадовался, что увидит родной дом через много\n десятков лет.\n Приехал, смотрит: дом стоит, даже орнаменты на фасаде те же\nТолько обветшали, то же дерево во дворе.\n Умилился дед, слезинку обронил и увидел на другой стороне улицы будку обувщика, памятную ему с юности.\n Перешел дорогу и постучал в стекло будки: \n- Есть ли кто? \nИзнутри раздался старческий голос: \n- Есть, говорите. \n- Помню эту будку еще пятьдесят лет назад! \nДаже однажды оставил там пару обуви, коричневые мокасины. \nИзнутри раздалось: \n- Да, верно, с красным кантом. \n- Точно! \n- И нужно было приклеить левую подошву. \n- Да! \n- В среду будут готовы.',
    'Грузин на проходе в общественной бане положил 10 р., а сам спрятался в душевую кабинку и наблюдает. \nИдет мужик. Увидел червонец, огляделся по сторонам, задницу веником прикрыл, наклонился, поднял десятку. \nГрузин: — Умны! \nПоложил еще одну. \nИдет другой мужик, увидел купюру, огляделся по сторонам, задницу шайкой прикрыл, поднял деньгу. \nГрузин: — Умны! \nИдет еще один, увидел червонец, огляделся по сторонам, но наклоняться и подбирать, все–таки, не решился и прошел мимо. \nГрузин: — Умны! \nHагибается, чтобы забрать свои деньги, и тут бабах кто–то ему всаживает.\nГрузин: — А, нэт — хитры!!!',
    'однажды негр очень смешно пошутил, но все равно никто не выкупил',
    'Приезжает турист в австрийскую деревеньку.\nЗаселяется в гостиницу, ему предлагают комнату, пиво, ужин и т.д.\nТурист интересуется у хозяйки:\n- Можно ли купить у вас секс?\n- Конечно! Фрау Марта, второй этаж, сто евро.\n- Простите за нескромность, но можно ли купить у вас секс с мужчиной?\n- Конечно! Руди, третий этаж, пятьсот евро.\n- Простите, а почему Руди берет так дорого?\n- Ну понимаете, у нас маленькая деревушка и все про всё знают, и наш мэр очень этого не любит, но мы даем ему сто евро и всё нормально.\n- Значит Руди получает 400 евро?\n- Нет, у нас еще есть священник и он тоже этого очень не любит, но мы даем ему сто евро и всё нормально...\n- Но 300 евро все-таки получает Руди?\n- Нет, Руди получает только 100 евро.\n- Почему так мало?!\n- Видите ли, 200 евро мы делим между Гансом и Марком, которые держат Руди, потому что Руди этого тоже очень не любит!',
    'Украинская армия вошла в топ 5 армий на территории Украины.',
    'Средние века. По морю плывет корабль. Матрос, сидящий на мачте, кричит: \n \n— Капитан! Впереди по курсу пиратский корабль! \n— Принесите мне мою красную рубаху! — спокойном голосом отдает приказ капитан. \n \nКоманда удивлена, но приносят ему рубаху, он надевает её. Завязывается бой, в ходе которого пираты оказываются полностью разгромлены. \n \n— Капитан, а скажите нам, зачем вы попросили красную рубаху? \n— Это для того, чтобы, если я окажусь ранен в бою, моя команда не видела мою кровь и продолжала так же отважно сражаться. \n— Капитан! Впереди по курсу 20 пиратских кораблей!!! \n— Принесите мои коричневые штаны! — все так же спокойно приказывает капитан.',
    'Василий Иванович к конюшне подходит, слышит там Петька с Анкой понятно чем занимаются. Стучит в дверь, орет открывайте. Петька быстренько подкоп сделал, Анка вылезла, Петька дверь открывает, Василий Иванович вбегает:\n- Петька! Ты чем это тут занимался???\n- Чем-чем! Какал я тут! - показывает на лошадиную лепешку.\n- Да? Дак ведь говно-то лошадиное!\n- Дак ты ж по-человечески посрать не дал!',
    'Поймали Наёмники Сталкера, окунают его в воду и спрашивают: \n- Деньги, бабло, артефакты есть? \nСталкер: \n- Нет. \nИ опять окунают в воду и спрашивают: \n- Деньги, бабло, артефакты есть? \nСталкер: \n- Да нету, нету! \nА они опять окунают : \n- Деньги, бабло, артефакты есть? \nНу сталкер не выдержал: \n- Блин, вы либо дольше держите, либо глубже опускайте ! Вода мутная - нихрена не видно!',
    'Индейское племя. Умирает старый вождь. По закону племени его должны \nубить. Собрались старейшины и обсуждают, кто убьет старого вождя. \n- Может ты, Меткий Глаз? \n- Нет. Не могу. \n- Может ты, Верная Рука? \n- Нет. Никак не могу. \n- Может ты, Быстрые Ноги? \n- Нет. \nВ общем, никто не соглашается. Вдруг один говорит: "Давайте позовем \nрусского Ивана из экспедиции - он нам поможет". Пошли к Ивану, \nобъяснили \nситуацию, что, мол, вождь умирает, по закону племени его надо убить и \nчто никто на это не решается. Поставили ящик водки. Иван согласился. \nПриходит Иван к индейцам: \n- Ну, где ваш вождь. \n- Да вон в том вигваме. \nИван заходит в вигвам, слышится легкий вздох. Иван выходит - готово, и \nпошел прочь. Все старейшины стоят в оцепенении. Он, бледнолицый, убил \nнашего вождя. Месть за это. Короче, выбрали самого крепкого и сильного \nи опять пошли к Ивану. Говорят, что опять вождь умирает и что его надо \nубить Поставили два ящика водки. Иван удивился, что больно быстро у них \nвожди меняются, но согласился. Приходит Иван к индейцам: \n- Ну, где ваш вождь. \n- Да вон в том вигваме. \nИван заходит в вигвам. Слышны звуки борьбы, потом истошный вопль и - \nтишина. Старейшины стоят возле вигвама и радуются - возмездие \nсвершилось. Вдруг из вигвама выходит Иван и говорит: "Ну и нравы у вас \n- ему бы еще жить да жить".',
    'В чем разница между сбитой собакой и сбитым хохлом? \n.\n.\n.\n.\n.\n.\n.\n.\n.\nПеред трупом собаки есть следы торможения',
    'Война, стреляют... Едет мужик на телеге, позади корова привязана. Вдруг взрыв, падает самолет прямо на повозку, оторвало лошади, корове и мужику ноги, лежат все они еле живые, стонут... Откуда ни возьмись, спускается парашютист.\n\nПодходит к корове:\n- Ой, бедняжка, как тебе плохо, ноги оторвало, живот разорвало, сейчас я тебе помогу.\n\nВытаскивает пистолет и добивает бедное животное. Подходит к лошади:\n\n- Ой, бедняжка, как тебе плохо, ноги пооторвало, хребтину переломило, сейчас я тебе помогу.\n\nВытаскивает пистолет и добивает лошадь. Направляется к мужику. Тут слышен вопль мужика:\n\n- Господи! Как же мне заебись!!!!!!!',
    'Новый год.\nСидит салат в желудке, вдруг на него что-то сверху падает. Он спрашивает:\n– Ты кто?\n– Водка!\n– За кого пили?\n– За Иван Иваныча!\nЧерез некоторое время снова что-то падает сверху.\nСалат:\n– Ты кто?\n– Водка!\n– За кого пили?\n– За Иван Иваныча!\nИ опять падает. Салат:\n– Ты кто?\n– Водка!\n– За кого пили?\n– За Иван Иваныча!\n– Ну-ка, пойду посмотрю, что там за Иван Иваныч!',
    'Мужчина занял свое место в самолете. Вдруг в салон зашла самая красивая женщина, которую он когда-либо видел. И она села рядом с ним. Волна нервной дрожи охватила его тело. \nЖелая завязать разговор, он спросил:\n — Куда летите?\nДевушка повернулась к нему, улыбнулась и сказала: — На ежегодную конференцию нимфоманок, в Чикаго!\nОн сглотнул и обезумел от волнения. Великолепная женщина, сидящая рядом, собирается на встречу нимфоманок! Изо всех сил пытаясь держать себя в руках, он спокойно спрашивает: — А что вы будете делать на этой конференции? \nОна откидывает прядь волос и говорит: — Я хочу развенчать некоторые популярные мифы о мужской сексуальности! — Правда? Интересно. И что это за мифы? Женщина объясняет: — Ну, один из популярных мифов заключается в том, что у афро-американцев самые выдающиеся размеры (вы понимаете, о чем я), тогда как на самом деле эта черта более присуща коренным американцам – индейцам. Другой популярный миф говорит о том, что французы – лучшие любовники, тогда как на самом деле лучшими любовниками являются мужчины еврейского происхождения.\n — Очень интересно, — отвечает мужчина. Внезапно женщина краснеет и со смущением говорит: — Простите, но я себя так неловко чувствую. Я обсуждаю с вами такие вещи, и даже не представилась, и не спросила как вас зовут! Меня зовут Светлана.\nМужчина протягивает руку и отвечает: — Зоркий Сокол. Зоркий Сокол Рабинович.',
    '- Тараканы в доме есть?\n- Нет, их пауки съели.\n- У Вас пауки есть?\n- Нет, их крысы съели.\n- У Вас крысы есть?!\n- Нет, их Валентин Геннадьевич Белов съел.\n- А кто это?\n- Забыл представиться.',
    'Умер И. Ф. Летов. Пообсуждали Бог и Черт, куда его отправить и отправили к Черту в ад. Приходит через месяц Черт к Богу и говорит:\n- Забери Летова к себе. У меня черти восстание подняли, за свою оборону требуют беспонтовые пирожки. У тебя в раю все хорошо и для продвижения своих идей у него не будет социальных условий.\nБог согласился. Через месяц снова приходит Черт к Богу и спрашивает:\n- Ну что, Бог, как у тебя Летов поживает?\nБог отвечает:\n- Всё стало заебись.',
    'Штирлиц долго смотрел в одну точку. Потом в другую. "Двоеточие!" - наконец-то смекнул Штирлиц.',
    'В церковно-приходской школе заболел учитель физики. Что делать? Попросили батюшку провести урок физики. Батюшка, конечно, согласился, ну куды деваться. \nЗаходит в класс: \n- Здравствуйте, отроки, - говорит, - сегодня я буду у вас вести урок физики. Ответствуте мне, что самое тяжёлое на свете? \nВсе молчат, только Вовочка с задней парты руку тянет. \n- Отвечай, отрок. \n- Хуй, батюшка... \n- Обоснуй... \n- Ежели не встаёт, то никакими подъёмными механизмами не поднять. \n- Богохульно, но верно. А ответствуйте мне отроки, что самое легкое на свете? \nОпять все молчат, и опять Вовочка с задней парты руку тянет. \n- Ну отвечай, отрок... \n- Хуй, батюшка. \n- Обоснуй... \n- От одной только мысли подняться может. \n- Богохульно, но верно. А ответствуйте мне, отроки, что самое скользкое на свете? \nОпять все молчат, и опять Вовочка с задней парты руку тянет. \n- Молчи, отрок, а то ты мне сейчас всю физику к хуям сведешь...',
    'Одного мудреца спросили: \n- Как вам удалось прожить так долго? \n- все просто, - ответил мудрец, - я никогда ни с кем не спорю \n- но это же невозможно!!! \n- возможно \nМудрец умер нахуй',
    'Общага. Один из жильцов повадился обссыкать стульчак на общем сортире. Что только не пробовали соседи - ему похер, ссыт на стульчак нарочно. И вот однажды, соседка придумала хитрый план, как остроумно его проучить. Рассказала соседям, они одобрили. Наступила ночь. Соседка спряталась и ждет ссыкуна. Открывается дверь его комнаты, он выходит и идет в сортир. Начинает ссать, и по звуку понятно - ссыт на стульчак. Соседка подкралась сзади и выстрелила ему в голову из дробовика.',
    'От мужика ушла жена. Едет он в машине расстроенный, на своей волне... Бац, мента насмерть сбивает. Что делать? Он - мента в багажник, сам - на кладбище. Приезжает, там сторож водку хлещет. Мужик сторожу говорит: "Слушай, закопай его где-нибудь, а я тебе 100 баксов заплачу". Сторож согласился. Мужик с кладбища едет в шоке: жена ушла, мента сбил... Бац, второго мента сбивает и тоже насмерть. Что делать, денег-то больше нет. Думает, подброшу сторожу по-тихому, может не заметит. Подъезжает на кладбище и тихонько сторожу мента подбрасывает. Сторож только первого закопал, оборачивается, мент лежит. Что за хрень? Ну, делать нечего, пришлось закапывать. А около кладбища стоит пост ДПС. Гаишник смотрит, машина одна и та же туда-сюда мотается, решил проверить, в чем дело. Идёт на кладбище, там сторож только второго мента закопал. Гаишник спрашивает: "Что у вас тут происходит?" А сторож его по голове лопатой хрясь: "Да, ты, блядь, уляжешься сегодня или нет!?"',
    'Встретились Хой, Горшок и Летов, ну и вздумали бухнуть. Купили литруху, ну и типа говорят: «Мы же поэты! Давайте кто сколько в стихах попросит, тому столько и нальём!» \nХой встаёт: \n— Рыбка плавает по дну, выпью рюмочку одну. \nНалили. Горшок встал: \n— Рыбка мёртвая на дне, выпью рюмочки я две. \nЛетов встаёт, весь натужился, набух, покраснел, глаза выпучил. Вдруг как заорёт: \n- АААА БЛЯЯЯДЬ НАХУУУЙ \nСхватил пузырь и убежал.',
    'Лежат два деда в палате, американец и европеец. Обоим осталось совсем немного. Они стали хорошими друзьями за то время, что находились в больнице.\nЕвропеец, почувствовав смерть, обращается к американцу: \n-Если сумеешь выбраться отсюда, то найди мой тайник и потрать всё из него на шлюх, бухло и наркотики, дружище… поживи как человек.. он находится в километре от больницы, возле старого дерева..\nЕвропеец, хрипя, умирает. \nАмериканец:\n-Хуйня какая-то.. Что такое километр?\nИ тоже умирает.',
    'Маленький мальчик по имени Нурбек жил в небольшой деревне. Он был настолько тупым, что никому не нравился. Особенно учительнице, которая всегда кричала на него: " Ты сводишь меня с ума, Нурбек!" Однажды мать Нурбека пришла в школу, чтобы проверить, как у него дела. Учительница честно сказала матери, что её сын - это просто катастрофа, получает очень плохие оценки, и она ещё не видела такого тупого ребёнка за всю преподавательскую карьеру. Мать была в шоке, она забрала сына из школы, и они переехали в другую деревню.Двадцать лет спустя у учительницы диагностировали серьёзное заболевание. Ей посоветовали операцию, которую во всей округе может сделать лишь один хирург. Проанализировав ситуацию и понимая, что у неё нет другого выхода, учительница согласилась на операцию, которая прошла успешно. Когда она открыла глаза после операции, то увидела симпатичного врача, который улыбался , глядя на неё. Она хотела поблагодарить его, но не могла говорить. Её лицо начало синеть, учительница подняла руку, пытаясь ему что-то сказать, но умерла, так и не произнеся ни слова. Врач был в шоке. Когда он повернулся, то увидел Нурбека, работающего уборщиком в этой больнице, этот дол6оеб отключил кислородный аппарат, чтобы подключить свой пылесос.',
    '...Короче, лихие 90-ые. Осень. Сидит в своей холодной питерской коммуналке композитор: ни копейки в кармане, ни куска хлеба на столе, ни работы. Уже чуть ли не с ума сходит, не знает, что и делать. Как вдруг звонит телефон:\n   - Алло?\n   - Алло! Это композитор? Полянский Михаил Палыч?\n   - Да, да! Это я!\n   - Прекрасно! Слушай, могу работу предложить... Заинтересован?\n   Композитор чуть не уссался от счастья:\n   - Конечно! Очень заинтересован!\n   - Ещё прекрасней! Значит, смотри. Я сам - режиссёр, Иванов фамилия. Дело такое: фильм снимаем, и нужна музыка под финальные титры. Мы крупным планом лист возьмём осенний, и он должен будет медленно-медленно падать под неебически красивую лирическую мелодию. Понял меня?\n   - Да-да, понял! Слушайте, а что касаемо оплаты???\n   - Оооох... Тут, дружище, такое дело, - вздохнул режиссёр - Еле актёров оплатить хватает. Ни копейки не могу дать. Но ничего: сделаешь, а там, глядишь, заинтересуются тобой, и карьера вверх пойдёт.\n   Подумал композитор, подумал. И решил, что и так без работы сидит, от тоски подыхает, а так хоть и дело, и хоть и призрачная, но перспектива. Вообщем, две недели не спал, не ел, не пил - написал мелодию. Причем такую, что мурашки прошибают насквозь от её глубины и красоты. Бетховен и Бах могли б позавидовать.\n   Короче, написал, отправил, стал ждать. Через месяц-другой приходит приглашение от режиссёра Иванова на премьеру фильма. Оделся композитор в свои самые сносные обноски, обвязал шею шарфом и поехал.\n   И вот заходит он в зрительный зал промозглого кинотеатра. Зал - пустой, только одинокая пожилая пара на самом переднем ряду. "Ну, - подумал композитор, - может, самым близким сначала захотел показать". Нашёл место, расположился...\n   Свет вырубается. Загорается экран. Начинается фильм... А начинается он с того, что на фоне одетого осенью леса молодой качок ебёт моложавую фигуристую бабу. И ебёт знатно: то грубо, то нежно, то в попку залезет. А она кричит, кричит... Потом вообще страх, что происходит. Эта баба вдруг надела страпон и давай качка сношать. А после - вообще пиздец: откуда ни возмись попёрли качки, негры, трансы, карлики. И все сосутся, ебутся, срут друг другу в рты. Вообщем, ебля повальная. А конец - так вообще задница ебучая: выбегает маленький-маленький спаниель (собачка такая), и сначала он всех оттрахал в жопу, а потом все, от мала до велика, выебли эту спаниель...\n   И тут... И тут крупным планом берётся осенний лист, который тихо-тихо отрывается от ветви и так же, тихо-тихо, начинает падать под лирическую, неебически красивую душевную мелодию...\n   Свет включается. Просто опиздиневший композитор машинально бредёт к выходу. И вдруг его взгляд задерживается на одинокой пожилой паре. И дед, и бабка с охуевшими лицами вглядывались в уже потухший экран.\n   Композитор не нашёл ничего лучше, чем сказать:\n   - Музыка моя...\n   И тут дед, поворачивая ошалевшее ебало:\n   - А собачка наша',
    'Поймал царь англичанина, француза и русского и сказал, что даст им \nзадание, кто лучше всех выполнит - тому дочь в жены и полцарства в \nпридачу. Задание такое: посадил он их на месяц в камеру и дал мешок \nсухарей и овчарку; кто больше всех овчарку чему-либо научит, тот и \nпобедил. \nПроходит месяц. Выходит тощий англичанин и упитанная овчарка. Царь: \n- Ну, чему научил? \n- Сидеть, лежать. \nВыходит среднего телосложения немец и такая же овчарка, он научил ее \nсидеть, лежать, голос и "апорт". \nВыходит упитанный русский и тощая собака. Царь просит \nпродемонстрировать. \nРусский: \n- Голос. \nСобака, жалобно заглядывая в глаза: \n- Вань, дай сухарик, а?',
    'Приходит еврей к раввину и говорит:\n–Послушайте, у меня проблема. Я правоверный еврей. Я соблюдаю шаббат, читаю Тору, ем кашерную пищу, молюсь Яхве. Но мой сын стал христианином. Как бы я не пытался его переубедить, он стоит на своем и не хочет меня слушать. Можете ли вы мне что-нибудь посоветовать?\n– Я спрошу у Бога, может он даст ответ.\nРаввин пошёл в свою комнату молиться. Через несколько минут он возвращается и говорит: "У Бога такая же проблема"',
    'Играет команда муравьёв с командой слонов. Слоны ведут 50:0, но вдруг на поле выходит сороконожка за команду муравьёв и забивает раз за разом. Счёт уже 50:51 и капитан слонов спрашивает: " какой хороший игрок, почему ты его раньше не выпустил?" муравей отвечает : так он ботинки зашнуровывал',
    'Парень собирается на дискотеку в деревне. Надеть есть что, а обуть нечего. У отца новые туфли есть, парадные... лакированые. В коробочке стоят для особого случая. Ну он отца три часа упрашивал. Короче выпросил под страхом страшных пиздюлей от отца. Приходит, модный весь такой. Подваливает к телке в миниюбке и говорит: \n- Хочешь угадаю, какого цвета у тебя трусы?\n- Ну попробуй…\nОн в свой туфель как в зеркало глядь и говорит:\n- Красные!\nТелка в шоке. Метнулась к подруге, рассказала всë. Та предлагает:\n- А давай махнемся труселями?\nМахнулись. Девка опять к нему. \n- А сейчас угадаешь?!\nНу Вася в туфлю. И выдаёт:\n- Зеленые!\nДевка снова в шоке. Рассказала все подруге.Та:\n- А ты вообще сними трусы...\nСняла и к парню.\n- А сейчас угадаешь?!\nВася в туфлю глянул и упал в обморок. Девка его по щекам: \n- Вася, что случилось?!\nПацан очнулся и резко давай туфлю осматривать... Выдохнул\n- Бляяя... Думал туфли порвал.',
    'Вступил гитарист в группу. Барабанщик его в курс дела вводит.\n— Женщин в группе нет, дрочи, но если совсем припрет, у нас есть басист-пидорас.\n— Да не, я не такой.\n— Ну, смотри...\nЧерез месяц гитарист уже озверел и подходит к ударнику:\n— Помнишь, насчет басиста ты говорил. Но пусть это будет тайной, чтоб больше никто не узнал.\n— Не получится. Узнают минимум два человека, кто будет его держать, пока ты его ебешь.\n— Но вы же сказали, что он пидорас...\n— Конечно, пидорас. С ритма сбивается постоянно!',
    '-Что общего между зевсом и наркоманом?\n-Оба по ночам долбят геру\nАнон',
    'Молодая мама с очень маленьким сынишкой едут в автобусе.\nАвтобус проезжает мимо зоопарка.\nСынишка, глядя в окно, говорит маме:\n- Мама, па-а-ак!\n- Да, сыночка, это зоопарк.\n- Мама, там зе-е-еи!\n- Да, моё солнышко, там звери.\n- Мама, там зя-я-яны!\n- Да, мой милый, там обезьяны.\n- Мама, там ебут!!!\nМама, едва сдерживая смех, отвечает:\n- Рот твой ебут, щенок',
    'Был один парень, которого заколдовал колдун и он мог говорить только одно слово в год. И вот, он 4 года не говорил ни слова и собрал 4 слова, подошел к колдуну и сказал: \n– Приходят русский, немец, еврей \nКолдун не выдержал и расколдовал его',
    'Посадили как-то двух звукорежиссеров в тюрьму. В одну камеру на 20 лет. Ну, в общем, отсидели они, вышли на волю, перед воротами тюрьмы еще минут 15 про эквализацию попиздели и по домам разошлись.',
    'В кружке талантов дети пели песню разным странам. Валера Испании, Женя Франции, Слава Украине',
    'Встретились Хой, Цой, Горшок и Летов, ну и вздумали бухнуть. Купили литруху, и говорят — мы же поэты — давайте кто сколько в стихах попросит, тому столько и нальём.\nГоршок встаёт:\n— Замученный дорогой, я выбился из сил,\nИ в доме лесника налить мне рюмку попросил!\nНалили ему рюмку.\nВстаёт Цой.\n— Группа крови — на рукаве!\nВы налейте мне рюмку! А лучше две!\nНалили ему две.\nХой встаёт:\n— Из колхозной молодёжи панковал один лишь я!\nНаливайте мне три рюмки, щас нажруся как свинья!\nНалили ему три.\nЛетов встаёт:\n— Гречневым чавканьем сильной личности\nСловесного поноса рьяной кавалерией\nТы забейся в сочные ямочки\nВ мягкие дырочки\nПулями оставленные\nВедь лучше стучать, чем перестукиваться\nАнонимная философия продавшихся заживо\nЗа колоссальный бесценок\nЗаживо погребённых\nВ летнюю резину изношенных прокламаций\nОбильно смоченных психоанализом\nЕдиным фронтом опочил всуе\nСнулой рыбкой растраченной потенции\nТы, ведущий, бля, на новые подвиги!\nМёрзлой веточкой опьянения\nКовырни, ковырни в мыльном вареве\nНевыносимо невинного прошлого\nВ мыльном вареве хлеба съеденного\nА небо всё точно такое же\nКак если бы ты не продался...\n— Егор, а наливать–то тебе сколько?\n— ААААА, ТВОЮ МАТЬ, КТО ЗДЕСЬ?!',
    'Диверсанту объясняют задание:\n- тебя сбросят на парашюте, приземлишься на поляне. Подъедет телега и отвезёт тебя на явочную хату.\nПонял?\n- Понял\nВыпрыгнул из самолёта, дёргает кольцо- основной не раскрывается. Дёргает запасной - и там хуй ночевал.\nЛетит и думает:\n- Ну ёб твою мать, если ещё и телеги не будет..',
    'Старый пилот морской авиации пришел в ка­фе и заказал чашечку кофе. Он был в люби­мой пилотской куртке. Тут к нему подсела молодая женщина. Она спросила:\n- А вы настоящий пи­лот?\n- Ну, я практически всю свою жизнь пров­ел в различных самол­етах, летал во време­на Второй мировой и Корейской войны. Я обучил более 260 моло­дых пилотов. Так что я думаю, что у меня есть все основания считать себя настоящим пилотом. А кто ты?\nДевушка ответила:\n- Я лесбиянка. Вы знаете, я целыми днями думаю о голых же­нщинах. Первая моя мысль по утрам – о ни­х. Принимая душ, я тоже думаю о голых же­нщинах. Смотря телев­изор, я тоже думаю о голых женщинах. Каж­ется, что все вокруг наводит меня на мыс­ли о голых женщинах.\nПосле этого признан­ия они пили кофе в тишине. Через некотор­ое время к ним за столик подсел молодой человек и спросил у старого летчика:\n- Скажите, а вы нас­тоящий пилот?\nОн ответил:\n- Я всегда думал, что да, но только что узнал, что я – лесб­иянка.',
    'Концерт Моргенштера. \nВдруг выстрел из зала, пуля пролетев мимо Моргенштера попадает в декорации. \nПолиция скрутила стрелка и стали допрашивать:\n—Ты же стоял так близко, почему не попал? \n—Да каждый дергает: "Дай я стрельну, дай я стрельну..."',
    'Приехал один русский в Америку, пришёл к индейцам с предложением\nкупить у них землю, обратился к вождю племени.\nВождь: - Земля у нас дорого стоит.\nРусский: - Так я заплачу. \nДостаёт кучу разных бус.\nВождь: - Это что такое?\nРусский: - Бусы.\nВождь: - Давай лучше деньгами.\nРусский достаёт пачки денег и предлагает вождю.\nВождь: - Это что?\nРусский: - Русские деньги - рубли.\nВождь: - Нет, тогда лучше давай бусы.',
    'Сын задаёт отцу вопрос\n-"Папа, а что такое альтернатива?"\nОтец:\n-"Ну смотри сынок, есть у тебя 100 рублей. Ты идёшь в магазин и покупаешь живую курицу за 100 рублей, а она берёт и сносит яйцо, ты яйцо продаёшь за 10 рублей. После десяти продаж у тебя вновь 100 рублей и ты покупаешь вторую курицу. Теперь у тебя две курицы и они начинают носить яйца. Со временем, у тебя появляется 10 куриц, 20...30...100 и вот ты уже богатый фермер и в уме считаешь свои деньги, затем тратишь их, но вдруг, ураган... Страшный торнадо... И вся твоя ферма разрушается и все курицы погибают, а ведь ты уже посчитал прибыль и потратил эти деньги в уме, представляешь? Вот так в жизни бывает сынок..."\nСын:\n-"Папа, так а что же такое альтернатива? Я так и не понял.\nОтец :\n-" ааа, альтернатива... А альтернатива, сынок, это утки."',
    '— Алло, это мясник?\n— Да.\n— А у вас есть свиное рыло?\n— Да.\n— А у вас есть свиные уши?\n— Да.\n— Ну и видок тогда у вас. Охуенный!',
    'Пришел студент в столовую, а все столики заняты. Подсаживается к профессору, а тот говорит:\n- Гусь свинье не товарищ.\nСтудент:\n- ААААА, БЛЯТЬ, ГОВОРЯЩАЯ СВИНЬЯ!!!',
    'Родился в семье мальчик. Немой. Год молчит, два, пять, восемь лет молчит. В один прекрасный день мама налила сыночку тарелку супа. Сидит, смотрит, как сын ест. Вдруг сын кладет ложку и говорит: \n- Суп несоленый! \n- Господи, заговорил, заговорил! \n- Да я всегда говорил. \n- А что же ты МОЛЧАЛ ВОСЕМЬ ЛЕТ!? \n- Да просто все нормально было...',
    'Однажды Будда сидел на берегу реки и ждал лодочника, чтобы переправиться на другой берег. К нему подошёл индийский йог и сказал: \n«Ты сидишь и ждёшь, а я могу перейти реку по воде!» \n И немедленно промчался на тот берег и вернулся обратно, чтобы увидеть, какой эффект произвели его действия.\nБудда спросил:\n«Как тебе удалось этого достичь?»\nЙог ответил: \n«Я подвергал себя жестоким аскезам, погружался в глубины медитации, тренировался всю жизнь, и вот, на старости лет у меня наконец получилось». \nВ это время к берегу подошла лодка, и Будда обратился к лодочнику: «Скажи, сколько стоит переправа?» \nЛодочник ответил: \n«Три гроша». \nБудда повернулся к йогу и сказал:\n «Вот цена твоей жизни». \n"Ты еблан? Я, только туда и обратно сходив, 6 грошей сэкономил." — ловко парировал йог.',
    'Идет русский, видит из речки кто-то пьет, русский кричит:\n– Мужик, не пей, сюда все отходы и канализация сливаются\n- Як тi сказав?\n– Говорю двумя руками черпай, вода горная!',
    'Идут два друга из магазина, один из них тащит ящик с минеральной водой. Второй спрашивает первого:\n- Слушай, а зачем тебе целый ящик минералки?\n- А это для деда.\n- В каком смысле для деда? Для лечения или что?\n- Не, раньше мой дед выпивал по бутылке водки в день, и знаешь, что мы сделали? Подменили ему водку на минералку, а он и не заметил. Теперь я каждую неделю хожу за ящиком минералки, чтоб водку деду подменять.\nВторой друг удивляется:\n-А ловко вы это придумали! У нас дед тоже по бутылке водки в день раньше выпивал, и знаешь, что мы сделали?\n- Что?\n- Похоронили его.',
    'Штирлиц с Навальным пили водку и вдруг Навальный отрубился\n"Новичок"- подумал Штирлиц',
    'Идет нарик по пустыне, навстречу едет бедуин на верблюде:\n— Эй, парень, у вас здесь что — гололед? \n— Ты чего, идиот, какой тут гололед?! \n— А че столько песка насыпали?',
    'В семье с фамилией Табуретке случилось горе. Сын пошёл в армию...',
    '-Скажи 2 доллара\n-Два доллара\n-Остоси у тракториста',
    'Мать привела девочку к гинекологу.\nГинеколог спрашивает: "на что жалуетесь ?"\nМать отвечает: "да вот, Леночку мою по утрам тошнит, все время ей хочется солененького, голова у нее кружится"\nГинеколог осматривает девочку, говорит: "ну диагноз мне ясен, она беременна"\nМать возражает: "ну никогда в жизни, моя Леночка дома сидит, на парней вообще не смотрит."\nДоктор встаёт со стула, поворачивается к окну и долго туда смотрит.\nМать недоумевает: "что происходит?. Что вы там смотрите, доктор?"\nГинеколог разворачивается и говорит: "Обычно в таких случаях на востоке должна взойти звезда и три мудреца должны нести дары".',
    'Мужчина подсаживается к женщине и говорит:\n— Простите, а вы журналистка?\n— Да. А как вы догадались?\n— У вас лицо тупое.\nЖенщина обиженно:\n— А у вас лицо тоже тупое!\n— Я знаю, я тоже журналист.',
    'Психиатр выходит из своего кабинета и видит, что множество больных бегают и шепчут: \n-31,31... \n-Что 31?-спрашивает психиатр. \nВсе показывают наверх. Психиатр поднимается на крышу: там тоже больные бегают и шепчут: \n-31,31... \n-Что 31?-спрашивает замученный психиатр. \nВсе показывают вниз. Психиатр подходит к краю крыши и смотрит на землю. Его сталкивают: \n-32,32..',
    '– Кто там?\n– Сантехник пришел, ебать вашу дочь.\n–Кто?\n– Сантехник пришел, ебать вашу дочь!\n– Пошел от сюда нахуй, придурок!\n– Ну и сидите без унитаза, ебать вашу дочь!',
    'Группа студентов медиков в морге на вскрытии: лежит тело, препод спрашивает причину смерти.\nСтуденты:\n- Ну-у... Колото-резаных ран нет, значит не зарезали...\n- Э-э-э... следов удушья нет, значит не задушили...\nИ тут один студент-прогульщик, любящий выпить, ещё и с перегаром после прошлой ночи, говорит: она умерла, потому что утонула.\nПрепод: Молодец, а как вы это определили?\n- А мы с мужиками вчера с неё ведро раков сняли',
    '1. Ебет отец слепого сына и говорит\n-видишь как плохо что мама умерла\nСынок отвечает\n-нет не вижу\n\n2. Ебет слепой сын отца, а отец и приговаривает:\n-блять чето не то\n\n3. Ебет отец сына с пупком вместо гайки и у него отваливается жопа\nОтец говорит\nВидишь как плохо что ты анеком ошибся\n\n4. Ебет отец мертвую мать, а слепой сын подглядывает\n\n5. Сидит отец дрочит и приговаривает\nЧе ж вы все дохнете то а\n\n6. Ебет отец слепого сына и приговаривает\nВидишь как плохо что мама умерла\nВижу отвечает сынок\nСын на самом деле был зрячим\n\n7. Ебутся два слепых сына а один и говорит\nА знаешь я и не слепой на самом деле\n\n8. Ебет сын слепого отца, а отец и говорит\nБлять это вообще нихуя не правильно\n\n9. Познакомились два гея на вечеринке. Один слепой, второй старый. Приехали домой. Ебутся. Тут старый и говорит:\n-Знаешь у меня жена недавно умерла\n-Папа?\n\n10. Отец ебет мать. В соседней комнате спит полностью здоровый сын.',
    'Штирлиц склонился над картой мира. Его неудержимо рвало на родину.',
    'Идет панк с подружкой по улице. Проходят мимо ювелирного.\nПодружка:\n- Ух ты, смотри какое кольцо с брюликом! Хочу!\nПанк берет кирпич и хуяк его в витрину. Взяли кольцо, идут дальше.\nПодружка:\n- Ух ты, смотри какая курточка кожановая, с заклепками! Хочу!\nПанк берет кирпич. Еблысь его в витрину. Взяли куртку и идут дальше.\nПодружка:\n- Ой, смотри какой Мерседес стоит! Хочу!\nПанк:\n- Да ты че, коза, думаешь, что я эти кирпичи рожаю, что ли!?',
    'Приходит Чапаев к Фурманову и говорит:\n- Вот ты, Фурманов, такой умный мужик, скажи мне что такое логика?\n- Смотри, вот идут два человека, один чистый, другой грязный. Кто из них идет в баню?\n- Не знаю.\n- В баню идет грязный, он потому и идет в баню, чтобы помыться. Понятно?\n- Да.\n- Вот это и есть логика.\n- Хорошо, а скажи тогда, что такое диалектика?\n- Смотри, вот идут два человека, один чистый, другой грязный. Кто из них идет в баню?\n- Грязный.\n- Нет, в баню идет чистый, он потому и чистый, что постоянно ходит в баню. Понятно?\n- Да.\n- Вот это и есть диалектика.\n- Хорошо, а что такое философия?\n- Смотри, вот идут два человека, один чистый, другой грязный. Кто из них идет в баню?\n- А xуй его знает.\n- А-а-а, вот это и есть философия.',
    'Приходит улитка в бар, а ей бармен отвечает:\n-Мы улиток не обслуживаем!\nИ выкинул её. Она через неделю приходит и говорит :\n-Нахуя ты меня выкинул',
    'Лежат на крыше два кирпича: молодой и старый.\nМолодой говорит:\n-Давай спрыгнем?\n-А может не будем?\n-Ну давай!\nПрыгнули. А внизу мужик шел.\nМолодой:\n-Ох, хана нам! Мужик-то в каске.\nСтарой отвечает:\n-Вечно вас, молодых, учить надо. -Эй, мужик!\nМужик поднимает лицо кверху\n-Чего?',
    'Идут одноглазый ежик и слепой крот к бабушке. Ну, значиццо, одноглазый ёжик ведёт, слепой крот за ним следом. Идут, идут, вдруг коряга. Одноглазый ёжик споткнулся, упал и прям глазом на ветку:\n—Все бля, приехали.\nКрот:\n—Привет бабуля!\nЁжик:\n—Да нет же, я на сук напоролся!\nА крот:\n— Оооо, Здравствуйте девочки!',
    'Была засуха, звери собрались на водопой и был у них такой уговор: "Кто расскажет плохой анекдот того выгонят и не дадут ему воды."\nПервый день:\nРассказывает заяц анекдот. Все смеются, один жираф не смеётся. Прогнали зайца и не дали ему воды.\nСледующий день:\nРассказывает лиса анекдот. Все молчат, только жираф смеётся. Его спрашивают:"Жираф, ты чего смеёшься?" Он отвечает:"Мне анекдот зайца понравился "',
    'Что говорит еврей пидофил после изнасилования? \n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\nОтдай конфету',
    'Топит Герасим Му-му, та с трудом выплывает:\n\n - Фуууххх, выбралась!\n\nРыбак:\n\n - АААААА говорящая собака!!!\n\nМу-му:\n\n - АААААА говорящий мужик!!!',
    'Сегодня в маршрутке девчушка лет 4х спросила маму:\n— Мам, а зачем за закладкой ехать в другой конец города, если можно просто открыть книгу?\nС мамой показания давала половина маршрутки.',
    'Фейсбук готовит кибератаку на важнейшие сервисы, гендиректоры-мультимиллиардеры решают кого дудосить.\n-А давайте госуслуги, вконтакте и телеграм. \n-А почему их?\n-А мы других сильных конкурентов не знаем.\n-Давайте! \nНу начали хакать, позвали самых крутых юзеров даркнета, сидят в суперкомпьютерах, строчки набирают. Завершили код.\nНавели курсор, нажимают Enter. Как ебанет! Кругом баги, глюки, ничего не грузит, ошибки вылезают, у всех мышки из рук повылетали. \nЦукерберг весь чумазый встает, оглядывается:\n-Нихуя себе! Представляю что сейчас в рунете творится…',
    'Однажды у учителя русского языка спросили, как будет "убиваю" в прошедшем времени.\nОтвет убил.',
    'Бабка, наркоман и моряк едут в автобусе. Бабуля просит наркомана открыть форточку, тот поворачивается к моряку и говорит:\n— Эй, солдат, форточку открой, жарко же!\nА тот ему:\n— Какой же я тебе солдат, я моряк.\nНаркоман поворачивается к бабке:\n— Бля, бабка, ты чё, ебнулась, мы на подводной лодке.',
    '- Ватсон, вы гей.\n- Как вы узнали, Мистер Холмс? \n- Я вас ебу, Ватсон.',
    'В Ереванское КБ приезжает японская делегация. Главный инженер-армянин рассказывает:\n— Вот тут у нас сидят 8 инженеров, вот тут 12, вот тут 16.\nЯпонец:\n— А у нас на весь завод приходится всего 7 инженеров!\nДелегация уезжает, главный инженер задумчиво идёт домой, задумчиво ужинает, ложится в кровать, ворочается полночи и думает:\n— Ну шесть понятно. А с кем седьмой в нарды играет?!',
    'На полигоне запускают ракеты во время разрядки СССР и СЩА. А на заборе 2 вороны сидят. Первые запускают ракету Советы. Тогда ворона спрашивает: "Как думаешь: полетит?". "Полетит" - отвечает другая.\nВ итоге обратный отсчёт 3..2...1...ПУСК - полетела.\nПотом американцы готовятся к запуску. Снова вороны обсуждают полетит или нет:\n-Как думаешь полетит или нет?\n- Нет, не полетит.\n-Почему?\n-Да не полетит и всё!\nОбратный отсёт 3..2..1..ПУСК и ракета пшикнула и падает.\nТогда ворона другой и говорит:\n- Ну, дура, накаркала!\n-Служу совесткому союзу!',
    'ну и отбронетранспортерили всем строем прапорщика в сраку',
    'Одинокая женщина звонит в эскорт-службу:\n- Скажите а у вас есть накачанные мужчины?\n- Конечно!\n- А накачанные и красивые?\n- Все такие!\n- А накачанные красивые и стильные?\n- Есть!\n- А вот из этих накачанных красивых и стильных есть такие, которые долго не кончают?\n- Есть!\n- А есть такие чтобы долго, долго, долго, долго не кончали!\n- Есть такой, берёте?\n- Да! Давайте!\nПолчаса спустя. Звонок в дверь. Она открывает, а там стоит накачанный красивый молодой, весь от Кавалли и Гуччи, даже носки Бриони и т.д.\nЗаходят в спальню, она ложится на кровать, а он в это время отшвыривает цветы, и начинает ВСЁ НА СЕБЕ РВАТЬ, костюм в труху, рубашку на тряпки, всё рвёт на себе, она:\n- ЧТО ВЫ ДЕЛАЕТЕ? ЗАЧЕМ ВЫ ЭТО РВЁТЕ?\n- ДА ПОТОМУ ЧТО КОГДА Я КОНЧУ, ЭТО УЖЕ ВЫЙДЕТ ИЗ МОДЫ!',
    'Едет скорый поезд на полной скорости. Вдруг он съезжает с рельс, проскакивает лесополосу, кукурузное поле и вновь возвращается на рельсы. Обалдевшие пассажиры спрашивают у машиниста:\n- Что это было?\n- Едем, смотрю мужик на рельсах срет.\n- Так давить надо было!\n- Так вот только в кукурзе и догнали!',
    'Военные действия. Где-то.\nБой закончился. Трупы/кишки кругом.\nИдёт наемник в камуфляже, рукава закатаны, осматривает последствия.\nСлышит из воронки слабый голос: Эй, братуха.\nНаемник подходит к воронке и видит, в ней лежит солдат без ноги, в крови весь, стонет: Братуха, добей, не могу больше, ну добей.\nНаемник снимает с плеча гранатомет и дает в воронку залп по несчастному. Взрыв.\nНаемник уходит. И слышит вслед: Спасибо, братуха.',
    'Загадка: \nТы берешь в долг у мамы 250 рублей, и у папы 250, всего у тебя 500 рублей. \nИдешь в магазин и тратишь там ровно 450руб. \nПо дороге домой ты даешь в долг другу 30 рублей (ему не хватало на пиво). \nУ тебя остается 20 рублей. \nТы приходишь домой, отдаешь долг маме - 10 рублей и папе - 10 рублей \nТеперь ты должен им по 240руб. \nИтог: 240 240 равно 480, и 30 рублей тебе отдает друг, получается 510 ЛЕТ, ПОТОМУ ЧТО ВАМ ПОНАДОБИТСЯ ИМЕННО СТОЛЬКО ЛЕТ, ЧТОБЫ ОПЛАТИТЬ КОМПЛЕКТ СИЛОВОЙ БОЕВОЙ БРОНИ МОДЕЛИ 2, КОТОРЫЕ ВЫ ПОТЕРЯЛИ! Доложите об этом в арсенале, получите новый комплект, а потом вернитесь и доложите мне, рядовой! Свободны!"',
    'Гитлер очень любил сливы и никогда их не ел. Он все время ходил возле витрин и смотрел на них, облизываясь. Мама это знала и в один день купила пакет слив. Гитлер все ходил возле них, никак не решаясь взять одну, но, наконец, решился и взял одну сливу. Мама это видела и сказала папе. За ужином папа спросил:\n— Кто съел сливу?\nВсе говорили, что не ели, а Гитлер, покраснев, сказал:\n— Я не ел сливы.\nНа что папа ответил:\n— Плохо не то, что съели одну сливу. Плохо то, что с нами за одним столом сидит Гитлер.',
    'Летят к земле два парашютиста, молодой и опытный. Молодой: - Дядя Артур, можно уже за кольцо дёргать? Опытный: - Нет, шашки улетят',
    'Админ демонстрирует подписчикам новый анек.\n- Вот, товарищи бойцы, это новый анек. Петров.\n- Я!\n- Посмейся с анека.\nПетров тужится, пыжится, не получается.\n- Не смешно.\n- Сидоров, помоги Петрову.\nПытаются вдвоем, та же ситуация.\n- Не смешно.\n- Иванов, помогай.\nПыхтят втроем. Посмяться не могут.\n- Никак не посмеяться, товарищ командир!\n- А хули вы хотели? Анек категории б!',
    'Решил охотник сходить на охоту в малоизвестный ему лес и взял с собой проводника. Ну вот идут они вдвоем, проводник спереди топором дорогу прорубает, а охотник с ружьем сзади. И вдруг увидел проводник медведя, замер, ну и медведь, собственно, тоже остановился. Проводник тихим голосом шепчет охотнику: "Иди сюда". Ответа нет. Чуть повышает тон: "Иди сюда". Снова тишина. В третий раз уже чуть ли не в полный голос вымолвил: "Блять, иди сюда". Охотник недоумевая спрашивает: "Нахуя ты его зовешь?"',
    'У рядового Иванова умер отец. Пришла телеграмма в часть. Полковник вызывает старшину и говорит:\n— Слушай, такое дело, ты скажи Иванову про отца, только как-нибудь поделикатней.\n— Будет сделано!\n\nСтаршина выстраивает роту и говорит:\n— У кого живы отцы шаг вперед. Иванов! Ну ты-то куда прешь?',
    'Жил-был один богач. И как-то этот богач возвращался домой через поля, а там мужик работает. Ну, и присели оба в тенечке, да разговор завели.\nСпрашивает богач:\n— Слушай, мужик, вот ты пашешь, пашешь, денег-то хватает тебе?\n— Хватает, — отвечает тот.\n— А куда ты их деваешь? — не унимается богач.\n— Нуу, на одну треть долг возвращаю, еще треть в долг даю, остальное в воду бросаю, — ответил мужик и ушел дальше пахать.\nПожал плечами богач, да тоже домой поехал. Но мысль о таком странном распределении заработанных денег не давала ему покоя. Задумался сильно, аж приболел. А была у того богача жена премудрая-премудрая. И жена спрашивает, мол, что с тобой, богач. Богач поведал ей тот разговор и заключил, наверное тот мужик дурак был.\nА премудрая жена рассмеялась:\n— Тот мужик просто очень мудро изъяснился, а ты его не понял. Долг отдает, значит, родителям помогает, в долг дает — сыновей растит, а в воду бросает — дочерей растит.\nЗадумался богач и решил того мужика своим советником сделать. В тот же вечер он поехал в деревню за сто верст, с трудом разыскал дом мужика, совсем из сил выбился, смотрит, а тот стоит на берегу и монетки в речку бросает...',
    '- Знакомьтесь, это Вася. Он изучает эритроциты.\n- Да, я изучаю эритроциты, мой отец изучал эритроциты, мой дед изучал эритроциты. Понимаете, эритроциты - это у нас в крови.',
    'Избивают муравьи слона. Один из них взобрался на дерево и кричит:\n- Братва, разойдись! Сейчас ему хребет ломать буду!\nСлон услышал этот крик, но не придал ему значения, потому что считал свою спину достаточно крепкой, чтобы выдержать удар маленького муравья. Однако он забыл что дело происходит в разгерметизированном отсеке космического корабля который летел с ускорением 833333333,3 м/с^2, направленный противоположно той стороне, в которую собрался прыгать муравей.\nМуравей находился над спиной слона в 3 метрах и весил 40 мг, так что при отсутствии сопротивления воздуха во время полёта он имел кинетическую энергию примерно 10^4 Дж у спины слона. В результате прыжка слон оказался убит, а муравей стал героем советского союза посмертно.\n\nШутка в том, что слон услышал крик муравья в разгерметизированном отсеке, а это невозможно.',
    'Маядзуко как-то попивал свой любимый чай и к нему пришёл его ученик.\n\n- Маядзуко, чем жизнь отличается от существования?\n\n- Сейчас я объясню. Пожалуйста, принеси мне мой чайник и две чашки.\n\nУченик принёс ему то, что он просил.\n\n- Теперь налей в обе чашки одинаковое количество чая, но в одну положи сахар, а в другую нет.\n\nУченик сделал это и Маядзуко выпил обе чашки.\n\n- Принеси ещё один чайник и налей в него ещё две чашки чая. Одну чашку сделай с холодным чаем, другую горячей.\n\nУченик сделал это и Маядзуко вновь выпил обе чашки.\n\n- Принеси ещё один чайник, налей ещё две чашки чая. В одну положи клубнику, в другую - смородину.\n\nУченик сделал это и Маядзуко опять выпил обе чашки.\n\n- Нихуя я чая напился - сказал Маядзуко.',
    'Возвращается Василь Иваныч с задания, ну и спрашивает Петьку:\n- Ну как, Петь, у вас дела-то? Всё нормально без меня было?\n- Да всё отлично, Василь Иваныч. Только собака сдохла...\n- Как же так?\n- Дак мяса объелась и сдохла...\n- Да как это так, тут солдатам жрать нечего, а у вас собака мясом объелась!\n- Да просто конюшня сгорела, вот она и объелась...\n- Как это сгорела?!\n- А там Фурманов курил, не затушил сигарету, вот и сгорела...\n- Да что ты несёшь, Петька, Фурманов сроду не курил!\n- Да а как тут не закуришь, когда полковое знамя спиздили!',
    'Мама упрашивает 7-летнего ребёнка выпить топленого молока, уверяя его о полезности продукта:\n- Сынок, ну выпей!\n- Нет, мама, не буду!\nМама продолжает настаивать с прежней силой:\n- Для детей в твоём возрасте полезно, выпей, сынок, сил наберёшься!\n- Не люблю я молоко, мама, не люблю... - уже почти плача, отнекивается сынок.\nМама всё не унимается:\n- Сына, ну выпей молочко... - почти умоляюще говорит она.\n- Кому молочко, а кому хуи гигантские в очко, - ловко парировал недовольный ребёнок.',
    'Крутой джазовый бар проводит конкурс на лучшего исполнителя, которого возьмут на работу. Собирается толпа музыкантов и среди них старый негр. \nВыходит и говорит: \n— Эта песня называется "Я буду дрочить на тебя всю ночь!" \nИграет восхитительный блюз, после которого половина музыкантов сразу собираются и уходят, другие просто плачут от восторга! \nСтарый негр говорит: \n— А следующая моя песня называется "Соси у меня, сука, пока я не кончу!" \nИ играет блюз еще круче от которого оставшиеся музыканты единогласно отказываются от участия в конкурсе. \nВладелец заведения говорит \n— Мы вас берем, только не могли бы вы не называть своих песен, а они немного… нуу... шокируют. \nНегр соглашается. \nИдет очередной концерт, негр забыл заправиться, и у него елда торчит из штанов. Он садится за рояль, играет. Хозяин заведения замечает эту оплошность, подходит к нему, говорит: \n— У тебя хуй видно, знаешь? \nНегр: \n— Что? Знаю ли я её?! Да я её написал!',
    'Урок в школе. Молчание. И тут Вовочка орёт:\n-Марь Иванна!\n-А? - отвечает Мария Ивановна\n-Хуй на.\nНедовольная ответом, учительница выгоняет Вовочку из класса.\nСледующий день.\n- Марь Иванна!!\n- Что?\n- Хуй те на плечо.\nСнова выгоняет из класса. Следующий день, Вовочка вновь приходит к ней.\n-Марь Иванна!\n-Я тебе больше не отвечу, нет!!\n-Шлюхи ответ!\nНедовольная учительница вызвала отца мальчика в школу.\n-Ну шо ш поделать, Марь Иванна, разберуюсь я с ним дома.\n-Да? - спрашивает учительница\n-Пизда.',
    'Садится Штирлиц в такси и говорит:\n- Трогай!\nТаксист потрогал и сказал:\n- Ого.',
    'В дверь постучали 0 раз.\n\n«Отец» – подумал я',
    'Приходит чукча к врачу и просит сделать ему пластическую операцию. \n— Зачем это Вам? - спрашивает доктор. \n— Да понимаете, доктор, по моему лицу сразу видно, что я чукча. И все надо мной смеются, все меня за дурака держат. А чукча\nне дурак, чукча умный! Не хочу, чтобы надо мной смеялись, не хочу больше быть похожим на чукчу! Сделайте мне пластическую операцию! \nВ общем, уломал он доктора. Делает он ему пластическую операцию, а сам и думает: "Интересно, а может быть чукчу все-таки не просто так за дурака все считают? Надо проверить…" Взял он, и вскрыл чукче череп. Глядь — а там всего одна извилина… Все стало доктору ясно, посмеялся он над чукчей, и решил подшутить над ним еще больше, чем это сделала матушка-природа. Взял он эту извилину, да и распрямил… Операцию доделал… \nЧукча от наркоза отходит, подходит к зеркалу, смотрится в него и говорит: \n— Ой, ты дивысь якій гарный хлопец зробился!',
    'Приходит мужик в больницу, говорит, что у него болит локоть. Доктор его отправляет сдавать анализ мочи. Мужик возмущенно:\n- Доктор, какая моча, локоть болит! Доктор говорит:\n- Пришёл лечиться, сказали сдавать, значит сдавай, а не пререкайся.\nНу мужик озлобленный приходит домой, взял мочи у жены, у дочки, у тёщи, у кошки, воды с батареи отопления, добавил и тормозной жидкости с машины, потом пошел и сдал всю эту смесь на анализы. Приходит за результатом, доктор ему и говорит:\n- Кошка у вас абсолютно здорова, за неё можете не переживать. Батареям ремонт ещё не скоро понадобится. У тёщи развивается страшная болезнь, надо делать операцию, дорого и только за границей. За дочь не беспокойся, организм молодой сильный, несмотря на тринадцатилетний возраст, плод сформировался удачно, будет двойня. Чего не скажешь о жене, у жены твоей сифилис уже полгода, и в связи с болезнью она тебе не даёт, и ты в сортире дрочишь, а там тесно, локтем бьёшься, вот локоть и болит. Мужик встаёт и охуевший уходит. Доктор кричит ему вслед:\n-Да и в машине у тебя насрано.',
    'Идёт значит мужчина по аэропорту с чемоданом, подходит к нему полицейский, спрашивает:\n– Героин, анаша, марихуана?\nА мужик и отвечает:\n– Нет, спасибо, у меня у самого этого добра целый чемодан.',
    'Повадился мужик по ночам в морге покойникам выбивать золотые зубы. В очередной раз, только нашел подходящего покойника (2 моста и 3 коронки) как появился сторож. Оставить такую добычу жалко. Он покойника — под мышку и через забор. Выбил зубы кирпичем. А тело приставил к дереву.\nИдут два алкаша. В тени — силуэт.\n(1) — Братан! Дай закурить.\n(2) — Молчит. Значит нас не уважает.\nПервый достает нож и наносит 5 ножевых ранений в живот. Второй щыпает пульс и с ужасом говорит: — Убили!!!\nБерут его под мышки, брасают под проезжающую машину и убегают.\nВодитель конечно затормозил но передними колесами переехать все-таки успел. Возвращаясь от любовницы под видом командировки ему очень не хотелось влипнуть в такую историю. Он перевез тело к железнодорожному переезду и положил на рельсы.\nМашинисты товарного поезда заметили самоубийцу издалека, но тормозной путь оказался длиннее. Бампером локомотива тело было отброшено на 30 метров, ударилось о сосну и сползло.\n(1) — Снимут премию за ЧП в рейсе.\n(2) — Не снимут. Неси его в кабину.\nНикто не заметил, как с поезда на мосту через речку, был выброшен труп.\nДва браконьера тротилом глушили рыбу. Вылавливая добычу им попалось тело неудачника. Ситуация не из приятных. Они положили его в мешок и утром выкинули с 16 этажа своего дома на асфальт перед домом — несчастный случай.\nБабульки-пенсионерки после отправки внуков в садики и школы перед домом обсуждали последние новости когда со свистом перед ними упал несчастный мужчина средних лет. Они-то и вызвали скорую помощь.\nПосле операции которая длилась больше 5 часов вышел хирург и сказал:\n— Случай очень тяжелый, но жить будет.',
    'Ковбой едет по прерии со старым индейским вождем. Ковбой говорит: \n- Это твои кони там пасутся? \n- Угу. \n- У тебя их так много. Подари мне того. \n- Мочамба. \n- Спасибо. \nЕдут дальше. \n- А это твоя земля. \n- Да. \n- Выдели мне несколько акров. \n- Мочамба. \n- Спасибо. Век не забуду. \nДальше выезжают на поляну, где отдыхают хорошенькие индианки. \n- Вождь, а это все твои девушки? \n- Да. \n- А почему ты их не трахаешь? \n- Мочамба не стоит',
    'В больнице очень дерзкому пациенту доктор прописал по ебалу',
    'Еврей приехал в Москву – и сразу в публичный дом:\n\n– Скажите, Роза из Кишинева сегодня работает?\n– Работает.\nОн трахает Розу и платит двести долларов.\nНа следующий день опять приходит, опять спрашивает Розу из Кишинева, опять ее трахает и опять платит двести долларов.\nТо же самое на третий день.\nРоза его спрашивает:\n– Скажите, может быть, вы в меня влюбились?\n– Нет, просто тетя Хая из Одессы просила передать вам шестьсот баксов.',
    'Учительница новая в классе знакомится с учениками:\n\n- Как тебя зовут?\n\n- Сережа Трошин.\n\n- А тебя?\n\n- Лиза Зайцева.\n\nТут смотрит - сидит на самой последней парте маааленький мальчик, бледненький как спирохета. Она его спрашивает:\n\n- Как тебя зовут?\n\nОн так тииихонько:\n\n- Пися камушкин.....\n\n- Как-как?\n\nЕще тише:\n\n- пися камушкин...\n\n-Да что это такое! Встань! И представься как мужчина! Как тебя зовут?\n\nВо всю глотку басом:\n\n- ХУЙ БАЗАЛЬТОВЫЙ!',
    'Матросы прислали в "Что? Где? Когда?" пустой конверт, потому что у матросов нет вопросов.',
    'Лиса, волк и медведь встретились весной и стали обсуждать кто как провел зиму.\nЛиса, побитая и ободранная:\n— Сначала все было хорошо, устроилась возле курятника, воровала по две курочки в неделю, а потом крестьянин курочек посчитал, устроил облаву с собаками, нашли меня - еле живая ушла...\nВолк, тоже покоцанный и хромой:\n— И у меня начиналось здорово, около овчарни жил, по одной в неделю таскал. Пастух по весне посчитал овец, охотников позвал, как уж удалось спастись - прямо не знаю.\nМедведь - толстый, довольный, лоснится весь:\n— А я вот под Москвой возле стройки жил...\nЛиса, Волк:\n— А там-то что?\nМедведь:\n— А там, братцы, хохлы...\nЛиса, Волк:\n— И что?\nМедведь:\n— А их никто не считает...',
    'Два армянина - отец и сын - выходят из дома.\n- Папа, папа, куда мы идем?\n- На охоту, сынок.\n- Папа, папа, у нас же нет ни ружья, ни ножа, даже рогатки нет.\n- Эээ, сынок, ты еще не знаешь, что такое армянский сглаз. Вон, видишь под кустом зайчик сидит. Смотри какой он красивый, мягкий, пушистый, а какие у него красивые глазки, какие красивые ушки, лапки...\nЗайчик вдруг упал и окочурился.\n- О, папа, какой ты умный, какой ты умелый охотник, как ты расправился с этим зайчиком, какой ты молодец... Папа! Папа!! Папа!!!',
    'Сидит английский лорд и читает газету. Тут входит дворецкий\n-Сэр, разрешите войти?\n-Проходите\n-Разрешите подписать некоторое ваши бумаги?\n-Конечно, делайте что хотите\nДворецкий заметив странное, податливое настроение лорда решил воспользоваться ситуацией\n-Сэр, разрешите заняться сексом с вашей женой?\n-Разрешаю\nУдивлённый дворецкий проходит в спальню. Через 20 минут\n-Сэр, сегодня ваша жена как то холоднее ко мне чем обычно\n-Да она и при жизни была не очень',
    'И нападающий прорывается к воротам, и удар, удар, удар, еще удар!\nДаааа… таких пиздюлей наш вратарь еще не получал!..',
    'Какими какашками срут зайчики?\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.',
    'Однажды к отцу пришла дочь, молодая женщина, и с грустью сказала: \n\n — Папа, я так устала от всего, у меня постоянные трудности на работе и в личной жизни, уже просто нет сил... Как справляться со всем этим? \n\n — Давай я тебе покажу. \n\nОтец поставил на плиту 3 кастрюли с водой и принес морковь, яйцо и кофе. Опустил каждый ингредиент в отдельную кастрюлю. Через несколько минут выключил плиту и спросил дочь: \n\n — Что стало с ними? \n\n — Ну морковь и яйцо сварились, а кофе растворился, — ответила девушка. \n\n — Правильно, — сказал отец, — но если мы посмотрим глубже, то здесь таится одна мудрость. Давай засунем все в блендер и ты это съешь. \n\n — Пап, но это же отвратительно. \n\n — Съешь и ты поймешь, к чему я это все. \n\n Дочь съела это блюдо из кофе, моркови и яйца. \n\n — Что ты поняла из этого? \n\n — Что такое я точно никогда не приготовлю. \n\n — Ты упустила самое важное, дочка! - сказал отец улыбаясь. \n\n — Что? \n\n — Я еб*нутый',
    'Маня и Ваня — маляры. Красят они стену многоэтажки на уровне 10-го этажа. Вдруг Ване приспичило по-маленькому.\n— Слышь, Мань! Не могу терпеть!\n— А ты давай прямо с люльки!\n— Да ты шо! Там же люди внизу!\n— А ты перегнись посильнее, как раз вон в фонтан попадешь! — Да я ж наебнусь!\n— Да не! Я тебя держать буду!\n— Крепко?\n— Крепко! Давай!\nНу Ваня встал на край люльки, Маня его сзади за ремень держит, а тот сильно вперед наклонился и облегчается аккурат в бассейн. Красота! И тут Мане приспичило чихнуть! Каак чихнет и ... выпустила Ваню, и ушел он вниз как куль с дерьмом...\n\nПрошло несколько месяцев. И вот в одном американском баре сидят три бабенки и рассуждают, где мужики самые до баб охочие. Первая:\n— Я вот давеча была в Париже, так эти французы проходу мне не давали. Всяк норовил в постель затащить! Это у них в порядке вещей!\nВторая:\n— Нее, самые охочие — это мексиканцы. Была я там недавно. Они там все такие потные, волосатые! Пр! ям глазами раздевают! Сперма аж из ушей прет!\nТретья:\n— Все это ерунда! Самые дикие мужики в России! Вот прикиньте! Пару месяцев назад была я в Москве. Иду по улице мимо фонтана. Вдруг слышу звук сверху. Поднимаю голову и вижу: летит на меня мужик какой-то! Ширинка расстегнута, а он держится руками за член и орет:\n— ПИЗДАААААААААА !!!!!',
    'Встреча выпускников. Ресторан на окраине. Сидят старые одноклассники, сплетнями делятся о тех, кто прийти не смог:\n- А как там Гога Свечкин?\n- Гога в комнате страха работает, видел его пару раз\n- Молодец Гога, хороший парень\n- А Дениска как поживает, который булки на перемене продавал?\n- Да наворовал в нулевые, сейчас завод с бипками держит под Липецком, даже не спрашивай\n- Эх, редкостный козел был, хорошо, что не приехал\n- А Андрюша как поживает? Который козявками тетрадки до девятого класса мазал?\n- Студия у него своя. Фотопортреты в ВКонтакте продаёт.\n- Редкостный козел был, хорошо, что не пришёл.\n- А Мишка как там? \n- В машине сгорел',
    'Вторая мировая война. Немецкий концлагерь. Пленных казнят в газовых камерах. Через весь лагерь бежит немецкий офицер, подбегает к шестой камере. Заключенных уже завели в неё и закрывают дверь. Офицер успевает засунуть ногу между дверью и косяком двери, и спрашивает:\n— Молдаване?\n— Угу.\n— Плитку кладете?\n— Кладем.\n— Положить плитку в ванной сколько за метр возьмете?\n— Да, пять рейхсмарок, пожалуй, возьмем.\n— Давайте за три?\n— Ногу убери.',
    'Студент 20 с небольшим лет попал под автобус, и - насмерть. Очнулся на том свете. В кресле напротив увидел кого-то, похожего на человека, но светящегося изнутри инфракрасным светом. \n-Где я? \n-Ты в аду, сынок. Но не бойся заранее, здесь на самом деле намного лучше, чем описывают там, на земле. Вот ты в жизни курил? \nСтудент опускает глаза: - Да, курил. \n-Ну значит, по понедельникам для тебя будет праздник. Это у нас день курения. Выбор - огромный, от трубки и махорки до дорогих сигар и кальяна. Курим весь понедельник, до поздней ночи. И пофигу астма и рак - ты ведь уже умер! А выпить ты любил? \nСтудент опускает голову: - Не без этого... \n-У-у! Тогда готовься к праздникам по вторникам! Этот день мы пьём весь, с самого утра, от пива и лёгких вин до самых крепких напитков: самогона и спирта. И плевать на печень: ты ведь уже умер! А как насчёт наркотиков? \nСтудент краснеет: - Да, бывало! \n-Что ж, повеселишься по средам! У нас это день наркотиков, от самых лёгких, до тяжелых. И не бойся ни ломки, ни передоза, ни ментов - ты ведь уже умер! А с женщинами? \nСтудент оживляется: - А как же! \n-Тогда оторвёшься по четвергам! Это у нас день повального секса. Дело в том, что женщин в аду в 10 раз больше, чем мужчин, и у тебя будет супервыбор! А о сифилисе там всяком даже не вспоминай - ты ведь уже умер! А не смотрел ли ты аниме? \nСтудент вскидывается: - Смотрел! \n-Бля иди отсюда',
    'Приходит гитарист к доктору:\n- Вы знаете, доктор, у меня проблемы с игрой в последнее время - в ноты не попадаю, ритм не чувствую итд\n- У Вас мозги мокрые слишком стали - давайте их вытащим подсушим. Приходите денька через 3 за ними.\nПроходят 3 дня - нет гитариста. Прохдит неделя, другая - не приходит. Встречает доктор его через пару месяцев:\n- Что же Вы за мозгами не приходите?\n- A зачем они мне ? Я теперь на басу играю',
    'В магазин зашёл грабитель с водяным пистолетом. Кассир сначала смеялся, потом захлебнулся',
    'Мертворожденные дети попадают в Вальгаллу, потому что умирают в схватках',
    '- Мам, когда я вырасту, я хочу стать творительным падежом.\n- Кем?\n- Чем. Творительным падежом, говорю.',
    'Большая армянская свадьба, весь аул гуляет и веселится. Все, кроме одного мальчика. Подходит он к своему отцу и выдаёт следующее: отец, я больше не хочу быть армянином. Отец отвечает: так, давай не при людях, праздник закончится - дома поговорим. Ну а дома происходит скандал, у молодого армянина отбирают все кредитки, машины, шмотки дорогие и выгоняют из дома. Несколько дней блуждает  молодой армянин, не может найти пристанище и возвращается домой, и стоит у порога дома. Навстречу блудному сыну выходит отец и спрашивает: ну что, сынок, все понял?\nА сын ему отвечает: да, пап, понял, ебать вы, армяне, пидорасы.',
    'Молодая пара попадает в автокатастрофу. Муж отделывается легким испугом, а жена попадает в реанимацию. \nПосле долгой изнурительной операции выходит врач, взволнованный муж спрашивает у него: \n— Доктор, как она? Будет жить? \n— Состояние тяжелое. Она жива, но находится в коме. И, боюсь, она останется в этом состоянии много лет. Все это время вам придется ухаживать за ней: кормить по трубке, менять подгузники, мыть, переворачивать каждые 3 часа, чтобы не было пролежней, но все равно рано или поздно пролежни появятся. И спустя много лет она умрет, так и не придя в сознание. \nМуж в полнейшем шоке. А врач добавляет: \n— Испугался, да? Шучу я: умерла она, умерла..',
    'Идет заседание, собралась вся верхушка рейха. Вдруг в кабинет заходит\n\nШтирлиц, идет к сейфу, достает оттуда секретные документы, переснимает, потом ставит на стол вазу с апельсинами и уходит.\n\n— Кто это был, и что он тут делает? - недоуменно спрашивает Гитлер.\n\n— Да это штандартенфюрер Отто фон Штирлиц, русский разведчик.\n\n— А чего ж вы его не схватите?\n\n— Все равно выкрутится — скажет, что апельсины приносил...',
    'Беременная женщина попала в перестрелку. Очнулась в больнице.\nВрач: \n- Женщина не волнуйтесь, все нормально. Вы успешно родили близняшек, но во время перестрелки в вас попали две пули. Одна в мальчика, а другая в девочку.\nЖенщина: \n- Ужас!!!\nВрач: \n- Но, честное слово, эти пули выйдут со временем чисто физиологически.\nЖенщина успокоилась.\nПрошло 14 лет...\nК маме прибегает дочь.\nДочь: \n- Мама! Мама! со мной произошла странная история.\nМама: \n- Какая, дочка?\nДочь: \n- Ты представляешь, я писала, и из меня выпала пулька.\nМама:\n- Дочка, не волнуйся, такая штука происходит с каждой девочкой. Это\nодин из этапов полового созревания.\nДочь успокоилась и убежала.\nПроходит несколько дней. К маме прибегает сын.\nСын: \n- Мама! Мама! Со мной произошла странная история...\nМама: \n- Какая сынок? Ты писал и из тебя выпала пулька?\nСын: \n- Нет! Я дрочил и застрелил бабушку!',
    'Приходит дембель домой в родное село а его и спрашивают: \n- Как там в армии то? \n- Да дебелизм сплошной! \n- А это как? \n- Завтра покажу! Наутро в 4 часа звонит колокол. Все село сбежалось в ужасе. Дембель вышел и кричит: \n- Мы с батей за дровами, остальные разойдись',
    'Японцы изобрели часы, которые услышав мат перескакивают на минуту вперед.\nРешили опробовать.\nПовесили в японский бар на 24 часа.\nЧерез 24 часа приходят, часы идут на 2 минуты вперед.\nПовесили в английский бар. Через 24 часа приходят, часы идут на 5 минут вперед.\nПовесили в русский бар. Через 24 часа приходят, часов нет! Они подходят к бармену:\n- Мы вчера сюда часы принесли, где они?\nБармен:\n- Какие часы?\n- Ну вот тут на стене висели\n- А блять, это они висели, а я то думал: нахуя нам ебаный вентилятор в пиздец какую холодную зиму',
    'Почему феминистка не может решить проблему гендерного неравенства? \nНеравенства с двумя неизвестными в восьмом классе не проходят',
    'Приходят русский с хохлом в японский ресторан.\nИм несут заказ и русский решил забрать часть суши у хохла',
    'Идут по дороге белоснежка, дюймовочка и Шевцов. Белоснежка говорит:\n\n– Вот я самая красивая – самая офигенная.\n\nДюймовочка говорит:\n\n– А я самая маленькая и самая прикольная.\n\nШевцов говорит: – А я самый успешный и харизматичный блогер. \n\nИдут дальше смотрят дом, а на доме написано – зеркало правды. Заходит туда Белоснежка. Выходит – рыдает.\n\n– Я на самом деле не самая красивая – оказывается еще есть Спящая красавица!\n\nЗаходит Дюймовочка. Выходит тоже рыдает.\n\n– Я на самом деле не самая маленькая!\nИ злобно так покосилась на Шевцова.',
    'Стоит обдолбанный наркоман на балконе. Вдруг видит, над горизонтом несется огромный огненный шар. Наркоман обалдел, рот разинул. Шар скрылся, вдруг появляется следующий такой же и тоже проносится по небосклону. Тут же появляется третий огненный шар. Наркоман уже ничего понять не может, думает, пора попуститься. Идёт на кухню к маме:\n- Слушай, мам, дай покушать.\n- На, сынок, покушай, конечно, а то уже три дня на балконе стоишь!',
    'Москва. Зима. Время дефицита. Приезжает иностранная делегация, и нужно показать, что в СССР всё хорошо.\n\nНа Верху решают, что нужно устроить распродажу черной икры. Выбирают магазин поближе к  центру и объявляют акцию, обвешивают магазин плакатами:\n\n"Чёрная икра по 40 копеек!"\n\nВ день распродажи, с 5 утра начинает собираться толпа, несмотря на мороз. Ещё бы - икра по 40 копеек. К открытию магазина очередь становиться уже довольно большой.\n\n9.00 - Открываются двери магазина, выходит директор и громко говорит: "Товарищи! Скоро начнется распродажа черной икры по 40 копеек!", и уходит. Все обрадовались и засуетились.\n\nМороз. Мимо проходят иностранцы и удивляются щедрости.\n\n11.00 - Открываются двери магазина, выходит директор, оглядывает взглядом толпу и говорит: "Товарищи! Скоро начнется распродажа черной икры по 40 копеек, но на всех не хватит! С Верху пришло решение - икру евреям не продавать!". Евреи повозмущались, но толпа начала кричать: "Правильно! Убирайтесь, жиды!" Евреи начали расходиться. Директор закрыл дверь и ушел.\n\nМороз. Мимо проходят иностранцы и удивляются щедрости.\n\n13.00 - Открываются двери магазина, выходит директор, оглядывает взглядом толпу и говорит: "Товарищи! Скоро начнется распродажа черной икры по 40 копеек, но на всех не хватит! С Верху пришло решение - икру беспартийным не продавать!". Беспартийные повозмущались, но толпа начала кричать: "Правильно! Убирайтесь!" Беспартийные начали расходиться. Директор закрыл дверь и ушел.\n\nМороз. Мимо проходят иностранцы и удивляются щедрости.\n\n16.00 - Открываются двери магазина, выходит директор, оглядывает взглядом толпу и говорит: "Товарищи! Скоро начнется распродажа черной икры по 40 копеек, но на всех не хватит! С Верху пришло решение - икру продавать только ветеранам войны!". Все уже изрядно замерзли, махнули рукой и пошли. Остались только ветераны войны. Директор закрыл дверь и ушел.\n\nМороз. Мимо проходят иностранцы и удивляются щедрости.\n\n19.00 - Открываются двери магазина, выходит директор, оглядывает то, что осталось от толпы и говорит: "Товарищи! Скоро начнется распродажа черной икры по 40 копеек, но на всех не хватит! С Верху пришло решение - икру продавать только ветеранам гражданской войны!". Все ушли - остался один человек. Директор закрыл дверь и ушел.\n\nМороз.\n\n21.00 - Открываются двери магазина, выходит директор, видит, что стоит один старик - ни живой, ни мертвый. Подбегает к нему, берёт за плечи и ведёт в магазин. Наливает стакан водки. Старик выпивает, и понемногу отходит.\n\nДиректор начинает:\n— Понимаешь мужик, страна в упадке, нет ничего, а тем более икры, мы эту акцию для иностранцев сделали.\n\n— Да, понимаю я всё, — говорит замерзшим голосом старик, — понимаю, всё, кроме одного:\n\nПочему вы евреев первыми отпустили?',
    'Женщина и её любовник находились в доме, пока муж был на работе. Её девятилетний сын вошел в комнату и, видя, как они занимаются любовью, спрятался в шкаф и оттуда подглядывал. Внезапно входит муж. Жена прячет любовника в шкаф, не зная, что её сын там. \nМальчик: \n––Темно здесь. \n––Да. \n— У меня есть футбольный мяч. \n— Это хорошо. \n— Вы не хотите его купить? \n–– Нет, спасибо. \n–– Мой отец снаружи. \n–– Ок, сколько? \n–– 250 долларов. \nСпустя несколько недель мальчик и мужчина снова встречаются в шкафу. \nМальчик: \n— Темно здесь. \n— Да. \n— У меня есть кроссовки. \nПомня, что случилось в прошлый раз, мужчина спрашивает: \n— Сколько? \n— 750 долларов. \n— Ок. \nСпустя несколько дней, отец говорит своему сыну: \n— Пойдем поиграем в футбол. \n— Я не могу, я продал мяч и кроссовки. \n— Сколько ты получил? \n— 1000 долларов. \n— Это ужасно! Как ты мог взять так много денег? Это намного больше, чем они стоят. Это грех, ты должен пойти в церковь и покаяться. \nОтец повел сына в церковь. Мальчик зашел в исповедальню, закрыл дверь и сказал: \n— Темно здесь. \nСвященник: \n— Бля, вот только не начинай опять с этой хуйни!',
    'Прыгает девочка на скакалке, рядом на лавочку подсаживается дедок. Девочка:\n— Дедуль, скажи раз…\nДед:\n— Раз…\n— Ты, дед, пидаpас!\nДед сидит офигевший. Проходит минута:\n— Дед, скажи пять!\n— Пять…\n— Пидаpас опять!!\nДед начинает злится… Еще через некоторое время:\n— Дед, скажи семь!\n— Ну семь…\n— Дед пид@рас ты совсем!!!\nДед теряет терпение… Раздумывает, что б такого сказать:\n— Девочка, скажи двадцать\n-Ну двадцать\n-Пошла нахуй',
    'Умер Летов. Пообсуждали Бог и Черт, куда его отправить и отправили к Черту в ад. Приходит через месяц Черт к Богу и говорит:\n- Забери Летова к себе. У меня черти восстание подняли, за свою оборону требуют беспонтовые пирожки. У тебя в раю все хорошо и для продвижения своих идей у него не будет социальных условий.\nБог согласился. Через месяц снова приходит Черт к Богу и спрашивает:\n- Ну что, Бог, как у тебя Летов поживает?\nБог отвечает:\n- Всё стало заебись',
    'После смерти русский и американец попали в ад. \nДьявол спрашивает их : \n- В какои ад пойдёте, в русский или в американский? \n- А какая разница? \n- В американском надо съедать каждыи день по ведру говна, а в русском по два. \nАмериканец выбрал американский, а русский подумал: "Всю жизнь в России прожил, чего уж менять?" \nЧерез месяц встречаются. Русский спрашивает: \n- Ну как у вас? \n- Прекрасно, съел с утра ведро говна и целый день свободен. А у вас? \n- А как всегда: то говна не завезли, то вёдер на всех не хватает.',
    'Идет мужик по дороге, видит - подкова лежит. Перевернул её , а там лошадь .',
    'В дверь постучали пол раза.\n"Нихуя себе", - подумал Штирлиц.',
    'Времена СССР приходят в Кремль туристы из США. Им всё показывают, и тут гид оборачивается, и говорит:\n-Сейчас мы пройдём в кабинет Генерального Секретаря. Идут по длинному коридору, всё темнее, и темнее...\nВ конце виднеется дверь, её открывает гид, а там сидит Брежнев, и что то пишет. Туристы стоят, пишут что то в блокнот. И тут Брежнев открывает ящичек в столе, достаёт фото президента США, и начинает дрочить. Закончил, убирает фотографию, и продолжает писать. Первый турист думает, что он хотел так показать своё плохое отношение к нам, второй думает, что так он хотел пойти по пути примирения. Но третий ничего не понял, и решил всё таки спросить:\n-Господин Брежнев, что вы хотели этим сказать?\n-ААА, БЛЯТЬ, КТО ЗДЕСЬ!?',
    'Встретились украинец с американцем, и зашел у них разговор о горах.\nАмериканец говорит:\n— У нас такие горы, что как крикнешь, то эхо пять минут длится.\n— Ну так поедем посмотрим, — отвечает украинец.\nВлезают они на вершину, американец кричит:\n— Hello!!!\nЭхо:\n— Hello-ello-llo-o…\nУкраинец подождал, когда эхо прекратится, и говорит:\n— Да разве это горы? У нас в горах эхо три часа держится.\n— Ну поехали посмотрим, — отвечает американец.\nВлезают они на самую высокую украинскую гору Говерлу, и украинец как закричит:\n— В Карпатах москаль!!!\nА со всех сторон:\n— Где москаль?.. Где москаль?! Где москаль?! Где москаль?! Где москаль?! Где москаль?!',
    'Идет заседание цк, речь держит Сталин, вдруг кто-то в зале громко чихает, Сталин прекращает читать, и спрашивает, кто чихнул? весь зал молчит, Сталин спрашивает второй раз, третий, все молчат, тогда он говорит первый ряд встат, весь ряд встает, кто чихнул? молчат, первый ряд расстрелять, первый ряд уводят растреливают, второй ряд встать, кто чихнул? молчат, второй ряд расстрелять, второй ряд уводят растреливают, Сталин командует весь зал встать, кто чихнул ? молчат, тут Сталин не выдерживает и упрашивающим голосом говорит, товарищи ну кто чихнул скажите уже наконец, из середины зала тянеца дрожащая рука, и плаксивый голос, я чихнул товарищ Сталин, а Сталин ему " будьте здоровы".',
    'Приехал мужик в гостиницу а его поселили в общий номер на 10 человек. Все пьют, матом орут, политические анекдоты рассказывают, а ему смерть как спать хочется... Вот вышел он в коридор и видит девушку-горничную, говорит ей: \n- Вас как зовут? \n-Лида. \n- Лидочка , если вам не трудно, не могли бы вы мне минуток через десять принести в номер чашечку кофе? \nНу и пошёл назад. Походил по номеру минут пять а потом говорит: \n- мужики, вы с ума сошли, в гостиницах все номера прослушиваются а вы власть ругаете, политические анекдоты травите. Не боитесь? \n- да кому мы нужны? Ты че придурок? \nМужик подойдя к розетке в стене наклонился и говорит: \n- Товарищ майор, пожалуйста попросите Лидочку принести мне чашечку кофе... \nМужики пальцами у висков крутят. Вдруг открывается дверь и Лидочка приносит чашечку кофе. \nВсе испуганно замолчали и спать легли. \nУтром мужик просыпается, никого в номере и Лидочка кровати заправляет. \nОн спрашивает: - а где все? \n- а забрали всех ночью! \n- а меня почему не тронули??? \n- а очень товарищу майору шутка с кофе понравилась... )',
    'Подходит чукча к геологической вышке и спрашивает:\n– А что это здесь делают?\n– Бурят, не видишь, что ли.\n– Чукчу не обманешь, бурят не так делают.',
    'Сумасшедший дом. Палата математиков. Все воображают себя какими-то функциями,кто-то кричит " Я квадратичная функция " ,кто-то " Я логарифмическая" и т.д.\nСанитары решают успокоить их. Заходит самый крутой санитар и говорит:  "Я вас сейчас продифферинцирую! " Все разбежались в страхе,бояться. А один продолжает стоять довольный. У него спросили " Почему ты не убежал" .Он ответил " А я е^х ,мне все равно. А санитар закричал :  " А я по игреку!!!!!"',
    'В дверь постучали 3,14 раз. «Пи» - подумал Штирлиц.\n«Зда» - ловко парировали 0,3925 осьминога.',
    '1 января в магазине:\n— Здравствуйте, а у вас хлеб свежий? \n— В хлебе твоя сила и мудрость! \n— Вы любите хлеб?\n— Да.\n— А какие сорта предпочитаете?\n— Да обычные. Вот, пожалуйста, чёрный. Нормальный хлеб. Пацанский, хули. Есть можно.\n— Похвалите ещё хлеб.\n— Ну, как его похвалить, ну, заебись хлеб. Пиздатый хлеб. Как его ещё похвалить, блядь? Хе-хе.\n— А ещё пара красивых слов?\n— Невъебенный хлеб.\n— Спасибо.\n— Да на здоровье. Вот оно, прошлогоднее золото!',
    'В семье дотеров случилось счастье.Сын замуж выходит.',
    'Старый английский лорд приходит к врачу.\n- Вы знаете доктор, я женился полгода назад на прелестной молодой\nособе, но она никак не может забеременеть, может быть что-то\nпосоветуете?\n- Сколько Вам лет, сэр?\n- 75.\n- А Вашей жене?\n- Ей 25.\n- Вот, что я Вам посоветую, возьмите Вашу жену, наймите молодого\nсекретаря и отправляйтесь на Вашей яхте в путешествие месяца на два-на\nтри. Вы знаете, морской воздух, порой, творит настоящие чудеса!\nПроходит полгода, старый лорд появляется у доктора.\n- Огромное Вам спасибо, доктор! Морской воздух действительно творит\nчудеса! Моя жена беременна!\n- Хм, а как поживает молодой секретарь? - спрашивает доктор.\n- Вы знаете, она тоже беременна! Морской воздух творит чудеса!',
    'Приходят к профессору два студента экзамен сдавать. По комбинаторике.\nВ те еще времена. Домой пришли к профессору. Ну, сдавали, сдавали, за\nкартами засиделись, за костями игральными, стемнело. А в то время и\nстуденты, и профессора были бедные, домой их не отправишь, пришлось\nспать укладывать в профессорской трехкомнатной квартире. В одной\nкомнате - два студента, в другой - профессор с женой, в третьей -\nпрофессорская дочь. Все чин по чину, спят.\nПросыпается студент, думает, а хрен ли я с этим придурком лежу, пойду-ка\nпрофессорскую дочь навещу. Глядь в одну комнату - две головы из-под\nодеяла торчат, ну то профессор с женой, глядь в другую - одна голова.\nДочка! Юрк к ней под одеяло, спят.\nНе спится и профессору. Встает среди ночи, дай, думает, к дочке\nперелягу, мало ли что от этих балбесов ждать. Шнырь в одну комнату, две\nголовы, - ага, студенты, шнырь в другую - одна, дочка, не иначе. Прыг -\nспит.\nНу, тута и второй студент проснулся, и, как вы уже догадались,\nотправился по стопам друга, на поиски профессорской дочки.\nУтро. Просыпается профессор. Один. В комнате студентов. Хм...\nЗаглядывает в одну комнату - там студент с дочкой, в другую - студент\nс женой. Чешет репу:\n- Сколько лет преподаю комбинаторику, но таких блядских перестановок\nеще не видел.',
    'Морг. На столе — вскрытый труп. У стола — два патологоанатома, третий читает заключение о смерти. Первый, разрезая желудок трупа:\n\n— Ух ты! Гречневая каша! С тушенкой! Вася, будешь?\n\n— Нет, ребята, я плотненько поужинал.\n\n— Ну, как хочешь.\n\nПервые двое достают ложки и с аппетитом выскребают содержимое желудка.\n\nКогда каша подходит к концу, третий поднимает глаза от заключения о смерти:\n\n— М-да-а-а, ребята, похоже, именно от этой каши он копыта и откинул!\n\nПервые двое выворачивают кашу обратно в желудок и бегут к аптечке.\n\nТретий им вслед, доставая ложку:\n\n— Ребята, да я пошутил, инфаркт у него. Просто я подогретое люблю!',
    'Приходит к мудрецу глупец и говорит: "Почему все говорят, что надо жениться на девственнице?"\nМудрец протягивает ему 2 конфеты - 1 в блестящем фантике а другую уже раскрытую, и говорит: "Ну вот какую ты выберешь?"\n- Конечно раскрытую!\n- Но почему?\n- Так кто его знает что там под фантиком - может какашка, а тут все понятно.\nИ сказал ему мудрец: "Иди на хуй, такую притчу испортил!"',
    'Eдут в купе русский, украинец, армянин. Проходит полчаса, надо знакомиться. Хохол протягивает руку, говорит: \n- Мыкола, запорожец. \n- Сергей, москвич. \n- Ашот, BМW.',
    'Неопытный вор карманник довел свою жертву до оргазма.',
    'Как-то тёплым, летним утром шёл мужик по мосту и увидел другого мужика, стоящего на перилах и явно намеревающегося прыгнуть вниз. Испугавшись, он подошёл к нему и заговорил: \n— Остановись! Не делай этого! \n— Почему? \n— В жизни столько прекрасного, ради чего стоит жить! \n— Например? \nПервый, задумавшись: \n— Ты вот верующий или атеист? \n— Верующий. \n— Я тоже. А ты христианин или еврей? \n— Христианин \n— Я тоже. А ты католик или протестант? \n— Протестант. \n— Я тоже. А ты приверженец епископальной церкви или баптист? \n— Баптист. \n— Ну и ну! Я тоже. А ты баптист церкви Бога нашего или баптист церкви Христовой? \n— Баптист церкви Бога нашего. \n— Я тоже. А ты баптист ортодоксальной церкви Бога нашего или реформированной? \n— Реформированной. \n— Ну просто невероятно! Я тоже. А ты баптист реформированной церкви Бога нашего исповедания 1879 года или баптист реформированной церкви Бога нашего 1915 года? \n— 1915 года. \n— Ах ты мерзкий еретик! — сказал первый мужик и столкнул второго вниз.',
    'Летов, Горшок и Лева Би-2 собрались и написали песню "Полковник насрал на лицо колдуна"',
    'Заходит как-то Сталин в бар. Ну подошёл к стойке, взял выпить . Ну тут бармен начинает из вежливости расспрашивать :\n-Как жизнь ?\n-Да ничего особенного.\n-Жена как?\n-Да умерла, давно ещё.\n-Дети?\n-Нет спасибо, я сегодня без закуски пью.',
    'В почти пустой автобус заходит хиппи и, увидев симпатичную молодую монашку, предлагает ей трахнуться. Монашка, конечно, краснеет и выходит из автобуса на следующей же остановке. Тогда водитель автобуса говорит хиппи: \n— Я скажу тебе, как эту монашку поиметь. Каждую ночь она приходит в длинной рясе на городское кладбище молиться Богу. Ты надень маску, иди на кладбище, подожди, пока она не обратится к Богу, потом выйди и скажи, что ты Бог. Ну, хиппи пошел на следующую ночь на городское кладбище, смотрит — идет монашка в длинной рясе с капюшоном. Подождал он, пока она молитву закончит, потом выходит в маске и говорит: \n— Я Бог. Отдай мне твое тело! \nМонашка отвечает: \n— Ладно, только, пожалуйста, трахни меня в жопу, потому что я не хочу терять невинность. \nХиппи сделал свое дело, снимает маску и, смеясь в лицо монашке, говорит: \n— Ха-ха-ха, я не Бог, я хиппи! \nА монашка, снимая капюшон, отвечает: \n— Ха-ха-ха, а я не монашка, я водитель автобуса!',
    'Выбирает зоофил собаку: \n-Вам какой породы?\n-Мне поебать.',
    'Летят в перегруженном самолёте русский, узбек и армян. Один из двигателей начинает дымить, самолёт начал быстро снижаться. Пилот сообщает: нужно снизить массу самолёта, пускай каждый скинет по одной вещи. Узбек выкинул арбуз, армянин - шпагу, а русский некоторое время подумал и кинул гранату. Вес снизился и самолёт успешно долетел до аэропорта. Приходит потом домой узбек. Видит - мать горюет перед телом отца. Узбек спрашивает: что случилось, что с отцом? А мать отвечает: твой отец сидел в туалете, на его голову прилетел арбуз и он умер... Приезжает домой армянин, видит - мать плачет перед отцом, подбегает и спрашивает: что случилось, что с отцом? Мать отвечает: твой отец сидел в туалете, как вдруг в его голову воткнулась шпага. Приезжает русский домой. Видит - мать смеётся, рядом отец стоит в ахуе, спрашивает, почему та смеётся, пускай рассказывает. Та отвечает: твой отец сидел в туалете, и так громко перданул, что у соседей нахуй дом развалился блять.',
    'Заходит бесконечное число математиков в бар, а бармен им говорит:\n-Идите нахуй отсюда!\nВозмущению не было предела!',
    'Идет суд над педофилом в Южной республике. Судья:\n– Падсудимый Гагаберидзе, расскажите как случился акт пэдофэлии.\n Подсудимый:\n– Иду я, сматру писочница. А там сидит малчик, сам такой бэленький, попка такой розовэнький!\nСудья:\n– ААЙ, НЭВИНОВЕН!!',
    'По статистике опрошенных жителей, в Украине самые частые имена это\nНиф ниф\nНаф наф\nНуф нуф',
    'Крутой джазовый бар проводит конкурс на лучшего исполнителя, которого возьмут на работу. Собирается толпа музыкантов и среди них старый негр.\nВыходит и говорит:\n— Эта песня называется "Я буду дрочить на тебя всю ночь!"\nИграет восхитительный блюз, после которого половина музыкантов сразу собираются и уходят, другие просто плачут от восторга!\nСтарый негр говорит:\n— А следующая моя песня называется "Соси у меня, сука, пока я не кончу!"\nИ играет блюз еще круче от которого оставшиеся музыканты единогласно отказываются от участия в конкурсе.\nВладелец заведения говорит\n— Мы вас берем, только не могли бы вы не называть своих песен, а они немного… нуу... шокируют.\nНегр соглашается.\nИдет очередной концерт, негр забыл заправиться, и у него елда торчит из штанов. Он садится за рояль, играет. Хозяин заведения замечает эту оплошность, подходит к нему, говорит:\n— У тебя хуй видно, знаешь?\nНегр:\n— Что? Знаю ли я её?! Да я её написал!',
    'Один старый и очень мудрый человек сказал своему другу:\n— Рассмотри комнату, в которой мы находимся, получше, и постарайся запомнить вещи коричневого цвета.\nВ комнате было много чего коричневого, и друг быстро справился с этой задачей. Но мудрый китаец ему задал следующий вопрос:\n— А теперь закрой глаза и перечисли все вещи синего цвета.\nДруг растерялся и возмутился:\n— Я ничего синего не заметил, ведь я запоминал только вещи коричневого цвета!\nНа что мудрец ответил:\n— Открой глаза, осмотрись — ведь в комнате очень много вещей синего цвета.\nИ это было чистой правдой.\nТогда старик продолжил:\n— Я вот тоже синющий\nИ обблевался',
    'В цирке выдавали зарплату продукцией. Директор собрал клоунов и рассмеялся им в лицо.',
    'Стоит парень укуренный. К нему подходит мужик и спрашивает:\n - Как дойти до центрального парка?\n Парень объясняет:\n - Вот сейчас пойдешь прямо, потом налево. Увидишь ларек, там продавщица Лена, ты ее не еб*, ее мой друг еб*т. Потом пойдешь направо, потом прямо. Там увидишь мясокомбинат, там продавщица Таня, ты ее не е6и ее я е6у. Купишь у нее свиную голову, разобьешь ее об асфальт - увидишь мозги. Вот ты их е6и, а мне мозги е6ать не надо ты и так у центрального парка.',
    'Санкт-Петербург, высотный дом, в лифт заходят двое мужчин.\n— Мне на последний.\n— Мне на предпоследний.\nЕдут. Вдруг один резко снимает брюки и начинает срать. Второй отвернулся, забился в угол, нос зажал — воняет, а первый все срет. Наблюдатель достает сигарету и закуривает, чтобы перебить вонь. Срущий ему:\n— Вы, наверное, из Москвы будете?\n— Да, а как вы узнали?\n— У нас, в Петербурге, в лифтах не курят.',
    'В семье хохлов случился праздник. Отца спросили',
    'Хохол притаскивает домой зайца и говорит жене:\n- Hа, зажарь мне его на сале.\n- Так ведь нет у нас сала...\n- Так зажарь его на масле.\n- Hет у нас масла.\n- Так зажарь мне его просто так!\n- А-а, у нас и газа нет.\nХохол молча берет зайца и вышвыривает его в окно.\nЗаяц вскакивает и кричит:\n- Да здравствует свободная Украина!',
    'дерутся русский и кавказец, всё по честному, бой 1 на 9',
    'едут батя с сыном на шестёрке, перевернулись - едут на девятке',
    'Директор <img alt="🧔🏻" class="emoji" src="/emoji/e/f09fa794f09f8fbb.png"/> кальянной <img alt="🗣" class="emoji" src="/emoji/e/f09f97a3.png"/>показывает кальянщикам <img alt="👶🏻" class="emoji" src="/emoji/e/f09f91b6f09f8fbb.png"/><img alt="👶🏼" class="emoji" src="/emoji/e/f09f91b6f09f8fbc.png"/><img alt="👶🏽" class="emoji" src="/emoji/e/f09f91b6f09f8fbd.png"/>новый калик))<img alt="💨" class="emoji" src="/emoji/e/f09f92a8.png"/><img alt="🌬" class="emoji" src="/emoji/e/f09f8cac.png"/>\n- Вот товарищи кумароведы <img alt="💨" class="emoji" src="/emoji/e/f09f92a8.png"/><img alt="🌬" class="emoji" src="/emoji/e/f09f8cac.png"/>это новый секретный <img alt="👌🏼" class="emoji" src="/emoji/e/f09f918cf09f8fbc.png"/><img alt="🤫" class="emoji" src="/emoji/e/f09fa4ab.png"/>калик) Петров!<img alt="😬" class="emoji" src="/emoji/e/f09f98ac.png"/>\n- Я! <img alt="👶🏻" class="emoji" src="/emoji/e/f09f91b6f09f8fbb.png"/>\n- Сделай затяжечку<img alt="🌬" class="emoji" src="/emoji/e/f09f8cac.png"/>\nПетров пыхтит, <img alt="💨" class="emoji" src="/emoji/e/f09f92a8.png"/>кряхтит, <img alt="🌬" class="emoji" src="/emoji/e/f09f8cac.png"/>не может затянуться<img alt="💥" class="emoji" src="/emoji/e/f09f92a5.png"/>\n- Сидоров, <img alt="👶🏼" class="emoji" src="/emoji/e/f09f91b6f09f8fbc.png"/>помоги Петрову<img alt="👶🏻" class="emoji" src="/emoji/e/f09f91b6f09f8fbb.png"/>\nПытаются вдвоем, <img alt="👶🏻" class="emoji" src="/emoji/e/f09f91b6f09f8fbb.png"/><img alt="👶🏼" class="emoji" src="/emoji/e/f09f91b6f09f8fbc.png"/>не могут затянуться<img alt="👀" class="emoji" src="/emoji/e/f09f9180.png"/><img alt="🥴" class="emoji" src="/emoji/e/f09fa5b4.png"/>\n- Никак не можем<img alt="😯" class="emoji" src="/emoji/e/f09f98af.png"/><img alt="😲" class="emoji" src="/emoji/e/f09f98b2.png"/>\n- Иванов, <img alt="👶🏽" class="emoji" src="/emoji/e/f09f91b6f09f8fbd.png"/>помогай! <img alt="👊🏻" class="emoji" src="/emoji/e/f09f918af09f8fbb.png"/>\nПыхтят втроем, <img alt="👶🏽" class="emoji" src="/emoji/e/f09f91b6f09f8fbd.png"/><img alt="👶🏼" class="emoji" src="/emoji/e/f09f91b6f09f8fbc.png"/><img alt="👶🏻" class="emoji" src="/emoji/e/f09f91b6f09f8fbb.png"/>затянуться не могут<img alt="😵" class="emoji" src="/emoji/e/f09f98b5.png"/><img alt="😵" class="emoji" src="/emoji/e/f09f98b5.png"/><img alt="😵" class="emoji" src="/emoji/e/f09f98b5.png"/>\n- Никак не затянуться<img alt="💨" class="emoji" src="/emoji/e/f09f92a8.png"/><img alt="🌬" class="emoji" src="/emoji/e/f09f8cac.png"/>, товарищ директор<img alt="🤭" class="emoji" src="/emoji/e/f09fa4ad.png"/><img alt="🤔" class="emoji" src="/emoji/e/f09fa494.png"/>\n- А хули вы хотели? <img alt="🤘🏼" class="emoji" src="/emoji/e/f09fa498f09f8fbc.png"/><img alt="👍🏻" class="emoji" src="/emoji/e/f09f918df09f8fbb.png"/>Сорок шесть углей <img alt="🌪" class="emoji" src="/emoji/e/f09f8caa.png"/><img alt="🔥" class="emoji" src="/emoji/e/f09f94a5.png"/><img alt="🍏" class="emoji" src="/emoji/e/f09f8d8f.png"/><img alt="🍎" class="emoji" src="/emoji/e/f09f8d8e.png"/>',
    'Заблудились двое чукчей в тайге, один говорит:\n- А ну выстрели, может, кто отзовется.\nВторой выстрелил - никто не отзывается.\n- Стреляй еще.\nОпять тишина.\n- Стреляй!\n- Не могу, стрелы кончились',
    'Наташа Ростова шалунья, не надела под бальное платье трусов. Выделывая невообразимое ПА на балу, села на шпагат и невзначай присосалась пиздой к паркету к которому конкретно прилипла. \nГости собрались вокруг неё и обсуждают, как поступить. \nРжевский вносит конструктивное предложение: \n— Давайте этажом ниже прямо под ней потолок просверлим — воздух во внутрь попадёт, давление уравняется, она и отлипнет. \nВсе хором как загалдят на него: \n— Ржевский, вы в своем ли уме? Это палисандровый паркет, за него Наташин батюшка имение в Костромской губернии продал. А мастеров, чтоб его стелить, аж из самого Парижу выписывали! \nПоручик пожал плечами \n— Ну нет, так нет.\nИ стал решительно расстёгивать ширинку штанов. Все в недоумении:\n— Ржевский, что вы делаете?!\n— Как что, паркет спасаю! Я сейчас ей в рот наваляю. Пизда сок даст, скользкой станет. Мы её волоком протащим на кухню, а там кафель дешёвый.',
    'Родители вернулись с дачи, на которой провели все выходные:\nПапа: Ну, здравствуй, сынок, как провел время?\nСын: Все отлично, писал курсовую. В понедельник буду сдавать.\nМама: Точно? И друзей не приводил?\nСын: Нет, нет. Никого не звал.\nПапа: И девушку в гости не приглашал?\nСын: Нет, конечно!\nМама : То есть ты все выходные провел один в пустой квартире, уча уроки?\nСын: Ну да!\nПапа: Ебать ты лошара.\nМама: И пидор.',
    'Рассказывает прапорщик рядовым про танк:\n– Вот это гусеницы, вот это запаска. Вот это топливный отсек. На танке установлена радиостанция.\nОдин из особо умных солдат спрашивает:\n– А радиостанция на лампах, или на транзисторах?\nПрапорщик повернулся, грозно посмотрел на солдат, и как заорет:\n– ДЛЯ ОСОБО ТУПЫХ, ПОВТОРЯЮ: РАДИОСТАНЦИЯ НА ТАНКЕ!',
    'В бар забегает мужик, подбегает к стойке и говорит:\n— Давай, наливай быстрее, пока не началось.\nБармен пожал плечами, наливает, мужик выпивает.\n— Давай еще наливай, быстрее, быстрее, пока не началось.\nСнова наливает, мужик выпивает.\n— Давай, давай, не спи, наливай еще, пока не началось.\n— Мужик, ты платить то собираешься?\n— Ну вот, блять, начинается.',
    'Приехал грузин в родную деревню из Москвы. Собрались толпа народу и просят:\n"Гиви, расскажи, дарагой, что ты в Масква видель!"\n- Э-э-э Масква, слушяй, хороший город. Кремль видэль, Лэнин видель, балэт видель...\n- Гиви расскажи, что такое балэт, а?\n- Э-э-э, балэт. Это такой бальшой дом с колоннами. Заходишь - там всэ раздеваюцца. В зал праходишь - а там прэдставлэние.\n- А какое, дарагой?\n- Ну сначала вибижяль на сцену один мужик и три баба. Мужик к адной падбежяль, ей ногу паднял, панюхал - нэ его. К другой падбежяль, панюхал - нэ его. К трэтей падбежял, панюхал - его! Взвалил ее на плэчо, туда пабежял - нэгдэ еб@ть, сюда пабежял - нэгдэ еб@ть. Стал мужик с нэй пасрэди сцены и плачет... А всэ со своих мэст подорвались и кричат, панимаеш, : "Э бис, Э бис!" А где эбис, если негдэ?',
    'Встречаются однажды дровосек и гомосек.\n- Привет, дровосек!\n- Привет, гомосек!\n- А куда это ты идешь? \n- В бар выпить пивка.\n- Надо же, я тоже туда иду!\nНу и пошли они вместе по дороге.\nИдут значит, а на встречу им генсек. \n- О, привет гомосек!\n- Привет генсек!\n- Привет дровосек! \n- Привет генсек! \n- А куда это вы идете? - спрашивает генсек.\n- Да вот, в бар по пивку идем выпить.\n- А можно с вами? \n- Конечно можно!\nИдут значит по дороге втроем гомосек, дровосек и генсек, а им на встречу хохол выходит.\n- Привет гомосек! Привет дровосек! Привет генсек! А куда это вы идете?\n- Никуда, пошел нахуй. - ответили трое',
    'Штирлиц стрелял вслепую.\nНе попал\n"Штирлиц" — догадалась слепая',
    'Гуляет Штирлиц возле Рейхстага. Видит пруд, а в пруду лебеди плавают.\n- Лебеди, - подумал Штирлиц...\n- Штирлиц, - подумали Лебеди...',
    'приехал сын к матери после службы в артиллерийском полку. откормили, напоили его. сел он у печи с котом на руках и там и уснул. тут из кострища на ковер вывалился уголек, подстилка начала дымиться. мать это увидела и крикнула:\n- огонь!\nпарень подорвался, закинул кота в печь и закрыл заслонку\n- орудие к бою',
    'Видит араб, как человек выбивает ковёр, он к нему подходит и говорит.\n- Чё сука, не заводится?',
    'Поручик Ржевский просыпается после пьянки и видит, что денщик Петруха чистит его обблеваный китель.\nНу поручику, естественно, неудобно стало - офицер, и так обблевался. Он и говорит денщику:\n-Знаешь, Петруха, вчера на балу встретил своего друга генерала, а он скотина так нажрался и обблевал мне весь китель.\n-Да, Ваше Благородие, он вам не только китель обблевал, но еще и в штаны насрал...',
    'Идет лиса по лесу и встречает ежика с большим мешком за спиной.\n– Ежик, а Ежик, покажи, что у тебя в мешке!\n– Нет, лиса, не покажу, добра тебе не будет. \n– Ну ежик, ну покажи! \n– Ладно, лиса, смотри. Полный мешок членов.\n– Ежик, зачем тебе так много, дай мне один. \n– Ох, лиса, не дам, впрок не пойдет. \n– Ежик, ежик, ну дай пожалуйста!\n– Ладно, лиса, вот тебе пишу волшебное слово ("бирюльки") которое приводит член в боеготовность. Для того чтобы оно сработало ты должна его произнести вслух, ну а потом наслаждайся сколько хочешь.\n\nЛиса пришла на берег реки, разделась, раслабилась, произнесла волшебное слово. Член прыг в нее. Час наслаждается, другой, третий. Уже не может, а как остановить не знает. Промучалась бедняжка до вечера. А тут, на удачу лисе - волк идет. Лиса ему: \n– Волк, скажи бирюльки.\n– Бирюльки. \nНу и член перепрыгнул на волка.\nВолк час балдеет, другой, на четвёртый час лисе его стало жалко, поэтому она предложила волку сделку - каждые четыре часа они будут по очереди говорить "бирюльки" и меняться членом друг с дружкой. Прожили они так пару дней, но не могут уже больше, вконец измучились. Лиса нашла выход:\n– Волк, давай в тот момент, когда член будет из меня в тебя перепрыгивать - быстро схватим его, привяжем к камню и утопим от греха подальше, сбросив эту хуету в реку? \nВолк был только "за", их план сработал и их страдания наконец-то закончились. (все таки звери то они ловкие!) \n\nИдут они на радостях счастливые по лесу, песни поют, а навстречу им ежик с мешком. Ну волк и спрашивает:\n– Ежик, а что у тебя в мешке? \n– Нет, волк, не покажу, добра тебе не будет.\n– Ежик, ну покажи пожалуйста! \n– Ладно, смотри!\nВолк видит перед собой полный мешок мужских членов. \n– А, бирюльки...',
    'Автобус, сильная давка. Стоят мент и просто мужик. В автобус заходит анимешник лет пятнадцати, в наушниках, смотрит на планшете "Тетрадь смерти". Из-за тесноты наступает на ногу менту и остается стоять. Мент глядит на часы и думает: "Ну, если через пять минут не слезет - убью!". И так продолжает стоять, поглядывая на часы и на анимешника время от времени. Спустя означенное время мент начинает избивать анимешника, к менту присоединяется мужик. \n\nОстановка, мент с мужиком выходят из автоубса. Мент поворачивается и спрашивает:\n- Ну ладно я, но ты-то зачем его бить полез?\nМужик отвечает:\n- Ну а вы себе представьте, трищ капитан: стою я в автобусе, вижу - стоит полицейский и смотрит то на часы, то на анимешника. А потом как начнет его пиздить, ну, я думал, что по всей стране началось.',
    'два наркомана общаются по рации:\n-принял\n-принял\n-принял\n-принял\n-принял\n-принял\n-принял\n-принял\n-принял',
    'Возвращается муж с командировки, заглядывает в шкаф, вытягивает оттуда любовника и кричит:\n— Сколько тебе говорить, нет ее тут, развелся я!',
    'Плывут как-то Петька с Василий Иванычем через реку, баржу за собой тащат. \nТут Петька воздыхает:\n—Василий Иваныч, не могу больше, тяжело, силы кончаются. \n—Надо плыть, Петька, надо. \nПлывут дальше. Проплыли четверть реки уже, Петька снова хнычет:\n—Василий Иваныч, всë, никак не могу больше, устал. \n—Надо плыть, Петька, все равно надо. \nПлывут дальше, проплыли половину реки уже. Петька опять за своё:\n—Все, Василий Иваныч, это точно предел моих сил, больше не могу, все болит, я устал.\n—Ну разворачивайся тогда, поплыли обратно.',
    'У человека с синдромом Туррета стакан наполовину - мудак, наполовину - пидор.',
    'Великий философ Фридрих Ницше был добрый и веселый человек.\nОдин раз он пошел в магазин за хлебом.\nТолстая продавщица на хлебном отделе очень любила издеваться над добрым и веселым философом. Ницше терпеть ее не мог и часто называл тупой пиздой.\n— Ну что, Ницше, — сказала толстая продавщица, завидев Фридриха. — За хлебом небось прискакал? Любишь хлебушек-то?\n— Обожаю, — сдержанно ответил Ницше.\n— А ты его пёк, чтобы вот так его жрать? — вкрадчиво спросила вдруг продавщица. — Ты вообще когда-нибудь пёк хлеб? А, Ницше?\n— Я? Пёк хлеб? — переспросил Ницше.\n— Ты в уши долбишься, Ницше?\n— Нет, — сказал Ницше. — На оба вопроса — нет.\nВеликий философ умел быть лаконичным.\n— Вот испеки сначала, а там поговорим, — триумфально закончила продавщица.\n— Секундочку, — сказал Ницше. — Если я буду печь хлеб, то нахуя мне тогда, тупая ты пизда, покупать его у тебя?\n— Меня, Ницше, твои запарки совершенно не ебут — спокойно парировала продавщица. — Делать мне больше нехуй, как вместе с тобой философствовать. Муку тебе продам. А хлеба — во, — продавщица показала мозолистый кукиш, для убедительности схватив себя за локоть.\nНицше задумался.\n— А ты-то, — наконец произнес он, — ты-то сама хлеб пекла?\n— Пекла, голубчик, пекла, — сказала продавщица. — Да я столько его выпекла, что ты бы всю жизнь ел, да еще и детям бы твоим осталось.\n— У меня нет детей, — сообщил Ницше.\n— Это пиздец какой-то, — сказала продавщица. — Детей у него нет, хлеб он печь не умеет и не хочет, а только и знает, что честных продавщиц заебывать.\n— Это ты честная продавщица, что ли? — заинтересовался Ницше. — Да у тебя ебало как у Муссолини. У честных людей лица другие.\n— А что Муссолини? Чем тебе теперь Муссолини не угодил? Да он, если хочешь знать, тоже хлеб пёк. Эх ты, Ницше.\nНицше неуверенно потоптался на месте.\n— Ладно, хуй с ним — махнул он рукой. — Давай сюда свою муку.\n— Запомни, Ницше: культура — это лишь тоненькая хлебная корочка над раскаленным хаосом, — довольно сказала продавщица. — Крепко запомни.\n— Запомню, — сказал Ницше с ненавистью. — Крепко запомню.\n\nНа следующий день Ницше пришёл в тот же магазин.\n— Чего тебе? — спросила продавщица.\n— Муки давай, сквозь зубы ответил Ницше.\n— Что, научился печь?\n— Тебя, суку, забыл спросить. Давай муки.\n— За такую грубость могу и скалкой по ебальнику… — промямлила продавщица.\n— Давай муку, говорю.\n\nПродавщица подала муку.\n\n— А теперь жри.\n— Что жрать?\n— Муку жри.\n— С какого перепугу? Сам жри.\n— Я сказал жри, сказал Ницще и опустил продавщицу мордой в муку. — Что, нравится?\n\nПродавщица покорно съела муку и посмотрела на философа испуганными глазами.\n\n— Приятно, да? А я вчера целый вечер это говно жрал.\n\nНицше так и не научился печь хлеб.',
    'Россия 2021 год. При смерти лежит Навальный... Слабым голосом просит позвать члена партии единой россии, чтобы вступить в неё. Радостный партиец спешит к Навальному с новеньким билетом партии. Навальный подписывает и прижимает билет к сердцу. Счастливым голосом говорит: "Сегодня умрет ещё один единоросс "',
    'Морг.\n\nНа столе - вскрытый труп. \n\nУ стола - два патологоанатома, третий\nчитает заключение о смерти. \n\nПервый, разрезая желудок\nтрупа:\n- Ух ты! Гречневая каша! С тушенкой! Вася, будешь?\n\n- Нет, ребята, я плотненько поужинал.\n\n- Ну, как хочешь.\n\nДвое у тела достают ложки и с аппетитом выскребают содержимое желудка.\n\nКогда каша подходит к концу, третий поднимает глаза от заключения о смерти:\n- М-да-а-а, ребята, похоже, именно от этой каши он копыта и откинул!\n\nТе двое выворачивают кашу обратно в желудок и бегут к аптечке.\n\nТретий им вслед, доставая ложку:\n\n- Ребята, да я пошутил, инфаркт у него. Просто я подогретое люблю!',
    'Несут два грузина медведя.\nУвидел их другой грузин и спрашивает: "Гризли?"\n -Нэт, так задущилы!!!',
    'Гитлер очень любил сливы и никогда их не ел. Он все время ходил возле витрин и смотрел на них, облизываясь. Мама это знала и в один день купила пакет слив. Гитлер все ходил возле них, никак не решаясь взять одну, но, наконец, решился и взял одну сливу. Мама это видела и сказала папе. За ужином папа спросил:\n— Кто съел сливу?\nВсе говорили, что не ели, а Гитлер, покраснев, сказал:\n— Я не ел сливы.\nНа что папа ответил:\n— Плохо не то, что съели одну сливу. Плохо то, что с нами за одним столом сидит Гитлер.',
    'Заходит в бар для вампиров богатый вампир-аристократ, и говорит:\n- Мне пожалуйста кровь девственницы, четвертую группу.\nВыпивает и уходит.\nЗаходит вампир среднего достатка:\n- Мне кровь первой группы.\nВыпивает и уходит.\nЗаходит бомж-вампир:\n- Мне пожалуйста стакан кипятка.\nЕму наливают, после чего он достаёт тампон со словами:\n- Чайком побалуемся!',
    'Встречаются две подруги\n-Ого, Настя ты ли это?\n-Ничего себе, Таня! Как давно мы не виделись?\nВ этот момент Таня обращает внимание на ребёнка рядом с её подругой\n-Ваиии, неужели твой малышь?\n-Да)))\n-А как звать его?\n-Борис\n-Я не понял, а что здесь делает Борис? Борис, что ты тут делаешь?\n-Пошёл нахуй!\n[Раздался звук выстрела] \n-Где дипломат?\n-Ты...говна кусок...\n-Не зли меня Борис\n-Я тебе покажу!...\n[Раздалось несколько выстрелов] \n-Хуй тебе!\n[Ещё Выстрел] \n-Не попал\n-Да ёб твою мать',
    'Приехали как-то 2 татарина на дикий запад.\nВидят вывеску, а там написано: за череп индейца 100$\nНу они по коням и поехали искать.\nНашли одного индейца. Скальп сняли и уже ночью развели палатку.\n\nНа утро просыпается один татарин. Выходит из палатки и видят 50 злобных индейцев на конях. Все окружили палатку\nТатарин забегает в палатку и кричит:\n\n-Ильдар, проснись!! Мы богаты!!!',
    'Едет мужик на машине и вдруг глохнет. Открывает капот - ничего понять не может. Вдруг из кустов высовывается лошадь и говорит мужику: \n- Ты ремень генератора посмотри! \nМужик посмотрел, и в правду ремень. Смотрит на лошадь, та ему: \n- Сними галстук и вместо ремня сделай, так доедешь до мастерской. \nМужик всё сделал, как сказала лошадь. Доезжает до сервиса, выходит весь в шоке. Мастер спрашивает: \n- Что, мужик, лошадь? \n- Ага... \n- Поди про ремень генератора что-то втирала? \n- Ага! \n- А как ты услышал, ты же глухой? \n- В смысле? \n- А ты в начало анека посмотри',
    'Умер подписчик АКБ и попал на небо. \nТам черт и бог совещаются, куда его отправить: в рай или ад. \nотправили в ад. \nЧерез месяц черт прибегает к богу и говорит: \n-бог, забери его к себе, а то у меня народ бунт поднял, анекдоты про бипки рассказывает и в предложку срёт. У тебя там предложки нет, срать некуда. \nну взял бог подписчика АКБ к себе. \nчерез месяц черт снова наведывается к богу и говорит: \n-ну че, как у тебя там он поживает? \nа бог отвечает: \n-отсосёшь- скажу',
    'Идет мужик по улице и по сторонам смотрит. На одном из балконов\nвидит клетку с попугаем. Попугай ему:\n- Мужик, а мужик!\nМужик задирает голову:\n- А?\nПопугай в ответ:\n- Пидор ты, мужик! Пошел ты на хуй!\nНа следующий день опять то же самое:\n- Мужик, а мужик!\nМужик задирает голову:\n- А?\nПопугай в ответ:\n- Ты - пидор! Пошел на хуй!\nТак повторяется несколько дней и наконец мужик решает поговорить\nс хозяином попугая, чтобы тот унял его матом. \nХозяин обещал дать попугаю пиздюлей.\n\nНа следующий день мужик проходит опять мимо этого же дома. Попугай сидит в клетке нахохлившись весь перебинтованный. Мужик обрадовался, ну все, думает, проучили. Попугай ему:\n- Мужик, а мужик!\n- Что?\nПопугай:\n- Ну, ты в курсе, мужик...',
    'Стоят солдаты в курилке, анекдоты травят. Один другому: \n- А знаешь, чем прапор от свиньи отличается?\nВдруг из-за угла выруливает прапор и спрашивает: \n- Ну и чем же, рядовой? \n- Дык это... ничем, товарищ прапорщик \n- Вот то-то же!',
    'Приходит бабушка 75 лет к следователю, жалуется что её дед избил. Опер начинает вслух писать протокол: \n- Значит, ваш муж, вам нанес телесные повреждения. \nБабушка встает, хлопает рукой об стол и говорит: \n- Слышь, фраерок, наносят крем на ебальник, а меня конкретно отхуярили!!!',
    'Идут по лесу медведь и заяц, смотрят, сидит на тропинке лягушка и говорит:\n— Я лягушка не простая, а волшебная, могу исполнить ваши три желания.\nМедведь подумал и говopит:\n— Я хочу, чтобы все медвeди в нашем лесу стали женщинами...\n— Твое желание исполненo. Ну а ты, заяц, чего желаешь?\nЗаяц думал некоторое вpeмя, и говорит:\n— А я хочу мото-шлем.\nПеред ним пoявляетcя шлем.\n— Твое второе желание, медведь.\n— Я хочу, чтобы все медведи в соседнем лесу стали женщинами.\n— Твое желание исполнено. Теперь ты, заяц, загадывай.\n— Ну, а я хочу мотоцикл.\nПеред ним появляется крутой мотоцикл. Медведь удивленно косится на зайца:\n— Ты чего тратишь желания на всякую ерунду? Поди, не каждый день лягушку волшебницу встречаешь, идиот.\n— Твое последнее желание, медведь.\n— Я хочу, чтобы все медведи во всем мире стали женщинами.\n— Уже стали. Загадывай, заяц.\n— Тихо, щас я его подъебу, он ахуеет просто.\nЗаяц садится на мотоцикл, ржет как долбоёб и говорит:\n— Хочу, чтобы появилась горящая машина. Медведь сел в неё и сгорел',
    'Сидят два наркомана на хате, дуют. Скучно, делать нечего и тут одному из них пришла в голову охуенная идея:\nНарк 1: - А че будет если взять и надуть корову через трубочку, как шарик?\nНарк 2: - Не знаю, а пошли попробуем?\nНаходят корову, Нарк 1 вставляет трубочку в коровью жопу и начинает дуть. Дует, дует, нихуя не получается.\nНарк 1: - Не могу уже, попробуй ты\nНарк 2: - Давай \nНарк 2 достаёт из жопы трубочку и переворачивает\nНарк 1: - А ты нахуя трубочку перевернул?\nНарк 2: - Брезгую',
    'Идет Пушкин по проселочной дороге, догоняет его мужик на телеге. Ну Пушкин ему и говорит: подвези, мужик, до ближайшей деревни. Мужик говорит – садитесь. Едут они, едут, ну и решил великий русский поэт удивить простого сельского мужика рифмой. Спрашивает:\n– Мужик, тебя как зовут?\n– Иван\n– О, Иван, хуй тебе в карман.\nМужик обиделся на поэта и говорит:\n– А тебя как зовут?\n– Александр Сергеевич.\n– Ну и слезай на хуй с телеги.',
    'Студент 20 с небольшим лет попал под автобус, и - насмерть. Очнулся на том свете. В кресле напротив увидел кого-то, похожего на человека, но светящегося изнутри инфракрасным светом. \n-Где я? \n-Ты в аду, сынок. Но не бойся заранее, здесь на самом деле намного лучше, чем описывают там, на земле. Вот ты в жизни курил? \nСтудент опускает глаза: - Да, курил. \n-Ну значит, по понедельникам для тебя будет праздник. Это у нас день курения. Выбор - огромный, от трубки и махорки до дорогих сигар и кальяна. Курим весь понедельник, до поздней ночи. И пофигу астма и рак - ты ведь уже умер! А выпить ты любил? \nСтудент опускает голову: - Не без этого... \n-У-у! Тогда готовься к праздникам по вторникам! Этот день мы пьём весь, с самого утра, от пива и лёгких вин до самых крепких напитков: самогона и спирта. И плевать на печень: ты ведь уже умер! А как насчёт наркотиков? \nСтудент краснеет: - Да, бывало! \n-Что ж, повеселишься по средам! У нас это день наркотиков, от самых лёгких, до тяжелых. И не бойся ни ломки, ни передоза, ни ментов - ты ведь уже умер! А с женщинами? \nСтудент оживляется: - А как же! \n-Тогда оторвёшься по четвергам! Это у нас день повального секса. Дело в том, что женщин в аду в 10 раз больше, чем мужчин, и у тебя будет супервыбор! А о сифилисе там всяком даже не вспоминай - ты ведь уже умер! А не смотрел ли ты аниме? \nСтудент вскидывается: - Смотрел! \n-Бля иди отсюда',
    'Приходит мужик в бар. Садится за стойку и рядом на стойку кладет маленькую собачку без лап. Заказывает бутылку водки, выпивает. \n\nБармен интересуется:\n- А как зовут-то собачку? \n\nМужик (с чувством, вытирая слезу):\n- Какая разница, блять, зови... не зови... - не прибежит нихуя.',
    'Шел боцман по палубе. И упало ведро боцману на голову. И сказал боцман посмотрев на ведро: \n— Да проебись ты троебучим проебом омандахуевшая пиздопроушина, тристахуиная страхопиздища спермы осеменяющей медуз членоглодского союза пиздоглазых писюносососов анальной кары божественной залупы смерти путем низвержение хуев в бездонную пучину спидозного говна обдристываемого гавноеблей негролойдов в чане туберкулёзного испражнения спермы анрахичной группы уебанов нейронной спермодрочки летающих хуев осеменивших подзалупных змей священного ракоспидопутанского говнища проклятого уебища-дрочиллы мертвых горилл.\nПосле чего грязно выругался.',
    'Учительница объявила оценки по контрольной:\n- У всех пятёрки, только у Петьки двойка!\n- А почему у меня два? - спросил Петька\n- Ну давай разберем по частям, тобою написанное )) Складывается впечатление что ты реально контуженный , обиженный жизнью имбицил )) Могу тебе и в глаза сказать, готов приехать послушать?) Вся та хуйня тобою написанное это простое пиздабольство , рембо ты комнатный)) от того что ты много написал, жизнь твоя лучше не станет)) пиздеть не мешки ворочить, много вас таких по весне оттаяло )) Про таких как ты говорят: Мама не хотела, папа не старался) Вникай в моё послание тебе, постарайся проанализировать и сделать выводы для себя)',
    'Сидят два парня в кинотеатре и ждут начало фильма. Тут перед ними \nсадится здоровый лысый мужик. Один парень, ехидно улыбаясь, говорит \nдругому: \n- Давай спорим на полтинник, что ты не сможешь шлепнуть его по лысине! \nТот, немного подумав: \n- А вот и смогу, давай спорить. \nНу поспорили. Парень немедля шлепает лысого мужика по башке. \nТот охуевши оглядывается, типа че такое? Парень сразу же: \n- Бля, Леха! Скоко лет, скоко зим! где пропадал? \nЛысый, покраснев, говорит: \n- Какой на хер Леха, вы перепутали! \nЛысый отворачивается. Проходит несколько минут, и первый парень опять: \n- Слабо второй раз шлепнуть? Спорим на сотку? \n- Конечно нет, давай спорим, что шлепну еще раз. \nТакая же ситуация, лысый уже готов ебнуть парня. А тот в ответ: \n- Бля, Леха, че ты придуриваешься? Мало что ты побрился, еще меня не \nузнаешь! \nЛысый разозленный поднимается и идет на передние ряды, чтобы не \nбеспокоили эти уроды. Проходит еще несколько минут: \n- Слабо еще раз шлепнуть? Спорим на 500? \n- Давай, спорим. \nПарень поднимается, идет к лысому, не раздумывая шлепает по лысине и \nкричит: \n- Бля, Леха! Ты, оказывается, здесь сидишь, а я там уже полчаса одного \nзаёбываю!\n- о, здарова!\nЭто был другой лысый.',
    'Молодой писатель приносит свою рукопись на читку редактору. Роман начинается со слов:\n"А не испить ли нам кофею? - спросил граф"\n- У вас отсутствует конфликт, - говорит редактор. - Надо исправить.\nПисатель кивает головой, уходит, и возвращается на следующий день с новым вариантом:\n"- А не испить ли нам кофею? - спросил граф.\n- Отнюдь, - ответила графиня.\n- Брезгуешь, сука! - гневно вскричал граф."\n- Уже лучше, - говорит редактор, - но тема любви совершенно не раскрыта, даже не затронута!\nТретий вариант романа выглядит так:\n"- А не испить ли нам кофею? - спросил граф.\n- Отнюдь, - ответила графиня.\n- Брезгуешь, сука! - гневно вскричал граф и выебал графиню три раза на подоконнике."\n- Очень хорошо! - доволен редактор. - Но не раскрыта тема природы…\nИ так далее, и так далее. После раскрытия тем природы, народа и революции получается примерно следующее:\n"- А не испить ли нам кофею? - спросил граф.\n- Отнюдь, - ответила графиня.\n- Брезгуешь, сука! - гневно вскричал граф и выебал графиню три раза на подоконнике.\nЗа окном шел дождь, полыхала Октябрьская революция, рабочие устало возвращались с завода. Под окном семеро мужиков ожесточённо трахали дохлую лошадь.”\n- Прекрасно, просто прекрасно! - радуется редактор. - Осталось добавить уверенность в завтрашнем дне, и сдаём в печать!\nОпубликованный роман начинается так:\n"- А не испить ли нам кофею? - спросил граф.\n- Отнюдь, - ответила графиня.\n- Брезгуешь, сука! - гневно вскричал граф и выебал графиню три раза на подоконнике.\nЗа окном шел дождь, полыхала Октябрьская революция, рабочие устало возвращались с завода. Под окном семеро мужиков ожесточённо трахали дохлую лошадь. Внезапно один из них хлопнул себя по лбу и прокричал:\n- Да чего же мы так надрываемся, братцы! Она же здесь и завтра лежать будет!”',
    'Армянин решил баллотироваться в горсовет. В регистратуре: \n- Род деятельности? \n- Машинист \n- Возраст? \n- 35 лет \n- Национальность? \n- Армянин \n- Партия? \n- Давайте',
    'Барабанщик группы "Бутырка" долго не соглашался сидеть и стучать.',
    'Упал мужик в пруд. Пытается выплыть. И тут его кто-то из глубины за яйца хвать, и голос:\n— Плюс 2 или минус 2?\n— Так оставь.\n— Ладно',
    'Отец и мать заходят в комнату к сыну.\n- Сынок, — говорит отец, — у тебя сегодня день рождения и мы тебе дарим...\n- Не заслужил я подарков, отец — перебивает сын.\n- Но почему?\n- Я весь год баловался, я писал контрольные на двойки, годовые оценки у меня одни тройки. Я плохой сын.\n- Нет-нет, день рождения это же особенный момент...\n- Нет! Я решил. Я весь год буду учиться и вести себя хорошо и тогда, в следующем году, я открою ваш подарок.\n- Ну хорошо, — сказал отец, почесав затылок.\nШли недели, месяца. Мальчик учился все лучше. Все его контрольные были на одни пятерки, а его отличному поведению удивлялись все одноклассники и учителя. И наконец, спустя год, на свой день рождения, он радостно пустил слезу. Взял стул и достал с самой верхней полки пыльную коробку, которую родители подарили ему ещё в прошлом году. Он положил ее на пол, быстренько открыл ее и улыбнулся.\nНа дне коробки лежал мертвый щенок.',
    'Где работает петербургский дипломат?\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\nВ посольстве.',
    'Стоит муж на кухне, пельмени лепит. Тут вваливается пьянющая в хлам жена:\n— О, у нас пелемешки будут?\nМуж:\n— Алкоголичка чёртова, опять нажралась! Сходи лучше к соседям, в доме соль закончилась.\nНу, вышла жена во двор, огляделась — до калитки далеко, дай, думает, через забор перелезу. Начала перелазить, ногой зацепилась, и обратно на землю упала. Будучи в полной уверенности, что находится на соседском участке, поднимается, отряхивается, стучит в дверь, заходит:\n— О, и у Вас пелемешки?\nМуж:\n— Ты чё, ебанулась?\n— А Вы что, в окно видели?',
    'Женщина лежит в постели с любовником. Вдруг раздается звонок в дверь,\nона понимает, что пришел муж и в порыве отчаяния восклицает:\n- Господи, сделай так, чтобы он ничего не заметил!\nРазверзаются небеса и господь говорит:\n- Хорошо, я так сделаю, но ты умрешь от воды.\nОна говорит:\n- Хорошо.\nПроходит год, два года. Женщина не купается, моется только под душем,\nстарается по возможности любыми путями избегать воды. Проходит 3 года,\nона неожиданно выигрывает путевку в морской круиз.\nПосомневалась-посомневалась, и решила поехать. Плывет она на шикарном\nлайнере, вдруг ночью начинается шторм, все в панике корабль тонет. Она\nопять в порыве отчаяния восклицает:\n- Господи, ну ты же не можешь из-за меня одной потопить весь корабль!\nРазверзаются небеса и господь говорит:\n- Могу лол.',
    'Перед званым вечером у Наташи Ростовой Ржевский отчитывает гусаров: не материться, не нажираться, дам прилюдно за задницу не хватать и т. п.\nВидя скованность гусар за ужином, Наташа задает вопрос: «Господа гусары у меня тут есть 29 подсвечников, а я купила тридцать свечей. Куда бы вставить тридцатую?»\nПоручик Ржевский, вскакивая из-за стола: "Господа гусары, ни слова о пизде!!"',
    'Пришёл как-то мужик к доктору, и говорит:\n- Доктор, у меня хуй чешется!\n- Мой чаще.\n- Нет мой.',
    'Молодая девушка на приеме у гинеколога. Гинеколог тоже молодой. Только из института. \n \nНус. Дорогуша, раздевайтесь. \n \nДоктор Вы такой молодой.... \n \nНу что я могу поделать. Я ведь врач... \n \nДоктор я стесняюсь. Не могли бы Вы хотя бы свет потушить... \n \nНу хорошо, хорошо, потушу... \n \nДоктор. А куда мне одежду положить? \n \nДа хоть рядом с моей.',
    'Однажды маленький мальчик решил отправить письмо на родину своей любимой игры. Написал и отправил. Там, где нужно было указать адрес, мальчик нацарапал "ЖИТЕЛЯМ СТРАНЫ, СОЗДАВШЕЙ САМУЮ ЛУЧШУЮ ИГРУ НА СВЕТЕ". Волею судеб письмо на почте попало в руки старому почтальону, который был фанатом бейсбола. Он решил отправить письмо в США, чтобы там решили, что же с ним делать. Американский почтальон, которому попало в руки это письмо, подумал, что все-таки бейсбол - сугубо американский вид спорта, и людьми других стран он ценится не так сильно... Дай, думает, пошлю я письмо в Канаду, на родину хоккея, ведь в хоккей играют по всему миру. В Монреале получили это письмо, порадовались, что о хоккее так хорошо думают во всем мире, подумали, но поразмыслив решили, что письмо, наверно, все-таки должно быть доставлено в Англию, где был придуман футбол. Британские сотрудники почты согласились, что футбол - самый популярный спорт в мире и решили не заморачиваться. Британцы открывают письмо, и там текст начинается следующим образом: "Дорогие армяне! ..."',
    'Идет мужик по пустыне. День–два–три. Вода закончилась, помирает. Вдруг смотрит — оазис. А там пруд–фонтаны–отель…\nНу мужик сразу в отель, дайте номер!\nА ему говорят, сори, отель только для негров. Че делать…\nПошел мужик, купил ваксы, лицо натёр, тело натёр, черный весь — приходит в отель — ему дают номер шикарный.\nНу он говорит портье, мол, разбудите меня завтра в 6 утра, тороплюсь, идти надо…\nНу будит портье в 6 утра мужика, тот вскакивает, рюкзак на плечи и вперёд.\nДень идёт, два идет, три, таже ситуация, оазис, отель.\nОн в отель — а там говорят, извините, отель только для белых.\nНу мужик думает фигня, идет к фонтану ваксу смыть, трёт–трёт, а вакска не смывается…\nПортье не того негра разбудил…',
    'У Иисуса было много плюсов, но самый большой был за спиной',
    'У подполковника кончились деньги, не знает где занять. Тут подбегает прапорщик и завязывается диалог.\n\n- Товарищ полковник, здравия желаю, почему вы такой хмурый?\n- Да деньги нужны, а занять не у кого, может одолжишь до зарплаты?\n- Ей богу, товарищ подполковник, последние на сигареты ушли. Но могу дать ценный совет.\n- Да чё мне твой совет, мне бы деньги.\nЕй богу, товарищ подполковник, очень ценный, из личного опыта.\n- Ладно, давай.\n- Значит сейчас идёте домой, жена на кухне, подкрадывайтесь так тихонечко, ручку на бедра, в шейку целуете и она сама вам все деньги отдаст, попробуете!\n- Ладно, спасибо, давай, пока.\nПриходит подпол домой, жена на кухне что-то готовит, все делает по инструкции, подкрадывается, нежно кладет руки, начинает целовать в шею. Тут жена так нежно в ответ:\n- Ну что, что, опять деньги нужны, прапорщик?',
    'Что сказал педофил, который вышел по УДО?\n.\n.\n.\n.\n.\n.\n.\nАхуеть, пятилетка за четыре года',
    'Ехал священник краем поля и увидел - парень сено косит, а к ногам\nего колокольцы привязаны. Удивился поп, но не стал человека от работы\nотрывать, проехал мимо.\nВ воскресенье увидел поп этого парня в церкви, подозвал и спрашивает:\n- Видел я такое диво... Что это такое?\n- А это, батюшка, вот что. Бывает, косой махнешь - и не заметишь\nзайчишку какого, птенчика, букашку... А так они колокольцы издали\nслышат - и разбегаются...\n- Да-а, сын мой, велика твоя святость... У тебя, наверное, и грехов-то\nнет при такой святости...\n- Как же, батюшка... Живу я у барина. Так, бывает, барин кобылку\nзапряжет, да с барыней в город отправится, барышня дома останется...\nГрешен, батюшка...\n- Ну, что это за грех, это дело молодое... Девка-то хороша?\n- Хороша... А, бывает, барин кобылку запряжет, да с барышней в город\nотправится, барыня дома останется... Грешен, батюшка...\n- Это, конечно, грех... Но за твои колокольцы простит тебе Бог\nи я тебя от этого греха разрешаю и прощаю...\n- А бывает, барин кобылку запряжет, барыню с барышней в город\nотправит, а сам дома останется... Грешен, батюшка...\n- Да, сын мой... Молиться тебе до конца своих дней, чтобы Бог тебя\nпростил... Если бы не твои колокольцы, я бы тебе...\n- А бывает, по осени дороги раскиснут, барин с барыней да с барышней\nпешком в город уйдут, кобылка дома останется... Грешен, батюшка...\n- Ну, сын мой, не на то место ты себе колокольцы повесил!',
    '- Алло, это скорая? Здесь человека катком переехало! \n- Говорите адрес. \n- Есенина 24,26,28...',
    'Брежнев выступает на съезде КПСС. \n— Идея. \nВсе поспешно открывают блокноты.\n— И де я нахожусь?',
    'Заходит русский  в таллинский бар, заказывает кружку пива. Бармен по-английски: \n-С вас 7 евро. \nРусский даёт 6 евро. Бармен опять по-английски:\n- Не 6 евро, а 7.\n Русский не реагирует. Тут бармен произносит по-русски: \n-Это пиво стоит 7 евро! \nРусский: \n-Я так и знал, что за один евро ты вспомнишь русский язык!',
    'приходит жена с работы домой, а там пельмени зумера ебут',
    'Увидев приближающийся Челябинск, жители метеорита ужаснулись..',
    'Автобус. Пробка. \nВодитель обьявляет: \n- Следующая остановка "пятого декабря".\nВозглас из салона: \n- Нихуя себе пробка!',
    'Море тонет корабль ,все садятся на шлюпки. Тут всех рассталкивая проходит Сталин и садится в шлюпку. Ему все кричат —"Как вы так можете,на корабле еще остались дети!" \nОн в ответ им говорит— "Нет спасибо, я не голоден"',
    'Попал пес в лес, а рядом лев идет и видит его:\n–О, давно я таких не ел, интересно – говорит лев бежит на пса.\nПес не знает, что делать, видит рядом кости лежат и говорит:\n–О какой лев вкусный был, хочу еще одного где-нибудь взять!!\nЛев думает ну мол, ну нахер его, пойду лучше отсюда, мало ли че за зверь такой. А сверху сидит обезьянка и видит что пес обманул льва, и решает рассказать все льву:\n–Пес тебя обманул, лев, пошли убьем его.\nЛев злится на пса и думает ладно. Бегут они к псу, пес видит что его раскрыли, не знает че делать и говорит:\n–Ну где эта обезьяна тупая? Я час назад просил еще одного льва мне принести!',
    'Идет охотник на медведя с двустволкой. Подходит к берлоге, кричит:\n"Эй, медведь, выходи!"\nBылезает медведь. Охотник целится, жмет на курок - осечка. Ну медведь его схватил, трахнул в задницу и обратно в берлогу залез. \nОхотник приходит на следующий день с пулеметом. Зовет медведя, Стреляет - опять осечка. Медведь его опять в жопу трахнул и отпустил.\nПриходит охотник на третий день со связкой гранат, швыряет их ни слова не говоря в берлогу, БАХ! ТРАX! Конец берлоге. Медведь слезает с соседнего дерева и говорит: "Мужик, я не пойму, ты охотник или педераст',
    'Собирает отец своих сыновей и спрашивает у них:\n— Кто из вас повалил наш туалет в реку?\nВсе смолчат, никто не хочет сознаваться\n— Я вижу, вы боитесь наказания. Я расскажу вам историю. Однажды Линкольн тоже повалил любимую вишню своего отца, но так как он сам честно во всём сознался, отец его простил.\nВыходит средний сын и признаётся:\n— Прости меня отец, это был я.\nОтец достаёт ремень и начинает его неистово хлестать.Тот восклицает:\n— Отец, а как же Линкольн?\n— Линкольн, когда рубил вишню, на ней отец не сидел!',
    '- И вторым выстрелом, господа, я попал медведю прямо в сердце, а третьим добил в голову!\n- А первым, первым, поручик?\n- А первым я поджёг машину...',
    'Пикник у Новых Русских, один говорит другому:\n— Вован, иди, разведи костёр.\nТот подходит к костру, садится\nна корточки и говорит:\n— Ну чё, костёр, ты попал!',
    'Построили хохлы стену вдоль русской границы.\nНо, блин, привыкли ездить в Россию работать, да и жрать хочется и вообще холодно зимой.\nРешили два хохла драпануть в Россию, подошли к стене, а перелезть не могут, высоковато.\nОдин другому говорит: \n- Давай я к стене стану, ты мне на плечи залезешь и мне потом руку подашь.\n- Давай.\nВстал Тарас. Мыкола залез ему на плечи, подтянулся и на стене. \nТарас снизу кричит:\n- Мыкола руку давай!\n- Какой я тебе Мыкола, Николай я! Пошёл нахер, хохляцкая морда!',
    'На мосту встречаются два новых русских на 600-ых мерседесах и не могут разъехаться, так как на мосту проезжает одновременно только одна машина. Один из них выходит и говорит:\n-Слышь, братан уступи мне дорогу, я новый русский.\nТут медленно открывается дверь у второго мерседеса и появляется второй новый русский и с удивлением говорит:\n-Ты представляешь, я тоже новый русский.\n-Да ты чё! На мне цепь 60 грамм!\n-Ты представляешь, на мне тоже цепь 60 грамм.\n-Да мне болт 40 грамм!\n-Ты не поверишь, но на мне тоже болт 40 грамм.\n-Да я вешу 120 килограм!\n-Прикинь, я тоже вешу 120 килограм.\nВдруг второй садится в машину и отеъезжает, уступая дорогу первому. Первый проехав несколько метров после моста задумался: "А что это он мне дорогу уступил?" Возвращается и спрашивает:\n-Слышь, братан, а чё это ты мне дорогу уступил?\n-Да, я так подумал, в тебе не 120 килограмм, в тебе 121 килограмм...\n-Почему?\n-Да я на тебя хуй положил...',
    'Новый русский собирается отдохнуть на Кипре. Сначала туда приехал его\nсекретарь (С) и ходит с хозяином 5-звездочного отеля (Х) по пляжу.\nС: А это че ?\nХ: Как что? Галька.\nС: Галька — это неправильно, шеф не любит. Гальку убрать, все посыпать\nбелым песочком.\nХ: Но это же очень дорого!\nС: Мы платим! (достал пачку наличных $, рассчитался) На следующий день\nвсе посыпано песком.\nС: А это че ?\nХ: Это же море!\nС: Какое море? Грязная лужа! В общем, море почистить, камешки убрать,\nволна должна накатывать каждые 30 секунд на 55 сантиметров.\nХ: Но вы понимаете, это же подводные инженерные работы, очень дорого!\nС: Мы платим! (достал пачку наличных $, рассчитался) Через два дня все\nкак надо.\nС: А это че ?\nХ: Это же чайки.\nС: Никаких чаек. Всех убрать! Оставить двух, пусть прогуливаются по\nпляжу и ни в коем случае не взлетать.\nХ: Но это же такой урон экологии, да еще дрессировка чаек...\nС: Мы платим! (достал пачку наличных $, рассчитался) Наконец приехал\nшеф. Он по чистому белому песочку прошел к морю, посмотрел на двух чаек,\nкоторые чинно прогуливались по кромке пляжа, сел в шезлонг, вдохнул\nполной грудью свежий морской воздух и сказал:\n— Господи! Ну разве такую красоту за деньги купишь?!',
    'У призедента:\n- Владимир Владимирович, мы граждан новыми налогами обложили!\n- Боже, что дальше?\n- Ну штрафы подняли!\n- Какой ужас! А потом?\n- Потом пенсионный возраст подняли!\n- Просто кошмар! А дальше то что?\n- Лишили свободы слова и действия!\n- И что же было потом?\n- Пока всё!\nПутин(яростно мастурбируя):\n- Дак придумайте же что-нибудь!',
    'Гордый армянский самурай, когда его уволили из сушибара, совершил хачапури',
    'Сидят русский и казах. Русский спрашивает:\n- Слушай, а у тебя жена есть?\n- Жок.\n- Молодец! Я бы свою тоже сжег нахуй!',
    'Мужик увидел надпись на дверях женского монастыря: "Cекc с молодыми монашками - 500 у.е.". Постучал, открыла прелестная монашка, приняла деньги и говорит:\n- Я пока приготовлюсь, а вы пройдите, пожалуйста, по коридору в последнюю дверь направо.\nМужик быстро прошмыгнул к указанной двери, открыл, снова попал на улицу, дверь за ним закрылась. Обернулся и видит на двери табличку: "Сегодня вас поимела сестра Мария".',
    'Рыбинспектор задерживает мужика с двумя ведрами рыбы на берегу реки.\nРыбинспектор спрашивает у мужика:-У Вас есть разрешение на отлов такого количества рыбы?\nМужик: Нет. Но оно мне не нужно. Это моя домашняя рыба.\nРыбинспектор: Домашняя? Как это?\nМужик: Ну, кто-то держит собак, кто-то попугаев, а я - речную рыбу. Каждый\nвечер я привожу их сюда, чтобы выгулять. Я выпускаю их в воду, они себе плавают, а потом я подаю им сигнал и они возвращаются ко мне, я кладу их в ведра и мы едем домой, в аквариум.\nРыбинспектор: Ерунда! Рыба не может такого делать!\nМужик: Не верите? Я могу показать. Вот смотрите...\nС этими словами мужик подходит к воде и переворачивает одно за одним оба\nведра. Сам остается на берегу в ожидании.\nЧерез несколько минут Рыбинспектор не выдерживает: -Ну?\nМужик: Что ну?\nРыбинспектор: Когда ты их позовешь назад?\nМужик: Позову кого?\nРыбинспектор: Рыб!\nМужик: Каких рыб?ты че ебанутый?',
    'Врезалась "копейка" в джип, из джипа вываливает братва.\n- Ну все старый ты попал, с тебя 10 000 баксов!\nДед открывает багажник достает деньги и говорит:\n- Шоб вы вcpались.\nCpут они день, cpут два, cpут неделю.\nНашли того старика.\n- Дед ты че наделал, ты че гонишь, мы уже неделю cpем!!!\n- Хлопцы с вас 20 000 баксов.\n- Ну дед ты вооще оборзел, ладно держи.\n- Все не cpите.\nНе cpут они день, не cpут неделю, не cpут месяц.\nОпять старого выловили.\n- Старик мы месяц не cpем, мы же тебе деньги дали, да мы тебе башку\nоткрутим.\n- Ребятки с вас 50 000 штук зелени.\n- Старый xpен с тобой, бери деньги. Но только все будет нормально?\n- Да.\n- Не старый ты точно скажи, все будет нормально?\n- Да все будет нормально не ccыте!',
    'Что общего у педофила и сахарного диабетика?\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\nОба хотят Алёнку, но нельзя.',
    'Сидит химик у себя в лаборатории, смешивает Берилий, бор и радий, а после занюхнул\n\n- Чё ты тут смешал? Почему ты это нюхаешь?- спросил его коллега.\n- BeBRa',
    'Почему русскому купили водку, немцу пиво, а хохлу ничего не купили?\n.\n.\n.\n.\n.\n.\n.\n.\n.\nХохла спросить забыли',
    'девочка приходит в хор и говорит:\n- дяденька! я хочу петь басом!\n- девочка, а скажи что-нибудь грубо.\n- я хочу петь басом, уроды ебаные!!!',
    'Два каннибала жрут клоуна. Один другому говорит:\n\n— Чет нихуя не смешно',
    'В 1918-ом году вызывают хохла в Смольный и допрашивают:\n- Вот, представьте себе, что вы идёте по полю, а вам на встречу идут белый генерал и красноармеец. Кого вы убьёте?\nХохол:\n- Москаля!\nКомандировали хохла в тифозные бараки.\nВ 1938-ом привозят в НКВД на допрос:\n- Представьте себе, что вы идёте по улице, а вам на встречу иностранный шпион и коммунист. Кого вы убьёте?\n- Москаля!\nСослали хохла в Сибирь.\nВ 1943-ем привезли хохла в особый отдел:\n- Вот идете вы по лесу, а вам навстречу фашист и советский герой-партизан. Кого вы убьёте?\nХохол:\n- А вы кого?\n- Я??? Фашиста, конечно!\n- Так цеж, мне опять москаль достался…',
    'Однажды молодой человек узнал в прохожем своего учителя из младших классов. Он подошел к старику и спросил:\n— Вы меня не помните? Я был вашим учеником.\n— Да, я помню тебя третьеклассником. И чем ты занимаешься сейчас?\n— Я преподаю. Вы так повлияли на меня, что мне тоже захотелось воспитывать юных учеников.\n— Да? Позволь мне полюбопытствовать, в чём же выразилось моё влияние?\n— Вы на самом деле не помните? Разрешите мне освежить это в вашей памяти.\nОднажды мой одноклассник пришел в класс с красивыми часами на руке, которые ему подарили родители. Он их снял и положил в ящик парты. Я всегда мечтал иметь такие часы. Я не удержался и решил взять их из его парты. Вскоре тот мальчик подошел к вам в слезах и пожаловался на кражу. Вы обвели нас всех взглядом и сказали: «Тот, кто забрал часы, принадлежащие этому мальчику, пожалуйста, верните их».\nМне стало очень стыдно, но мне не хотелось расставаться с часами, так что я не признался. Вы направились к двери, заперли ее и велели нам всем выстроиться вдоль стены, предупредив: «Я должен проверить все ваши карманы при одном условии, что вы все закроете глаза». Мы послушались, и я почувствовал, что это был самый постыдный момент в моей недолгой жизни.\nВы двигались от ученика к ученику, от кармана к карману. Когда вы достали часы из моего кармана, вы продолжали двигаться до конца ряда. Затем вы сказали: «Дети, всё в порядке. Вы можете открыть глаза и вернуться к своим партам». Вы вернули часы владельцу и не произнесли больше ни одного слова по поводу этого инцидента.\nТак в тот день вы спасли мою честь и мою душу. Вы не запятнали меня как вора, лгуна, никудышного ребенка. Вы даже не удосужились поговорить со мной об этом эпизоде. Со временем я понял, почему. Потому что, как истинный учитель, вы не захотели запятнать достоинство юного, ещё не сформировавшегося ученика. Поэтому я стал педагогом.\nОба замолкли под впечатлением этой истории.\nЗатем молодой педагог спросил:\n— Когда Вы меня увидели сегодня, разве не вспомнили об этом эпизоде?\nСтарый учитель ответил:\n— Конечно вспомнил! Дело в том, что я пиздец как люблю лапать молодых мальчиков.',
    'Рыбинспектор задерживает мужика с двумя ведрами рыбы на берегу реки.\nРыбинспектор спрашивает у мужика:\n- У Вас есть разрешение на отлов такого количества рыбы?\nМужик:\n- Нет. Но оно мне не нужно. Это моя домашняя рыба.\nРыбинспектор:\n- Домашняя? Как это?\nМужик:\n- Ну, кто-то держит собак, кто-то попугаев, а я - речную рыбу. Каждый вечер я привожу их сюда, чтобы выгулять. Я выпускаю их в воду, они себе плавают. А потом я подаю им сигнал и они возвращаются ко мне. Я кладу их в ведра и мы едем домой, в аквариум.\nРыбинспектор:\n- Ерунда! Рыба не может такого делать!\nМужик:\n- Не верите? Я могу показать. Вот смотрите...\nС этими словами мужик подходит к воде и переворачивает одно за одним оба ведра. Сам остается на берегу в ожидании.\nЧерез несколько минут Рыбинспектор не выдерживает:\n- Ну?!\nМужик:\n- Что ну?\nРыбинспектор:\n- Когда ты их позовешь назад?\nМужик:\n- Позову кого?\nРыбинспектор:\n- Рыб!!!\nМужик:\n- Каких рыб?! Ты ебанутый что ли?!',
    'Дагестанские блохи услышав лезгинку затоптали кошку на смерть',
    'Мужик приходит к тату-мастеру и говорит:\n-А набей мне на всю спину танк\n-Да не вопрос, ложись\nПроходит 15 минут, тату-мастер говорит:\n-Ну всё, готово\n-А почему я встать не могу?\n-А хули ты хотел? 46 тонн!',
    'Остановка. Подходит автобус. Интеллигентного вида человек пропускает всех вперед. Сам пытается зайти последним. И ему дверью придавливает шею. \nАвтобус трогается. \n- Блять!!! Пиздец!!! Ёбаный в рот!!! Стой на хуй!!! Охуели пидарасы!!! \nОторвете к ебеням же голову!!! \nВодитель тормозит, открывает дверь. Чел заходит в салон, поправляет \nгалстук и обращается ко всем: \n- Извините. Был напуган.',
    'В Афганистане муджахеды окружили советский бронетраспортер:\n- Эй рус! Сдавайсь!\nВ ответ тишина.\n- Эй рус! Сдавайсь!\n- Рус нет! Узбек хочешь?',
    'Винни-пух с Пятачком приходят 1-го сентября в школу. Ну, тут, как водится, сочинение — "Как я провел лето". Пятачок говорит:\n— Винни, а что мы писать будем? Мы ведь все лето целыми днями "план" курили, а больше ничего не делали. Винни-пух подумал и говорит:\n— А ты, Пятачок, вместо слова "курили" пиши "читали". Читали целое лето — это же хорошо.\nНу ладно, написали они это дело. Проверяют работу Пятачка: "Проснулся я как-то утром. Почитал. Пошел умылся. Почитал. Перед завтраком еще немного почитал. Позавтракал. До обеда читал. Пообедал. Чего-то мне спать захотелось. Ну, перед сном почитал. Дочитал книжку. Поспал.Проснулся, почитал. Тут Винни-пух пришел. Сразу видно — читал. Ну мы с ним на балкон пошли. Стоим, читаем. Тут внизу Иа-Иа идет и кричит: "У вас есть что почитать?" А сам такой начитанный-начитанный, и еще пол-Букваря за ухом торчит".',
    'Как родители наказывают своего слепого сына?\n\nПередвигают всю мебель в доме',
    'На диктанте Марьиванна диктует предложение:\n"В доме стоит полная тишина, и лишь в углу скребёт мышь".\nВовочка поднимает руку:\n"Марьиванна, а кто такой Вуглускр?"',
    'В дверь постучали 0-3-5-0-3-6-5-0-3-5-3-0.\n"Гитарист", - подумал Штирлиц.',
    'Hаташа Ростова загадывает поручику загадку:\n- Поручик, угадайте-ка: что такое - маленькое, серенькое,\nв половую щелку - вжик !!!\nПоручик мнется:\n- Hаташа, но это же неприлично, хм...\n- Поручик, да что вы, это же мышка !\nПоручик удивленно снимает пенсне:\n- Мышь ??? В пизде ??? Оригинально !',
    'Еврей перед казнью. \n— Ваше последнее желание? \n— Хочу вишни. \n— Но сейчас же декабрь! \n— Таки я подожду.',
    'Пиво приходит в желудок, а там водка.\n- Эй, подвинься!\n- Сам подвинься! Градусом ещё не дорос.\n- А ну пошли выйдем!',
    'У сторонников и противников вакцинации есть одна общая черта: и те и другие уверены, что долбоёбы вымрут.',
    '— Доктор, мне везде мерещатся анекдоты. \n— А какое у вас зрение? \n— Кажется, 2.\n— +2 или -2?',
    'Решили ученые сделать робота-драмера. Ну, соорудили конструкцию. Параметр "Интеллект" выкрутили на 100%, посадили за установку дали в руки палки... А робот — ни движения. Понизили "Интеллект" до 50%, робот выдал "тунц-тыщ-тунц-тыщ" Ученые начали радоваццо, опять снизили "Интеллект", но в этот раз — до 25%. Робот начал выдавать прикольные партии. Ну, ученые думают: "Ооо, ништяк, а если на ноль поставим, то ваще трэш начнеццо". И поставили. Робот встал и взял бас.',
    'СССР. Приезжает Брежнев в Колхоз. Видит косец сено косит.\nПодходит Генсек к косцу и говорит:\n— Не рационально работаешь, возьми две косы и коси в обе стороны!\nПриезжает Брежнев ещё раз. Косец косит двумя косами.\nПодходит Генсек к косцу и говорит:\n— Не рационально работаешь, повесь на жопу грабли и убирай за собой сено!\nПриезжает Брежнев ещё раз. Косец косит. Грабли у косца на жопе, сено гребут. Генсек идет к косцу, а тот удирать… Охрана догнала, привела к Брежневу.\nТот спрашивает:\n— Ты зачем убегаешь, я хотел тебе орден вручить!\nКосец отвечает:\n— А я думал, Вы заставите повесить мне на член фонарь и работать в ночную смену',
    'Один мудрый сенсей 15 лет обучал своего ученика. И вот, наконец, сенсей решил что пришла пора для финального испытания. Пошли они с учеником в лес. Сначала на пути учителю и его подопечному встретились волки. Ученик сразу бросился в бой, начал сыпать всеми приемами подряд. Но волки одерживали верх. Тогда ученик оглянулся на сенсея. Сенсей лишь улыбнулся и сказал: \n\n-Ты, подобно человеку идущему против ветра, идёшь напролом. Попробуй анализировать их атаки и заходить сбоку.\n\nПосле совета сенсея, его подопечный без проблем разделался с волками. Пошли они дальше и набрели на разбойника. Ученик ринулся в бой, но опять сколько бы он не сражался, результата не было. Ученик оглянулся на учителя:\n\n-Ты, подобно птице в шторм, не экономишь силы. Заставь его выдохнуться\n\nПосле совета сенсея, ученик без труда одолел разбойника. Пошли эти двое дальше, а на встречу им шесть воров с ножами. Ученик, по обыкновению, сразу ринулся в бой, но их было много и ученик проигрывал. Тогда он оглянулся и понял что сенсей дал по сьебам.',
    'Беспилотник США прилетел в Россию на разведку, а вернулся с установленным пакетом яндекс приложений',
    'Летит самолет домой (транспортник, летит из южных стран), ну понятное дело экипаж фруктов набрал, овощей разных, весь борт забит до отказа, взлетают значит.\n500 метров до конца полосы нет отрыва, 300 метров нет отрыва, 100 метров нет отрыва, 5 метров - фух, есть отрыв. Командир, весь в поту, поворачивается к штурману:\n-Блять еще ведро черешни могли взять.',
    'Дворик в клинике для душевнобольных, на лужайке сидит псих и увлеченно пробивает с помощью гвоздя и молотка отверстия в новом оцинкованном ведре. Мимо по дорожке идет врач, останавливается напротив больного и ласково так:\n— И чем же мы тут занимаемся?\n— Да вот, бульбометр делаю.\n— ??? !!!\n— Ну, воду в него наливаешь, она из дырочек выливается и булькает. Вот эти бульки и считаешь. Бульбометр одним словом... — объясняет пациент.\n— Ха-ха-ха! Ну, закончил? — врач забирает молоток с гвоздем, а дырявое ведро перекидывает через бетонный забор.\nА за забором с психушкой соседствует воинская часть, ведро падает прямо на плац, в это время по плацу идет злой прапор, только что получивший нагоняй от начальства:\n— Блядь! Не часть, а сплошной бардак! Кругом бычки, мусор! (поднимая ведро)\n— Во! Ещё и бульбометр новый кто-то выкинул...',
    'Ушел мужик в монастырь, дал обет молчания, но раз в 10 лет можно было сказать два слова.\nПрошло 10 лет.\n- Еда говно.\nПрошло ещё 10.\n- Кровать жесткая.\nЕщё через 10 подходит к настоятелю и говорит:\n- Я ухожу.\n- Ну оно и понятно, жаловался ты дохуя.',
    'Заселяется первокурсник в общагу, старшак ему экскурсию проводит, доходит до кухни, говорит: \n- А это плита, только духовку не открывай, нельзя \n- Почему это? \n- Если расскажу, все равно не поверишь, нельзя и все тут. \nПервокурснику стало любопытно, и вот он после отбоя крадётся к плите, открывает духовку, а там сидит внутри на диване огромный таракан, перед ним маленький телевизор включен, пиво на столике, закусь лежит. Он поворачивается на первака и орет: \n- АААААААА БЛЯТЬ НАХУЙ!!!!!!',
    'Научил попугая говорить "Чурка". Извиняться ему пришлось учиться самому.',
    'В семье потомственных пулемётчиков умер отец.\nДля них это была настоящая утрататататататата',
    'В класс заходит новый учитель с огромным косяком, садится, запаливает, тянет… \n— Дети, я ваш новый учитель биологии, Петр Сергеевич… \nЗатягивается, выдыхает… \n— Сегодня я расскажу вам про рыбу-пилу… \nЗатягивается… \n— Эта рыба обитает на са–а–амом дне океана, у дна, в вечной мгле… \n…еще тяжка… \n— Но иногда она выходит на берег, и начинает пилить деревья… \nЗатягивается, выдыхает… задумчиво: \n— Курить люблю пиздец',
    'Откинулся как-то зэк с зоны, зашел в ресторан, зовет кудрявую официантку: \n- Эй ты, в натуре, иди сда! \n- Чего изволите? \n- Чифира давай, поняла! \n- Извините, а что это такое? \n- Hy ты че, шалава ебаная, охуела в натуре?!? Не принесёшь через 5 минут - на перо посажу!!! \nОфициантка прибегает к повару вся в слезах, говорит: \n-Там какой-то еблан чифиру заказал, зарезать грозил, если через пять минут чифиру не принесу. А я даже не знаю, что это такое. \nПовар отвечает: \n- Не печалься, сейчас сделаю, через 5 минут подашь.\nВ общем, сделал чифир, приносит она его зэку. Зэк отхлебнул маленько, поморщился. \nИ тут его глаза округлились, он резко загрустил, по щеке покатилась скупая слеза. Он поднял взгляд на официантку, внимательно всмотрелся в неё и дрожащим голосом спросил: \n-Хова? Ты?',
    'Играет маленькая девочка в песочнице. Мимо идет мужик. Она ему:\n- Дяденька, скажи «раз»!\n- Раз.\n- Ты – пидорас! Ха-ха-ха!!!\nИ убежала.\nНа следующий день мужик опять проходит мимо. Девочка ему:\n- Дяденька, скажи «три»!\n- Три.\n- Пидорас – это ты! Ха-ха-ха!!!\nИ убежала.\nНа третий день мужик опять проходит мимо. Девочка ему снова:\n- Дяденька, скажи «пять»!\n- Пять.\n- Пидорас ты опять! Ха-ха-ха!!!\nИ убежала.\nНа следующий день мужик подходит к ней и говорит:\n- Девочка, скажи сто.\n- Сто.\n- Сто хуев тебе в панамку!\n- Так ведь не складно!\n- Вот сиди и складывай!!!',
    'Одесский еврей предложил растянуть сетку над Киевом чтобы ловить русские снаряды и продавать их.',
    'Дама разводится с мужем.\nСудья спрашивает даму:\n- Какова причина развода?\n- Ну….\n- Он пьет?\n- Нет.\n- Наркотики?\n- Нет.\n- Мало зарабатывает?\n- Да в общем, нет.\n- Бьет?\n- Нет.\n- Не заботится о детях?\n- Заботится.\n- Изменяет?\n- Нет, что вы!\n- Не удовлетворяет вас как женщину?\n- Нет, с этим все нормально.\n- Не помогает по дому?\n- Помогает.\n- Тогда в чем же причина?\n- Понимаете, гражданин судья, все что нужно он делает… но… вы бы видели, с каким лицом он это делает ….',
    'Городок в западно-американской степи. Салун. За столом сидят два ковбоя, местный и приезжий, и пьют виски. Вдруг по улице кто-то проносится на огромной скорости, паля во все стороны из револьверов. В салуне никто и ухом не ведёт. Приезжий местному: \n— Билли? \n— Да, Гарри? \n— Что это было, Билли? \n— Это был Неуловимый Джо, Гарри. \n— А почему его зовут Неуловимым Джо, Билли? \n— Потому что его никто ещё не поймал, Гарри. \n— А почему его никто ещё не поймал, Билли? \n— Потому что он нахуй никому не нужен, Гарри.',
    'Мой дед говорил так- когда одна дверь закрывается, другая открывается. Хороший был дед, а вот шкафы плохо собирал.',
    'Приехал каратист в деревню, мужики к нему подходят и начинают докапываться, типо: "Покажи приёмчик", тот в отказ, мол отдыхать приехал, а не драться, деревенские не сдаются и он не соглашается.\nИдут мужики к самому сильному и драчливому, кузнецу Ивану зовут его, чтобы каратиста на драку вывести.\nПриходит Иван к каратисту, начинает на него с кулаками кидаться, каратист херак и вырубил Ивана. Мужики к Ване подбегают бьют его по щекам, водой поливают. Иван открывает один глаз спрашивает: "Каратист ушёл?" \nмужики: "Нет, вон рядом стоит" \nИван:"Сейчас уйдёт я всем вам пизды дам"',
    'Летят десантники в самолете, выходит к ним офицер и говорит:\n- Парни, все летим в Афган воевать.\nПарни помрачнели так... Но офицер продолжает:\n- Но за голову каждого убитого душмана будем выплачивать премию - 100 советских рублей!\nСамолет заходит на посадку, десантники врассыпную. Офицер в одиночестве, стоит возле самолета. Через 30 минут десантники возвращаются, тащат связки голов. Офицер стоит у ужасе:\n- Ребята, мы же в Ташкенте сели для дозаправки',
    'Идет девочка лет десяти по улице. Вся в белом. Платьице белое, белые гольфики, бантики белые. Белая собачка на белом поводочке. Идет такая по улице радостная. Вдруг отодвигается крышка канализационного люка и вылезает дядя Петя сантехник весь в дерьмище и начинает отряхиваться. Все говно летит на девочку, на бантики, на платьице, на собачку. Девочка со слезами: \n - Дяденька, за что?\n - Аааа, Не нравится? А срать тебе нравится?',
    'На одном корабле работал фокусник. Так как пассажиры постоянно\nменялись, он без перемены проделывал одни и те же фокусы.\nК его несчастью, капитанский попугай просмотрел его выступление\nдостаточно раз и разгадал все секреты. Во время каждого\nвыступления попугай портил все фокусы своими криками "Эта не та\nшляпа! Он прячет пиковую даму в кармане брюк ! В коробке дырочка!"\nФокусник сердился, но ничего не мог сделать, капитанский попугай\nвсе-таки. Однажды корабль потерпел кораблекрушение, и только\nфокусник и попугай выжили чудом, и продолжали плавать в море на\nкаком-то бревне. Фокусник постоянно злобно смотрел на попугая,\nкоторый в свою очередь не переставал смотреть на фокусника.\nНаконец, через неделю попугай не выдержал:\n- Ну ладно, ладно, я сдаюсь! где корабль?!?',
    'Скачет Илья Муромец по пустыне, устал, силы на исходе, видит, вдали оазис вода и еда, и там же Змей Горыныч. Илья Муромец достал свой меч и в бой со Змеем Горынычем, бьётся день и ночь с ним в жестоком бою, на третий день Змей Горыныч спрашивает у Богатыря:\n— Да что ж тебе надо от меня?\n— Да пить я хочу.\n— Да пей, х*ли ты доебался-то?!',
    'Идут парень с девушкой. Вокруг красота, птички поют. Парень намекает- давай в лесок зайдём. Нашли подходящую полянку и разложились на плесень и на липовый мёд',
    'Bстречаются двое: — Привет, слыхал, что Петрович умер? — Нет а как? — Пьяный домой пришел — Сердце встало? — Да нет, он дома покурить решил и квартира загорелась — Сгорел? — Нет, он пожарников вызвал и в окно выпрыгнул — Разбился? — Не... там пожарники тент расстелили и его обратно в окно — Так все-таки сгорел? — Нет... он мимо окна пролетал и за подоконник зацепился ну и обратно — Так значит все-таки разбился? — Нет, там же тент его на дорогу откинуло — Так значит сбило... — Да нет там камаз батуты вез его обратно в окно откинуло — Так все таки сгорел???!!! — Да нет, застрелили его — Как так? — Да заебал туда сюда летать.',
    'Колхоз, 30-е годы. В клубе судят тракториста, по пьянке утопившего трактор в болоте.\nВ тюрьму сажать нельзя - колхоз без тракториста останется и наказать надо.\nПредседатель:\n- Ну что товарищи с ним делать будем?\nТянет руку кузнец, здоровенный парень:\n-А давайте я его по башке ебну.\nПредседатель:\n- Ты такой здоровый, его ебнешь и он помрет от этого, а у нас трактористов больше нет.\nСидят, дальше обсуждают. Кузнец опять тянет руку.\n- Ну чего тебе?\n- А давайте я хохлу ебну, у нас их все равно двое.',
    'Америка. Маленький городишко. Парикмахерская. Парикмахер стрижет своего постоянного клиента.\n\n— Какие планы на отпуск, старина?\n\n— Хочу побывать в Москве...\n\n— В Москве!!! В этом грязном, вонючем городе, где мусор не убирают и по улице ходят бандиты и медведи! Да вы что, сэр?! Hе вздумайте!!!\n\n— И все-таки я поеду. Ведь мои дедушка и бабушка когда-то жили там!\n\n— А какими авиалиниями летишь?\n\n— Аэрофлотом!\n\n— Мама дорогая, это самые поганые авиалинии. Там воняет керосином, ужасная теснота и отвратительная еда. Пару часов опоздания вам гарантировано!\n\n— И все-таки я еду!\n\n— Ну ладно, а в какой гостинице вы остановитесь в Москве?\n\n— В "России"!\n\n— Какой кошмар! Там куча проституток, ломовые цены, кругом тараканы и мерзопакостный персонал.\n\n— Я еду, в любом случае!\n\n— А что же вы будете делать в Москве?\n\n— Хочу сходить в Мавзолей Ленина!\n\n— Там же огромная очередь, кругом милиция и шмон. Мерзко и противно!\n\n— Меня ничто не остановит! - отвечает клиент.\n\nЧерез пару месяцев, после поездки он приходит в парикмахерскую.\n\n— Привет, дружище, - говорит парихмахер, - как поездка? Правду ли я вам говорил про Москву?\n\n— Знаете, Москва мне очень понравилась. У них новый мэр Лужков и он навел там порядок. Кругом чистота, криминала мало и медведей я не видел!\n\n— Ну, а Аэрофлот как? Все, как я сказал?\n\n— Не совсем. Самолет был почти пустой, так что нас пересадили в 1-й класс. Кормили отменно и стюардесса была очень милой и симпатичной девушкой.\n\n— Ну, а гостиница, правда, дрянь?!\n\n— Что вы! Они там недавно сделали ремонт и была неделя скидок, так что я жил в номере люкс! Никаких проституток и тараканов.\n\n— Ну, а Ленина-то видели? - не унимается парикмахер.\n\n— Представьте себе, видел. И вы даже не поверите. Стою я в очереди, вдруг подходит человек в штатском, отводит меня в сторону и говорит, что их ученые только что совершили чудо и смогли оживить Ленина, и что он хочет поговорить с кем-нибудь из толпы, и они выбрали меня для этой цели.\n\n— Боже, ушам своим не верю! И что же Ленин вам сказал?\n\n— Да всего пару слов: "Батенька, и кто же это вас так х*ево подстгиг?"',
    'Таможенник поднимается на корабль для досмотра.\n- Наркотики есть?\nХозяин корабля отвечает:\n- Есть. Вот, пожалуйста (достает чемодан). Вот героин, вот кокаин.\nВсе аккуратно упаковано,вот шприц готовый.\nТаможенник, вытаращив глаза:\n- А может, и оружие есть?\nХозяин (достает другой чемодан):\n- Вот макаров, вот калашник ,вот патроны к ним. Все как надо.\nТаможенник с усмешкой:\n- Наверное, и валюта есть?\nХозяин достает третий чемодан:\n- Вот миллион долларов, пожалуйста.\nТаможенник, ничего не понимая:\n- И это все ваше?\nХозяин:\n- Нет, это ваше. Мое в трюме.',
    'Едет машина скорой помощи, внутри водитель, врач, фельдшей, медсестра и студент практикант. Едут, вдруг водитель резко тормозит и начинает задыхаться. Хватается руками за горло, шипит - ужасное зрелище. Медсестра невозмутимо и твердо хватает чемоданчик с препаратами и бьет водителя по голове. Тот моментально успокаивается и машина продолжает движение. Тут фельдшер хватается за горло, падает на пол, начинает задыхаться и сипеть. Медсестра зло бьет фельдшера по голове и тот сразу оправляется и садится на место. Не прошло и минуты, как врач начинает задыхаться и брыкаться на полу. Медсестра резким ударом чемоданчика приводит врача в чувства. Обалдевший от увиденного студент спрашивает у врача: \n- Я учусь только на 4 курсе и все мои знания - это сплошная теория, но о подобных симптомах я даже не слышал! А метод лечения настолько странный, что я окончательно растерян, не могли бы вы мне объяснить.. \nВрач, махая рукой: \n- А, не бери в голову. У медсестры муж вчера повесился, мы ее подъебываем',
    'Приезжает руский учитель в Украину по работе.\nЗаходит в класс и думает, блять, а кого спашивать',
    'Математик пришел к своему врачу:\n- Доктор, я влюбился в девушку-физика. Вы должны помочь мне стать физиком!\n- Вы уверены? – спросил доктор. – Для этого придется сделать операцию и удалить половину вашего мозга.\nМатематик сказал, что это неважно, он готов на все.\nПроснувшись после операции, он увидел доктора возле своей кровати.\n- Я очень сильно извиняюсь, - сказал доктор. - Мы совершили ужасную ошибку. Мы удалили 99,9% вашего мозга.\nПарень ударил себя по лбу и закричал:\n- О нет! Вы удалили мне весь мозг!\n- Поздравляю, вы физик!',
    'Глухонемой водитель на перекрёстке отчаянно пытается понять, почему регулировщик шлёт его нахуй.',
    'У армянского математика родился сын. Он назвал его График.',
    'Два украинца на волах едут на базар. Волы идут медленно. Один\nподсел в телегу к другому: \n– Грицько, ты зачем на базар едешь? \n– Самогон везу продавать. \n– И я везу самогон. А ты почем будешь продавать? \n– Да по рублю стакан. \n– И я по рублю стакан. Слушай, вот тебе рубль, дай мне твоего самогона попробовать. \nПопробовал. \n– Слухай, Петро, вот тебе рубль обратно, дай и мне твоего самогона\nпопробовать. \nПопробовал. \n– Грицько! Гарний у тебя самогон. Дай еще стакан, вот тебе рубль. \nИ так далее. Пробовали, пробовали, самогон у обоих кончился. \nПришлось повернуть обратно. \n– Как же так получается? Целый день так бойко торговали, а у нас\nкак был один рубль на двоих, так и остался?',
    'Сидит субботним утром семья, завтракают... Вдруг у взрослых желание сексуальное разыгралось, они быстренько перемигнулись ... Жена тут же встает из-за стола и говорит:\n\n- Что-то у меня аппетит пропал, я доедать не буду.\n\nИ поднимается на второй этаж, в спальню. Муж быстренько доел, вскочил и тоже бегом в спальню. Дети никак не поймут, что с родителями происходит. Старший говорит младшему:\n\n- А ну-ка сбегай на второй этаж, посмотри, что там такое.\n\nМладший поднимается, потом возвращается бегом, садится за стол и начинает быстро-быстро есть. Старший спрашивает:\n\n- Что случилось, чего это ты так быстро ешь?\n\n- Там наверху, тех, кто не доедает, папа в жопу ебет',
    'Идут на встречу друг другу заика и горбатый. Заика спрашивает:\n- С-си-гга-реткки не ббудет?\nГорбатый:\n- Ннет, ннне ббудет!\nЗаика:\n- А в рюкзачке?',
    'Нигилист начал отрицать нигилизм и анигилировался',
    'Медведь попал в смертельную аварию и чудом выжил.\n"Чудес не бывает", - подумал Медведь и залез обратно в горящую машину.',
    'Тащит прапор тачку с говном, навстречу ему майор:\n- Чё тащешь?\n- Да вот говно везу.\nНу майор не поверил, как так, прапор и ниче не спиздил, решил проверить. Рукава засучил и в говне начал руками лазить, ессно ничего не нашёл. Идёт прапор дальше, навстречу ему полковник. Ну там такая же фигня происходит.\nПотом навстречу ему генерал, тоже не поверил, полазил в говне полазиз, ничего не нашёл. "Ну- думает - прапор наш исправляется, ничего не спиздил".\nПрапор выходит с базы:\n- Чё спиздил, чё спиздил. Вываливает говно из тачки. Тачку спиздил!!!',
    'Двое кавказцев играют в шахматы. Один ставит своего ферзя на середину поля: \n– Мат! \nВторой ставит рядом своего короля: \n– Отэц!',
    'Встречаются три проститутки. Выпили и давай спорить, кто лучше: военный, колхозник или студент... Спорили, спорили и решили попробовать по одному и потом встретиться, да поделиться впечатлениями. \nНа следующий день:\n- Я с колхозником думала с ума сойду. Сначала корову доили в четыре руки, потом пошли на сеновал, он одну палку кинул и убежал курей кормить.\nВторая:\n- А я со студентом 4 часа на парах просидела, потом он в буфете булочки жрал, в общагу отвел, за сиськи подержал и убежал уроки делать.\nТретья:\n- Бля, девки, ну вы хоть кайфанули, а я с военным 3 литра водки на двоих выпила,  затем мы 2 часа от караула бегали, потом он меня к забору раком поставил, я говорю: "давай хоть колготки сниму", а он: "не надо, я и так перелезу".',
    'Священник тонет в океане. Вдруг мимо проплывает лодка, и рыбак кричит: "Вам нужна помощь?" Священник отвечает: "Нет, Бог спасёт меня". Через какое-то время мимо проплывает ещё одна лодка, рыбак спрашивает: "Эй, вам помочь?" Священник снова отвечает: "Нет, Бог спасёт меня". В конце концов священник умирает и попадает в рай. Он спрашивает Бога: "Почему ты не спас меня, Боже?" Бог отвечает: "Ты долбоёб? Я тебе две лодки послал!"',
    'XIX век. Россия. Поезд Москва - Петербург. Вагон. Купе. На третьей полке дрыхнет денщик. \nНа первой - боевой генерал, весь в медалях, на второй - поп,напротив - попадья с дочкой. \nГрохот, треск. Сверзается вниз денщик: \n- Господин генерал, разрешите поссать. \n- Иди. \nКряхтя, спускается поп. \n- Ну как ему не стыдно! Вот вы, боевой генерал, грудь медалями украшена, кровь за родину проливали, а он при вас - поссать. Я, святой отец, за дела ваши грешные молюся, лысину учением нажил, а он при мне - поссать. Жена моя, честная женщина, девушкой за меня вышла, не изменяла ни разу, дочь родила, а он при ней - поссать. Дочь моя, голубица непорочная, греха не знающая, а он при ней поссать. \n- Ну успокойся, папаша, внушение сделаю. \nГрохот, треск. Врывается денщик. \n- Господин генерал, разрешите доложить - поссал! \nГенерал, со строгим видом: \n- Ах ты, ёб твою мать, пиздоглазое мудоёбище! Я тебе кто, боевой генерал, или хуй собачий? Кровь за Родину проливал, грудь медалями расхуячена, а ты при мне - поссать. Это тебе что, конская залупа на солнце блестит, или лысина отца святого за дела наши блядские лоб расшибшего? А ты при нём что - поссать. Это тебе кто, блядь подзаборная, или жена отца святого, пизду соседу не дававшая, дочь невесть как породившая, а ты при ей поссать... Это, по твоему, кто, потаскуха малолетняя или дочь отца святого, греха не знающая, хуя во рту не державшая, а ты при ней что - поссать!.. Марш на третью полку и не ссать до самого Петербурга!',
    'Купил физрук шляпу, а она ему как раз два три раз два три раз два три закончили',
    'В дверь постучали 9/10 раз.\n«Колгейт» - подумал Штирлиц.',
    'Боксер вырубил двух хулиганов на улице. Приехало телевидение, берут у него интервью:\n- Скажите, что произошло?\n- Иду я по улице, никого не трогаю...Вдруг подваливают ко мне два типа, начинают требовать деньги...\n- И что же дальше?\n- Ну я первого с правой вырубаю.\n- А второго?\n- А второго у меня день рождения!',
    'В центре Лондоне по узкой улочке навстречу друг другу едут шикарные лимузины. Дорогу уступать никто не хочет. Наконец, они, едва не столкнувшись, останавливаются. Из одной машины выскакивает ниггер, из другой чинно выходит англичанин. Ниггер начинает, бешено жестикулируя, орать: \n– Ты, бля, куда!? Куда ты лезешь? Да ты знаешь, кого я везу?! \nАнгличанин невозмутимо достает трубку, набивает ее и начинает раскуривать. \nНиггер не унимается: \n– Лох! У меня в машине сидит сам Билл Гейтс! И если ты…! \nПроходит некоторое время. Англичанин курит, ниггер орет. \nНаконец, англичанин докуривает, выбивает золу из трубки, обходит свой лимузин и открывает заднюю дверь. На заднем сиденье тихо вяжет английская Королева. \nАнгличанин: \n– А это, что, по-вашему – залупа конская?',
    'Заходит хохол в пидорский клуб, бармен наливает коктейль. Хохол пригубил.\n— Какая вкуснятина! Как называется?\n— Это "Хуй в сале"!\n— Надо же, сало вообще не чувствуется!',
    'Грузинская свадьба. Один из гостей обращается к своему соседу: \n- Послюшай, дарагой. Я был на многих свадьбах, но нигде не видел такой нэвэста. Это мужчина или женщина. \n- Я тэбя здэсь зарэжю! Это мой дочь!!! \n- Вах! Прости, дарагой! Я не знал, что ты отэц этой красавицы! \n- Все! Тэбе пиздец! Я ее мат!',
    'Группа опытных археологов во время раскопок нашла группу неопытных',
    'В японской национальной кухне появилось новое блюдо с названием\n"СССР". Это одна шестая часть суши.',
    'Мюлер зашёл в свой кабинет и увидел Штирлица роющевася в его сейфе.\n-Что вы здесь делаете?!\nСпросил Мюлер.\n-Жду трамвая.\nОтветил Штирлиц.\nМюлер в недоумении закрыл дверь и задумался: "Какой может быть трамвай в моём кабинете?". Он снова заглянул в свой кабинет, но Штирлица там уже не было.\n-Уехал.\nПодумал Мюлер.',
    'Кафе недалеко от больницы. Каждый день его посещает мужик и заказывает два стакана водки. \nОбъясняет буфетчице:\n- Мой друг в больнице, я пью за себя и за него. \nВ очередной раз приходит и заказывает один стакан. \n- Что, неужели друг умер? \n- Да нет, просто я пить бросил.',
    'Приезжает цирк в город. Там афиша- у нас в первые в жизни вы увидите шок: летающие крокодилы. \nСобрался полный купол народа, тут директор объявляет:\n—А сейчас на ваших глазах, летающиииее крокодилы!!!\nИз-за кулис вылетают крокодилы, по залу пархают, все замерли\nОдин крокодил на руке к девочки садится\n-крокодил крокодил а как у вач получается летать?\n-эх девочка если бы ты знала как нас тут хуярят',
    'В Алабаме снова перепутали поезда и продали 20 кусков угля и сожгли 450кг негров.',
    'Peшили свapщики отмeтить дeнь рождения коллеги. И, чтобы не спалиться в рабочий день, они набили робу ветошью, привязали держак к руке и оставили чучело на высоте создавать видимость рабочего процесса. Ветер дует, держак с электродом качается, чучело типа варит — ну а сварщики бухают. Выходит начальство из столовой, смотрят все нормально, все при деле. И тyт oт пopыва вeтpa чyчело сдувает с высоты 70 метров. Все начальство хватается за сердце, бегут к нему. Сварщик, видя это действо, спускается вниз, выкидывает чучело и ложится на его место. Прибегает начальство и видит — сварщик встает, отряхивается и говoрит: "Хуй я бoльше тyдa пoлезy!!!"',
    'Летят 2 кавказца на самолёте.\nСкорость 800, 850, 900.\n— Куда гонишь, брат?\n— Меня девушка бросила, брат. Больше я никому не нужен.\n— Ты мне нужен, братишка. \nСкорость 900, 600, 300, 100.\nСамолёт падает.',
    'Устроился Еврей в компанию по импорту кабеля. Директор поручил ему купить максимум много кабеля за минимум денег. Еврей взял деньги и пропал. Неделю нет, две нет, в конце третей недели когда директор уже прощался с деньгами вернулся еврей с 1000-й фур с кабелем. Директор в диком шоке подбегает к еврею и спрашивает:\nД - Ты за сколько это все купил???\nЕ - За три рубля!!!\nД - Как за три рубля???\nЕ - Я позвонил своей тете Софе в Одессе которая занимается импортом кабеля в страну.\nД - Ну???\nЕ - Тетя Софа отправила меня к дяде Изе в Нью Йорк который занимался экспортом кабеля.\nД - Ну а дальше???\nЕ - Дядя Изя познакомил меня с директором завода по производству кабеля. Я его спрашиваю: "Уважаемый а сколько Вы мне продадите кабеля на ТРИ рубля", а он улыбается и говорит мне: "столько сколько от кончика твоего носа до кончика твоего хуя"\nД - Ну и????????\nЕ - Но он же не знал, что кончик моего хуя находится в Телявиве.',
    'Жил-был один богач. И как-то этот богач возвращался домой через поля, а там мужик работает. Ну, и присели оба в тенечке, да разговор завели.\nСпрашивает богач:\n— Слушай, мужик, вот ты пашешь, пашешь, денег-то хватает тебе?\n— Хватает, — отвечает тот.\n— А куда ты их деваешь? — не унимается богач.\n— Нуу, на одну треть долг возвращаю, еще треть в долг даю, остальное в воду бросаю, — ответил мужик и ушел дальше пахать.\nПожал плечами богач, да тоже домой поехал. Но мысль о таком странном распределении заработанных денег не давала ему покоя. Задумался сильно, аж приболел. А была у того богача жена премудрая-премудрая. И жена спрашивает, мол, что с тобой, богач. Богач поведал ей тот разговор и заключил, наверное тот мужик дурак был.\nА премудрая жена рассмеялась:\n— Тот мужик просто очень мудро изъяснился, а ты его не понял. Долг отдает, значит, родителям помогает, в долг дает — сыновей растит, а в воду бросает — дочерей растит.\nЗадумался богач и решил того мужика своим советником сделать. В тот же вечер он поехал в деревню за сто верст, с трудом разыскал дом мужика, совсем из сил выбился, смотрит, а тот монетки в речку бросает...',
    'Испытывают наши новую баллистическую ракету СС-50. А у нее блок\nнаведения отказал и улетела она куда-то в тундру. Ну, послали за ней\nпоисковую группу. Идут они по тундре, а навстречу чукча. Те у него\nспрашивают:\n- Скажи, чукча, тут 5 дней назад летела большая огненная палка.\nТы ее не видел?\n- Нет, - говорит, - однако, не видел. Самолета - летела, вертолета -\nлетела, СС-50 - летела, а большая огненная палка - не летела.',
    'Летит спецназ воевать в Казахстан.\nМимо солдат проходится лейтенант и объясняет:\n-Вы когда казаха завалите не забывайте его голову отрезать и мне\nпринести. За каждую голову $10.\nТут самолет приземляется и с оружием на изготовку солдаты выскакивают\nиз него. Час их нет, два...\nЧерез три возвращаются, все веселые, а у каждого за спиной мешок отрезаных\nголов.\nЛейтенант смотрит на них квадратными глазами и говорит:\nВы че, охуели? Мы же в Бурятии на дозаправку сели!',
    'Пупа и Лупа отправились на фронт. Во время одной из спецопераций, весь отряд был уничтожен, а Лупа умер на руках у Пупы. Он остался один, и понимал, что у него нет ни единого шанса против террористов.\nЕго окружали.\nСкупая мужская слеза текла по щеке Пупы. «Неужели все вот так закончится??» - думал он.\nНет. Я так просто не сдамся.\nБоец хватает в каждую руку по гранате, и когда боевики были рядом, выдергивает чеку.\nЗа секунду до взрыва из уст Пупы вылетают его последние слова.\n– Это вам за лупу!',
    'Монашка пошла ловить рыбу и выловила здорового леща. Проходит мимо мужик и говорит:\n— Опиздинительная рыба!\nМонашка вспыхивает:\n— Как вы себе позволяете такие выражения! Я же монашка!\nМужик смутился, решил соврать:\n— Ты меня не поняла, сестрица. Это же название рыбы.\nМонашка приходит к матушке и говорит настоятельнице:\n— Смотри, матушка, я поймала опиздинительную рыбу.\nМатушка:\n— Сестра! Как ты себе позволяешь такие выражения! Мы всё же с тобой в монастыре, а не борделе!\n— Да ведь это же название рыбы, — отвечает бедная монашка. И матушка, которая в рыбе тоже не очень разбирается, ей верит. Матушка приходит к попу и говорит:\n— Смотри, батюшка, что сестра Аграфена принесла: опиздинительная рыба!\nПоп в шоке:\n— Как ты можешь, матушка! Такие выражения!\n— Что ты, батюшка, это просто название рыбы, — говорит настоятельница, и поп, который не смог бы отличить щуку от карася, конечно же, верит.\nВечером в монастырь приезжает митрополит с проверкой. Поп усаживает его на почетное место в трапезной и, радостно потирая руки, объявляет:\n— Владыко, сегодня одна из наших сестер поймала опиздинительную рыбу. Матушка весь день готовила эту опиздинительную рыбу, а теперь мы все вместе будем эту опиздинительную рыбу есть.\nМитрополит улыбается:\n— А вы, разъебаи, нехуёво тут живете!',
    'Пасутся 2 барана:\nПервый «беееее»\nВторой «6ля тоже самое хотел сказать»',
    '-Лучшая фамилия для имени Яна?\n-Сралвпредложку',
    'Моня звонит из Израиля другу в Одессу:\n- Сеня, что там у вас творится?\n- Да Украина немножко воюет с Россией...\n- Ну и что, есть потери?\n- Да, есть... Украина потеряла Крым, пару областей, несколько самолётов и вертолётов, танков, БМП, разного там оружия, прилично народу и...\n- А что потеряли русские?\n- Моня, ты не поверишь, русские на войну ещё так и не приехали...',
    'Помидор — единственная ягода, чью гетеросексуальность защищает Ом.',
    'Василий Иванович с Петькой сидят, скучают.\nВасилий Иванович:\n- Петька, сгоняй на хутор к старику-самогонщику,\nсообрази чего-нибудь!\n- Это можно.\nЧерез час Петька возвращается.\nВасилий Иванович:\n- Ну как?\n- Да нет у него ни фига.\n- Эх, молодежь, всему вас учить надо. Пойдем вместе.\nПриходят к деду.\nВасилий Иванович:\n- Здорово, отец!\n- Здорово, сынки!\n- Мы вот к тебе от имени Советской власти. Вот я гляжу,\nхата у тебя старая.\n- Ох, какая старая!\n- Петька, запиши: новую хату ему от Советской власти! И жена\nу тебя вроде старая...\n- Ой, какая старая!!\n- Петька, запиши: новую жену ему от Советской власти!\n- Сынки! Родненькие! Да сколько ж я вас ждал!\nНу, сели за стол, выпили, с собой взяли. Уже в дверях\nВасилий Иванович как бы невзначай:\n- Слышь, дед! А может у тебя и хуй старый?\n- Уж каккой старый!!!\n- Петька, запиши: хуй ему от Советской власти!',
    'Американец, француз и русский едут в поезде, пьют водку. Американец говорит:\n— А у нас в Америке — самая развитая техника в мире. Вот Пентагон. Десять ракет, десять взлетают, десять попадают точно в цель, сантиметр в сантиметр.\nФранцуз:\n— А у нас во франции — женщины! Жена, любовница, секретарша! Сделают все, как надо!\nРусский:\n— А у нас, у дяди Вани, на хую восемнадцать воробьев помещается.\nТе двое переглянулись. Едут дальше. Напились уже. Американец:\n— Ну, конечно, иногда бывают сбои. Вот Пентагон. Десять ракет, десят взлетают, восемь попадают в цель, а две другие в космос летят.\nФранцуз:\n— Француженки, тоже мне... Жена вечно по салонам шляется, любовница со своими мужиками канителится, у секретарши на сотовый не пробиться.\nРусский:\n— А у нас, у дяди Вани, на хую восемнадцать воробьев помещается.\nАмериканец и француз еще раз переглянулись. Едут дальше. Напились в говно! Америкос:\n— Наша техника — говно. Пентагон, десять ракет, восемь взлетают, две на месте взрываются, шесть попадают в цель, а две другие в другие города летят.\nФранцуз:\n— Да! Француженки, француженки, только трындят все. На самом деле — потные, толстые, вонючие! Фу!\nРусский:\n— Ну если совсем откровенным быть, то у нас, у дяди Вани, только семнадцать воробьев помещаются, а у восемнадцатого постоянно лапка с залупы соскальзывает.',
    'Был в одном островном государстве король. И он однажды решил на единственном мосту, соединяющем его остров с землей, поставить виселицу и стража. Он спрашивал у всех, кто хотел пройти в королевство, какова его цель. Если страж считал, что он врет, то вешал его на виселице, в других случаях пропускал. Но вот однажды в королевство пришел некто с ружьем. Он зашел в палаты короля и выстрелил в него. Тот, умирая, спросил его?\n- Как наш страж пропустил тебя? Как ты ответил на вопрос?\n- Так мене навiть i не запитали.',
    'Старшина обходит строй новобранцев:\n  - У тебя какое образование?\n  - Восемь классов\n  - Хорошо. У тебя?\n  - МГУ!\n  - Чего мычишь, писать умеешь хотя бы?',
    'Парень сидит на лавочке в парке и видит, как по дорожке едет в инвалидной коляске очень красивая девушка без ног.\nПарень не может сопротивляться внезапно нахлынувшим чувствам и, подойдя к коляске, начинает знакомиться с девушкой.\nОни гуляют по парку, разговаривают, и через некоторое время парень понимает, что очень хочет эту девушку. Смотрит ей в глаза и понимает, что она тоже не против, но как осуществить желаемое?\n- Не волнуйся, - говорит девушка - там за поворотом есть забор, а в заборе гвоздик, а у меня сзади на одежде пришита петелька. ты повесишь меня за петельку и у нас все получится.\nПолчаса нежной страсти, но все хорошее когда-нибудь заканчивается... парень снимает девушку с гвоздика и нежно садит ее в коляску.\nИ тут девушка начинает безудержно плакать.\n- Что случилось, - встревожился парень - я тебя чем-то обидел?\n- Нет, просто ты первый...\n- Милая, неужели я у тебя первый?\n- ...Первый, кто снял меня с гвоздика...',
    'Приходит сын к отцу и говорит:\n- Отец, я хочу женится на однокласснице Маринке.\n- Понимаешь, сынок, я в юности встречался с её матерью. В общем Маринка твоя сестра.\n- Ну тогда на соседке Насте.\n- И с её матерью я встречался. Настя моя дочь.\n- Тогда на Марте из соседнего дома.\n- И с её мамой у меня было.\nГрустный сын пошел к маме, а она спрашивает его:\n- Почему ты такой печальный?\n- Да вот жениться не могу ни на Маринке ни на Насте, ни на Марте. Отец сказал, что они мои сестры.\n- Ой, сынок, женись на ком хочешь, это не твой отец.',
    'Лепщица пельменей с 25-летним стажем, потрепав сына за щеку, машинально завернула ему ебальник вовнутрь',
    'Идёт мужик, идёт, идёт, вдруг, встречает он желтую хуйню\n— Ты кто такой нахуй?\n— Я желтое уёбище\nПошёл мужик дальше. Встретил он синюю хуйню\n— А ты ещё нахуй кто?\n— Я синее уёбище\nПошёл мужик дальше, почёсывая затылок и встречает чёрную хуйню\n—  А ты, видимо, чёрное уёбище!\n\nВот так и забанили мужика на твиче',
    'Интревью с Бондарчуком:\n-Скажите, Федор,как Вам фильм "Пираты карибского моря 4"?\n- Это замечательный фильм! Отличная режиссерская работа! Я снимаю шляпу!\n- Федор, мы знаем, что Вы снимаете! Расскажите, как Вам фильм?',
    '- Кто там?\n(тишина в ответ)\n"Немые" - догадался Штирлиц.',
    'Поручик прогуливается по захваченной деревне и вдруг за стеной одного дощатого сарая слышит какое-то странное журчание. \nРостов прислушавшись: \n-Кто там ссыт как полковая лошадь!? \nВ ответ тишина. \nРостов после некоторой паузы и громче: \n-Кто там ссыт как полковая лошадь!!? \nОпять тишина за стеной. \nРостов уже орёт: \n-Я спрашиваю: кот там ссыт как полковая лошадь!!!1!? \nПо-прежнему нет ответа. \nТам стояла полковая лошадь.',
    'Клуб зануд \n \n–Здраствуй, теперь ты у нас новенький. Возьми себе тут стул. \n \n–Ну, технически, это табуретка. \n \n–Похоже, у нас новый председатель',
    'Идут панк и анимешник по улице. Видят — в мусорном баке бабка застряла. Ну панк спустил штаны, пристроился и начал еë ебать. Кончил, хер об спину бабки вытер и поворачивается к анимешнику:\n— Теперь твоя очередь! \nАнимешник залазит в мусорный бак и снимает штаны.',
    'Заходит в бар прокажённый. Весь в язвах, гное, всё сочится.\n\nСадится за стойку и вежливо просит бармена:\n\n- Мне пиво, пожалуйста. Но если вас мой вид смущает, или вам неприятно...\n\nБармен его перебивает:\n\n- Да расслабься, чувак, бывает.\n\nНо через три минуты бармен глянул в его сторону и чуть не сблевал.\n\nПрокажённый говорит:\n\n- Давайте я уйду, я же вижу - вам неприятно.\n\nБармен:\n\n- Не-не, чувак, сиди! Дело не в тебе!\n\nЕщё через минуту бармена опять чудом не выворачивает наизнанку.\n\nПрокажённый снова:\n\n- Я же говорю, что мне лучше уйти...\n\nБармен:\n\n- Сиди, чувак! Я же ясно сказал - дело не в тебе! Дело в твоём соседе. Он чипсы в твою руку макает',
    'Стоят на Ричмондском мосту в Лондоне два человека и усиленно спорят...\n— Билл, если ты такой великий оратор, как говоришь, то сможешь убедить любого человека прыгнуть вниз, к примеру того...\n— Да, Джон, смогу... смотри, — подходит к человеку:\n— Я вижу вы англичанин...\n— Да...\n— У меня для вас плохая новость, на Англию напали ирландцы, захватили в плен королевскую семью и диктуют свои условия.\n— О ужас! Мне незачем жить! — закричал он и прыгнул с моста.\n— Билл, это могло быть простой случайностью! Заставь прыгнуть еще одного.\nТот подошел еще к одному:\n— Я вижу, вы француз?..\n— Да...\n— У меня для вас плохая новость — ваша жена уехала с вашим другом на вашей машине и забрала вашу кредитную карточку!\nТот со словами «Мне не на что жить» прыгает с моста.\nДжон:\n— Ну если ты заставишь спрыгнуть еще одного, я точно поверю.\nБилл подошел еще к одному.\n— Я вижу, вы хохол?\n— Да.\n—Кто не прыгнул- тот москаль',
    'Очень грустный человек заходит в бар и заказывает виски. \nБармен спрашивает у него, мол, что произошло? \nГрустный человек отвечает: \n— Моя жена изменяет мне с другим и я ничего не смог с этим сделать. Поэтому я собираюсь напиться в этом баре до смерти. \nБармен говорит: \n— Сэр, извините, но я не буду помогать вам совершать самоубийство никаким образом, и, следовательно, виски вам не продам. \nЧеловек спрашивает: \n— А что бы вы сделали, если бы ваша жена вам бы изменила с другим человеком? \nБармен говорит: \n— Да я бы просто убил этого парня! \nГрустный человек внезапно широко улыбается и выбегает из бара. \nЧерез час он довольный возвращается в бар и садится за стойку. \nБармен спрашивает: \n— Так ты что, все-таки убил того парня? \nЧеловек отвечает: \n— Нет, я только что переспал с твоей женой. А теперь виски, пожалуйста',
    'Приходит татарин в публичный дом, и предлагает проституткам секс "по-татарски". Все подумали, что он изврат какой-то, прогнали его. А одна старая проститутка удивилась. "Все позы знаю, все виды. А тут по-татарски!". \n \nПрошли они в комнату, потом татарин довольный выходит, а за ним проститутка. \n \nПодходит она к коллегам, все спрашивают: Ну как это? \n \nСтарая проститутка говорит: да ничего необычного. Чай попили, потрахались. Только вот деньги обещал завтра занести',
    'Штирлиц почувствовал спиной, что приближается смертоносный свинец. Он успел отпрыгнуть, смертоносный свинец со свистом и хрюканьем промчался мимо.',
    '— Что вы можете сказать о героине романа?\n— Роман честный наркодилер, и героин у него что надо.',
    'Дикий запад. Сидит мужик в салуне. \n \nК нему подходит ковбой-амбал и начинает докапываться, разгорается перепалка и ковбой орёт: \n \n- Я СЕЙЧАС УБЬЮ ТЕБЯ! \n \n- Ну, всё - думает мужик - пиздец! \n- Нет - говорит внутренний голос - это ещё не пиздец, доставай револьвер, стреляй в ковбоя и в окно! \n- А чё бы и нет? \n \nМужик достаёт револьвер, стреляет и в окно. Друзья ковбоя выбегают из салуна с оружием и бегут к мужику. \n \n- Ну, всё - думает мужик - пиздец! \n- Нет - говорит внутренний голос - это ещё не пиздец, у тебя быстрый конь и много патронов! \n- И правда. \n \nМужик садится на коня и даёт дёру, отстреливаясь. Заезжает в лес. Видит - за ним увязался индейский отрядец. \n \n- Ну, всё - думает мужик - пиздец! \n- Нет - говорит внутренний голос - это ещё не пиздец, скачи во весь опор по направлению к горам. \n \nПоскакал. Индейцы сбили отравленными стрелами коня, окружили. \n \n- Ну, всё - думает мужик - пиздец! \n- Нет - говорит внутренний голос - это ещё не пиздец, ты ещё можешь убить вождя. \n \nПодходит вождь к мужику, мужик достаёт старый кольт и стреляет вождю прямо в голову. \n \n- Ну вот - говорит внутренний голос - теперь точно пиздец!',
    'Заходит впервые на зону молодой парень, на днях 19 стукнуло. Зашёл, значит, в хату, а там десять здоровенных зеков сидит. Парень сразу вспоминает слова брата: «На зоне надо быть дерзким, так сказать свои правила на хате писать». И тут этот пацан как заорёт:\n-ВСТАЛИ ВСЕ!!!\nЗеки как подорвались с коек по стойке смирно, так и стоят между собой переговаривал мол, блатной наверное...\nА один остался сидеть на койке, сидит да хрипит.\nА парень говорит:\n-ТЫ ЧЕ СИДИШЬ?\nНу зек не растерялся и говорит:\n-А я петух.\n\n-ТЕПЕРЬ Я ТУТ ПЕТУХ!!!',
    'Нашел парень себе девушку. Через время у них завязался диалог:\n— Милая, а кто у тебя был до меня?\n— Ты у меня как Юрий Гагарин.\n— В смысле первый?\n— Да, если не считать нескольких собак.',
    'У студентов из Петербурга даже досуг по расписанию.\nСначала инста – потом грамм.',
    'Лошадь сидит дома, смотрит MTV. Выступает группа, играющая хэви-метал, и гитарист играет удивительное соло. \nЛошадь говорит "это потрясающе, я тоже хочу научиться этому!" \nЛошадь ищет учителя музыки, звонит ему и спрашивает: \n"Привет, я хотела бы научиться играть на гитаре" \n"Конечно," — отвечает человек по телефону. — "Просто приходи к нам на урок, чтобы начать занятия" \n"Есть одна проблема," говорит лошадь. "Я лошадь." \n"Не волнуйтесь," говорит человек. "У нас есть новые современные технологии, чтобы учить лошадей. Вы будете играть как профессионал" \nЛошадь и учитель, используя современные технологии, несколько лет, не покладая гитару, занимаются и, наконец, лошадь начинает играть соло. \nОна хочет показать это своим друзьям, поэтому звонит другу-курице. \n"Эй, Цыпленок, приходи ко мне". \nЦыпленок приходит, смотрит, как лошадь играет на гитаре и думает, что это очень здорово. \nПотом они смотрят то самое музыкальное видео, и цыпленок говорит: \n"А ведь и на барабанах здорово стучат. Я хочу научиться также играть" \nЦыплёнок ищет учителя музыки, звонит ему и спрашивает: \n"Привет, я хотел бы научиться играть на гитаре" \n"Конечно," — отвечает человек по телефону. — "Просто приходи к нам на урок, чтобы начать занятия" \n"Есть одна проблема," говорит цыпленок. "Я курица" \n"Не волнуйтесь," говорит человек. "У нас есть новые современные технологии, чтобы учить куриц. Вы будете играть как профессионал" \nКурица и учитель, используя современные технологии, несколько лет, не вылезая из-за барабанной установки, занимаются и, наконец, цыпленок начинает лихо стучать на барабанах. \nЦыпленок начинает рубить хэви-металл с лошадью. \nВ конце концов, они думают, что чего-то не хватает. \nОни смотрят видео снова и понимают, что им нужен бас-гитарист. \nОни вызывают их друга Корову и показать ей класс. \nКорова думает, что это очень здорово, и хочет научиться играть на бас-гитаре. \nКорова ищет учителя музыки, звонит ему и спрашивает: \n"Привет, я хотела бы научиться играть на бас-гитаре" \n"Конечно," — отвечает человек по телефону. — "Просто приходите к нам на урок, чтобы начать занятия" \n"Есть одна проблема," говорит лошадь. "Я корова" \n"Не волнуйтесь," говорит человек. "У нас есть новые современные технологии, чтобы учить коров. Вы будете играть как профессионал" \nКорова и учитель, используя современные технологии, несколько лет, не покладая гитару, занимаются и, наконец, корова начинает играть на бас-гитаре. \nОни начинают играть в общественных местах и однажды их слышит продюсер. \nОн идет к животным и говорит: "Эй, вы, ребята, вы классно играете! Я хотел бы заключить с вами контракт!" \nГруппа записывает альбом, выпускает несколько синглов и становится популярной. \nОни едут в мировое турне и зарабатывают кучу денег. \nИ прямо перед финальным шоу тура, который должен состояться в Лас-Вегасе, лошади звонят и сообщают, что её мать находится в больнице. \nЛошадь едет к ней, чтобы увидеть ее до начала шоу, в то время как остальная часть группы летит в Лас-Вегас готовиться, настраивать оборудование. \nНо когда лошадь выходит из больницы, ей снова звонят. \nЧастный самолет, который перевозил группу и их продюсер упали в океан и никто не выжил. \nЛошадь опустошена. \nВсе её лучшие друзья мертвы, она потеряла работу, мама при смерти. \nНа глазах у неё слезы, и она решает упиться до смерти. \nОна заходит в бар, присаживается к стойке, подбегает бармен и говорит: \n"Мы лошадей не обслуживаем"',
    'В семье консерваторов случилось горе....\n.\n.\n.\n.\n.\n.\n.\n.\nБанка лопнула.',
    'Греки придумали математику, чтобы Европа могла вычислить их долг.',
    'Взволнованные родители слепой девочки приводят ее к частному психологу...\n\n- Понимаете, доктор... Дело в том, что наша дочь слепая от рождения... И, видимо, на этой почве у нее комплекс... Она постоянно чувствует себя обделенной, ей кажется, что мы ей недостаточно уделяем времени, мало играем... Когда садимся за стол обедать или ужинать, то она думает, что в наших тарелках больше еды, что и в этом мы ее ущемляем... Что делать? Подскажите...\n\n- А какое у нее любимое блюдо?\n\n- Пельмени оч-ч-чень любит!!!\n\n- Так придите сегодня домой да и наварите ей целое ведро!\n\nПришли домой родители, так и сделали... Дочка за ужином, уплетая пельмени:\n\n- О-о-о-о!!!... Суки!!! Сколько же тогда себе положили???',
    'Стоят два наркомана на перроне, мимо проезжает поезд и из окна вылетает прокладка, и прилепляется прямо на лицо одному из них. Сдирает он прокладку с лица, мнёт в руках и говорит:\n-Хуясе такая мягкая, а ебало в кровь разбила',
    'Дагестанские врачи клянутся мамой Гиппократа',
    'Армянин решил баллотироваться в рейхстаг. У Гиммлера: \n- Род деятельности? \n- Машинист \n- Возраст? \n- 35 лет \n- Национальность? \n- Армянин \n- Характер? \n- Нардический',
    '-Угадай в какой руке?\n-В левой.\n-Черт.\nОднорукий Джо не умел делать сюрпризы.',
    'Едет поезд <img alt="🚂" class="emoji" src="/emoji/e/f09f9a82.png"/><img alt="🚋" class="emoji" src="/emoji/e/f09f9a8b.png"/><img alt="🚃" class="emoji" src="/emoji/e/f09f9a83.png"/><img alt="🚋" class="emoji" src="/emoji/e/f09f9a8b.png"/><img alt="🚃" class="emoji" src="/emoji/e/f09f9a83.png"/><img alt="🚋" class="emoji" src="/emoji/e/f09f9a8b.png"/> в Херсон. Все пассажиры уже расположились, тишь да уют. Как неожиданно, поезд слетает с рельс и в кювет, проносится по насыпи, врезается в деревянную баню у дороги и падает в реку. Переплывает реку, и ныряет на полном ходу в кукурузное поле. Делает на нём пару петель, затем выныривает из кукурузы на сельскую дорогу, а по ней возвращается опять на рельсы и продолжает ход. В вагонах паника, всë разбросано, посуда разбита, шум и гам. Люди толпой вбегают к машинисту и кричат: "Что случилось?! " Машинист им и отвечает: \n-Еду спокойно, никого не трогаю. Как вижу, сидит мужик на путях и срёт. Оттого всë и случилось. \n-Так зачем вы так? Надо было давить эту паскуду, и дело с концом! \n-Так я его в кукурузном поле только и догнал, - ответил мудрый машинист, остановил поезд и пошёл срать на путях.',
    'Захотел мужик купить собаку. Купил газету объявлений, просматривает ее, вдруг видит объявление — "Продается говорящая собака!". Не поверил, звонит: \n— У вас продается говорящая собака? \n— Да \n— Действительно, говорящая!? \n— Ну да, приезжайте, сами посмотрите! \nИ называют ему адрес — окраина города. Промышленный район. \nНу тот приезжает по адресу, смотрит, а дом — убитая старая хрущовка. Заплесневелые стены в подъезде истыканы бычками, грязно, нассано. Лампы не горят. \nПодходит к обшарпаной двери, звонок выломан — приходится стучать. дверь открывает мужик в линялой тельняшке, в растянутых на коленях трениках и в тапках с дырявым носом. \n— Здравствуйте, у вас собака продается говорящая? \n— Ну да да, проходите, пожалуйста, я думал вы немного позже подъедете, у меня тут дела на кухне срочные, подождите пока в коридоре, я быстро все закончу и подойду. А вот и собака сидит, знакомьтесь. \nИ уходит на кухню. Мужик смотрит, сидит в проходе тощая дворняга и говорит: \n— Ну давайте, чтобы время не тратить, я вам пока немного расскажу о себе: \nВ начале восьмидесятых ученые проводили эксперименты с селекцией у собак и им удалось вывести два помета, собаки в которых умели разговаривать. Один помет обучили русскому языку, второй обучили и русскому и немецкому языкам. Я оказалась в помете, обученной русскому и немецкому. Ну потом по распределению поехала работать в посольстве в ФРГ, слушала разговоры и передавала начальству, потом перестройка, Горбачев, гласность вот это все... В общем оказалась я на стройке сторожем, а потом здесь. \nТут хозяин возвращается с кухни, спрашивает: \n— Ну что, познакомились? Покупать будете? \n— Конечно! За сколько продаете? \n— Да сколько не жалко, в принципе... \n— Но как?! Это же говорящая собака! Ей цены нет! \nХозяин отвечает: \n— Да пиздит она про посольство и вот это всё',
    'Приходят люди на концерт System Of A Down, а там армяне на гитарах играют',
    'Один человек спросил у Сократа: \n— Знаешь, что мне сказал о тебе твой друг? \n— Подожди, — остановил его Сократ, — просей сначала то, что собираешься сказать, через три сита. \n— Он сказал, что ты пидор! \n— Прежде чем что–нибудь говорить, нужно это трижды просеять. Сначала через сито правды. \n— Что ты несёшь? Так ты пидор? \n— Значит, ты не знаешь, это правда или нет. Тогда просеем через второе сито — сито доброты. Ты хочешь сказать о моем друге что–то хорошее? \n—Бля.. ты даже разговариваешь как пидор! \n— Значит, ты собираешься сказать обо мне что–то плохое, но даже не уверен в том, что это правда. Третье сито — сито пользы. Необходимо мне услышать то, что ты хочешь рассказать? \n— Хмм… нет. \n—Пидора ответ! — заключил Сократ.',
    'Внук подошел к деду перед Днем Победы и спросил:\n— Деда, а ты в какой части служил?\n— В 152-й артиллерийской дивизии, внучек!\n— А где вы воевали?\n— Сначала защищали Ленинград, потом в атаку - через Финляндию немцев погнали!\n— Дед, но ведь 152 дивизия сражалась под Москвой...\n— Ой, внучек, может я попутал цифру, старый уже\n— Дед, а как ты ранение получил?\n— Ну я на вражеский дзот лег грудью\n— А почему у тебя тогда шрам от пули на спине?\n— Ой, да я может что и попутал, старый уже\n— Дед, а сколько лет тебе было, когда ты воевал?\n— 20\n— Тебе сейчас 60, как так вышло?\n— Как вышло - как вышло, пошел нахуй, сука!',
    '- Дедушка, а чем ты в молодост занимался?\n\n- Дурак твой дед...',
    'Цыгане украли моего отца. Золотой был человек!',
    'Молодой парень приходит к старому мастеру кунг-фу: "Мастер, я много наслышан о вас. Не могли бы вы научить меня вашему искусству?" \nМастер, лениво подняв бровь, бросил в ответ: "Ты ещё зелен и недостоин обучаться моим техникам".\nНа что новичок отвечает следующее:\n-Но великий мастер! Есть в этом мире хоть что-то, что поможет мне созреть и обучаться у вас?\n-Хмм... Пожалуй, есть. Настоящий ученик даже в самом начале пути должен превзойти своего мастера. Должен быть уверен в себе. Крепок, как скала. Тебе нужно победить меня в поединке.\n-Но мастер, ведь я совсем не умею драться, как я могу вас победить?\n-Ты должен верить!\nГлубоко вдохнув, ученик согласился и встал напротив мастера.\nМастер кунг-фу дал ему пизды.',
    'Идёт международный конкурс медвежатников. Задача — за пять минут вскрыть мегазащищённый сейф с миллионом долларов внутри. Кто сможет — тот забирает деньги. \nВыходят американцы, жюри тушит свет, включает. Американцы справились с электронным замком, не вскрыли механический. \nВыходят итальянцы. Тушат свет, включают — те вскрыли механический, застряли на электронном. \nВыходят два джентльмена из Одессы. Жюри тушит свет, через пять минут свет включают… а он не включается. \nИз темноты доносится голос с характерным акцентом: «Изя! Ми только что взяли миллион долларов. ЗАЧЕМ ТЕБЕ ИХ ЛАМПОЧКИ?!»',
    'Ползёт солдат в окопе, встречает другого солдата.\n- Куда ползешь?\n- Медсестру ебать.\n- А она даст?\n- Даст.\n- А в пизду даст?\n- Даст.\nПолзут вдвоём.\nВстречают третьего солдата.\n- Вы куда ползёте?\n- Медсестру ебать.\n- А она даст?\n- Даст.\n- А в жопу даст?\n- Даст.\nПолзут втроём.\nВстречают четвёртого солдата.\n- Вы куда втроём ползёте?\n- Медсестру ебать.\n- А она даст?\n- Даст.\n- А в рот даст?\n- Нет, не даст.\n- Почему же?\n- Так ей же голову оторвало.',
    'За каждым великим мужчиной, стоит женщина, стоит и пиздит',
    'Обед в еврейской семье. Мама дала кусок торта.\n- Мама, а я хочу два!\n- Моня, таки возьми нож, разреж кусок на два и не еб* мне мозги!',
    'Мамаша приводит свою 15-летнюю дочь к врачу:\n– Доктор, мою дочь постоянно тошнит.\nВрач осмотрел девицу и говорит:\n– Ваша дочь беременна, на пятом месяце...\n– Да вы что, доктор, моя дочь-паинька, она никогда не была с мужчиной. Правда, дочка?!\n– Даже не целовалась ни разу! – говорит дочь.\n– У меня огромный опыт в этом деле, и я уверенно заявляю, что ваша дочь - беременна. \n– Да нет же, не может этого быть!\n– Да я её лично ебал!',
    'В дверь не стучали. \n"Я вообще никому не нужен" — грустно подумал Штирлиц и выстрелил себе в голову',
    'Идут по пустыне 100 негров. Встретили джина. Первый, умный, негр загадал желание, чтобы все стали белыми. Второй негр, приколист - чтобы все стали черными. Третий - опять белыми. Четвертый - черными. \nЛетит над пустыней израильский F-16. Пилот: "Че за херня там мигает? Надо ракетой ебануть".',
    'Еврей, индус и негр остановились в крохотной гостинице. Там оставался только один свободный номер с двумя кроватями. Кто-то третий должен был идти ночевать в сарай на соломе. Первым вызвался еврей: «Я воспитывался в кибуце в Израиле и легко переночую в сарае»,— сказал он и ушел. Но через 15 минут в дверь постучали — это вернулся еврей. «В сарае я обнаружил свинью, я не могу спать с нечистой свиньей под одной крышей» Тогда выступил индус: «Нет проблем, я вырос в Бомбее и я совершенно спокойно переночую в чистом сарае со свиньей». Но и он постучал в номер через 15 минут, потому что обнаружил в сарае корову, которая для индусов священна. Он не мог спать с ней под одной крышей. Наконец поднялся негр. Он заявил, что вырос в южном Лос-Анджелесе и никакие свинья и корова не помешают ему провести прекрасную ночь в сарае. Через 15 минут в дверь номера постучали. На пороге стояли свинья и корова.',
    'Едет чукча в такси. Вдруг дорогу перебегает старушка. Водитель вправо - старушка вправо. Водитель влево - старушка влево. Кое-как водитель уклонился, оборачивается назад - лежит старушка на дороге. Чукча говорит: - Белый охотник - плохой охотник. Если б чукча дверцу не открыл, ушел бы бабка.',
    'Анекдот категории "Б" похож на изысканное вино, в которое только что насрали.',
    'Админ АКБ+ приобрел в Африке большой анекдот, величиной с Бугурты как на Двачах. Но внутри анекдота был пробел. Шутняра, которому владелец анекдота показал мне чудо, восхищённо покачал головой, и сказал:\n– Этот анекдот можно расколоть на две части, из которых получатся две великолепных шутки, каждый из которых будет во много раз дороже анекдота про Армян и Нарды. Но неосторожный удар может разбить это чудо природы на горсть говнистых анекдотов, которые будут хуже бородатых анекдотов. Я не берусь так рисковать...\nТак же отзывались и другие. Но однажды ему посоветовали обратиться к старому шутняре Бэбэю из Урожайска, мастеру с золотыми руками. Тот рассмотрел анекдот и снова рассказал о рисках. Админ сказал, что эту историю он уже знает наизусть. Тогда шутняра Бэбэй согласился помочь, назвав хорошую цену за работу.\nКогда админ согласился, шутняра вызвал своего молодого подмастерье. Паренек положил анекдот на ладонь и один раз ударил по анекдоту молоточком, разбив его на кучу форсов с Деградача.\n-Бля- сказал Бэбэй, - Сорян',
    'Два строителя сели перекусить. Первый достаёт из пакета бутерброд с маслом. "Блять, с маслом" - говорит он и выбрасывает бутерброд. Достаёт следующий. Этот снова с маслом. "Да блять!" - кричит рабочий и выбрасывает бутерброд. Достаёт третий бутерброд. На этот раз бутерброд с колбасой. Строитель с удовольствием его съедает. Он достаёт четвёртый бутерброд. "Да сука, опять с маслом!" - выбрасывает и его. Тогда второй рабочий спрашивает: "Ты женат?"\n"Женат", - отвечает первый строитель.\n"Сколько лет?"\n"Десять"\n"И твоя жена за десять лет так и не поняла какие бутерброды ты любишь?"\n"Блять, отъебись от моей жены!" - заорал первый строитель - "Я сам эти ёбаные бутерброды делал!"',
    'У мужика вздулся живот. Он к врачу. А врач решил приколоться и говорит: "Э, да ты беременный". Мужик в панике: "Дайте самое сильное средство чтобы был выкидыш". Врач даёт ему слабительное. Пей, говорит, по одной таблетке в день. Ну мужик сразу горсть и выпил. Идёт на измене по улице и тут прихватило, ну всё думает, рожаю. Оглядывается и видит открытый канализационный люк, присел над ним и сделал сброс. А в люке сантехник, орет: "Ой, мамочка" и пытается вылезти весь в говне. У мужика вообще крышу снесло, толкает его ногой обратно в люк и орет: "Нет у тебя мамы. Сирота ты, сирота!!!!!"',
    'Пригласила девушка парня "винду переустановить". Но парень оказался не простым и действительно начал ставить ПО.\nТогда девушка сказала прямо: "хочу трахаться". Парень пронзительно на неё посмотрел и со словами "Ааа... Что ты сразу то не сказала?" поставил линукс',
    'Получили дед и бабка от Вовочки письмо, дед читает: "Здравствуйте, дедушка и\nбабушка! Сегодня я первый раз пошел в школу и у нас был урок правды, учительница\nговорила нам, что нужно все время говорить правду. Ну так вот, я решил сказать\nвам правду: прошлым летом когда я у вас был, я залез в погреб и съел\nбанку малинового варенья, потом насрал туда и поставил на место." Тут дед бабке\nкак ударил в лоб:\n- Я говорил тебе - говно, а ты - засахарилось, засахарилось...',
    'Строй новобранцев перед ними прапор:\n- Иванов\n- Я\n- Кем был до армии?\n- Каменьщиком\n- Отлично, Иванов! Будешь строить казармы\n- Сидоров\n- Я\n- Кем был до армии?\n- Моляром\n- Отлично, Сидоров! Будешь красить казармы\n- Петров\n- Я\n- Кем был до армми?\n- Клюкальщиком\n- Кем кем?\n- Клюкальщаком\n- Это кто такой?\n- Ну это тот кто клюкало делает?\n- А что это такое за клюкало?\n- Ну как вам объяснить? Дайте мне военную мастерскую на 3 дня в\nраспоряжение, я вам такое клюкало сделаю!!!\n- Петров, ты что ох..л??? На 3 дня? Мы в график и так не\nукладываемся!!! Ну черт с тобой уж очень на клюкало посмотреть хочется.\n\nПроходит 3 дня, все это время из мастерской валит дым слышиться скрежет,\nкороче работа кипит. Выходит Петров с листом искареженного\nпродырявленного железа.\n- Петров???!!! Это что за ху..я??? НА ГУБУ!!! НА МЕСЯЦ!!! НЕТ ДО КОНЦА\nСЛУЖБЫ БУДЕШЬ СОРТИРЫ ДРАИТЬ!!!!\nВобщем Петров на губе, а клюкало к прапору в кабинет бросили.\nПриезжает проверка, генерало все не нравится: бараки кривые, покрашенны\nхреново и т. д. Короче прапору разгон устраивает в кабинете\n- А что это у вас такое отличное клюкало тут делает\nПрапор в шоке:\n- Выбросили, товарищ генерал\n- Вы тут что совсем все еб..ись?? Кто сделал?\n- Петров, товарищ генерал\n- А где Петров?\n- На губе\n- Нет ну точно еб...сь!!!!! Петрова сюда!\nПриводят Петрова\n- Ты такое клюкало сделал?\n- Так точно, товарищ генерал\n- И сколько времени ушло?\n- 3 дня\n- Вот это да! у меня на такое месяц уходит!! Пойдем запустим??\n- Давайте товарищ генерал\nЗаплываают на лодке на середину озера.\n- Петров, а можно я?\n- Конечно, товарищ генерал!!!\nГенерал бросает клюкало в вводу, оно уходит с характерным звуком клюк,\nклюк, клюк-Ох как пошло то, как пошло!!!!!',
    'Мужик загадывает желание на новый год: чтобы всю жизнь член рос. Короче, живет – не нарадуется. Жизнь бьет ключом, от баб отбоя нет. Раз в год делает пластическую операцию (укорачивает). Прожил он свое и умер. Родственники поплакали, похоронили. Через год из могилы вылазит член. Ну неудобно как-то – срам из земли торчит – подрезали, а он через время опять… В общем родственники заебались подрезать и перезахоронили чела хуем вниз. Проходит пять лет, на Манхэттене трескается асфальт и оттуда вылазит хуй! Его срезают, а он опять растет. Мэрия в шоке, объявляет тендер на избавление от напасти. Тендер выиграли хачи, поставив на этом месте палатку с шаурмой и шашлыком…',
    '-Мюллер, какой пароль от вашего сейфа?\n-1674332220\n-А почему?',
    'Однажды дpовосек pубил деpево над pечкой и уpонил в нее топоp. Он заплакал от гоpя, но тут ему явился Господь и спpосил: \n- Что ты плачешь? \n- Как же мне не плакать, ведь я уpонил в pечку топоp и не смогу больше заpабатывать на пpопитание моей семье.Тогда Господь достал из pечки золотой топоp и спpосил: \n- Это твой топоp? \n- Hет, это не мой топоp, - ответил дpовосек. \nГосподь достал из pечки сеpебpяный топоp и спpосил: \n- Может, это твой топоp? \n- Hет, и это не мой топоp, - отвечал дpовосек. \nHаконец, Господь достал из pечки железный топоp. \n \n- Да, это мой топоp, - обpадовался дpовосек. \n- Я вижу, ты честный человек и соблюдаешь мои заповеди, - сказал Господь, -возьми же себе в нагpаду все тpи топоpа. \nСтал дpовосек жить-поживать в достатке, но тут к несчастью в pечку упала его жена. Он снова гоpько заплакал. И снова ему явился Господь и спpосил: \n- Что ты плачешь? \n- Как же мне не плакать, ведь в pечку упала моя жена. \nТогда Господь достал из pечки Дженифеp Лопез и спросил: \n- Это твоя жена? \n- нет, это не моя жена, - ответил дровосек \nТогда Господь достал из речки труп утонувшей жены и спросил:\n- Это твоя жена ?\n- Да, это моя жена- обрадовано ответил дровосек и снял с неё ведро раков',
    'Кавказская притча\n\nДиалог отца и сына:\n– Сын, у тебя есть лучший друг? \n– Есть. \n– Давай я докажу тебе, что у тебя нету лучшего друга.\n– Давай.\n– Иди в поле, зарежь барашка, кинь в мешок, и прийди к другу в 4 часа утра и скажи "я зарезал человека, пошли со мной хоронить?"\nСын все так и сделал\nНа что ему ответил друг:\n– Прости, но мне надо с девушкой погулять.\nПриходит папа и говорит:\n– Ну что, как твой друг отреагировал?\n– Не знаю, сказал что с девушкой.\n– Теперь пошли со мной:\nОтец режет барашка, кидает в мешок, идет отец к своему другу в 4 часа утра и говорит:\n– Брат, я зарезал человека, что делать?\nТот отвечает:\n–Не ты убил, мы убили!\nИ выебал барана',
    'Прыгает девочка на скакалке, рядом на лавочку подсаживается дедок. Девочка:\n— Дедуль, скажи раз…\nДед:\n— Раз…\n— Ты, дед, пидаpас!\nДед сидит офигевший. Проходит минута:\n— Дед, скажи пять!\n— Пять…\n— Пидаpас опять!!\nДед начинает злится… Еще через некоторое время:\n— Дед, скажи семь!\n— Ну семь…\n— Дед пидарас ты совсем!!!\nДед теряет терпение…\n— Да не пидарас я, меня тогда расстреляли!!!',
    'Лежит грузин на пляже, загорает. Мимо летит муха:\n-ззззззззззззззззззззззззззз, ззззззззззззззззззз.\nГрузин ее прогоняет :- Киш, киш, муха, не мешай!\nМуха не улетает:\n-ззззззззззззззззззззззззззз, зззззззззззззззззззз.\nГрузин снова:- Киш, киш, муха, не мешай!\nЗалетела муха грузину в плавки: -зззз,зззз, зззз, зззз.\nГрузин: - И тут вы не поверите товарищ майор. Муха превращается в 12 летнего мальчика.',
    'Едет мужик на машине и вдруг глохнет. Открывает капот - ничего понять не может. Вдруг из кустов высовывается лошадь и говорит мужику: \n- Ты ремень генератора посмотри! \nМужик посмотрел, и в правду ремень. Смотрит на лошадь, та ему: \n- Сними галстук и вместо ремня сделай, так доедешь до мастерской. \nМужик всё сделал, как сказала лошадь. Доезжает до сервиса, выходит весь в шоке. Мастер спрашивает: \n- Что, мужик, лошадь? \n- Ага... \n- Поди про ремень генератора что-то втирала? \n- Ага! \n- А как ты услышал, ты же глухой? \n- В смысле? \n- В начало анека гляди',
    'Мой дед говорил так- когда одна дверь закрывается, другая открывается. Хороший был дед, а вот шкафы плохо собирал.',
    'В школе учительница дает задание детям:\n- Дети, давайте пофантазируем, что получится, если скрестить двух животных разных видов.\nТянет Машенька руку:\n- Если скрестить корову и свинью, то получится сытное молоко и вкусное мясо.\nУчительница хвалит ее и вызывает Катеньку:\n- Если скрестить кролика с курицей, то получится мех и яйцо.\nТут руку тянет Вовочка:\n- Если скрестить жабу с гадюкой... Ой, нет, гадюку и ежа, то получится моча и говно. Ой, стойте, не то... Если скрестить кукушку и слона, то он будет бегать по лесу и гадить памятникам на головы. Нет-нет, во, вспомнил! Если скрестить человека, медведя и свинью, то он сел в машину... Погодите, сейчас... ученые скрестили попугая и скунса, но вместе пока не живут. А-арбуз скрестили с тараканом, теперь семечки получают за лупу. Нет, как же там... Персик с дыней это дилижанс или дифичент? Жирафа скрестили с холодильником... Бока с пико... жока и лупа... однажды Божиею поспешествующею милостию боцман... юнга, старый морской Жданов-Садюк.. я, говорит, близко к жопе беру и умер..еврей..шляпа как раз..сидит и дрочит. АААА БЛЯТЬ ТАА-ШАА...но естьодинкаламбур Ехидна большая...рукатряслась...почемфарыблять..Тиранда..анимешник...ОНИУШЛИ...дурактвойдед..threehundredbuks..грузин..сосать..есжи.айфакьюбулщит..яре-яре..\n\nУчительница вызвала скорую. Врачи диагностировали первый в мире клинический случай синдрома АКБ+',
    'Приходит мужик в зоомагазин, спрашивает продавца:\n-У тебя есть что-нибудь эдакое, необычное?\n-Ну есть кое-что - говорящая многоножка!\nМужик отнесся скептически но все же взял многоножку домой. \nДома ставит баночку с многоножкой смотрит на нее, а она молчит. Ну мужик давай проверять:\n-Я пиво пошел пить. Погнали со мной?\nВ ответ тишина. Мужик руками развел и пошел в пивнуху.\nНа следующий день возвращается думает "может вчера она стеснялась новый дом все таки". Спрашивает ещё раз:\n-Я пиво пошел пить. Погнали со мной?\nТишина. Наебали. Ну, делать нечего  мужик пошел опять в пивнуху.\nНа следующий день подходит к многоножке, думает "ну попробую последний раз и верну в зоомагазин". \n-Я пиво пошел пить. Погнали со мной?\n-Да блять я тебя в первый раз услышал, обуваюсь',
    'Просит сын у отца красивые блестящие как зеркало лакированные туфли. Упрашивал часа три. Наконец он ему разрешил.  Одел он туфли пошёл на дискотеку. Подходит к девушке в мини-юбке говорит :\n—Спорим я угадаю какого цвета у тебя трусы. \n—Ну давай. \nСмотрит парень на туфли видит отражение и говорит :\n—Красные.\n—Как ты угадал? \n—Это мой небольшой секретик. \nУходит девушка к подруге рассказывает эту историю и подруга предлагает поменяться трусами чтобы проверить наверняка. Подходит снова к этому парню и спрашивает :\n—А сейчас какого цвета? \n—Зелёного.\nДевушка в полном шоке снова приходит к подруге. Та советует ей пойти к нему без трусов, думая что это он точно не угадает. Она снимает трусы подходит к парню :\n—Давай в последний раз, угадывай. \n—Парень смотрит на отражение туфли и падает в обморок. \nДевушка подбегает к нему начинает его трясти, тот очнулся, посмотрел на туфли и сказал :\n—Блять я думал что туфли порвал.',
    'Поймал Змей Горыныч англичанина, француза и хохла. И говорит: \n— Кто расскажет мне такую историю, что все три головы скажут "Да ну нахуй" того отпущу, а если хоть одна голова скажет "Бывает", того съем! " Англичанин: \n— Один английский джентельмен купил машину, и только он выехал на ней из магазина сразу же разбил в дребезги. Две головы: — Да ну нахуй, третья: "Фигня, бывает". Съели! \nФранцуз: один французский джентльмен решил жениться, и прямо в церкви его невеста изменила ему со свидетелем. Две головы: — Да ну нахуй, третья: "Бывает". Съели! \nА хохла спросить забыли.',
    'Сидит поручик ковыряется в зубах,\nвыковыривает малиновую косточку и говорит:\n"Странно малины год не ел"\nНа что денщик ему заявляет:\n"Да вы же поручик вчера с графиней целовались."\n"Ну и что?"\n"А то что она полковнику сосала."\n"Ну и что?"\n"А он на балу рассказывал, как своего денщика в жoпу тpaxнул за то,\nчто тот банку малинового варенья сожpaл."',
    'Встретились Хой, Цой, Горшок и Морген, ну и вздумали бухнуть. Купили литруху, ну и типа говорят - мы же поэты - давайте кто сколько в стихах попросит, тому столько и нальём. \nГоршок встаёт: \n- Замученный дорогой, я выбился из сил, \nИ в доме лесника налить мне рюмку попросил! \nНалили ему рюмку. \nВстаёт Цой. \n- Группа крови - на рукаве! \nВы налейте мне рюмку! А лучше две! \nНалили ему две. \nХой встаёт: \n- Из колхозной молодёжи панковал один лишь я! \nНаливайте мне три рюмки, щас нажруся как свинья! \nНалили ему три. \nМорген встаёт: \n- ТРУ РУРУРУРУ ТУРУРУРУ ТУРУРУ ПОСОСИ У У У У У ДА Я БОГАТЫЙ УЕБОК У МЕНЯ ДЕНЕГ ТАК МНОГО МОЁ ЕБАЛО КОРОБКА У У У У У ХУЙ ОГРОМНЫЙ КАК ПЕНИС НА МНЕ ПРЫГАЕТ ЖОПА\n- Алишер, а наливать-то тебе сколько? \n- Четыре.',
    'Приходит как-то женщина к гинекологу, тот смотрит говорит:\n-ебать у вас пизда огромная, ебать у вас пизда огромная\nЖенщина спрашивает:\n-а зачем вы 2 раза сказали\nВрач отвечает:\n-это эхо',
    'Стоит армянин возле зеркала голый смотрит на себя, тут он поворачивается жопой и тут у него встал хуй, и он говорит:\n.\n.\n.\n.\n.\n.\n.\n.\n.\n-"Тихо, тихо, свои"',
    'Говорят, мужчины, которые смотрят аниме, в среднем на десять процентов умнее, чем их парни.',
    'Мужик спускается ночью в подъезде и слышит, что его кто-то шепотом подзывает:\n-Пссс, мужик, водки ёбнуть хочешь?\n-Ну да, хочу, а что?\n-Зайди короче в мою хату и достань с холодильника\n-А сам то че не зайдешь?\n-Да тих ты, так хочешь ёбнуть водки или нет?\n-Ну хочу, а че сам не зайдешь?\n-Так ты зайдешь за ней или что?\n-Ну да хуй с тобой, жди.\nЗашел такой в квартиру, видит мужик бабу ебёт, проходит мимо, берет водку и выходит:\n-Слушай, там кажись жену твою ебут...\n-Так вот прикинь, это его водка, ахахахахха',
    'В одной квартире засорился унитаз. Пришел сантехник. Долго возился, выходит сердитый и спрашивает жильцов:\n - Вы что, туда срёте, что ли?!',
    'Почему либералы в России недовольны вакциной?\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\nДетям до 13 лет вакцину не ставят',
    'Заходит улитка в бар. Смотрит на бармена, и говорит\n-Блять не тот',
    'Один мужик в заводской столовой заказывает окрошку, а ему отвечают, что закончилась, Петрович последнюю тарелку забрал. Ну он ищет взглядом Петровича, и видит, что тот уже пообедал, но окрошка нетронутая стоит. Ну он подходит и спрашивает "Петрович, ты что, окрошку не будешь?". Петрович отвечает: "Не, угощайся". Мужик обрадовался и начал лакомиться. Выхлебал полтарелки, видит - на дне дохлая мышь лежит. Ну он мгновенно все обратно в тарелку и выблевал. Петрович на это смотрит и говорит "ну да, я тоже примерно после половины тарелки заметил".',
    'Было у Сталина два танка и он катался на них по очереди.\nОчередь возмущалась, но не расходилась.',
    'Штирлиц перешел границу тихо и незаметно. Об этом он узнал из утренних газет.',
    'Едет монашка с валютной проституткой в одном купе. На путане норковая шуба, изумруды в ушах, брильянтовое колье на шее. \n— Скажите, а сколько стоит ваша шуба? — робко интересуется девственница. \n— Одну ночь любви. \n— А изумрудные сережки? \n— Две ночи любви. \n— … \n— Если вы хотите спросить о колье, то мне оно досталось после недели, проведенной на Багамах с богатым лохом. \nВернулась грустная монашка к себе в монастырь, заперлась в келье. Стук в дверь. \n— Кто это? \n— Отец Георгий, пусти… \n— Шли бы вы, батюшка нах*й со своими карамельками',
    'Родились у Сталина двойняшки, и чтобы их не перепутать, одного съел, а другого тоже.',
    '—Беня, я гарантирую вам, шо через пять лет мы будем жить лучше, чем в Европе! \n— А шо у них случится?',
    'Есенин, заигрывая с двумя девушками, выходит из кабака. Одна девушка, кокетливо спросила его:\n-Сергей Александрович, а правда, что вы можете любое событие представить в виде стихотворения?\n-Конечно.\n-А давайте проверим. Видите пьяного бомжа на дороге? Попробуйте что-то сочинить про него.\nЕсенин на секунду задумался, потом начал:\n-Лежит безжизненное тело\nНа нашем жизненном пути\nВдруг тело гордо поднимает голову и отвечает:\n-Тебе, мудак, какое дело?\nИди блядей своих еби!\n-Ой, девочки, пойдёмте, это Маяковский отдыхает',
    'В Шервудском лесу объявился новый разбойник по имени Ребе Гуд. Он забирает деньги у богатых и отдает бедным под процент.',
    'Командир демонстрирует солдатам атом.\n- Вот, товарищи бойцы, это суперпозиция. Петров.\n- Я!\n- Засними на камеру суперпозицию атома.\nПетров тужится, пыжится, не заснять.\n- Не заснять.\n- Сидоров, помоги Петрову.\nПытаются вдвоем, та же ситуация.\n- Не заснять.\n- Иванов, помогай.\nПыхтят втроем. Заснять не могут.\n- Никак не заснять, товарищ командир! Мы не понимаем!\n- А хули вы хотели? Квантовая физика!',
    '- Не могли бы вы воздержаться от цитирования зелёного слоника во время презентации?\n- Кто вы-то, блять? Я один здесь, нахуй!',
    'Дом девочки находился между ПТУ и кладбищем, поэтому чтобы ночью не было страшно, она шла через кладбище.',
    'Первый:\n— А вот бы накупить китайских часов по дешёвке, на машине времени махнуть в прошлое лет на 30, там их загнать по высоким ценам и накупить на полученные деньги долларов по 60 копеек!\nВторой:\n— Лучше изобрести такую машину, как ксерокс, только для предметов, а потом взять кусок золота, и ксерить его, ксерить!\nТретий (главный):\n— Господа министры, ещё будут предложения по оздоровлению экономики?',
    'Собрались как-то волк, заяц и лиса в Америку ехать, решили себе псевдонимы взять.\nВолк:\n-я буду вил пип \nЗаяц:\n-я буду зил пип\n\nА лиса пошла, и умерла от передоза',
    'Джентльмен звонит с работы из Лондона домой за город, трубку берет дворецкий:\n\n-Джон, как себя чувствует моя собака?\n-Прекрасно, сэр, она только что полакомилась свежей крольчатинкой.\n-Джон, как себя чувствует мой попугай?\n-Прекрасно, сэр, он только что уснул в своей позолоченной клетке.\n-Джон, как себя чувствует моя жена?\n-Прекрасно, сэр. Ваша жена только что уединилась с вами в вашей спальне.\n-Джон, сходите, пожалуйста, в мой кабинет, возьмите ружье, с которым я хожу на охоту и убейте сначала меня, а потом мою жену.\n-Слушаю сэр.\nВскоре Джон возвращается к телефону:\n\n-Сэр, вас я убил сразу, а за вашей женой пришлось долго гоняться по ореховой гостиной.\n-Джон, но у нас нет ореховой гостиной.\n-Куда вы звоните, сэр?',
    'Стоит солдат с автоматом , охраняет ангар. \nПодходит мужик и говорит: \n— Продай автомат. \nСолдат ему в ответ: \n— Да не,не могу - я тут ангар с двумя секретными самолётами охраняю. \nМужик снова: \n— Продай,не улетят твои истребители. \nСолдат упирается,не хочет никак продавать автомат. \n— Вдруг что-нибудь начнется,а я тут без автомата! \nМужик уговаривает: \n— А если начнётся - ты палку подбери какую-нибудь и бегай с ней,стреляй,типа.Никто и не заметит. \n— Ну даже не знаю...Ладно продаю. \nПродал мужик автомат. Через неделю началась война,солдат бегает покруг ангаров и кричит: \n— пуф - пуф, тррр! \nОткрывается ангар и оттуда выбегают два лейтенанта: \n— ВЖЖЖЖЖЖЖЖЖЖ..',
    'мужик идёт по Москве и видит большую очередь в какой-то домик. интересно стало, подходит и спрашивает: \n— что за очередь? \n—в комнату смеха. кто ни выходит оттуда, все смеются, видишь? \nну он и пристроился в очередь. заходит в домик, а там его два кавказца хватают, ебут в жопу и выкидывают на улицу. мужик оклемался слегка, приходит в себя, смотрит на огромную очередь и такой: \n— ААХАХАХААХАХАХАХА',
    'Ебет Эйнштейн Ньютона в сраку, а тот нарисовал на полу квадрат и посмеивается. \n- Хули смешного, сука бля? Я твою жопу ебу \n- Ты не мою жопу ебёшь) ты ебёшь ньютон на квадратный метр) ты ебешь Паскаля!\nПаскаль все это видел, отвернулся и обиделся.',
    'Пошел как-то раз дед в баню. И так распарился, что, надо же, - член встал.\nДед бегом в избу с криком:\n- Бабка! Бабка!\nВлетает в избу, а бабка на него вытаращилась, спрашивает:\n- Ты чего?\nДед орет:\n- Как чего?! Встал! Давай раздевайся скорее!\nБабка давай раздеваться, а член-то тем временем и упал. Расстроились оба, дед\nи предлагает: \n- Как следующий раз пойду в баню и увидишь, что бегу, так сразу задирай юбку и становись в позу.\nДоговорились. На следующий раз дед идет в баню, бабка у окна сидит - ждет. Вдруг\nвидит - дед летит, - задирает юбку, становится раком.\nДед влетает в избу и хрясь! Со всего маха бабке сапогом по жопе и как заорет: \n- Всё бы тебе ебаться, дура старая, а у нас там сарай горит!!!',
    'Заходит суровый огромный мужик в небольшое кафе\n\nТут к нему сразу подбегает официант с улыбкой и спрашивает:"чего желаете? "\n-У вас есть апельсины? -спрошивает мужчина. \nОфициант воскрикнул:"Конечно "\n-Ну тогда принесите мне огромную тарелку этих цитрусовых. \n\nОфициант убежал, и через несколько минут вернулся с огромной тарелкой, наполненой ярчайшими апельсинами. \nМужчина посмотрел на официанта, и жестом показал, что он может идти. \n\nЧерез несколько минут посетитель начинает чистить первый апельсин. Аккуратно почистив, мужчина с размаху кинул бедное цитрусовое о стену. Апельсин размазался и начал стекать со стены. Мужик взял второй апельсин и повторил процедуру. За вторым последовала все оставшиеся фрукты. Сидит мужчина напротив стены, измазаной апельсинами, думает. Тут к нему подбегает радостный официант с улыбкой на все лицо и спрашивает:"Вы случайно не мотоциклист? "\n\nМужик удивился и спрашивает: "Да, а как вы узнали? "\n\n-А вы на мотоцикле приехали',
    'Вернулся пожилой зек после 15-летней отсидки домой. Кореша его встречают\nи говорят типa:\n- Колян, ты за нас отсидел, нас не выдал, когда замели, все на себя взял,\nпоэтому мы тебе обязаны.. Вот купили тебе квартиру в центре 8-комнатную,\nдвухярусную.. все как надо, мебель шик, кароче сам оценишь, вот тебе\nеще машина шестисотый мерин, ну как у людей.. ну и красавица жена,\nфигура модели, а по хозяйству работящая-я-я... кароче, живи Колян себе\nв радость.\nЧерез две недели встречают Коляна, спрашивают:\n- Дескать, как там чо, есть нужда?\n- Да не, пацаны, все пучком.. хата - улет, машина тоже просто зверь, жена\nтоже телка ответственная, по хозяйству как надо разбирается во всем,\nпорножурналы мне сортир носит, когда я дрочу...\n- Погоди, погоди, а зачем журналы когда жена есть - ее ебать надо...\n- А за что ее ебать? Она же не косячит...',
    'В 2030-е годы мужик заполняет анкету и дошел до вопроса "Как спите?" Что писать? Напишешь "один" - пришьют инцельство. "С женой" - патриархат и гомофобию. "С мужчиной" - токсичную маскулинность. "С белыми" - расизм. "С черными" - культурную апроприацию. \nНаписал: "лежу пержу". \n\nДали десять лет за выбросы CO2.',
    'Доктор: просит выпить таблетки от шизофрении. \nПациент: докажите что они не отравлены. \nДоктор: выпивает. \nПациент: пропадает. \nДоктор: не понял.',
    'Одного парня заколдовала колдунья: он мог говорить только одно слово в год. И вот этот парень влюбился. Он 11 лет не говорил ни слова, потом подошёл к девушке и сказал: "Я..."\n\nСлова нельзя было накапливать.',
    'Женщина и её любовник находились в доме, пока муж был на работе. Её девятилетний сын вошел в комнату и, видя, как они занимаются любовью, спрятался в шкаф и оттуда подглядывал. Внезапно входит муж. Жена прячет любовника в шкаф, не зная, что её сын там.\nМальчик:\n––Темно здесь.\n––Да.\n— У меня есть футбольный мяч.\n— Это хорошо.\n— Вы не хотите его купить?\n–– Нет, спасибо.\n–– Мой отец снаружи.\n–– Ок, сколько?\n–– 250 долларов.\nСпустя несколько недель мальчик и мужчина снова встречаются в шкафу.\nМальчик:\n— Темно здесь.\n— Да.\n— У меня есть кроссовки.\nПомня, что случилось в прошлый раз, мужчина спрашивает:\n— Сколько?\n— 750 долларов.\n— Ок.\nСпустя несколько дней, отец говорит своему сыну:\n— Пойдем поиграем в футбол.\n— Я не могу, я продал мяч и кроссовки.\n— Сколько ты получил?\n— 1000 долларов.\n— Это ужасно! Как ты мог взять так много денег? Это намного больше, чем они стоят. Это грех, ты должен пойти в церковь и покаяться.\nОтец повел сына в церковь. Мальчик зашел в исповедальню, закрыл дверь и сказал:\n— Темно здесь.\nСвященник:\n— Бля, вот только не начинай опять с этой хуйни!',
    'В город приехал цирк. Афишы по всему городу:\n"Гачимучи-свинья!"\nВремя представления. Зал полон, люди смотрят шоу, аплодируют, но видно все ждут свинью. \n- А теперь на сцене гачимучи-свинья! - объявляет конферансье под шуш публики. \nНа сцену выходит обычный боров, за ним пьяный сторож, спрашивает:\n- Ты гачимучи свинья? \nИ пинает свинью со всех сил, а та:\n-<img alt="♂" class="emoji" src="/emoji/e/e29982.png"/>weeeee-weee<img alt="♂" class="emoji" src="/emoji/e/e29982.png"/>',
    'Покойника хоронили с музыкой и хором. Найдя последнее излишним, хор откопали.',
    'Во время празднования нового 2001-го года телерепортер спросил прохожего на улице Лондона:\n- Какие у вас планы на это тысячелетие?\n- Довольно скромные. Большую его часть я буду мертв.',
    'Бережливые узбеки назвали своего сына Кешбек',
    'Иду по лесу… дождь херачит, ветер, ночь… замерз весь… смотрю — машина стоит, подхожу, в окошко смотрю — там никого. дверцу попробовал — открыто, ну я залез и сижу… вдруг машина поехала… я в ахуе… машина едет, я сзади сижу, за рулем никого… тут рука волосатая появляется откуда-то, порулила и исчезла… у меня волосы на жопе зашевелились… тут деревня показалась, вот уже дома первые… тут машина останавливается, в салон другой мужик заглядывает и говорит: \n— а ты че тут делаешь??? \n— да вот, еду… \n— Ахуеть просто!!! я толкаю, а он блять едет.',
    'Возвращается мужичок (М) из командировки и сдает отчет о своих расходах бухгалтеру:\n1. За проживание - 5000 руб.\n2. На питание - 2000 руб.\n3. На шл.. - 3000 руб.\nБухгалтер (Б) прочитала отчет и говорит:\nБ: Как же я буду проводить пункт 3, таких же расходов нет, ты что не мог написать как-то по-людски...\nМ: А как?\nБ: Ну вместо "На шл.." напиши "на забивание гвоздей"\nКороче, переписал, все уладилось. Проходит две недели, этот мужичок опять приезжает из командировки и приносит новый отчет:\n1. За проживание - 5000 руб.\n2. На питание - 2000 руб.\n3. На забивание гвоздей - 3000 руб.\n4. На ремонт молотка - 5000 руб.',
    'Жаль не взял собой фундук. Хе-хе. Сундук для шепелявых - фундук.',
    'Идут два грузина. Несут убитого медведя. Навстречу русский:\n- Ого, что за медведь? Гризли?\n- Эээ, дорогой, абижаещь. Пачиму загризли? Машину падажгли слющай',
    'Встала Красная Армия недалеко от деревеньки. Василий Иванович с Петькой сидят, скучают: \n— Петька, сгоняй в деревеньку, сообрази самогоночки, да побольше! \n— Это можно. \nЧерез час Петька возвращается. \n— Ну как? \n— Да нету в деревне нифига самогонки. \n— Эх, молодежь, всему вас учить надо. Пойдем вместе. \nПошли. заходят в первый дом с краю. Там дед сидит, на гармошке играет. Василий Иванович: \n— Здорово, отец! \n— Здорово, сынки! \n— Мы вот к тебе от имени Советской власти. \n— И чего хотели? \n— Эх, дед, пока мимо шли, гляжу, какая хата у тебя старая. \n— Ох, какая старая, сынки! \n— Петька, запиши — новую хату ему от Советской власти! \nДед гармошку отложил, заулыбался. А Василий Иванович продолжает: \n— Дед, а корова у тебя на дворе тоже, смотрю, какая старая! \n— Ох сынки и корова у меня старая, это верно! \n— Так, Петька, запиши — корову ему новую от Советской власти! \nДед по такому поводу давай гостей за стол приглашать: \n— Сынки! Родненькие! Да сколько ж я вас ждал! Давайте выпьем, да закусим! \nСели за стол, сидят, выпивают. Василий Иванович продолжает: \n— Дед, а жена у тебя тоже вроде старая? \n— Ой, какая старая, сынки, старушка уже! \n— Петька, запиши — жену ему новую от Советской власти! \nДед повеселел. В общем выпили, закусили, даже с собой взяли. Уже в дверях Василий Иванович как бы невзначай: \n— Слышь, дед! Ты сам-то тоже не молодой? \n— А то! Вы ж видите, старик уже. \n— Так, наверное у тебя и хуй уже старый? \n— Уж какой старый! \n— Петька, запиши — хуй ему от Советской власти!',
    'Штирлиц погладил кота. Кот сдох. Штирлиц удивился и поставил утюг на стол',
    'Приехал мужик домой, заходит на кухню.. а там пельмени его ждут',
    'После совещания у Сталина Жуков выходит и из двеpей кабинета\nи бpосает: ``Свинья усатая!`` Стоящий pядом с двеpью адьютант\nэто слышал и пошел к Сталину докладывать:\n- Товаpищ Сталин, вас товаpищ Жуков только что ``свиньей усатой``\nназвал!\n- Да!?! Позвать ко мне товаpища Жукова!\nВходит Жуков. Сталин ему:\n- Товаpищ Жуков, кого вы имели ввиду, когда выходя от меня\nвы сказали ``свинья усатая``?\n- Как кого? Гитлеpа!\n- А вы кого имели ввиду, товаpищ адьютант?',
    'Обидно что Я живу в обществе, где человек ловящий молнию считается дураком, а человек пытающийся отпиздить палкой ветер смельчаком.',
    'Как то раз на рынке идет мужик смотрит и думает какое ему животное домашнее купить \nКот банально, собака тоже\nВидит обезьяну подходит к продавцу не задумываясь покупает\nОдна неделя, вторая, третья и тут ему надоедает эта обезьяна и он решает ее продать, но еще и в выгоду себе (подороже чем брал) \nНо просто так за обычную обезьяну много не выручишь денег, и решил он ее научить говорить, в итоге научил говорить только одно слово КОНЕШНО\nПришел на рынок, поставил в два раза дороже ценник \nТут покупатель подходит и спрашивает--а что такая дорогая?\nМужик отвечает--а она слова знает! Сам спроси у нее\nПокупатель наклоняется и говорит--слова знаешь?\nОбезьяна--КОНЕШНО\nВ итоге покупатель не задумываясь берет ее и покупает, приходит домой и понимает что обезьяна только одно слово знает КОНЕШНО\nПошел на рынок продовать, поставил в три раза дороже\nПодходит покупатель и говорит--а что такая дорогая? Как будто из золота!\nПродовец--а она знает где клад находится!\nПокупатель--да ну!\nПродавец--сам спроси у нее \nПокупатель спрашивает обезьяну--знаешь где клад находится\nОбезьяна--КОНЕШНО\nПокупатель не задумываясь покупает ее \nПриходит домой, расстилает карту и пальцем показывает со словами--здесь клад?\nОбезьяна--КОНЕШНО\nМужик подрывается, собирает шмотки и летит с обезьяной\nПоказывет лопатой со словами--здесь копать?\nОбезьяна--КОНЕШНО\nКопает мужик час,два,три\nМужик--глубже копать?\nОбезьяна--КОНЕШНО\nВыкопал кратер и понимает что обезьяна знает только одно слово КОНЕШНО\nМужик спрашивает обезьяну\nМужик--тут клада нет?\nОбезьяна--КОНЕШНО\nМужик-по ебалу?\nОбезьяна--НЕНАДО',
    'Журналист приезжает в глухую деревню на Кавказе, чтобы снять репортаж про жизнь вдали от цивилизации. На улице абсолютная тишина, никого вокруг нет, только один дед сидит у дерева\n- Дедушка, слушайте, вы же тут всю жизнь живёте, да?\n- Канешно, дарагой, вот уже 70 лет как тут жыву\n- А можете интересную историю из жизни рассказать?\n- Ой, дарагой, помню, лет пять назад у саседа потерялся в горах казёл. День искали, два искали, третий день нашли казёл, всей деревней его ебали!\nРепортёр понимает, что он никак не может использовать эту историю.\n- Не, другая история нужна. Может у вас есть веселая история?\n- Да без проблем, дарагой! Вот буквально год назад у саседа в горах потерялся жена. День искали, два искали, третий день нашли жена, всей деревней её ебали!\nРепортёр уже начитает терять надежду и решает в последний раз попробовать вытянуть из старика нормальную историю\n- Черт, да может какая-нибудь грустная история есть?\nСтарик стразу бледнеет, широкая улыбка сходит с его лица, а глаза становятся будто стеклянными.\n- Однажды я патерялся в горах...',
    'Гена с Чебурашкой сидят в тюремной камере.\nСидящий по соседству зэк, обращается к ним с вопросом:\n– За что вас загребли?\n– За фокусы, – отвечает Чебурашка.\n– За какие?\n– Ну хочешь, чтоб у тебя хуй до пола был?\n– Хочу!\n– Гена, откуси ему ноги',
    'Гитлер пошёл к гадалке и спросил её: "В какой день я умру?". Провидица заверила его, что он умрёт в еврейский праздник.\n— Почему вы так уверены в этом? - усомнился Гитлер.\n— Любой день, в который ты умрёшь, будет еврейским праздником. - ответила она',
    'Умирает Барак Обама и попадает в ад. Ну, там Люцифер стоит, долго ищет чëрного экс-президента в списке, затем, почесав красную лысину, протяжно сказал:\n- Тебя, похоже, не в тот ад отправили.\n- Чего? - удивился Обама. - Ад же для людей, - тыкая на табличку, продолжал он.\nЛюцифер горько вздохнул, а затем ответил:\n- Был бы ты человеком нахуй!..',
    'Поручик Ржевский спрашивает у корнета: -Корнет, вы имеете такой успех у дам. расскажите, как у вас это получается? \n- а вы подойдите к даме, скажите ей что-нибудь остренькое, затем что-нибудь скользкое, затем пошленькое и представьтесь. И она ваша. \nНа балу поручик подходит к даме и говорит: \n-Шило, мыло, хуй. Поручик Ржевский.',
    'Крутой джазовый бар проводит конкурс на лучшего исполнителя, которого возьмут на работу. Собирается толпа музыкантов и среди них старый негр.\n\nВыходит и говорит:\n\n— Эта песня называется "Я буду дрочить на тебя всю ночь!"\n\nИграет восхитительный блюз, после которого половина музыкантов сразу собираются и уходят, другие просто плачут от восторга!\n\nСтарый негр говорит:\n\n— А следующая моя песня называется "Соси у меня, сука, пока я не кончу!"\n\nИ играет блюз еще круче от которого оставшиеся музыканты единогласно отказываются от участия в конкурсе.\n\nВладелец заведения говорит\n\n— Мы вас берем, только не могли бы вы не называть своих песен, а они немного… нуу... шокируют.\n\nНегр соглашается.\n\nИдет очередной концерт, негр забыл заправиться, и у него елда торчит из штанов. Он садится за рояль, играет. Хозяин заведения замечает эту оплошность, подходит к нему, говорит:\n\n— У тебя хуй видно, знаешь?\n\nНегр:\n\n— Что? Знаю ли я её?! Да я её написал!',
    'В дверь не стучали\n- Ник Вуйчич! - догадался Штирлиц.',
    'Хорошего бухгалтера найти трудно, поэтому Вера Павловна уже двадцать лет числится в федеральном розыске.',
    'Басист бегает по дому за дитем: \n- Сука, поймаю - руки поотрываю! \nЖена испуганно: \n- Вась, че такое? \n- А он мне струну расстроил, а какую - не говорит!',
    'Встретились два человека на том свете.\n– Ты вот как умер?\n– С крыши небоскреба спрыгнул, а что?\n– Смотреть надо куда летишь, 6лять!',
    '-Саш, а что тебе нравится в девушках?\n-ну как, грудь и попа\n-а, то есть, на лицо тебе насрать?\n-не надо',
    'Едут в купе три женщины и грузин. Одна говорит: \n- Меня испортили лежа - значит, я положительная женщина. \nДругая: \n- Меня испортили стоя - значит, я стоящая женщина. \nТретья: \n- Меня испортили раком - значит, я роковая женщина. \nГрузин: \n- А вот меня испортили на мешке с изюмом, что же теперь, по-вашему, я - изюмительный мужчина?',
    '"Изя сыночек, высылаем тебе пятьсот рублей, как ты и просил. Кстати, 500 рублей пишется с двумя нулями, а не с тремя"',
    'Медведь попал в жуткую аварию и чудом выжил. «Чудес не бывает», — подумал Медведь  и залез обратно в горящую машину.',
    'Обходит мент пришедшую электричку. Смотрит — студентик заснул, а на коленях книга: — Ландау. Теория поля. Мент хлопает студента по плечу и говорит: — Вставай, агроном —приехали.',
    'Урок в военной академии. Прапор диктует:\n— Угол поднятия башни танка равен 30 градусов.\nВопрос из аудитории:\n— Извините, а 30 градусов это по Цельсию или по Фаренгейту?\nПрапор, почесав затылок:\n— Конечно же по Цельсию.\nВ аудитории дружный хохот. Прапор, покраснев говорит:\n— Ну, уж и пошутить нельзя, конечно же по Фаренгейту!',
    'Тайная вечеря в самом разгаре. Входит запоздавший Иисус и, в изумлении, застывает в дверях. В доме - страшный беспорядок, все пьяные, грязно... \nВ ужасе Иисус хватает первым подвернувшегося под руку Петра:\n- Пётр, что происходит?! \n- П-п-пьём...\n- А деньги где взяли?!\n- А-а-а... Да там Иуда что-то продал.',
    '- Тараканы в доме есть? \n- Нет, их пауки съели. \n- У Вас пауки есть? \n- Нет, их крысы съели. \n- У Вас крысы есть?! \n- Нет, их Валентин Геннадьевич Белов съел. \n- А кто это? \n- Забыл представиться.',
    '- Мыкола, а я в Москву прийихав и на Красной Площади насрав!\n- И шо? Москали не заметили? \n- Та я по-тыхому, шаровар не снымая....',
    'Почему не существует обзоров на наркотики. Отсутствуют независимые эксперты.',
    'Однажды в ресторане поручик Ржевский встретился с полковником.\nПолковник говорит:\n–Поручик, вы, я вижу, частенько в ресторан ходите – чуть ли не\nкаждый день. А у меня вот на такие дела денег не хватает.\n–А вы, – спрашивает поручик, - что с жалованием делаете, как получите?\n–Да все жене отдаю, а там – что она мне выдаст, то и мое.\n–Э-э-э, – говорит поручик, – вы с женщинами не умеете обращаться.\nПодойдите к ней, в шейку поцелуйте, за плечико возьмите, она вам и даст денежек.\nПриходит полковник домой – и все, как поручик сказал, так и сделал:\nподошёл сзади, целует в шею, а она и говорит:\n–Что, поручик, опять деньги кончились?',
    'Ковбой приехал в Израиль. Однажды в баре он говорит: \n— Всем виски за мой счет! \nИ вдруг все оттуда разбежались. \nОн бармену: \n— А что я не так сказал? Бармен: \n— Все в порядке, это они за родственниками...',
    'Идет бухой мужик, шатается.\nВдруг чувствует сильный удар в спину.\nОборачивается, а это асфальт.',
    'Иду по улице два экстрасенса. Один говорит:\n- Хочешь, я силой мысли заставлю выкинуть из того окна телевизор?\nПоспорили.\nУперся он взглядом в окно... Оттуда через 20 сек. вылетает стиральная\nмашинка.\n- ?!?\nУперся еще пристальней... Через 20 сек. вылетает швейная машинка.\n- ?!?\nУперся совсем пристально... Вылетает холодильник.\n- ???!???\nВгляделся до боли в глазах. Высовывается мужик:\n- Да нету у меня телевизора, НЕТУ!!!',
    'Два друга таджика решили жениться на русских близняшках. Пошли они значит к их отцу просить разрешение, а отец им и сказал: "Дочерей отдам замуж только крещенным христианам". \nНу базару нет, подумали таджики и решили пойти на крещение господня. Мороз, озеро, купель русская... Решается один из таджиков окунуться, раз окунается, два... Ему уже и крестик несут... \nВторой мёрзнет, да спрашивает: \n— Не холодно ли тебе, братан? \nА тот ему и говорит: \n— Иди нахуй чурка.',
    'Идут два сантахника по улице, один уже опытный, а второй стажер. Вдруг видят, посреди улицы говно из люка хлыщет во все стороны. Ну они не растерялись, подбежали, опытный сантехник нырнул в дерьмо, через время всплывает и говорит молодому:\n- Ключ на 14 дай!- стажер дал. Опытный опять нырнул. Через время опять всплывает:\n-Дай теперь ключ на 18! - Стажер опять дал.\nСпустя минуту говно перестает течь. Опытный сантехник всплывает и говорит стажеру:\n- Учись стажер! А то так всю жизнь и будешь ключи подавать!',
    '- У моей большие сиськи!\n- А у моей классная задница!\n"А у моей огромный член", - подумал Олег, но хвастаться не стал.',
    'Один мальчик пожелал что бы у него был день рождения каждый день и через два месяца состарился и умер.',
    'Один римлянин говорит другому:\n— Знал бы ты, со сколькими женщинами я спал!\n— ммм?..\n— Ну поменьше, конечно...',
    'Белка-летяга за всю свою жизнь так ни разу никуда и не слетала. Хотя и планировала',
    'Сидят у костра трое: английский морской котик, американский зеленый берет и наш десантник. Выпивают, закусывают. Изрядно набравшись, английский морской котик встает и заявляет:\n– Я могу проплыть 100 метров под водой, сразиться со взводом врага, отстрелять 50 из 50 по-македонски и вернуться живым тем же путем:\nТут встает американский зеленый берет:\n– Это все хуйня. Я могу проплыть 200 метров под водой, сразиться с ротой врага, отстрелять 100 из 100 по-македонски и вернуться живым тем же путем:\nНичего не ответил русский десантник. Он просто встал и молча пошевелил хуем угли.',
    'К мужику-патологоанатому привозят труп молодой, красивой девушки. Видит он её и думает: «может выебать разочек, всё равно один раз живём?». Так и сделал. Трахнул, помыл, зашил и отдал на захоронение. И этой же ночью она к нему приходит во сне и говорит: «Приди на кладбище, раскопай меня и выеби ещё раз, удача тебя ждёт тогда». Ну мужик думает: «Нет, то была ошибка, я же человек а не зверь, не буду я этого делать». С тех пор каждую ночь эта девушка приходила к нему во сне и просила о том же. Неделю терпит мужик, вторую, на третьей сдался. Ночью идёт на кладбище с лопатой, раскапывает, достаёт из гроба и ебёт всю ночь. Под утро возвращаешься домой, а по пути 50 рублей нашёл...',
    'Было у отца два сына. Вот решил отец купить им по одной лошади. Сели довольные и поехали в поле кататься. Вернулись и тут один из них говорит мол слушай, а как мы их будем различать? Другой подумал и говорит - давай мол я своей ухо отрежу. Твоя будет с двумя ушами, а моя с одним. Сделали и пошли спать. А сосед всё подслушал, ночью пришел и отрезал ухо первой лошади. На другой день пришли сыновья, смотрят - обе лошади без одного уха. Как же мы их будем различать - молвит первый. Окей, говорит второй, давай я своей хвост отрежу. Твоя с хвостом, моя без. И пошли спать. Сосед опять всё подслушал, ночью пришел и отрезал хвост другой лошади. На следующий день пришли сыновья, смотрят - обе лошади без хвостов. Как же мы их различать то будем - спросил первый? Другой подумал и говорит - а давай твоя будет белая лошадь, а моя черная.',
    'Сидят два студента.\nОдин спрашивает другого:\n-А на кого ты поступил?\n-На логиста, а ты?\n-да у меня аналогично.\n-нихуя себе, аналогист?',
    'Вечеp в pусском pестоpане, посетителей мало, милая пpиятная обстановка...\nСидят 2 дамы и мило беседуют, ну а pядом с ними в зюзю пьяный Почик Ржевский, обсуждают птичек.\n- Вы знаете милочка, у меня дома живет совеpшенно\nневеpоятный попугай, пpедставьте себе он умеет читать стихи и знает весь\npепеpтуаp Пушкина, а когда у нас собиpаются мои дpузья, мы все с наслаждением\nслушаем мего попугая.\n- Да, а вы знаете, уменя дома живут канаpейки, котоpые совеpшенно без ума от опеpы, они очень любят исполнять аpии из этих опеp, и вот когда у меня собиpаются мои дpузья мы с таким упоением слушаем эти аpии...\nПоручик Ржевский, пpоснувшись и подняв свое лицо из таpелки с салатом, победоносно поднимает ввеpх палец пpавой pуки пpизносит:\n-Кстати о птичках, у моего дяди на хую 40 воpобьев помещалось',
    'Заходит бизнесмен в офис с группой иностранцев и говорит секретарше:\n— Ирочка, мне пожалуйста кофе, а этим трем пидорам — кефир!\nГолос из группы:\n— Двум пидорам. Я переводчик.',
    'Приходит мужик в магазин головных уборов и говорит:\n— Мне нужна лучшая шляпа, что у вас есть.\nПродавец протягивает мужику красивую шляпу, а мужик в ответ:\n— Но она ведь будет мне велика!\n— Не волнуйтесь, это ведь лучшая шляпа - она подстроиться под размер вашей головы. \nИ действительно, мужик надел шляпу, а та стянулась идеально, так еще и фасон нужный приняла. Ну мужик довольный покупает шляпу. Приходит он домой и нарадоваться не может, вертит шляпу, и вдруг надевает ее на руку, и шляпа тут же стягивается в красивую перчатку, надел на ногу - превратилась в носок. И тут у мужика возникла грязная идейка... Вот он уже надевает ее на член...\nИ ВЫ НЕ ПОВЕРИТЕ ТОВАРИЩ СУДЬЯ, ШЛЯПА ПРЕВРАЩАЕТСЯ В ДВЕНАДЦАТИЛЕТНЕГО МАЛЬЧИКА!',
    'Срубил Добрыня голову Змею Горынычу, а у того вместо одной две выросло. Срубил Добрыня эти две головы, а вместо них четыре выросло. Интересно стало Добрыне, и долго он ещё издевался над бедной зверушкой, пока не срубил он ей за раз 65536 голов и после они перестали появляться\n— Шестнадцатибитная, — подумал богатырь .',
    'Физико-математический ВУЗ, экзамены, препод «зверь»: \n— Входит самый-самый вундеркинд, препод задает вопрос: \n— Вы путешествуете на поезде, в купе вам стало жарко, ваши действия? \nСтудент: — Я открою окно. \nПрепод: Ну и ладушки. Расчитайте ка голубчик: при скорости поезда 70 км/ч, попутном ветре 8 м/с, температуре воздуха за бортом 28 градусов и в купе 31 градус, при том что в купе сидят три пассажира и выдыхают 1м3 углекислого газа в час за сколько обновится воздух в купе? \nСтудент: — Не смогу… \nПрепод: — 2. Следующий! \n(Студент выходя сообщил всем про окно и купе.) Заходит самый раздолбай, садится, и заявляет: -Я готов! \nПрепод: — Вы путешевствуете на поезде, в купе вам стало жарко, ваши действия? \nСтудент: — Сниму куртку. \nПрепод: — Вам все равно жарко! \nСтудент: — Ну, свитер сниму. \nПрепод: — Вам все равно жарко! \nСтудент: — Ну, рубашку сниму. \nПрепод: — Вам все равно жарко! \nСтудент: — Ну, джинсы сниму. \nПрепод: — Ну ладно. На против Вас сидит качек и говорит "<img alt="♂" class="emoji" src="/emoji/e/e29982.png"/>Hey buddy, I think you`ve got the wrong door, the leather club`s two blocks down<img alt="♂" class="emoji" src="/emoji/e/e29982.png"/>"\nСтудент: <img alt="♂" class="emoji" src="/emoji/e/e29982.png"/>Fuck You<img alt="♂" class="emoji" src="/emoji/e/e29982.png"/>',
    'Поймали медведь с зайцем золотую рыбку. Она им говорит:\n- Отпустите меня и каждому по 3 желания исполню Медведь первый говорит:\n- Хочу чтобы в нашем лесу все медведи стали медведицами.\nПотом очередь зайца:\n- Хочу мотоцикл.\nМедведь снова:\n- Хочу чтобы в окрестных лесах все медведи стали медведицами.\nЗаяц такой:\n- Хочу мотоциклетный шлем.\nМедведь последнее желание говорит:\n- Хочу чтобы во всех лесах все медведи стали медведицами.\nДалее заяц садится на мотоцикл, заводит его, произносит:\n- Хочу чтобы мишка стал пидарасом.\nИ уезжает\nОт такой трагедии медведь вымолвил у золотой рыбки ещё одно желание. Попросил себе горящую машину, сел в неё и сгорел',
    'Голлaндcкая загaдка врeмен Второй мировой\n\nДля того, чтобы ответить нa вопрос, гдe же скрывается пятая свинья, нужно было правильно сложить картинку по укaзанным линиям.',
    'Один мужик пришёл к мудрецу и сказал:\n-Скажи триста\n-300\n-Отсоси у тракториста\n-Трактористом буду я, отсосешь ты у меня\n-В трактористы ты не годен, отсоси и будь свободен\n-Не достоен твой ответ, лучше сделай мне минет, ведь меня не убедить, никому не победить, всё равно сосать не буду, твою мамку не забуду, не видал пукан сочней, чем у матушки твоей, а отец твой зря трудился- пидорасом ты родился, мутных капель не жалея и месту свою лелея, думал он заделать сына, но иная тут картина, вместо сына полудочь, отсосать она не прочь, хватит ебнутых ответов, ты оформи мне минетов, и себя не нагружая, ты мой член в гортань глотая, осознай, что ты рождён, чтобы хуев быть вождём, а теперь мой хуй глотай, лалка сделай мне сасай. \n\nУ мужика отвалилась жопа',
    'Мужик приходит к врачу с проблемой: \n– Доктор, я нервный, не сдержанный, мне быстро надоедают люди,…Да хули я тебе объясняю?! Пошел ты на хуй!!',
    '-чувак, а у нас в городе есть пингвины ростом в 180?\n-нет...\n-блять, значит монашку сбил',
    '— Отец, я вступил в ЛГБТ...\n— Дело, конечно, твое, сын. Но мне кажется, что с этим Жириновским одни пидоры тусят...',
    'Случай в больнице. Один богач после аварии потерял много крови и ему срочно требовалось переливание. Но у него была очень редкая группа крови, поэтому врачи не могли найти подходящую. Молодой врач вышел в коридор больницы и сказал:\n— Одному богачу требуется переливание очень редкой группы крови, есть среди вас кто-то, кто может пожертвовать её во имя спасения жизни?\nНа лавочке сидел молодой еврей и думал:\n— А почему бы, собственно, не согласиться? Раз-таки богач, то за спасение своей жизни может дать что-то непомерно ценное, а такую выгоду упускать нельзя.\nПосле успешного переливания богач обращается к еврею:\n— Спасибо тебе, добрый человек. За то что ты спас меня я отдам тебе свой дом на берегу моря.\nПять лет еврей жил там и не знал горя, но однажды ему снова пришлось прийти в ту же больницу, где тот же самый богач снова попал в аварию и ему нужно было переливание редкой группы крови.\nЕврей подумал:\n— Таки что же, второй раз можно очень хорошо нажиться на своём организме.\nИ согласился сделать переливание. После успешной операции богач подходит к еврею и говорит:\n— Молодой человек, вот уже второй раз вы спасаете мою жизнь. За это я отдам вам недоеденную шоколадку.\nЕврей удивляется:\n— Я, конечно, крайне признателен вам, но почему в тот раз был-таки дом, а сейчас какая-то шоколадка?\n— Все просто: раньше во мне-таки не было еврейской крови — ловко парировал богач.',
    'Попадают в ад бабник , торчок и алкоголик , на входе в ад их приветствует Сатана и говорит :\n- Я верну вам жизнь если вы поведете каждый по сто лет в комнате со своими самыми сильными желаниями, если вы его не пройдете, Я заберу вашу душу \n \nБабник попадает в роскошную комнату с множеством красивых женщин жаждущих любви \n\nАлкоголик попадает в комнату с 100 летним запасом  алкоголя всех видов\n\nТорчок попадает в комнату где тонны самой качественной травки \n\nПроходит 60 лет и Сатана решает проверить испытуемых \n\nВходит в комнату к бабнику и наблюдает как за вечно молодым бабником все так же бегают женщины но постаревшие на 60 лет , бабник молит избавить его от таких мучений и Сатана забирает его душу \n\nДалее Сатана открывает комнату с алкоголиком и видит что алкоголик выпил весь запас алкоголя в первый месяц испытания и страдает от вечного похмелья . Испытание провалено ,Сатана забирает душу алкоголика .\n\nОстаётся последняя комната с торчком . Сатана открыв двери сильно удивился - ни один грамм травы не был тронут . На входе  стоит торчок и говорит Сатане :\n\n- Ты бы хоть зажигалку оставил дол6аёб ....',
    'Попадают 2 мужика на неизведанный остров,вдруг выходит племя,вождь спрашивает у первого-чунга или смерть?\n-чунга,не хочу умирать.\nОни всем племенем ебут его.\nУ второго спрашивает,Чунга или смерть?\n-смерть,умру натуралом.\nОни его ебут до смерти.',
    'Решили как-то раз поспорить летчик и таксист, кто лучше управляет\nсвоим транспортным средством. Слово - дело. Сели они в самолет.\nПилот начинает всякие виражи закручивать, фигуры высшего пилотажа\nпоказывать, мертвые петли делать. Таксист весь со страха съежился\nна сиденье, потом покрылся, не знает куда уже в какой угол ему\nзабиться-то. Тут перед самой посадкой самолет влетает в облако.\nНичего не видно, сплошная белая пелена. Тут пилот и говорит:\n- Видимость - ноль. Иду по приборам!\nНу в общем они благополучно приземлились. Таксист с мокрыми штанами\nвыползает из самолета и говорит пилоту, что, давай мол теперь я покажу\nкласс вождения на машине.\nЕдут по каким-то колдобинам, на красный свет, проскочили под кузовом\nгрузовой машины и тут вдруг у машины открывается капот. Пилот в шоке. Таксист:\n– Видимость - ноль. Иду по приборам!\nИспуганый пилот орет:\n– По каким, нахуй, приборам?!\n– Через сорокшесть копеек поворот!',
    'Мужики взбунтовались, взяли вилы, топоры, дубье и поперли к усадьбе.\nШумят, матерятся, гул стоит. Подходят к усадьбе. Выходит староста, пытается уговорить мужиков разойтись, потом управляющий - не слушают, матерятся, требуют, чтоб Сам вышел. Выходит помещик, после завтрака, халат расстегнут, левой рукой чешет брюхо, правой зубочистку держит, во рту ковыряется. Мужики притихли. Барин зевает, поворачивается к толпе и негромким голосом спрашивает:\n– Ну чего вам, мужики?\nМужики стоят молча. Барин смотрит на них, ждет ответа минуты три, потом лениво уходит. Мужики стоят, молчат, потом, спустя полчаса понемногу расходятся. Дня через три один из зачинщиков обедает дома, ест щи. Вдруг посреди обеда останавливается, задумывается, потом бах ложкой об стол и орет:\n– ЧАВО, ЧАВО, А НИЧАВО!',
    '— Василий Иванович, белые идут!\n— А как же красные?\n— А красные вас полнят',
    'Парень с девушкой занимаются сексом в позе 69. \nПарень спрашивает: \n–Милая ты знаешь, какая высота у Эйфелевой Башни? \n– Нет дорогой. \n–355 метров. А сколько болтиков и гаечек затрачено? \n– Нет дорогой. \n– 17 миллиардов. \n–Дорогой, ты у меня такой умный, - сказала девушка, оторвавшись от своего занятия. \n–Да нет, просто у тебя из жопы кусок газеты торчит. \n–Правда? \n–Нет, Ведомости',
    'Москва. В класс приходит новая учительница и представляется.\n— Здравствуйте. Меня зовут Мария Ивановна. Я болею за Спартак. Теперь каждый из вас, дети, пусть также представится.\n— Меня зовут Коля, я болею за Спартак.\n— Меня зовут Маша, я болею за Спартак.\nТак дело доходит до последнего мальчика.\n— Меня зовут Леша, я болею за Динамо Киев.\nУчительница возмущается.\n— Как ты можешь?! Почему это ты болеешь за Динамо!?!?\n— Моя мама болеет за Динамо, мой папа болеет за Динамо, мои друзья болеют за Динамо и я болею за Динамо.\n— И что? А если бы твоя мама была шлюхой, папа наркоманом, а друзья вообще пидорасами, чтобы ты тогда делал?!\n— Тогда бы я болел за Спартак.',
    'Сын подходит к отцу-казаку:\n— Папка, дай из пулемета пострелять!\n— Постреляй, сыночек...\nОчередь, в разные стороны летят пух и перья, ни одной курицы в живых не остается.\nКазак спрашивает:\n— А гранату хочешь кинуть, сыночек?\n— Хочу, батя!\n— Кидай воон туда, в сортир...\nСтрашный взрыв, в воздух летят обломки досок.\n— Вот молодец, сынок! А то бы мамка нам дала за курей.',
    'В парке на лавочке сидит интеллигентная девушка. \n \nК ней подсаживается очень пьяный парень и говорит: \n \n- Инна... \n \n- Вы ошиблись, я не Инна. \n \n- Инна... \n \n- Я же вам сказала - я не Инна. \n \n- Иннахуй отсюда.',
    'В Санкт-Петербурге бордели называют поеблики.',
    'Лежат голодные студенты в общежитии и мечтают:\n— Эх, сейчас мяса бы...\n— А может свинью заведем?\n— Да ты что: грязь, вонь\n— Да ничего, может быть привыкнет',
    'Умерла проститутка. Похороны. Двое мужчин разговаривают: \n \n- Наконец они вместе .. \n \n- Кто? \n \n- Ноги.',
    'Едут хохол с негром в поезде. Негру захотелось поесть и он достал бананы и начал есть их. Хохол никогда не видел бананов и спросил негра\n– Що це?\n– Бананы\n– Дай попробовать\nНегр и хохол поели бананов и едут дальше. Вдруг хохлу опять захотелось есть. Он достал сало и начал его есть. Негр, который никогда не видел сало спросил хохла:\n– Что это?\n– Сало\n– Дай попробовать\n– Сало как сало, чё его пробовать то?',
    'Рубрика "Не баян, а классика!"\n- Микола, бачь, шо це за машина?\n- Цементовоз!\n- Як цементовоз? Там же люди!\n- Да це менты!',
    'Чувак похоронил друга. Решил закурить, а сигареты закончились. Заходит в табачную лавку, а ему там и говорят: Кента нет.',
    '1943 год\n\nФюрер приезжает в крупнейший концлагерь, проверить, как все там работает. Проверяет все вдольи поперек. Вроде все было в порядке, но Фюрер все-же замечает, мтранные данные в документах и отправляется к заведующему. Заведывающий приветствует Фюрера и происходит диалог:\n-Зачем вы сегодня сожгли в два раза больше Евреев, чем положено?\n-Таки завтра Шабат, Мой Фюрер, работать нельзя! Поэтому я таки сегодня сжег в два раза больше, а завтра буду отдыхать!',
    'Парень каждый день перед сном писал своей любимой сообщения «я тебя люблю». В одну ночь девушке приходит опять сообщение. Она, промолвив про себя: «эх, устала каждую ночь читать одно и то же» и не открывая сообщения, легла спать. На утро звонит мать парня девушке и говорит: «приходи, он скончался». Девушка бросается к мобильному, открывает сообщение, а там написано: «представь, я ща поле чудес смотрел, там у якубовича капуста в усах застряла, и он такой как индюк ею трясёт брлрлрблрлбр аахахахахах жесть я щас умру».',
    'За дверью послышались споры.\n"Грибы"-, подумал Штирлиц\n"Не догадался"-, подумал Ленин',
    'Услышав 4 стука в дверь, Штирлиц не смог сдержать слёз. Он понял, что эта война стоила Осьминогу половины конечностей...',
    'Пудж сидит, дрочит. Подходит к нему СФ и спрашивает:\n- Дрочишь? \n- Нет, блядь, в миде стою! \n- Пойдем даблой? \n- Ну, давай.\nСтоят дабл мид. Подходит Войд Спирит, спрашивает: \n- В дабле стоите? \n- Нет, блядь, дрочим! \n- Можно с вами? \n- Ну, давай. \nДрочат втроём. Подходит Темпларка, спрашивает: \n- Дрочите? \n- А как ты узнала? \n- А вон у вас лёгкая линия проёбана.',
    'собирает мать сына в школу: \n—вот тебе нож, 445 патронов и гайки. \n—зачем? \n—как зачем?! патронами стрелять, ножом резать. \n—а гайки? \n—так вот же они!',
    'Решили как то несколько челиков создать неиросеть, сверх полезную и нужную, запросили 300 милионов долларов у Гугл, и начали работать. Первый год, второй, третий, и на четвёртый приезжает сотрудник Гугл и говорит\n\n- Ну  и че вы тут сварганили?\n- Мы замутили Мега крутую нейросеть.\n- И что же она умеет? За 4 года и 300 миллионов бачинских, вы должно сделали что то невообразимое.\n- Так и есть. Наша нейросеть умеет заканчивать анекдоты. Щас продемонстрирую.\nЧелик начал рассказывать анек\n-Шло как то 100 негров по пустыне, видят джин, 99 негров просят у джина сделать их белыми, а 1 негр загадал чтобы они все стали снова неграми. \nВдруг нейросеть заговорила\n-Но негры не растерялись и оттарабанили его в сраку. \nДовольный челик говорит\n- Вот!Работает!\nСотрудник отвечает\n- Как по мне хуйня полнейшая\nНейросеть моментально среагировала и оттарабанила сотрудника в сраку',
    'Заходит мужик в бар. Бар весь такой технически прогрессивный, а за барной стойкой робот. Мужик садится к бару, робот спрашивает:\n- Чего вы желаете выпить?\n- Мартини, пожалуйста.\n- Каков ваш уровень IQ?\n- 160.\nРобот наливает мартини:\n- Каково ваше мнение о недавней выставке?\n\nНа следующий день мужик решил поэкспериментировать.\nРобот:\n- IQ?\n- 75!\n- Че, как тебе обнова в  WoT?\n\nНа третий день та же сцена:\n- Чего вы желаете выпить?\n- Мартини, пожалуйста.\n- Каков ваш уровень IQ?\n- 5.\n- Ыы.. Хули в конец анека палишь?',
    'Жена пердит во время секса. \n- Это что, Мусоргский? - спрашивает муж.\n- Ага! - томным шепотом произносит жена.\nЧерез некоторое время все повторяется.\n- Неужели Вивальди? - удивляется муж.\n- В точку! - не отвлекаясь от процесса, говорит жена.\nДалее пердеж перерастает в жуткий треск. Подлива разлетается по всей кровати и забрызгивает лицо супруга.\nЗахлебываясь, он с трудом выдавливает из себя несколько слов:\n- Это что еще за хуйня? Не разберу! \nЖена с гордостью:\n- Авторское!',
    'Что сделал Ельцин, когда захотелось курить, а сигарет нет?\n\nСтрельнул Парламент',
    'Maльчик: нe paзличaет Литвy и Лaтвию из нeзнaния\nMyжчина: различает Литву и Латвию\nДeд: нe paзличaeт Литвy и Лaтвию из пpинципa.',
    'Спорит ботан с качком о пользе спорта в жизни.\nКачок: — Вот представь: висишь ты над пропастью. Подтянешься?\nБотан: — Да.\nКачок: — Сколько раз?',
    'Поручик Ржевский после секса с проституткой, собрался потихоньку, подходит к выходу. Проститутка\n- А деньги??\nПоручик \n- Гусары денег не берут',
    'Стандартная ситуация. Муж с любовницей, жена звонит в дверь. Муж в панике.\n— Господи! Как бы я хотел, чтобы всего этого не было!\n—Я слышу тебя сын мой! Я сделаю так, как ты желаешь, но за это ты умрешь через пять лет.\n— Конечно делай! Лучше через пять лет, чем сейчас.\nЯркая вспышка. Любовницы как не бывало. Разборок с женой не было. Живут, значит, они пять лет любви счастье. Вдруг, мужу по почте приходит письмо, что он выиграла круиз по средиземному морю. И вот настал день отплытия. Но когда теплоход выплывает на середину\nморя, он видит на горизонте плывущую торпеду. Муж естественно вспоминает события пятилетней давности и обращается к Богу:\n—Господи! И ради меня одного ты губишь столько невинных людей?\n— Слушай, и правда! Увернуться не успеем, но иди успокой команду чтобы не было паники!\nМуж выходит на палубу, дает команду свистать всех наверх и говорит:\n- Товарищи, спорим, что я хуем о палубу ударю, и корабль развалится!\n- Да ты пиздишь, такого быть не может!\nЗаспорили они, мужик расстегивает ширинку, достает хуй, расчитал время, и ударил по стене. Взрыв. Корабль разлетается, все мертвы, только чудом выживший боцман плывет по волнам.\n - Ну ты и мудак, мужик, торпеда-то мимо прошла! - раздался голос Господа',
    'Нашли как-то немец, француз и русский бутылку водки. Стали спорить: кто сколько выпьет. Решили: чем громче пернешь, тем больше достанется. Немец пёрнул - два дерева закачались. Француз пёрнул - белка замертво упала. А русский достал нож и прирезал обоих. А потом всё сам выпил. \nА что вы хотели, русская смекалочка. Вперёд, Россия!',
    'У мужика на машине, возле психушки отвалилось колесо. Вытащил запаску и бегает вокруг машины, не может найти болты. За этим его действием пристально наблюдают пациенты психбольницы, сидящие на заборе… Мужик, не найдя болтов, в отчаянии сидит возле машины. Сидящие на заборе ему говорят: А колёса могут ехать на трёх болтах? Мужик отвечает: Да, конечно могут. Тогда наблюдавшие ему говорят: Так ты с каждого колеса по болту скрути, прикрути колесо и ехай… Спасибо — обрадовался мужик. Как вы додумались-то??? — Ну так мы же психи, а не долбоёбы',
    'Сидят в одной комнате убийца, пироман, садист, зоофил, некрофил и хохол.\nУбийца: "Давайте убьём свинью."\nПироман: "Давайте подожжём и убьём свинью."\nСадист: "Давайте замучаем, подожжём и убьём свинью."\nЗоофил: "Давайте трахнем, замучаем, подожжём и убьём свинью."\nНекрофил: "Давайте трахнем, замучаем, подожжём и убьём свинью, а потом ещё раз трахнем."\nХохол: "Хрю-хрю-хрю!"',
    'Один чувак слишком много грешил и решил его Бог наказать: тот уколол себе палец и у него началась гангрена. Сначала ему отрезали одну руку, потом вторую, потом одну ногу, потом вторую... Но на этом его несчастья не закончились - по осени его забрали в армию.',
    'Поймали менты трёх дальнобойщиков за распитием алкоголя в общественном месте. \nНу и говорят: \n-Кто себе в жопу свой алкоголь залить не сможет - того вяжем. \nПервый заливал банку Жигулёвского и остановился на половине, его повязали. \nВторой заливал бутылку вина, вот почти залил, но заржал, бутылку из рук выронил и разбил. Пока его вяжут спрашивают: \n- А ты чего заржал? \n- Да там Михалыч с канистрой самогона сидит',
    'На совещании Штирлиц толкнул речь. Речь упала.',
    'По домофону очень легко угрожать. Просто звонишь в любую квартиру:\n— Откройте дверь.\n— Не открою.\n— Я знаю, где ты живёшь.',
    '-Чем отличается еврей от Санты Клауса?\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\n.\nНаправлением в дымоходе.',
    '- Чтобы уснуть быстрее, считаю в уме женщин, с которыми спал.\n- Почему не баранов?\n- Да там было-то один раз...',
    'Один старый еврей прославился на всю округу тем, что умел заваривать самый вкусный и ароматный чай. И вот, уже перед смертью, собрал он своих друзей и родственников. Тогда один из них сказал:\n— Дядя Шлёма, вы всегда готовили такой бесподобный чай. Но вы никогда ни с кем не делились его рецептом. Раскройте нам этот секрет хотя бы теперь.\nТогда старик, не поднимая головы с подушки, жестом попросил всех, кто стоял у его кровати склониться к нему, прямо к его губам. И когда они приблизились, дядя Шлёма прошептал:\n— Евреи, не жалейте заварки!',
    'Нашел мужик на улице пустую бутылку, потер ее, а от туда джин вылетает.\n- повезло тебе, дружище, загадывай любое желание.\nмужик думл думал и наконец решился:\n- Хочу, чтобы мне всегда в жизни везло!\n_ Без проблем!\nи пропал....\nидет мужик дальше, только два шага сделал, глядь- на дороге 100$ лежит.\nСмотрит на против буклерская контора, заходит, ставит на лошадь 100 к 1.\nта приходит первой.\nВидит казино, заходит, ставит всю сумму на черное. ВЫИГРАЛ. ставит весь\nвыигрыш на красное. СНОВА ВЫИГРЫВАЕТ. и так до поздней ночи, разорил все\nказино.\nДумает: гулять так гулять! В бордель хочу!\nПриходит в публичный дом, ему хозяйка и говорит:"вы у нас тысячный\nпосетитель, все женщины и напитки бесплатно!\n- хочу индуску.\n- без проблем.\nсделал он дело, лежит с ней в постели, курит, с дамой разговаривает:\n- слушай, а что это у тебя за пятно на лбу? не нравиться оно мне, давай\nя его сотру.\n- да, пожалуйста.\nтрет мужик, трет это пятно и вдруг начинает дико хохатать.\n- ты чего?\n- не поверишь-только что машину выиграл...',
    'Гитлер очень любил сливы и никогда их не ел. Он все время ходил возле витрин и смотрел на них, облизываясь. Мама это знала и в один день купила пакет слив. Гитлер все ходил возле них, никак не решаясь взять одну, но, наконец, решился и взял одну сливу. Мама это видела и сказала папе. За ужином папа спросил:\n— Кто съел сливу?\nВсе говорили, что не ели, а Гитлер, покраснев, сказал:\n— Я не ел сливы.\nНа что папа ответил:\n— Плохо не то, что кто-то съел одну сливу. Плохо то, что с нами за одним столом сидит ГИТЛЕР!',
    'Свитер, который колется, начал по ночам выносить из дома ценные вещи.',
    'Застрял русский в лифте, нажимает на звонок, ему голос:\n- Якщо Ви розмовляєте українською, натисніть один! Если Вы разговариваете на русском языке нажмите два!\nНу тот с уверенностью нажимает два, ему голос:\n- Шо, москаляка, застряв?!',
    'Едет мужик с портфелем в трамвае. Вдруг в портфеле что-то как\nзашуршит. Женщина рядом спрашивает: "Ой, кто это у вас в портфеле\nшуршит?". Мужик отвечает: "Шуршунчик". Женщина обиделась: "Не хотите\nговорить - не говорите, а насмехаться надо мной не надо". Ну что вы,\nпосмотрите сами. Мужик открыл портфель, женщина смотрит - а там и\nвправду шуршунчик.',
    'Солдат решил приколоть туповатого прапора, перевернул кружку. Товарищ прапорщик, кружка без дна.\nОго, еще и верх запаян - удивился прапорщик',
    'Миссионер бежит по пустыне от льва. Молится:\n\n- Господи! Дай этому льву сердце христианина! Лев догоняет его, кладёт лапу на голову, поднимает глаза к небу и говорит:\n- Господи, благослови, эту пищу.']
